searchData={"items":[{"type":"task","doc":"Runs visualization performance benchmarks.","title":"mix benchmark.visualization","ref":"Mix.Tasks.Benchmark.Visualization.html"},{"type":"task","doc":"$ mix benchmark.visualization [--small|--medium|--large|--production]","title":"Usage - mix benchmark.visualization","ref":"Mix.Tasks.Benchmark.Visualization.html#module-usage"},{"type":"task","doc":"* `--small` - Run a small benchmark with fewer data points (default)\n    * `--medium` - Run a medium-sized benchmark\n    * `--large` - Run a large benchmark with more data points\n    * `--production` - Run a comprehensive benchmark for production analysis","title":"Options - mix benchmark.visualization","ref":"Mix.Tasks.Benchmark.Visualization.html#module-options"},{"type":"module","doc":"Raxol is a feature-rich terminal UI framework for Elixir.\n\nIt provides a comprehensive set of components and tools for building\nbeautiful, accessible, and responsive terminal applications.","title":"Raxol","ref":"Raxol.html"},{"type":"module","doc":"* **Modern Component Library**: A rich set of pre-built UI components like buttons,\n  text inputs, tables, modals, and more.\n\n* **Accessibility Support**: Built-in features for screen readers, high contrast\n  mode, and keyboard navigation.\n\n* **Theming System**: Customize the look and feel of your application with\n  consistent theming.\n\n* **Responsive Layouts**: Create layouts that adapt to different terminal sizes.\n\n* **The Elm Architecture**: Follows TEA (The Elm Architecture) for predictable\n  state management.\n\n* **Event Handling**: Comprehensive event system for keyboard, mouse, and terminal events.","title":"Features - Raxol","ref":"Raxol.html#module-features"},{"type":"module","doc":"To create a new Raxol application, you need to define three core functions:\n\n* `init/1`: Initializes your application state\n* `update/2`: Updates the state based on events\n* `render/1`: Renders the UI based on the current state\n\nHere's a simple counter example:\n\n    ```text\n    defmodule Counter do\n      @behaviour Raxol.Core.Runtime.Application\n\n      require Raxol.Core.Renderer.View\n      alias Raxol.Core.Runtime.Events.Event\n\n      def init(_opts) do\n        {%{count: 0}, []}\n      end\n\n      def update(%{count: count} = model, %Event{type: :command, data: :increment}) do\n        {%{model | count: count + 1}, []}\n      end\n\n      def update(%{count: count} = model, %Event{type: :command, data: :decrement}) do\n        {%{model | count: count - 1}, []}\n      end\n\n      def update(model, _event_or_msg), do: {model, []}\n\n      def view(model) do\n        Raxol.Core.Renderer.View.column [padding: 1] do\n          [\n            Raxol.Core.Renderer.View.text(\"Count: #{model.count}\"),\n            Raxol.Core.Renderer.View.row [gap: 1] do\n              [\n                Raxol.Core.Renderer.View.button \"-\", on_click: {:command, :decrement},\n                Raxol.Core.Renderer.View.button \"+\", on_click: {:command, :increment}\n              ]\n            end\n          ]\n        end\n      end\n    end\n\n    # Start the application\n    Raxol.run(Counter)\n    ```","title":"Getting Started - Raxol","ref":"Raxol.html#module-getting-started"},{"type":"module","doc":"Raxol is built on the Elm Architecture:\n\n1. **Model**: Your application state\n2. **Update**: Logic to update the state based on messages\n3. **View**: Pure functions to render UI based on the current state\n\nMessages can be generated by user interactions (like button clicks) or\nsystem events (like terminal resize).","title":"Architecture - Raxol","ref":"Raxol.html#module-architecture"},{"type":"module","doc":"Raxol provides a rich set of built-in components in the Raxol.Components\nmodule. Common components include:\n\n* Buttons\n* Text inputs\n* Tables\n* Progress indicators\n* Modals\n* Dropdown menus\n* Tab bars\n\nEach component follows consistent patterns for styling and behavior.","title":"Components - Raxol","ref":"Raxol.html#module-components"},{"type":"function","doc":"Gets the current accessibility settings.","title":"Raxol.accessibility_settings/0","ref":"Raxol.html#accessibility_settings/0"},{"type":"function","doc":"A map of current accessibility settings.","title":"Returns - Raxol.accessibility_settings/0","ref":"Raxol.html#accessibility_settings/0-returns"},{"type":"function","doc":"```elixir\nsettings = Raxol.accessibility_settings()\nif settings.high_contrast do\n  # Do something for high contrast mode\nend\n```","title":"Example - Raxol.accessibility_settings/0","ref":"Raxol.html#accessibility_settings/0-example"},{"type":"function","doc":"Gets the current default theme.","title":"Raxol.current_theme/0","ref":"Raxol.html#current_theme/0"},{"type":"function","doc":"The current theme map.","title":"Returns - Raxol.current_theme/0","ref":"Raxol.html#current_theme/0-returns"},{"type":"function","doc":"```elixir\ntheme = Raxol.current_theme()\n```","title":"Example - Raxol.current_theme/0","ref":"Raxol.html#current_theme/0-example"},{"type":"function","doc":"Runs a Raxol application.\n\nThis function starts the Raxol runtime with the provided application module\nand options. The application module must implement the `Raxol.Core.Runtime.Application` behaviour.","title":"Raxol.run/2","ref":"Raxol.html#run/2"},{"type":"function","doc":"* `app` - Module implementing the `Raxol.Core.Runtime.Application` behaviour\n* `opts` - Additional options for the runtime","title":"Parameters - Raxol.run/2","ref":"Raxol.html#run/2-parameters"},{"type":"function","doc":"* `:quit_keys` - List of keys that will quit the application (default: `[{:ctrl, ?c}]`)\n* `:fps` - Target frames per second (default: `60`)\n* `:title` - Terminal window title (default: `\"Raxol Application\"`)\n* `:font` - Terminal font (if supported)\n* `:font_size` - Terminal font size (if supported)\n* `:accessibility` - Accessibility options\n  * `:screen_reader` - Enable screen reader support (default: `true`)\n  * `:high_contrast` - Enable high contrast mode (default: `false`)\n  * `:large_text` - Enable large text mode (default: `false`)","title":"Options - Raxol.run/2","ref":"Raxol.html#run/2-options"},{"type":"function","doc":"The return value of the application when it exits.","title":"Returns - Raxol.run/2","ref":"Raxol.html#run/2-returns"},{"type":"function","doc":"```elixir\nRaxol.run(MyApp, %{initial: \"state\"}, title: \"My Application\", fps: 30)\n```","title":"Example - Raxol.run/2","ref":"Raxol.html#run/2-example"},{"type":"function","doc":"Enables or disables accessibility features.","title":"Raxol.set_accessibility/1","ref":"Raxol.html#set_accessibility/1"},{"type":"function","doc":"* `opts` - Map of accessibility features to enable/disable","title":"Parameters - Raxol.set_accessibility/1","ref":"Raxol.html#set_accessibility/1-parameters"},{"type":"function","doc":"* `:screen_reader` - Enable screen reader support\n* `:high_contrast` - Enable high contrast mode\n* `:large_text` - Enable large text mode\n* `:reduced_motion` - Reduce or eliminate animations","title":"Options - Raxol.set_accessibility/1","ref":"Raxol.html#set_accessibility/1-options"},{"type":"function","doc":"```elixir\nRaxol.set_accessibility(screen_reader: true, high_contrast: true)\n```","title":"Example - Raxol.set_accessibility/1","ref":"Raxol.html#set_accessibility/1-example"},{"type":"function","doc":"Sets the default theme for Raxol applications.\n\nThis function sets the default theme that will be used by Raxol components.","title":"Raxol.set_theme/1","ref":"Raxol.html#set_theme/1"},{"type":"function","doc":"* `theme` - A theme created with `Raxol.UI.Theming.Theme.new/1` or one of the built-in themes","title":"Parameters - Raxol.set_theme/1","ref":"Raxol.html#set_theme/1-parameters"},{"type":"function","doc":"```elixir\n# Use a built-in theme\nRaxol.set_theme(Raxol.UI.Theming.Theme.dark())\n\n# Create and use a custom theme\ncustom_theme = Raxol.UI.Theming.Theme.new(name: \"Custom\", colors: %{primary: :green})\nRaxol.set_theme(custom_theme)\n```","title":"Example - Raxol.set_theme/1","ref":"Raxol.html#set_theme/1-example"},{"type":"function","doc":"Gracefully stops a running Raxol application.\n\nThis function can be called from within your application to exit gracefully.","title":"Raxol.stop/1","ref":"Raxol.html#stop/1"},{"type":"function","doc":"* `return_value` - Value to return from the `Raxol.run/3` function","title":"Parameters - Raxol.stop/1","ref":"Raxol.html#stop/1-parameters"},{"type":"function","doc":"```elixir\ndef update(model, :exit) do\n  Raxol.stop(:normal)\n  model\nend\n```","title":"Example - Raxol.stop/1","ref":"Raxol.html#stop/1-example"},{"type":"function","doc":"Returns information about the terminal environment.\n\nThis includes terminal size, color support, and other capabilities.","title":"Raxol.terminal_info/0","ref":"Raxol.html#terminal_info/0"},{"type":"function","doc":"A map with terminal information.","title":"Returns - Raxol.terminal_info/0","ref":"Raxol.html#terminal_info/0-returns"},{"type":"function","doc":"```elixir\nRaxol.terminal_info()\n# => %{\n#      name: \"iTerm2\",\n#      version: \"3.5.0\",\n#      features: [:true_color, :unicode, :mouse, :clipboard],\n#      ...\n#    }\n```","title":"Example - Raxol.terminal_info/0","ref":"Raxol.html#terminal_info/0-example"},{"type":"function","doc":"Returns the current version of Raxol.","title":"Raxol.version/0","ref":"Raxol.html#version/0"},{"type":"function","doc":"A string representing the current version.","title":"Returns - Raxol.version/0","ref":"Raxol.html#version/0-returns"},{"type":"function","doc":"```elixir\nRaxol.version()\n# => \"1.0.0\"\n```","title":"Example - Raxol.version/0","ref":"Raxol.html#version/0-example"},{"type":"module","doc":"Content generation capabilities for Raxol applications.\n\nThis module provides AI-powered content generation for various aspects of\nterminal UIs, including:\n\n* Text suggestions\n* Command completions\n* Help content generation\n* Documentation generation\n* Interactive tutorials\n* Contextual hints\n\nThe generation is configurable and can be adapted to different contexts\nwithin the application.","title":"Raxol.AI.ContentGeneration","ref":"Raxol.AI.ContentGeneration.html"},{"type":"function","doc":"Generates content based on the specified type and prompt.","title":"Raxol.AI.ContentGeneration.generate/3","ref":"Raxol.AI.ContentGeneration.html#generate/3"},{"type":"function","doc":"* `:max_length` - Maximum length of the generated content (default: 100)\n* `:style` - Style of the generated content (default: :neutral)\n* `:tone` - Tone of the generated content (default: :neutral)\n* `:context` - Additional context for generation (default: %{})\n* `:model` - AI model to use for generation (default: :default)","title":"Options - Raxol.AI.ContentGeneration.generate/3","ref":"Raxol.AI.ContentGeneration.html#generate/3-options"},{"type":"function","doc":"iex> generate(:text, \"Create a welcome message\", max_length: 50)\n    {:ok, \"Welcome to the terminal! How can I assist you today?\"}","title":"Examples - Raxol.AI.ContentGeneration.generate/3","ref":"Raxol.AI.ContentGeneration.html#generate/3-examples"},{"type":"function","doc":"Generates a contextual help document based on application state.","title":"Raxol.AI.ContentGeneration.generate_help/2","ref":"Raxol.AI.ContentGeneration.html#generate_help/2"},{"type":"function","doc":"iex> generate_help(%{current_view: :editor, command_mode: true})\n    {:ok, %{title: \"Editor Mode Commands\", content: \"...\"}}","title":"Examples - Raxol.AI.ContentGeneration.generate_help/2","ref":"Raxol.AI.ContentGeneration.html#generate_help/2-examples"},{"type":"function","doc":"Generates an interactive tutorial for a specific feature.","title":"Raxol.AI.ContentGeneration.generate_tutorial/2","ref":"Raxol.AI.ContentGeneration.html#generate_tutorial/2"},{"type":"function","doc":"iex> generate_tutorial(:keyboard_shortcuts)\n    {:ok, %{steps: [...], interactive: true}}","title":"Examples - Raxol.AI.ContentGeneration.generate_tutorial/2","ref":"Raxol.AI.ContentGeneration.html#generate_tutorial/2-examples"},{"type":"type","doc":"","title":"Raxol.AI.ContentGeneration.generation_options/0","ref":"Raxol.AI.ContentGeneration.html#t:generation_options/0"},{"type":"type","doc":"","title":"Raxol.AI.ContentGeneration.generation_type/0","ref":"Raxol.AI.ContentGeneration.html#t:generation_type/0"},{"type":"function","doc":"Generates text suggestions based on current input context.","title":"Raxol.AI.ContentGeneration.suggest_text/2","ref":"Raxol.AI.ContentGeneration.html#suggest_text/2"},{"type":"function","doc":"iex> suggest_text(\"print(\", context: %{language: :python})\n    {:ok, [\"print(\"Hello, World!\")\", \"print(value)\", \"print(f\"Value: {value}\")\"]}","title":"Examples - Raxol.AI.ContentGeneration.suggest_text/2","ref":"Raxol.AI.ContentGeneration.html#suggest_text/2-examples"},{"type":"module","doc":"Runtime AI features for intelligent performance optimization.\n\nThis module provides AI-driven performance optimizations including:\n\n* Predictive rendering - Intelligently determine what needs to be rendered\n* Resource allocation - Dynamically allocate system resources based on usage patterns\n* Component caching - Smart caching of frequently used components\n* Prefetching - Predict and preload content likely to be needed soon\n* Adaptive throttling - Adjust refresh rates based on current activity\n* Runtime profiling - Continuously monitor and analyze performance patterns","title":"Raxol.AI.PerformanceOptimization","ref":"Raxol.AI.PerformanceOptimization.html"},{"type":"function","doc":"Analyzes performance and suggests optimizations.","title":"Raxol.AI.PerformanceOptimization.analyze_performance/0","ref":"Raxol.AI.PerformanceOptimization.html#analyze_performance/0"},{"type":"function","doc":"iex> analyze_performance()\n    [\n      %{type: :component, name: \"data_table\", issue: :slow_rendering, suggestion: \"Consider virtual scrolling\"},\n      %{type: :pattern, issue: :excessive_updates, suggestion: \"Implement throttling for search inputs\"}\n    ]","title":"Examples - Raxol.AI.PerformanceOptimization.analyze_performance/0","ref":"Raxol.AI.PerformanceOptimization.html#analyze_performance/0-examples"},{"type":"function","doc":"Recommends components for prefetching based on usage patterns.","title":"Raxol.AI.PerformanceOptimization.get_prefetch_recommendations/1","ref":"Raxol.AI.PerformanceOptimization.html#get_prefetch_recommendations/1"},{"type":"function","doc":"iex> get_prefetch_recommendations(\"user_profile\")\n    [\"user_settings\", \"user_activity\"]","title":"Examples - Raxol.AI.PerformanceOptimization.get_prefetch_recommendations/1","ref":"Raxol.AI.PerformanceOptimization.html#get_prefetch_recommendations/1-examples"},{"type":"function","doc":"Gets the recommended refresh rate for a component based on current activity.","title":"Raxol.AI.PerformanceOptimization.get_refresh_rate/1","ref":"Raxol.AI.PerformanceOptimization.html#get_refresh_rate/1"},{"type":"function","doc":"iex> get_refresh_rate(\"animated_progress\")\n    16  # milliseconds (approximately 60fps)","title":"Examples - Raxol.AI.PerformanceOptimization.get_refresh_rate/1","ref":"Raxol.AI.PerformanceOptimization.html#get_refresh_rate/1-examples"},{"type":"function","doc":"Initializes the performance optimization system.","title":"Raxol.AI.PerformanceOptimization.init/1","ref":"Raxol.AI.PerformanceOptimization.html#init/1"},{"type":"function","doc":"* `:optimization_level` - Level of optimization to apply (:minimal, :balanced, :aggressive)\n* `:features` - List of features to enable","title":"Options - Raxol.AI.PerformanceOptimization.init/1","ref":"Raxol.AI.PerformanceOptimization.html#init/1-options"},{"type":"function","doc":"iex> init(optimization_level: :balanced)\n    :ok","title":"Examples - Raxol.AI.PerformanceOptimization.init/1","ref":"Raxol.AI.PerformanceOptimization.html#init/1-examples"},{"type":"function","doc":"Records component usage for optimization analysis.","title":"Raxol.AI.PerformanceOptimization.record_component_usage/1","ref":"Raxol.AI.PerformanceOptimization.html#record_component_usage/1"},{"type":"function","doc":"iex> record_component_usage(\"dropdown_menu\")\n    :ok","title":"Examples - Raxol.AI.PerformanceOptimization.record_component_usage/1","ref":"Raxol.AI.PerformanceOptimization.html#record_component_usage/1-examples"},{"type":"function","doc":"Records component render time for optimization analysis.","title":"Raxol.AI.PerformanceOptimization.record_render_time/2","ref":"Raxol.AI.PerformanceOptimization.html#record_render_time/2"},{"type":"function","doc":"iex> record_render_time(\"user_profile\", 25)\n    :ok","title":"Examples - Raxol.AI.PerformanceOptimization.record_render_time/2","ref":"Raxol.AI.PerformanceOptimization.html#record_render_time/2-examples"},{"type":"function","doc":"Sets the optimization level for the system.","title":"Raxol.AI.PerformanceOptimization.set_optimization_level/1","ref":"Raxol.AI.PerformanceOptimization.html#set_optimization_level/1"},{"type":"function","doc":"iex> set_optimization_level(:aggressive)\n    :ok","title":"Examples - Raxol.AI.PerformanceOptimization.set_optimization_level/1","ref":"Raxol.AI.PerformanceOptimization.html#set_optimization_level/1-examples"},{"type":"function","doc":"Determines if a component should be rendered based on current conditions.\nUses predictive rendering to optimize performance.","title":"Raxol.AI.PerformanceOptimization.should_render?/2","ref":"Raxol.AI.PerformanceOptimization.html#should_render?/2"},{"type":"function","doc":"iex> should_render?(\"large_table\", %{visible: false, scroll_position: 500})\n    false","title":"Examples - Raxol.AI.PerformanceOptimization.should_render?/2","ref":"Raxol.AI.PerformanceOptimization.html#should_render?/2-examples"},{"type":"function","doc":"Enables or disables a specific optimization feature.","title":"Raxol.AI.PerformanceOptimization.toggle_feature/2","ref":"Raxol.AI.PerformanceOptimization.html#toggle_feature/2"},{"type":"function","doc":"iex> toggle_feature(:predictive_rendering, true)\n    :ok","title":"Examples - Raxol.AI.PerformanceOptimization.toggle_feature/2","ref":"Raxol.AI.PerformanceOptimization.html#toggle_feature/2-examples"},{"type":"module","doc":"The Accounts context.\nManages user accounts and registration.\n(Currently uses an in-memory Agent for storage)","title":"Raxol.Accounts","ref":"Raxol.Accounts.html"},{"type":"function","doc":"Authenticates a user by email and password.\n\nCurrently checks against plaintext passwords stored in the agent.\nIn a real app, this should use password hashing.","title":"Raxol.Accounts.authenticate_user/2","ref":"Raxol.Accounts.html#authenticate_user/2"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Accounts.child_spec/1","ref":"Raxol.Accounts.html#child_spec/1"},{"type":"function","doc":"Retrieves the full user map by user ID.\nNote: Inefficient O(N) scan of the agent state.","title":"Raxol.Accounts.get_user/1","ref":"Raxol.Accounts.html#get_user/1"},{"type":"function","doc":"Returns the list of registered users.","title":"Raxol.Accounts.list_users/0","ref":"Raxol.Accounts.html#list_users/0"},{"type":"function","doc":"Registers a new user.","title":"Raxol.Accounts.register_user/1","ref":"Raxol.Accounts.html#register_user/1"},{"type":"function","doc":"iex> register_user(%{email: \"user@example.com\", password: \"password\"})\n    {:ok, %{id: ..., email: \"user@example.com\"}}\n\n    iex> register_user(%{email: \"user@example.com\", password: \"password\"})\n    {:error, %{email: \"has already been taken\"}}","title":"Examples - Raxol.Accounts.register_user/1","ref":"Raxol.Accounts.html#register_user/1-examples"},{"type":"function","doc":"","title":"Raxol.Accounts.start_link/1","ref":"Raxol.Accounts.html#start_link/1"},{"type":"function","doc":"Updates a user's password after verifying the current password.\nUses user_id to find the user.","title":"Raxol.Accounts.update_password/3","ref":"Raxol.Accounts.html#update_password/3"},{"type":"module","doc":"Handles accessibility concerns for the Animation Framework,\nspecifically adapting animations for reduced motion preferences.","title":"Raxol.Animation.Accessibility","ref":"Raxol.Animation.Accessibility.html"},{"type":"function","doc":"Adapts an animation definition for cognitive accessibility by increasing its duration.\n\nThis makes animations slower and potentially easier to follow.","title":"Raxol.Animation.Accessibility.adapt_for_cognitive_accessibility/1","ref":"Raxol.Animation.Accessibility.html#adapt_for_cognitive_accessibility/1"},{"type":"function","doc":"Adapts an animation definition based on reduced motion settings.\n\nCurrently, it significantly shortens the duration to provide a near-instant transition.\nAlternative strategies include setting duration to 0 or changing animation type.","title":"Raxol.Animation.Accessibility.adapt_for_reduced_motion/1","ref":"Raxol.Animation.Accessibility.html#adapt_for_reduced_motion/1"},{"type":"module","doc":"Delegates animation API calls to Raxol.Animation.Framework for test and compatibility purposes.","title":"Raxol.Animation.Animation","ref":"Raxol.Animation.Animation.html"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.apply_animations_to_state/1","ref":"Raxol.Animation.Animation.html#apply_animations_to_state/1"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.create_animation/2","ref":"Raxol.Animation.Animation.html#create_animation/2"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.get_current_value/2","ref":"Raxol.Animation.Animation.html#get_current_value/2"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.init/0","ref":"Raxol.Animation.Animation.html#init/0"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.init/1","ref":"Raxol.Animation.Animation.html#init/1"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.start_animation/2","ref":"Raxol.Animation.Animation.html#start_animation/2"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.start_animation/3","ref":"Raxol.Animation.Animation.html#start_animation/3"},{"type":"function","doc":"","title":"Raxol.Animation.Animation.stop/0","ref":"Raxol.Animation.Animation.html#stop/0"},{"type":"module","doc":"Provides standard easing functions for animations.","title":"Raxol.Animation.Easing","ref":"Raxol.Animation.Easing.html"},{"type":"function","doc":"Calculates the eased value for a given progress `t` (0.0 to 1.0).","title":"Raxol.Animation.Easing.calculate_value/2","ref":"Raxol.Animation.Easing.html#calculate_value/2"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_back/1","ref":"Raxol.Animation.Easing.html#ease_in_back/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_bounce/1","ref":"Raxol.Animation.Easing.html#ease_in_bounce/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_circ/1","ref":"Raxol.Animation.Easing.html#ease_in_circ/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_cubic/1","ref":"Raxol.Animation.Easing.html#ease_in_cubic/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_expo/1","ref":"Raxol.Animation.Easing.html#ease_in_expo/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_back/1","ref":"Raxol.Animation.Easing.html#ease_in_out_back/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_bounce/1","ref":"Raxol.Animation.Easing.html#ease_in_out_bounce/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_circ/1","ref":"Raxol.Animation.Easing.html#ease_in_out_circ/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_cubic/1","ref":"Raxol.Animation.Easing.html#ease_in_out_cubic/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_expo/1","ref":"Raxol.Animation.Easing.html#ease_in_out_expo/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_quad/1","ref":"Raxol.Animation.Easing.html#ease_in_out_quad/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_quart/1","ref":"Raxol.Animation.Easing.html#ease_in_out_quart/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_quint/1","ref":"Raxol.Animation.Easing.html#ease_in_out_quint/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_out_sine/1","ref":"Raxol.Animation.Easing.html#ease_in_out_sine/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_quad/1","ref":"Raxol.Animation.Easing.html#ease_in_quad/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_quart/1","ref":"Raxol.Animation.Easing.html#ease_in_quart/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_quint/1","ref":"Raxol.Animation.Easing.html#ease_in_quint/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_in_sine/1","ref":"Raxol.Animation.Easing.html#ease_in_sine/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_back/1","ref":"Raxol.Animation.Easing.html#ease_out_back/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_bounce/1","ref":"Raxol.Animation.Easing.html#ease_out_bounce/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_circ/1","ref":"Raxol.Animation.Easing.html#ease_out_circ/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_cubic/1","ref":"Raxol.Animation.Easing.html#ease_out_cubic/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_expo/1","ref":"Raxol.Animation.Easing.html#ease_out_expo/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_quad/1","ref":"Raxol.Animation.Easing.html#ease_out_quad/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_quart/1","ref":"Raxol.Animation.Easing.html#ease_out_quart/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_quint/1","ref":"Raxol.Animation.Easing.html#ease_out_quint/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.ease_out_sine/1","ref":"Raxol.Animation.Easing.html#ease_out_sine/1"},{"type":"function","doc":"","title":"Raxol.Animation.Easing.linear/1","ref":"Raxol.Animation.Easing.html#linear/1"},{"type":"module","doc":"Coordinates the lifecycle of animations within Raxol.\n\nThis module acts as the main entry point for creating, starting, stopping,\nand applying animations to the application state. It relies on supporting\nmodules for specific concerns:\n\n- `Raxol.Animation.StateManager`: Handles the storage and retrieval of\n  animation definitions and active instances.\n- `Raxol.Animation.Accessibility`: Adapts animations based on user\n  accessibility preferences (e.g., reduced motion).\n- `Raxol.Animation.Interpolate`: Provides easing and value interpolation\n  functions.\n\nThe framework automatically handles:\n- Timing and progress calculation.\n- Applying interpolated values to the application state via configured paths.\n- Managing animation completion and callbacks.\n- Adapting to reduced motion settings.","title":"Raxol.Animation.Framework","ref":"Raxol.Animation.Framework.html"},{"type":"module","doc":"```elixir\n# Initialize the framework (typically done once on application start)\nRaxol.Animation.Framework.init()\n\n# Define an animation\nRaxol.Animation.Framework.create_animation(:fade_in, %{\n  target_path: [:opacity], # Path within state to animate\n  duration: 300,\n  easing: :ease_out_cubic,\n  from: 0.0,\n  to: 1.0\n})\n\n# Start the animation on an element\nRaxol.Animation.Framework.start_animation(:fade_in, :my_element_id)\n\n# In the application's update loop, apply animations to the state\nupdated_state = Raxol.Animation.Framework.apply_animations_to_state(current_state)\n```","title":"Usage - Raxol.Animation.Framework","ref":"Raxol.Animation.Framework.html#module-usage"},{"type":"function","doc":"Update animations and apply their current values to the state.","title":"Raxol.Animation.Framework.apply_animations_to_state/1","ref":"Raxol.Animation.Framework.html#apply_animations_to_state/1"},{"type":"function","doc":"* `state` - Current application state","title":"Parameters - Raxol.Animation.Framework.apply_animations_to_state/1","ref":"Raxol.Animation.Framework.html#apply_animations_to_state/1-parameters"},{"type":"function","doc":"Updated state with animation values applied.","title":"Returns - Raxol.Animation.Framework.apply_animations_to_state/1","ref":"Raxol.Animation.Framework.html#apply_animations_to_state/1-returns"},{"type":"function","doc":"Create a new animation.","title":"Raxol.Animation.Framework.create_animation/2","ref":"Raxol.Animation.Framework.html#create_animation/2"},{"type":"function","doc":"* `name` - Unique identifier for the animation\n* `params` - Animation parameters","title":"Parameters - Raxol.Animation.Framework.create_animation/2","ref":"Raxol.Animation.Framework.html#create_animation/2-parameters"},{"type":"function","doc":"* `:type` - Animation type (:fade, :slide, :scale, :color, :generic)\n* `:duration` - Duration in milliseconds\n* `:easing` - Easing function name\n* `:from` - Starting value\n* `:to` - Ending value\n* `:direction` - Animation direction (:in, :out)\n* `:announce_to_screen_reader` - Whether to announce to screen readers\n* `:description` - Description for screen reader announcements","title":"Options - Raxol.Animation.Framework.create_animation/2","ref":"Raxol.Animation.Framework.html#create_animation/2-options"},{"type":"function","doc":"iex> AnimationFramework.create_animation(:fade_in, %{\n    ...>   type: :fade,\n    ...>   duration: 300,\n    ...>   easing: :ease_out_cubic,\n    ...>   from: 0.0,\n    ...>   to: 1.0,\n    ...>   direction: :in\n    ...> })\n    %{\n      name: :fade_in,\n      type: :fade,\n      duration: 300,\n      easing: :ease_out_cubic,\n      from: 0.0,\n      to: 1.0,\n      direction: :in\n    }","title":"Examples - Raxol.Animation.Framework.create_animation/2","ref":"Raxol.Animation.Framework.html#create_animation/2-examples"},{"type":"function","doc":"Gets the current value and completion status of an animation instance.","title":"Raxol.Animation.Framework.get_current_value/2","ref":"Raxol.Animation.Framework.html#get_current_value/2"},{"type":"function","doc":"* `animation_name` - The name of the animation\n* `element_id` - Identifier for the element being animated","title":"Parameters - Raxol.Animation.Framework.get_current_value/2","ref":"Raxol.Animation.Framework.html#get_current_value/2-parameters"},{"type":"function","doc":"* `{value, done?}` - A tuple with the current animation value and a boolean indicating if it's finished.\n* `:not_found` - If the animation instance is not active.","title":"Returns - Raxol.Animation.Framework.get_current_value/2","ref":"Raxol.Animation.Framework.html#get_current_value/2-returns"},{"type":"function","doc":"iex> AnimationFramework.get_current_value(:fade_in, \"search_button\")\n    {0.5, false}","title":"Examples - Raxol.Animation.Framework.get_current_value/2","ref":"Raxol.Animation.Framework.html#get_current_value/2-examples"},{"type":"function","doc":"Initialize the animation framework.\n\nThis sets up the necessary state for tracking animations and\nintegrates with accessibility settings.","title":"Raxol.Animation.Framework.init/1","ref":"Raxol.Animation.Framework.html#init/1"},{"type":"function","doc":"* `:reduced_motion` - Start with reduced motion (default: from accessibility settings)\n* `:cognitive_accessibility` - Start with cognitive accessibility (default: from accessibility settings)\n* `:default_duration` - Default animation duration in milliseconds (default: 300)\n* `:frame_ms` - Frame duration in milliseconds (default: 33)","title":"Options - Raxol.Animation.Framework.init/1","ref":"Raxol.Animation.Framework.html#init/1-options"},{"type":"function","doc":"iex> AnimationFramework.init()\n    :ok\n\n    iex> AnimationFramework.init(reduced_motion: true)\n    :ok","title":"Examples - Raxol.Animation.Framework.init/1","ref":"Raxol.Animation.Framework.html#init/1-examples"},{"type":"function","doc":"","title":"Raxol.Animation.Framework.should_apply_cognitive_accessibility?/0","ref":"Raxol.Animation.Framework.html#should_apply_cognitive_accessibility?/0"},{"type":"function","doc":"","title":"Raxol.Animation.Framework.should_reduce_motion?/0","ref":"Raxol.Animation.Framework.html#should_reduce_motion?/0"},{"type":"function","doc":"Start an animation for a specific element.","title":"Raxol.Animation.Framework.start_animation/3","ref":"Raxol.Animation.Framework.html#start_animation/3"},{"type":"function","doc":"* `animation_name` - The name of the animation to start\n* `element_id` - Identifier for the element being animated\n* `opts` - Additional options","title":"Parameters - Raxol.Animation.Framework.start_animation/3","ref":"Raxol.Animation.Framework.html#start_animation/3-parameters"},{"type":"function","doc":"* `:on_complete` - Function to call when animation completes\n* `:context` - Additional context for the animation","title":"Options - Raxol.Animation.Framework.start_animation/3","ref":"Raxol.Animation.Framework.html#start_animation/3-options"},{"type":"function","doc":"iex> AnimationFramework.start_animation(:fade_in, \"search_button\")\n    :ok\n\n    iex> AnimationFramework.start_animation(:slide_in, \"panel\", on_complete: &handle_complete/1)\n    :ok","title":"Examples - Raxol.Animation.Framework.start_animation/3","ref":"Raxol.Animation.Framework.html#start_animation/3-examples"},{"type":"function","doc":"Stops a specific animation for an element.","title":"Raxol.Animation.Framework.stop_animation/2","ref":"Raxol.Animation.Framework.html#stop_animation/2"},{"type":"function","doc":"* `animation_name` - The name of the animation to stop\n* `element_id` - Identifier for the element being animated","title":"Parameters - Raxol.Animation.Framework.stop_animation/2","ref":"Raxol.Animation.Framework.html#stop_animation/2-parameters"},{"type":"function","doc":"iex> AnimationFramework.stop_animation(:fade_in, \"search_button\")\n    :ok","title":"Examples - Raxol.Animation.Framework.stop_animation/2","ref":"Raxol.Animation.Framework.html#stop_animation/2-examples"},{"type":"module","doc":"Gesture-driven interactions for Raxol animations.\n\nThis module provides a system for detecting and handling gestures in terminal UI,\nwhich can be used to trigger physics-based animations.\n\nSupported gestures include:\n* Swipe (rapid movement in a direction)\n* Tap (quick press and release)\n* Long press (press and hold)\n* Drag (press, move, release)\n* Pinch/zoom (simulated in terminal context)\n* Multi-tap (multiple quick taps)","title":"Raxol.Animation.Gestures","ref":"Raxol.Animation.Gestures.html"},{"type":"type","doc":"","title":"Raxol.Animation.Gestures.direction/0","ref":"Raxol.Animation.Gestures.html#t:direction/0"},{"type":"type","doc":"","title":"Raxol.Animation.Gestures.gesture_type/0","ref":"Raxol.Animation.Gestures.html#t:gesture_type/0"},{"type":"function","doc":"Gets the current state of all objects in active animations.\nThis is used for rendering.","title":"Raxol.Animation.Gestures.get_animation_objects/0","ref":"Raxol.Animation.Gestures.html#get_animation_objects/0"},{"type":"type","doc":"","title":"Raxol.Animation.Gestures.handler/0","ref":"Raxol.Animation.Gestures.html#t:handler/0"},{"type":"function","doc":"Initializes the gesture system.","title":"Raxol.Animation.Gestures.init/0","ref":"Raxol.Animation.Gestures.html#init/0"},{"type":"type","doc":"","title":"Raxol.Animation.Gestures.position/0","ref":"Raxol.Animation.Gestures.html#t:position/0"},{"type":"function","doc":"Registers a handler for a specific gesture type.","title":"Raxol.Animation.Gestures.register_handler/2","ref":"Raxol.Animation.Gestures.html#register_handler/2"},{"type":"function","doc":"iex> register_handler(:swipe, fn %{direction: :left} -> handle_left_swipe() end)\n    :ok","title":"Examples - Raxol.Animation.Gestures.register_handler/2","ref":"Raxol.Animation.Gestures.html#register_handler/2-examples"},{"type":"function","doc":"Handles a touch/mouse down event.","title":"Raxol.Animation.Gestures.touch_down/2","ref":"Raxol.Animation.Gestures.html#touch_down/2"},{"type":"function","doc":"Handles a touch/mouse move event.","title":"Raxol.Animation.Gestures.touch_move/2","ref":"Raxol.Animation.Gestures.html#touch_move/2"},{"type":"function","doc":"Handles a touch/mouse up event.","title":"Raxol.Animation.Gestures.touch_up/2","ref":"Raxol.Animation.Gestures.html#touch_up/2"},{"type":"function","doc":"Updates all active physics-based animations.\nShould be called on each frame.","title":"Raxol.Animation.Gestures.update_animations/1","ref":"Raxol.Animation.Gestures.html#update_animations/1"},{"type":"module","doc":"Provides interpolation functions for different data types.","title":"Raxol.Animation.Interpolate","ref":"Raxol.Animation.Interpolate.html"},{"type":"function","doc":"Interpolates between two values based on progress `t` (0.0 to 1.0).","title":"Raxol.Animation.Interpolate.value/3","ref":"Raxol.Animation.Interpolate.html#value/3"},{"type":"module","doc":"Force field implementation for physics simulations.\n\nForce fields apply forces to physics objects within their influence.\nTypes of force fields include:\n\n* Point (radial forces emanating from a point)\n* Directional (constant force in a direction, like wind)\n* Vortex (spinning forces)\n* Noise (random forces based on position)\n* Custom (user-defined force function)","title":"Raxol.Animation.Physics.ForceField","ref":"Raxol.Animation.Physics.ForceField.html"},{"type":"function","doc":"Calculates the force applied by a field on an object.","title":"Raxol.Animation.Physics.ForceField.calculate_force/2","ref":"Raxol.Animation.Physics.ForceField.html#calculate_force/2"},{"type":"function","doc":"Creates a new custom force field.\n\nA custom force field uses a user-provided function to calculate forces.","title":"Raxol.Animation.Physics.ForceField.custom_field/2","ref":"Raxol.Animation.Physics.ForceField.html#custom_field/2"},{"type":"function","doc":"* `:function` - Function to calculate force (fn object, field -> force_vector end)\n* `:properties` - Additional properties for the function (default: %{})","title":"Options - Raxol.Animation.Physics.ForceField.custom_field/2","ref":"Raxol.Animation.Physics.ForceField.html#custom_field/2-options"},{"type":"function","doc":"Creates a new directional force field.\n\nA directional force field applies a constant force in a specific direction,\nlike wind or gravity.","title":"Raxol.Animation.Physics.ForceField.directional_field/1","ref":"Raxol.Animation.Physics.ForceField.html#directional_field/1"},{"type":"function","doc":"* `:direction` - Direction of the force (default: up)\n* `:strength` - Strength of the field (default: 1.0)","title":"Options - Raxol.Animation.Physics.ForceField.directional_field/1","ref":"Raxol.Animation.Physics.ForceField.html#directional_field/1-options"},{"type":"type","doc":"","title":"Raxol.Animation.Physics.ForceField.field_type/0","ref":"Raxol.Animation.Physics.ForceField.html#t:field_type/0"},{"type":"function","doc":"Creates a new noise force field.\n\nA noise force field applies pseudo-random forces based on position.","title":"Raxol.Animation.Physics.ForceField.noise_field/1","ref":"Raxol.Animation.Physics.ForceField.html#noise_field/1"},{"type":"function","doc":"* `:strength` - Strength of the field (default: 1.0)\n* `:scale` - Scale of the noise (default: 0.1)\n* `:seed` - Random seed (default: random)","title":"Options - Raxol.Animation.Physics.ForceField.noise_field/1","ref":"Raxol.Animation.Physics.ForceField.html#noise_field/1-options"},{"type":"function","doc":"Creates a new point force field.\n\nA point force field applies forces radiating from or towards a point.\nPositive strength = repulsive, Negative strength = attractive.","title":"Raxol.Animation.Physics.ForceField.point_field/1","ref":"Raxol.Animation.Physics.ForceField.html#point_field/1"},{"type":"function","doc":"* `:position` - Position of the field (default: origin)\n* `:strength` - Strength of the field (default: 1.0)\n* `:radius` - Radius of influence (default: 10.0)\n* `:falloff` - How force decreases with distance (:linear, :quadratic, :none) (default: :quadratic)","title":"Options - Raxol.Animation.Physics.ForceField.point_field/1","ref":"Raxol.Animation.Physics.ForceField.html#point_field/1-options"},{"type":"type","doc":"","title":"Raxol.Animation.Physics.ForceField.t/0","ref":"Raxol.Animation.Physics.ForceField.html#t:t/0"},{"type":"function","doc":"Creates a new vortex force field.\n\nA vortex force field applies spinning forces around an axis.","title":"Raxol.Animation.Physics.ForceField.vortex_field/1","ref":"Raxol.Animation.Physics.ForceField.html#vortex_field/1"},{"type":"function","doc":"* `:position` - Center of the vortex (default: origin)\n* `:direction` - Axis of rotation (default: up)\n* `:strength` - Strength of the field (default: 1.0)\n* `:radius` - Radius of influence (default: 10.0)\n* `:falloff` - How force decreases with distance (:linear, :quadratic, :none) (default: :linear)","title":"Options - Raxol.Animation.Physics.ForceField.vortex_field/1","ref":"Raxol.Animation.Physics.ForceField.html#vortex_field/1-options"},{"type":"module","doc":"Physics engine for Raxol animations.\n\nProvides physics-based animation capabilities including:\n* Spring simulations\n* Gravity and bounce effects\n* Friction and damping\n* Collisions\n* Particle systems\n* Force fields\n\nThese can be used to create natural, organic animations that respond\nto user interactions in a physically plausible way.","title":"Raxol.Animation.Physics.PhysicsEngine","ref":"Raxol.Animation.Physics.PhysicsEngine.html"},{"type":"function","doc":"Adds a force field to the physics world.","title":"Raxol.Animation.Physics.PhysicsEngine.add_force_field/2","ref":"Raxol.Animation.Physics.PhysicsEngine.html#add_force_field/2"},{"type":"function","doc":"Adds an object to the physics world.","title":"Raxol.Animation.Physics.PhysicsEngine.add_object/2","ref":"Raxol.Animation.Physics.PhysicsEngine.html#add_object/2"},{"type":"function","doc":"Applies an impulse force to an object.","title":"Raxol.Animation.Physics.PhysicsEngine.apply_impulse/3","ref":"Raxol.Animation.Physics.PhysicsEngine.html#apply_impulse/3"},{"type":"function","doc":"Creates a particle system at the specified position.","title":"Raxol.Animation.Physics.PhysicsEngine.create_particle_system/4","ref":"Raxol.Animation.Physics.PhysicsEngine.html#create_particle_system/4"},{"type":"function","doc":"Creates a new physics object with the given properties.","title":"Raxol.Animation.Physics.PhysicsEngine.new_object/2","ref":"Raxol.Animation.Physics.PhysicsEngine.html#new_object/2"},{"type":"function","doc":"Creates a new physics world with default values.","title":"Raxol.Animation.Physics.PhysicsEngine.new_world/0","ref":"Raxol.Animation.Physics.PhysicsEngine.html#new_world/0"},{"type":"function","doc":"Creates a new physics world with custom settings.","title":"Raxol.Animation.Physics.PhysicsEngine.new_world/1","ref":"Raxol.Animation.Physics.PhysicsEngine.html#new_world/1"},{"type":"type","doc":"","title":"Raxol.Animation.Physics.PhysicsEngine.physics_object/0","ref":"Raxol.Animation.Physics.PhysicsEngine.html#t:physics_object/0"},{"type":"function","doc":"Removes an object from the physics world.","title":"Raxol.Animation.Physics.PhysicsEngine.remove_object/2","ref":"Raxol.Animation.Physics.PhysicsEngine.html#remove_object/2"},{"type":"function","doc":"Sets the boundaries of the physics world.","title":"Raxol.Animation.Physics.PhysicsEngine.set_boundaries/2","ref":"Raxol.Animation.Physics.PhysicsEngine.html#set_boundaries/2"},{"type":"function","doc":"Creates a spring force between two objects.","title":"Raxol.Animation.Physics.PhysicsEngine.spring_force/5","ref":"Raxol.Animation.Physics.PhysicsEngine.html#spring_force/5"},{"type":"function","doc":"Updates the physics world by one time step.","title":"Raxol.Animation.Physics.PhysicsEngine.update/2","ref":"Raxol.Animation.Physics.PhysicsEngine.html#update/2"},{"type":"type","doc":"","title":"Raxol.Animation.Physics.PhysicsEngine.world_state/0","ref":"Raxol.Animation.Physics.PhysicsEngine.html#t:world_state/0"},{"type":"module","doc":"3D vector implementation for physics simulations.\n\nProvides basic vector operations needed for physics calculations.","title":"Raxol.Animation.Physics.Vector","ref":"Raxol.Animation.Physics.Vector.html"},{"type":"function","doc":"Adds two vectors.","title":"Raxol.Animation.Physics.Vector.add/2","ref":"Raxol.Animation.Physics.Vector.html#add/2"},{"type":"function","doc":"Calculates the angle between two vectors in radians.","title":"Raxol.Animation.Physics.Vector.angle/2","ref":"Raxol.Animation.Physics.Vector.html#angle/2"},{"type":"function","doc":"Calculates the cross product of two vectors.","title":"Raxol.Animation.Physics.Vector.cross/2","ref":"Raxol.Animation.Physics.Vector.html#cross/2"},{"type":"function","doc":"Calculates the distance between two points represented as vectors.","title":"Raxol.Animation.Physics.Vector.distance/2","ref":"Raxol.Animation.Physics.Vector.html#distance/2"},{"type":"function","doc":"Calculates the dot product of two vectors.","title":"Raxol.Animation.Physics.Vector.dot/2","ref":"Raxol.Animation.Physics.Vector.html#dot/2"},{"type":"function","doc":"Creates a vector from spherical coordinates.","title":"Raxol.Animation.Physics.Vector.from_spherical/3","ref":"Raxol.Animation.Physics.Vector.html#from_spherical/3"},{"type":"function","doc":"Performs linear interpolation between two vectors.","title":"Raxol.Animation.Physics.Vector.lerp/3","ref":"Raxol.Animation.Physics.Vector.html#lerp/3"},{"type":"function","doc":"Calculates the magnitude (length) of a vector.","title":"Raxol.Animation.Physics.Vector.magnitude/1","ref":"Raxol.Animation.Physics.Vector.html#magnitude/1"},{"type":"function","doc":"Returns the negation of the vector.","title":"Raxol.Animation.Physics.Vector.negate/1","ref":"Raxol.Animation.Physics.Vector.html#negate/1"},{"type":"function","doc":"Creates a new vector with the specified components.","title":"Raxol.Animation.Physics.Vector.new/3","ref":"Raxol.Animation.Physics.Vector.html#new/3"},{"type":"function","doc":"Normalizes a vector (makes it unit length).","title":"Raxol.Animation.Physics.Vector.normalize/1","ref":"Raxol.Animation.Physics.Vector.html#normalize/1"},{"type":"function","doc":"Multiplies a vector by a scalar.","title":"Raxol.Animation.Physics.Vector.scale/2","ref":"Raxol.Animation.Physics.Vector.html#scale/2"},{"type":"function","doc":"Subtracts the second vector from the first.","title":"Raxol.Animation.Physics.Vector.subtract/2","ref":"Raxol.Animation.Physics.Vector.html#subtract/2"},{"type":"type","doc":"","title":"Raxol.Animation.Physics.Vector.t/0","ref":"Raxol.Animation.Physics.Vector.html#t:t/0"},{"type":"function","doc":"Converts the vector to a string representation.","title":"Raxol.Animation.Physics.Vector.to_string/1","ref":"Raxol.Animation.Physics.Vector.html#to_string/1"},{"type":"module","doc":"Manages the state for the Raxol Animation Framework.\n\nThis module encapsulates the storage and retrieval of animation settings,\ndefinitions, and active instances, currently using the process dictionary.","title":"Raxol.Animation.StateManager","ref":"Raxol.Animation.StateManager.html"},{"type":"function","doc":"Clears all animation state (used primarily for testing or reset).","title":"Raxol.Animation.StateManager.clear_all/0","ref":"Raxol.Animation.StateManager.html#clear_all/0"},{"type":"function","doc":"Retrieves all active animations. Returns a map of `{element_id, %{animation_name => instance}}`.","title":"Raxol.Animation.StateManager.get_active_animations/0","ref":"Raxol.Animation.StateManager.html#get_active_animations/0"},{"type":"function","doc":"Retrieves an animation definition by name.","title":"Raxol.Animation.StateManager.get_animation/1","ref":"Raxol.Animation.StateManager.html#get_animation/1"},{"type":"function","doc":"Retrieves the animation framework settings.","title":"Raxol.Animation.StateManager.get_settings/0","ref":"Raxol.Animation.StateManager.html#get_settings/0"},{"type":"function","doc":"Initializes the animation state storage.","title":"Raxol.Animation.StateManager.init/1","ref":"Raxol.Animation.StateManager.html#init/1"},{"type":"function","doc":"Stores an active animation instance for a given element.","title":"Raxol.Animation.StateManager.put_active_animation/3","ref":"Raxol.Animation.StateManager.html#put_active_animation/3"},{"type":"function","doc":"Stores an animation definition.","title":"Raxol.Animation.StateManager.put_animation/1","ref":"Raxol.Animation.StateManager.html#put_animation/1"},{"type":"function","doc":"Removes a completed or stopped animation instance for a specific element.","title":"Raxol.Animation.StateManager.remove_active_animation/2","ref":"Raxol.Animation.StateManager.html#remove_active_animation/2"},{"type":"module","doc":"Authentication module for handling user authentication and authorization.\n\nThis module provides functionality for:\n- User authentication\n- Token generation and validation\n- Role-based access control\n- Session management","title":"Raxol.Auth","ref":"Raxol.Auth.html"},{"type":"function","doc":"Cleans up a user session.","title":"Raxol.Auth.cleanup_user_session/1","ref":"Raxol.Auth.html#cleanup_user_session/1"},{"type":"function","doc":"Creates a new session for an authenticated user.\n(Session logic currently commented out, returns :ok)","title":"Raxol.Auth.create_user_session/2","ref":"Raxol.Auth.html#create_user_session/2"},{"type":"function","doc":"Retrieves user information by ID (Calls Accounts).","title":"Raxol.Auth.get_user/1","ref":"Raxol.Auth.html#get_user/1"},{"type":"function","doc":"Retrieves a user by their session ID.\nNOTE: This function is a stub. Raxol.Auth.Session is undefined; consider removing if not needed.\nReturns the user or nil if not found or session is invalid.","title":"Raxol.Auth.get_user_by_session/1","ref":"Raxol.Auth.html#get_user_by_session/1"},{"type":"function","doc":"Checks if a user has permission for a specific action (Placeholder).","title":"Raxol.Auth.has_permission?/3","ref":"Raxol.Auth.html#has_permission?/3"},{"type":"function","doc":"Checks if a user has the required role.","title":"Raxol.Auth.has_role?/2","ref":"Raxol.Auth.html#has_role?/2"},{"type":"function","doc":"Validates a session token and returns the associated user ID.\nWARNING: This is a placeholder and insecure. Needs proper implementation.","title":"Raxol.Auth.validate_token/2","ref":"Raxol.Auth.html#validate_token/2"},{"type":"module","doc":"Permission schema for role-based access control.","title":"Raxol.Auth.Permission","ref":"Raxol.Auth.Permission.html"},{"type":"function","doc":"Creates a changeset for a permission.","title":"Raxol.Auth.Permission.changeset/2","ref":"Raxol.Auth.Permission.html#changeset/2"},{"type":"function","doc":"Creates a changeset for a system permission.","title":"Raxol.Auth.Permission.system_changeset/2","ref":"Raxol.Auth.Permission.html#system_changeset/2"},{"type":"module","doc":"Plug for handling authentication and authorization.","title":"Raxol.Auth.Plug","ref":"Raxol.Auth.Plug.html"},{"type":"function","doc":"Authenticates a user by email and password.","title":"Raxol.Auth.Plug.authenticate_user/3","ref":"Raxol.Auth.Plug.html#authenticate_user/3"},{"type":"function","doc":"","title":"Raxol.Auth.Plug.call/2","ref":"Raxol.Auth.Plug.html#call/2"},{"type":"function","doc":"","title":"Raxol.Auth.Plug.init/1","ref":"Raxol.Auth.Plug.html#init/1"},{"type":"macro","doc":"","title":"Raxol.Auth.Plug.is_admin?/1","ref":"Raxol.Auth.Plug.html#is_admin?/1"},{"type":"function","doc":"Logs out the current user.","title":"Raxol.Auth.Plug.logout_user/1","ref":"Raxol.Auth.Plug.html#logout_user/1"},{"type":"function","doc":"Checks if the current user is logged in.","title":"Raxol.Auth.Plug.require_authenticated_user/2","ref":"Raxol.Auth.Plug.html#require_authenticated_user/2"},{"type":"function","doc":"","title":"Raxol.Auth.Plug.require_permission/3","ref":"Raxol.Auth.Plug.html#require_permission/3"},{"type":"module","doc":"Role schema for role-based access control.","title":"Raxol.Auth.Role","ref":"Raxol.Auth.Role.html"},{"type":"function","doc":"Creates a changeset for a role.","title":"Raxol.Auth.Role.changeset/2","ref":"Raxol.Auth.Role.html#changeset/2"},{"type":"function","doc":"Creates a changeset for a system role.","title":"Raxol.Auth.Role.system_changeset/2","ref":"Raxol.Auth.Role.html#system_changeset/2"},{"type":"module","doc":"User schema for authentication and authorization.","title":"Raxol.Auth.User","ref":"Raxol.Auth.User.html"},{"type":"function","doc":"Creates a changeset for a user.","title":"Raxol.Auth.User.changeset/2","ref":"Raxol.Auth.User.html#changeset/2"},{"type":"function","doc":"Creates a changeset for password reset.","title":"Raxol.Auth.User.password_reset_changeset/2","ref":"Raxol.Auth.User.html#password_reset_changeset/2"},{"type":"function","doc":"Creates a changeset for registration.","title":"Raxol.Auth.User.registration_changeset/2","ref":"Raxol.Auth.User.html#registration_changeset/2"},{"type":"module","doc":"Performance benchmarking and validation tools for Raxol.\n\nThis module provides utilities for measuring and validating performance metrics\nincluding rendering speed, memory usage, and event handling latency.","title":"Raxol.Benchmarks.Performance","ref":"Raxol.Benchmarks.Performance.html"},{"type":"function","doc":"Runs all performance benchmarks and returns the results.","title":"Raxol.Benchmarks.Performance.run_all/1","ref":"Raxol.Benchmarks.Performance.html#run_all/1"},{"type":"function","doc":"* `:save_results` - Save results to file (default: `true`)\n* `:compare_with_baseline` - Compare with baseline metrics (default: `true`)\n* `:detailed` - Include detailed metrics (default: `false`)","title":"Options - Raxol.Benchmarks.Performance.run_all/1","ref":"Raxol.Benchmarks.Performance.html#run_all/1-options"},{"type":"function","doc":"Map containing benchmark results with the following structure:\n\n```\n%{\n  render_performance: %{...},\n  event_latency: %{...},\n  memory_usage: %{...},\n  animation_fps: %{...},\n  metrics_validation: %{...}\n}\n```","title":"Returns - Raxol.Benchmarks.Performance.run_all/1","ref":"Raxol.Benchmarks.Performance.html#run_all/1-returns"},{"type":"module","doc":"Animation performance benchmark functions for Raxol.","title":"Raxol.Benchmarks.Performance.Animation","ref":"Raxol.Benchmarks.Performance.Animation.html"},{"type":"function","doc":"Benchmarks animation performance and frame rate stability.\n\nTests:\n- Maximum achievable FPS\n- Frame time consistency\n- Animation smoothness\n- CPU usage during animation","title":"Raxol.Benchmarks.Performance.Animation.benchmark_animation_performance/0","ref":"Raxol.Benchmarks.Performance.Animation.html#benchmark_animation_performance/0"},{"type":"module","doc":"Event handling performance benchmark functions for Raxol.","title":"Raxol.Benchmarks.Performance.EventHandling","ref":"Raxol.Benchmarks.Performance.EventHandling.html"},{"type":"function","doc":"Benchmarks event handling latency for different event types and volumes.\n\nTests event handling for:\n- Keyboard events\n- Mouse events\n- Window events\n- Custom events\n- High-volume event bursts","title":"Raxol.Benchmarks.Performance.EventHandling.benchmark_event_handling/0","ref":"Raxol.Benchmarks.Performance.EventHandling.html#benchmark_event_handling/0"},{"type":"module","doc":"Memory usage performance benchmark functions for Raxol.","title":"Raxol.Benchmarks.Performance.MemoryUsage","ref":"Raxol.Benchmarks.Performance.MemoryUsage.html"},{"type":"function","doc":"Benchmarks memory usage patterns for components and rendering cycles.\n\nMeasures:\n- Memory consumption per component\n- Memory growth during rendering\n- GC impact on performance\n- Memory leaks in long-running scenarios","title":"Raxol.Benchmarks.Performance.MemoryUsage.benchmark_memory_usage/0","ref":"Raxol.Benchmarks.Performance.MemoryUsage.html#benchmark_memory_usage/0"},{"type":"module","doc":"Rendering performance benchmark functions for Raxol.","title":"Raxol.Benchmarks.Performance.Rendering","ref":"Raxol.Benchmarks.Performance.Rendering.html"},{"type":"function","doc":"Benchmarks rendering performance for various component types and complexities.\n\nTests rendering performance for:\n- Simple components (text, buttons)\n- Medium complexity (tables, lists)\n- Complex components (dashboards, multi-panel layouts)","title":"Raxol.Benchmarks.Performance.Rendering.benchmark_rendering/0","ref":"Raxol.Benchmarks.Performance.Rendering.html#benchmark_rendering/0"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Rendering.calculate_components_per_frame/1","ref":"Raxol.Benchmarks.Performance.Rendering.html#calculate_components_per_frame/1"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Rendering.calculate_renders_per_second/1","ref":"Raxol.Benchmarks.Performance.Rendering.html#calculate_renders_per_second/1"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Rendering.generate_test_component/1","ref":"Raxol.Benchmarks.Performance.Rendering.html#generate_test_component/1"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Rendering.measure_full_screen_render/1","ref":"Raxol.Benchmarks.Performance.Rendering.html#measure_full_screen_render/1"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Rendering.measure_render_time/2","ref":"Raxol.Benchmarks.Performance.Rendering.html#measure_render_time/2"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Rendering.render_component/1","ref":"Raxol.Benchmarks.Performance.Rendering.html#render_component/1"},{"type":"module","doc":"Reporting functions (saving, printing) for Raxol performance benchmarks.","title":"Raxol.Benchmarks.Performance.Reporting","ref":"Raxol.Benchmarks.Performance.Reporting.html"},{"type":"function","doc":"","title":"Raxol.Benchmarks.Performance.Reporting.print_summary/2","ref":"Raxol.Benchmarks.Performance.Reporting.html#print_summary/2"},{"type":"function","doc":"Saves benchmark results to a file.","title":"Raxol.Benchmarks.Performance.Reporting.save_benchmark_results/2","ref":"Raxol.Benchmarks.Performance.Reporting.html#save_benchmark_results/2"},{"type":"function","doc":"* `results` - Benchmark results map\n* `file_path` - Path to save results (default: auto-generated)","title":"Parameters - Raxol.Benchmarks.Performance.Reporting.save_benchmark_results/2","ref":"Raxol.Benchmarks.Performance.Reporting.html#save_benchmark_results/2-parameters"},{"type":"module","doc":"Validation functions for Raxol performance benchmarks.","title":"Raxol.Benchmarks.Performance.Validation","ref":"Raxol.Benchmarks.Performance.Validation.html"},{"type":"function","doc":"Retrieves baseline performance metrics for the current platform.\n\nIf no platform-specific baseline exists, falls back to default baseline.","title":"Raxol.Benchmarks.Performance.Validation.get_baseline_metrics/0","ref":"Raxol.Benchmarks.Performance.Validation.html#get_baseline_metrics/0"},{"type":"function","doc":"Validates performance against baseline requirements.","title":"Raxol.Benchmarks.Performance.Validation.validate_metrics/2","ref":"Raxol.Benchmarks.Performance.Validation.html#validate_metrics/2"},{"type":"function","doc":"* `results` - Current benchmark results\n* `baseline` - Baseline metrics to compare against","title":"Parameters - Raxol.Benchmarks.Performance.Validation.validate_metrics/2","ref":"Raxol.Benchmarks.Performance.Validation.html#validate_metrics/2-parameters"},{"type":"function","doc":"Map containing validation results and pass/fail status for each metric","title":"Returns - Raxol.Benchmarks.Performance.Validation.validate_metrics/2","ref":"Raxol.Benchmarks.Performance.Validation.html#validate_metrics/2-returns"},{"type":"module","doc":"Performance benchmarking tool for visualization components.\nProvides tools to measure rendering time, memory usage, and optimization effectiveness\nfor different data sizes and visualization types.","title":"Raxol.Benchmarks.VisualizationBenchmark","ref":"Raxol.Benchmarks.VisualizationBenchmark.html"},{"type":"function","doc":"Benchmark chart rendering performance.","title":"Raxol.Benchmarks.VisualizationBenchmark.benchmark_charts/4","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#benchmark_charts/4"},{"type":"function","doc":"Benchmark treemap rendering performance.","title":"Raxol.Benchmarks.VisualizationBenchmark.benchmark_treemaps/4","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#benchmark_treemaps/4"},{"type":"function","doc":"Run a comprehensive benchmark suite for visualization components.\n\nThis test will:\n1. Generate test datasets of varying sizes\n2. Benchmark chart rendering performance\n3. Benchmark treemap rendering performance\n4. Test cache hit performance\n5. Measure memory usage\n6. Generate a summary report","title":"Raxol.Benchmarks.VisualizationBenchmark.run_benchmark/1","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#run_benchmark/1"},{"type":"function","doc":"* `:output_path` - Path to write the benchmark results (default: \"benchmark_results\")\n* `:datasets` - List of dataset sizes to test (default: [10, 100, 1000, 10000])\n* `:iterations` - Number of times to run each test (default: 5)\n* `:cache_test` - Whether to test cache performance (default: true)\n* `:memory_test` - Whether to track memory usage (default: true)","title":"Options - Raxol.Benchmarks.VisualizationBenchmark.run_benchmark/1","ref":"Raxol.Benchmarks.VisualizationBenchmark.html#run_benchmark/1-options"},{"type":"module","doc":"A realistic benchmark tool for visualization components with progressive data sizes.\nTests the performance impact of our optimizations on various dataset sizes.","title":"Raxol.Benchmarks.VisualizationBenchmarkRealistic","ref":"Raxol.Benchmarks.VisualizationBenchmarkRealistic.html"},{"type":"function","doc":"Run a benchmark test with realistic dataset sizes.\n\nThis function tests the caching system and data sampling optimizations\nwith progressively larger data sizes.\n\nReturns a map with the benchmark results.","title":"Raxol.Benchmarks.VisualizationBenchmarkRealistic.run_benchmark/0","ref":"Raxol.Benchmarks.VisualizationBenchmarkRealistic.html#run_benchmark/0"},{"type":"module","doc":"A simplified benchmark tool for visualization components, without external dependencies.\nThis is designed for direct testing during development without requiring the full application.","title":"Raxol.Benchmarks.VisualizationBenchmarkSimple","ref":"Raxol.Benchmarks.VisualizationBenchmarkSimple.html"},{"type":"function","doc":"Run a simple benchmark test of the visualization caching system.\n\nThis function directly tests the VisualizationPlugin's caching system\nwith small data samples and doesn't require the full application to be running.\n\nReturns a map with the benchmark results.","title":"Raxol.Benchmarks.VisualizationBenchmarkSimple.run_simple_benchmark/0","ref":"Raxol.Benchmarks.VisualizationBenchmarkSimple.html#run_simple_benchmark/0"},{"type":"module","doc":"CLI command for managing Raxol updates.\n\nThis module handles:\n- Checking for updates\n- Performing self-updates\n- Managing update settings","title":"Raxol.CLI.Commands.UpdateCmd","ref":"Raxol.CLI.Commands.UpdateCmd.html"},{"type":"function","doc":"Executes the update command with the provided options and arguments.","title":"Raxol.CLI.Commands.UpdateCmd.execute/1","ref":"Raxol.CLI.Commands.UpdateCmd.html#execute/1"},{"type":"function","doc":"- `--check` or `-c`: Check for updates without installing\n- `--force` or `-f`: Force update check, bypassing the check interval\n- `--auto` or `-a`: Enable or disable automatic update checks (value: on/off)\n- `--version` or `-v`: Update to a specific version\n- `--no-delta` or `-n`: Disable delta updates and use full updates only\n- `--delta-info` or `-d`: Show information about delta update availability","title":"Options - Raxol.CLI.Commands.UpdateCmd.execute/1","ref":"Raxol.CLI.Commands.UpdateCmd.html#execute/1-options"},{"type":"function","doc":"Check for updates:\n```\nraxol update --check\n```\n\nPerform an update:\n```\nraxol update\n```\n\nUpdate to a specific version:\n```\nraxol update --version 0.2.0\n```\n\nUpdate without using delta updates:\n```\nraxol update --no-delta\n```\n\nDisable automatic update checks:\n```\nraxol update --auto off\n```","title":"Examples - Raxol.CLI.Commands.UpdateCmd.execute/1","ref":"Raxol.CLI.Commands.UpdateCmd.html#execute/1-examples"},{"type":"module","doc":"Handles clipboard operations across different platforms.\nProvides a unified interface for copy/paste functionality.","title":"Raxol.Clipboard","ref":"Raxol.Clipboard.html"},{"type":"function","doc":"Gets text from the system clipboard.\nReturns {:ok, text} on success, {:error, reason} on failure.","title":"Raxol.Clipboard.get_text/0","ref":"Raxol.Clipboard.html#get_text/0"},{"type":"function","doc":"Sets text to the system clipboard.\nReturns :ok on success, {:error, reason} on failure.","title":"Raxol.Clipboard.set_text/1","ref":"Raxol.Clipboard.html#set_text/1"},{"type":"module","doc":"Cloud integration system for Raxol applications.","title":"Raxol.Cloud","ref":"Raxol.Cloud.html"},{"type":"function","doc":"","title":"Raxol.Cloud.config/3","ref":"Raxol.Cloud.html#config/3"},{"type":"function","doc":"","title":"Raxol.Cloud.connect/1","ref":"Raxol.Cloud.html#connect/1"},{"type":"function","doc":"","title":"Raxol.Cloud.deploy/1","ref":"Raxol.Cloud.html#deploy/1"},{"type":"function","doc":"","title":"Raxol.Cloud.discover/1","ref":"Raxol.Cloud.html#discover/1"},{"type":"function","doc":"","title":"Raxol.Cloud.execute/2","ref":"Raxol.Cloud.html#execute/2"},{"type":"function","doc":"","title":"Raxol.Cloud.init/1","ref":"Raxol.Cloud.html#init/1"},{"type":"function","doc":"","title":"Raxol.Cloud.monitor/3","ref":"Raxol.Cloud.html#monitor/3"},{"type":"function","doc":"","title":"Raxol.Cloud.register/1","ref":"Raxol.Cloud.html#register/1"},{"type":"function","doc":"","title":"Raxol.Cloud.scale/1","ref":"Raxol.Cloud.html#scale/1"},{"type":"function","doc":"","title":"Raxol.Cloud.start/0","ref":"Raxol.Cloud.html#start/0"},{"type":"function","doc":"","title":"Raxol.Cloud.status/0","ref":"Raxol.Cloud.html#status/0"},{"type":"function","doc":"","title":"Raxol.Cloud.stop/0","ref":"Raxol.Cloud.html#stop/0"},{"type":"module","doc":"Configuration management for Raxol cloud integrations.\n\nProvides centralized configuration management with validation,\ndynamic updates, and multiple source support.","title":"Raxol.Cloud.Config","ref":"Raxol.Cloud.Config.html"},{"type":"function","doc":"Gets the current configuration.","title":"Raxol.Cloud.Config.get/1","ref":"Raxol.Cloud.Config.html#get/1"},{"type":"function","doc":"* `:section` - Specific configuration section to get\n* `:flatten` - Whether to flatten nested maps","title":"Options - Raxol.Cloud.Config.get/1","ref":"Raxol.Cloud.Config.html#get/1-options"},{"type":"function","doc":"Gets the default configuration value for a key.","title":"Raxol.Cloud.Config.get_default/1","ref":"Raxol.Cloud.Config.html#get_default/1"},{"type":"function","doc":"Initializes the configuration system.","title":"Raxol.Cloud.Config.init/1","ref":"Raxol.Cloud.Config.html#init/1"},{"type":"function","doc":"* `:sources` - List of configuration sources [:env, :file]\n* `:environment` - Environment to use (:development, :test, :production)\n* `:config_file` - Path to configuration file\n* `:auto_apply` - Whether to automatically apply configuration","title":"Options - Raxol.Cloud.Config.init/1","ref":"Raxol.Cloud.Config.html#init/1-options"},{"type":"function","doc":"Reloads configuration from all sources.","title":"Raxol.Cloud.Config.reload/1","ref":"Raxol.Cloud.Config.html#reload/1"},{"type":"function","doc":"* `:sources` - List of sources to reload from\n* `:apply` - Whether to apply the reloaded configuration","title":"Options - Raxol.Cloud.Config.reload/1","ref":"Raxol.Cloud.Config.html#reload/1-options"},{"type":"function","doc":"Gets the current status of the configuration system.","title":"Raxol.Cloud.Config.status/0","ref":"Raxol.Cloud.Config.html#status/0"},{"type":"function","doc":"Updates the configuration with new values.","title":"Raxol.Cloud.Config.update/2","ref":"Raxol.Cloud.Config.html#update/2"},{"type":"function","doc":"* `:section` - Section to update\n* `:validate` - Whether to validate the configuration\n* `:persist` - Whether to persist changes\n* `:apply` - Whether to apply changes","title":"Options - Raxol.Cloud.Config.update/2","ref":"Raxol.Cloud.Config.html#update/2-options"},{"type":"module","doc":"Core functionality for Raxol cloud integrations.\n\nThis module combines edge computing and monitoring capabilities,\nproviding a unified interface for cloud operations.","title":"Raxol.Cloud.Core","ref":"Raxol.Cloud.Core.html"},{"type":"function","doc":"Deploys an application component.","title":"Raxol.Cloud.Core.deploy/1","ref":"Raxol.Cloud.Core.html#deploy/1"},{"type":"function","doc":"Discovers services available in the current environment.","title":"Raxol.Cloud.Core.discover_services/1","ref":"Raxol.Cloud.Core.html#discover_services/1"},{"type":"function","doc":"Executes a function in the optimal location (edge or cloud).","title":"Raxol.Cloud.Core.execute/2","ref":"Raxol.Cloud.Core.html#execute/2"},{"type":"function","doc":"* `:priority` - Priority for execution (:speed, :reliability, :cost)\n* `:location` - Preferred location (:auto, :edge, :cloud)\n* `:timeout` - Timeout in milliseconds","title":"Options - Raxol.Cloud.Core.execute/2","ref":"Raxol.Cloud.Core.html#execute/2-options"},{"type":"function","doc":"Gets a connection to a cloud service.","title":"Raxol.Cloud.Core.get_service_connection/1","ref":"Raxol.Cloud.Core.html#get_service_connection/1"},{"type":"function","doc":"Initializes the cloud core components.","title":"Raxol.Cloud.Core.init/1","ref":"Raxol.Cloud.Core.html#init/1"},{"type":"function","doc":"* `:edge` - Edge computing options\n* `:monitoring` - Monitoring options\n* `:providers` - List of cloud providers to enable","title":"Options - Raxol.Cloud.Core.init/1","ref":"Raxol.Cloud.Core.html#init/1-options"},{"type":"function","doc":"Records an error or exception.","title":"Raxol.Cloud.Core.record_error/2","ref":"Raxol.Cloud.Core.html#record_error/2"},{"type":"function","doc":"Records a metric with the given name and value.","title":"Raxol.Cloud.Core.record_metric/3","ref":"Raxol.Cloud.Core.html#record_metric/3"},{"type":"function","doc":"Registers the current application as a service.","title":"Raxol.Cloud.Core.register_service/1","ref":"Raxol.Cloud.Core.html#register_service/1"},{"type":"function","doc":"Runs a health check on the system.","title":"Raxol.Cloud.Core.run_health_check/1","ref":"Raxol.Cloud.Core.html#run_health_check/1"},{"type":"function","doc":"Scales a service based on current metrics and conditions.","title":"Raxol.Cloud.Core.scale/1","ref":"Raxol.Cloud.Core.html#scale/1"},{"type":"function","doc":"Starts all cloud services.","title":"Raxol.Cloud.Core.start/0","ref":"Raxol.Cloud.Core.html#start/0"},{"type":"function","doc":"Returns the current status of all cloud services.","title":"Raxol.Cloud.Core.status/0","ref":"Raxol.Cloud.Core.html#status/0"},{"type":"function","doc":"Stops all cloud services.","title":"Raxol.Cloud.Core.stop/0","ref":"Raxol.Cloud.Core.html#stop/0"},{"type":"function","doc":"Triggers an alert with the given type and data.","title":"Raxol.Cloud.Core.trigger_alert/3","ref":"Raxol.Cloud.Core.html#trigger_alert/3"},{"type":"module","doc":"Edge computing support for Raxol applications.\n\nThis module provides functionality for optimizing Raxol applications\nat the edge, allowing for improved performance, reduced latency,\nand offline capabilities.\n\nFeatures:\n* Edge processing configuration\n* Offline mode and data synchronization\n* Resource optimization for edge devices\n* Automatic failover between edge and cloud\n* Edge-specific monitoring and diagnostics\n* Edge-to-cloud data streaming","title":"Raxol.Cloud.EdgeComputing","ref":"Raxol.Cloud.EdgeComputing.html"},{"type":"function","doc":"Manually checks the cloud connection status and updates the system state.","title":"Raxol.Cloud.EdgeComputing.check_connection/0","ref":"Raxol.Cloud.EdgeComputing.html#check_connection/0"},{"type":"function","doc":"Clears the edge cache.","title":"Raxol.Cloud.EdgeComputing.clear_cache/0","ref":"Raxol.Cloud.EdgeComputing.html#clear_cache/0"},{"type":"function","doc":"Executes a function at the edge or in the cloud based on current mode and conditions.","title":"Raxol.Cloud.EdgeComputing.execute/2","ref":"Raxol.Cloud.EdgeComputing.html#execute/2"},{"type":"function","doc":"* `:force_edge` - Force execution at the edge even in hybrid mode (default: false)\n* `:force_cloud` - Force execution in the cloud even in hybrid mode (default: false)\n* `:fallback_fn` - Function to execute if primary execution fails (default: nil)\n* `:timeout` - Timeout in milliseconds for the operation (default: 5000)\n* `:retry` - Number of retry attempts (default: from config)","title":"Options - Raxol.Cloud.EdgeComputing.execute/2","ref":"Raxol.Cloud.EdgeComputing.html#execute/2-options"},{"type":"function","doc":"iex> execute(fn -> process_data(data) end)\n    {:ok, result}","title":"Examples - Raxol.Cloud.EdgeComputing.execute/2","ref":"Raxol.Cloud.EdgeComputing.html#execute/2-examples"},{"type":"function","doc":"Forces the system into a specific mode.","title":"Raxol.Cloud.EdgeComputing.force_mode/1","ref":"Raxol.Cloud.EdgeComputing.html#force_mode/1"},{"type":"function","doc":"Gets metrics for the edge computing system.","title":"Raxol.Cloud.EdgeComputing.get_metrics/0","ref":"Raxol.Cloud.EdgeComputing.html#get_metrics/0"},{"type":"function","doc":"Initializes the edge computing system.","title":"Raxol.Cloud.EdgeComputing.init/1","ref":"Raxol.Cloud.EdgeComputing.html#init/1"},{"type":"function","doc":"* `:mode` - Operation mode (:edge_only, :cloud_only, :hybrid) (default: :hybrid)\n* `:connection_check_interval` - Time in ms between connection checks (default: 5000)\n* `:sync_interval` - Time in ms between cloud syncs (default: 30000)\n* `:retry_limit` - Number of retry attempts for operations (default: 5)\n* `:compression_enabled` - Whether to compress data for transfer (default: true)\n* `:offline_cache_size` - Maximum size in bytes for offline cache (default: 100MB)\n* `:priority_functions` - List of functions that should prioritize edge execution","title":"Options - Raxol.Cloud.EdgeComputing.init/1","ref":"Raxol.Cloud.EdgeComputing.html#init/1-options"},{"type":"function","doc":"iex> init(mode: :hybrid)\n    :ok","title":"Examples - Raxol.Cloud.EdgeComputing.init/1","ref":"Raxol.Cloud.EdgeComputing.html#init/1-examples"},{"type":"function","doc":"Checks if the system is currently operating in offline mode.","title":"Raxol.Cloud.EdgeComputing.offline?/0","ref":"Raxol.Cloud.EdgeComputing.html#offline?/0"},{"type":"function","doc":"Gets the current status of the edge computing system.","title":"Raxol.Cloud.EdgeComputing.status/0","ref":"Raxol.Cloud.EdgeComputing.html#status/0"},{"type":"function","doc":"Synchronizes data between edge and cloud.","title":"Raxol.Cloud.EdgeComputing.sync/1","ref":"Raxol.Cloud.EdgeComputing.html#sync/1"},{"type":"function","doc":"* `:force` - Force immediate synchronization (default: false)\n* `:selective` - List of data types to synchronize (default: all)\n* `:direction` - Sync direction (:both, :to_cloud, :from_cloud) (default: :both)\n* `:conflict_resolution` - Strategy for resolving conflicts (default: :latest_wins)","title":"Options - Raxol.Cloud.EdgeComputing.sync/1","ref":"Raxol.Cloud.EdgeComputing.html#sync/1-options"},{"type":"function","doc":"iex> sync(force: true)\n    {:ok, %{status: :completed, synced_items: 5}}","title":"Examples - Raxol.Cloud.EdgeComputing.sync/1","ref":"Raxol.Cloud.EdgeComputing.html#sync/1-examples"},{"type":"function","doc":"Updates the edge computing configuration.","title":"Raxol.Cloud.EdgeComputing.update_config/2","ref":"Raxol.Cloud.EdgeComputing.html#update_config/2"},{"type":"module","doc":"Cloud integration utilities for Raxol applications.\n\nThis module provides integration utilities for connecting various cloud services\nwith Raxol applications, focusing on edge computing, monitoring, and service discovery.\nIt serves as a central coordination point for cloud-related features.\n\nFeatures:\n* Edge-to-cloud integration helpers\n* Centralized configuration management\n* Service discovery and registration\n* Multi-cloud provider support\n* Deployment and scaling utilities","title":"Raxol.Cloud.Integrations","ref":"Raxol.Cloud.Integrations.html"},{"type":"function","doc":"Deploys an application component to the appropriate environment based on configuration.","title":"Raxol.Cloud.Integrations.deploy/1","ref":"Raxol.Cloud.Integrations.html#deploy/1"},{"type":"function","doc":"* `:component` - Name of the component to deploy\n* `:version` - Version to deploy\n* `:environment` - Target environment (:production, :staging, :development)\n* `:strategy` - Deployment strategy (:blue_green, :canary, :rolling)","title":"Options - Raxol.Cloud.Integrations.deploy/1","ref":"Raxol.Cloud.Integrations.html#deploy/1-options"},{"type":"function","doc":"iex> deploy(\n    ...>   component: :api_service,\n    ...>   version: \"1.2.3\",\n    ...>   environment: :production,\n    ...>   strategy: :blue_green\n    ...> )\n    {:ok, %{deployment_id: \"dep-12345\", status: :in_progress}}","title":"Examples - Raxol.Cloud.Integrations.deploy/1","ref":"Raxol.Cloud.Integrations.html#deploy/1-examples"},{"type":"function","doc":"Discovers services available in the current environment.","title":"Raxol.Cloud.Integrations.discover_services/1","ref":"Raxol.Cloud.Integrations.html#discover_services/1"},{"type":"function","doc":"* `:type` - Type of service to discover (:all, or a specific service type)\n* `:provider` - Cloud provider to query (:all, or a specific provider)\n* `:region` - Region to search in","title":"Options - Raxol.Cloud.Integrations.discover_services/1","ref":"Raxol.Cloud.Integrations.html#discover_services/1-options"},{"type":"function","doc":"iex> discover_services(type: :database)\n    {:ok, [\n      %{name: \"main-db\", type: :database, endpoint: \"main-db.example.com:5432\"},\n      %{name: \"analytics-db\", type: :database, endpoint: \"analytics-db.example.com:5432\"}\n    ]}","title":"Examples - Raxol.Cloud.Integrations.discover_services/1","ref":"Raxol.Cloud.Integrations.html#discover_services/1-examples"},{"type":"function","doc":"Executes a function in the optimal location (edge or cloud) based on current conditions.\n\nThis is a wrapper around EdgeComputing.execute/2 that adds monitoring.","title":"Raxol.Cloud.Integrations.execute/2","ref":"Raxol.Cloud.Integrations.html#execute/2"},{"type":"function","doc":"iex> execute(fn -> perform_calculation(data) end, priority: :speed)\n    {:ok, result}","title":"Examples - Raxol.Cloud.Integrations.execute/2","ref":"Raxol.Cloud.Integrations.html#execute/2-examples"},{"type":"function","doc":"Gets a connection to a cloud service with the specified parameters.","title":"Raxol.Cloud.Integrations.get_service_connection/1","ref":"Raxol.Cloud.Integrations.html#get_service_connection/1"},{"type":"function","doc":"* `:service` - Service name or type to connect to (required)\n* `:provider` - Cloud provider to use (:aws, :azure, :gcp, or :custom)\n* `:region` - Region to connect to\n* `:config` - Additional configuration for the connection","title":"Options - Raxol.Cloud.Integrations.get_service_connection/1","ref":"Raxol.Cloud.Integrations.html#get_service_connection/1-options"},{"type":"function","doc":"iex> get_service_connection(\n    ...>   service: :storage,\n    ...>   provider: :aws,\n    ...>   region: \"us-west-2\"\n    ...> )\n    {:ok, %{\n    ...>   client: client,\n    ...>   endpoint: \"s3.us-west-2.amazonaws.com\",\n    ...>   service: :storage,\n    ...>   provider: :aws\n    ...> }}","title":"Examples - Raxol.Cloud.Integrations.get_service_connection/1","ref":"Raxol.Cloud.Integrations.html#get_service_connection/1-examples"},{"type":"function","doc":"Initializes all cloud integrations with the provided configuration.","title":"Raxol.Cloud.Integrations.init/1","ref":"Raxol.Cloud.Integrations.html#init/1"},{"type":"function","doc":"* `:edge` - Options for edge computing (passed to EdgeComputing.init/1)\n* `:monitoring` - Options for monitoring system (passed to Monitoring.init/1)\n* `:providers` - List of cloud providers to enable [:aws, :azure, :gcp, :custom]\n* `:service_discovery` - Service discovery configuration\n* `:deployment` - Deployment and scaling configuration","title":"Options - Raxol.Cloud.Integrations.init/1","ref":"Raxol.Cloud.Integrations.html#init/1-options"},{"type":"function","doc":"iex> init(\n    ...>   edge: [mode: :auto, sync_interval: 30000],\n    ...>   monitoring: [backends: [:prometheus], active: true],\n    ...>   providers: [:aws]\n    ...> )\n    :ok","title":"Examples - Raxol.Cloud.Integrations.init/1","ref":"Raxol.Cloud.Integrations.html#init/1-examples"},{"type":"function","doc":"Registers the current application as a service in the service discovery system.","title":"Raxol.Cloud.Integrations.register_service/1","ref":"Raxol.Cloud.Integrations.html#register_service/1"},{"type":"function","doc":"* `:name` - Service name (required)\n* `:type` - Service type (required)\n* `:endpoint` - Service endpoint (required)\n* `:metadata` - Additional metadata about the service\n* `:health_check_path` - Path for health checks","title":"Options - Raxol.Cloud.Integrations.register_service/1","ref":"Raxol.Cloud.Integrations.html#register_service/1-options"},{"type":"function","doc":"iex> register_service(\n    ...>   name: \"user-api\",\n    ...>   type: :api,\n    ...>   endpoint: \"user-api.example.com:8080\",\n    ...>   health_check_path: \"/health\"\n    ...> )\n    {:ok, %{registration_id: \"reg-12345\", status: :registered}}","title":"Examples - Raxol.Cloud.Integrations.register_service/1","ref":"Raxol.Cloud.Integrations.html#register_service/1-examples"},{"type":"function","doc":"Scales a service based on current metrics and conditions.","title":"Raxol.Cloud.Integrations.scale/1","ref":"Raxol.Cloud.Integrations.html#scale/1"},{"type":"function","doc":"* `:service` - Service name to scale (required)\n* `:min` - Minimum number of instances\n* `:max` - Maximum number of instances\n* `:desired` - Desired number of instances (if specified, overrides automatic scaling)\n* `:metrics` - Metrics to use for scaling decisions","title":"Options - Raxol.Cloud.Integrations.scale/1","ref":"Raxol.Cloud.Integrations.html#scale/1-options"},{"type":"function","doc":"iex> scale(\n    ...>   service: \"api-server\",\n    ...>   min: 2,\n    ...>   max: 10,\n    ...>   metrics: [\n    ...>     %{name: \"cpu\", target: 70},\n    ...>     %{name: \"requests\", target: 1000}\n    ...>   ]\n    ...> )\n    {:ok, %{service: \"api-server\", current: 2, target: 4, status: :scaling}}","title":"Examples - Raxol.Cloud.Integrations.scale/1","ref":"Raxol.Cloud.Integrations.html#scale/1-examples"},{"type":"function","doc":"Returns the current status of all cloud integrations.","title":"Raxol.Cloud.Integrations.status/0","ref":"Raxol.Cloud.Integrations.html#status/0"},{"type":"function","doc":"iex> status()\n    %{\n      edge: %{mode: :auto, connected: true, ...},\n      monitoring: %{active: true, ...},\n      providers: %{aws: :connected, ...}\n    }","title":"Examples - Raxol.Cloud.Integrations.status/0","ref":"Raxol.Cloud.Integrations.html#status/0-examples"},{"type":"module","doc":"Cloud monitoring system for Raxol applications.\n\nThis module provides comprehensive monitoring capabilities for Raxol\napplications, including performance metrics, error tracking, usage statistics,\nand health checks.\n\nFeatures:\n* Performance monitoring and metrics collection\n* Error and exception tracking\n* Resource usage tracking\n* Health checks and status monitoring\n* Alerting and notification system\n* Integration with popular monitoring services","title":"Raxol.Cloud.Monitoring","ref":"Raxol.Cloud.Monitoring.html"},{"type":"function","doc":"Gets recent alerts.","title":"Raxol.Cloud.Monitoring.get_alerts/1","ref":"Raxol.Cloud.Monitoring.html#get_alerts/1"},{"type":"function","doc":"* `:limit` - Maximum number of alerts to return (default: 100)\n* `:since` - Only return alerts since this timestamp (default: 1 day ago)\n* `:until` - Only return alerts until this timestamp (default: now)\n* `:type` - Filter alerts by type\n* `:severity` - Filter alerts by severity","title":"Options - Raxol.Cloud.Monitoring.get_alerts/1","ref":"Raxol.Cloud.Monitoring.html#get_alerts/1-options"},{"type":"function","doc":"iex> get_alerts(limit: 10, severity: :critical)\n    [%{type: :high_cpu_usage, severity: :critical, ...}]","title":"Examples - Raxol.Cloud.Monitoring.get_alerts/1","ref":"Raxol.Cloud.Monitoring.html#get_alerts/1-examples"},{"type":"function","doc":"Gets recent errors.","title":"Raxol.Cloud.Monitoring.get_errors/1","ref":"Raxol.Cloud.Monitoring.html#get_errors/1"},{"type":"function","doc":"* `:limit` - Maximum number of errors to return (default: 100)\n* `:since` - Only return errors since this timestamp (default: 1 day ago)\n* `:until` - Only return errors until this timestamp (default: now)\n* `:severity` - Filter errors by severity\n* `:tags` - Filter errors by tags","title":"Options - Raxol.Cloud.Monitoring.get_errors/1","ref":"Raxol.Cloud.Monitoring.html#get_errors/1-options"},{"type":"function","doc":"iex> get_errors(limit: 10, severity: :critical)\n    [%{error: %RuntimeError{...}, severity: :critical, ...}]","title":"Examples - Raxol.Cloud.Monitoring.get_errors/1","ref":"Raxol.Cloud.Monitoring.html#get_errors/1-examples"},{"type":"function","doc":"Gets recent metrics for the specified metric name.","title":"Raxol.Cloud.Monitoring.get_metrics/2","ref":"Raxol.Cloud.Monitoring.html#get_metrics/2"},{"type":"function","doc":"* `:limit` - Maximum number of metrics to return (default: 100)\n* `:since` - Only return metrics since this timestamp (default: 1 hour ago)\n* `:until` - Only return metrics until this timestamp (default: now)\n* `:tags` - Filter metrics by tags","title":"Options - Raxol.Cloud.Monitoring.get_metrics/2","ref":"Raxol.Cloud.Monitoring.html#get_metrics/2-options"},{"type":"function","doc":"iex> get_metrics(\"response_time\", limit: 10, tags: [\"api\"])\n    [%{name: \"response_time\", value: 123, timestamp: ~U[2023-01-01 12:00:00Z], tags: [\"api\"]}]","title":"Examples - Raxol.Cloud.Monitoring.get_metrics/2","ref":"Raxol.Cloud.Monitoring.html#get_metrics/2-examples"},{"type":"function","doc":"Initializes the monitoring system.","title":"Raxol.Cloud.Monitoring.init/1","ref":"Raxol.Cloud.Monitoring.html#init/1"},{"type":"function","doc":"* `:active` - Whether monitoring should be active on start (default: true)\n* `:metrics_interval` - Interval in ms between metrics collection (default: 10000)\n* `:health_check_interval` - Interval in ms between health checks (default: 60000)\n* `:error_sample_rate` - Fraction of errors to track (0.0-1.0) (default: 1.0)\n* `:metrics_batch_size` - Number of metrics to batch before sending (default: 100)\n* `:backends` - List of monitoring service backends to use (default: [])\n* `:alert_thresholds` - Map of alert thresholds (default: see State.new)","title":"Options - Raxol.Cloud.Monitoring.init/1","ref":"Raxol.Cloud.Monitoring.html#init/1-options"},{"type":"function","doc":"iex> init(metrics_interval: 5000, backends: [:datadog, :prometheus])\n    :ok","title":"Examples - Raxol.Cloud.Monitoring.init/1","ref":"Raxol.Cloud.Monitoring.html#init/1-examples"},{"type":"function","doc":"Records an error or exception.","title":"Raxol.Cloud.Monitoring.record_error/2","ref":"Raxol.Cloud.Monitoring.html#record_error/2"},{"type":"function","doc":"* `:context` - Additional context information about the error\n* `:severity` - Severity level (:debug, :info, :warning, :error, :critical)\n* `:tags` - List of tags to associate with the error\n* `:timestamp` - Custom timestamp for the error (default: current time)","title":"Options - Raxol.Cloud.Monitoring.record_error/2","ref":"Raxol.Cloud.Monitoring.html#record_error/2-options"},{"type":"function","doc":"iex> record_error(%RuntimeError{message: \"Connection failed\"},\n    ...>   context: %{user_id: 123}, severity: :error)\n    :ok","title":"Examples - Raxol.Cloud.Monitoring.record_error/2","ref":"Raxol.Cloud.Monitoring.html#record_error/2-examples"},{"type":"function","doc":"Records a metric with the given name and value.","title":"Raxol.Cloud.Monitoring.record_metric/3","ref":"Raxol.Cloud.Monitoring.html#record_metric/3"},{"type":"function","doc":"* `:tags` - List of tags to associate with the metric\n* `:timestamp` - Custom timestamp for the metric (default: current time)\n* `:source` - Source of the metric (default: :application)","title":"Options - Raxol.Cloud.Monitoring.record_metric/3","ref":"Raxol.Cloud.Monitoring.html#record_metric/3-options"},{"type":"function","doc":"iex> record_metric(\"response_time\", 123, tags: [\"api\", \"users\"], source: :api)\n    :ok","title":"Examples - Raxol.Cloud.Monitoring.record_metric/3","ref":"Raxol.Cloud.Monitoring.html#record_metric/3-examples"},{"type":"function","doc":"Records a batch of metrics.","title":"Raxol.Cloud.Monitoring.record_metrics/1","ref":"Raxol.Cloud.Monitoring.html#record_metrics/1"},{"type":"function","doc":"iex> record_metrics([\n    ...>   {\"cpu_usage\", 0.75, [source: :system]},\n    ...>   {\"memory_usage\", 0.5, [source: :system]}\n    ...> ])\n    :ok","title":"Examples - Raxol.Cloud.Monitoring.record_metrics/1","ref":"Raxol.Cloud.Monitoring.html#record_metrics/1-examples"},{"type":"function","doc":"Runs a health check on the system.","title":"Raxol.Cloud.Monitoring.run_health_check/1","ref":"Raxol.Cloud.Monitoring.html#run_health_check/1"},{"type":"function","doc":"* `:components` - List of components to check (default: all)\n* `:timeout` - Timeout for health checks in milliseconds (default: 5000)","title":"Options - Raxol.Cloud.Monitoring.run_health_check/1","ref":"Raxol.Cloud.Monitoring.html#run_health_check/1-options"},{"type":"function","doc":"iex> run_health_check(components: [:database, :api])\n    {:ok, %{status: :healthy, components: %{database: :healthy, api: :healthy}}}","title":"Examples - Raxol.Cloud.Monitoring.run_health_check/1","ref":"Raxol.Cloud.Monitoring.html#run_health_check/1-examples"},{"type":"function","doc":"Starts the monitoring system if it's not already active.","title":"Raxol.Cloud.Monitoring.start/0","ref":"Raxol.Cloud.Monitoring.html#start/0"},{"type":"function","doc":"Gets the current monitoring status.","title":"Raxol.Cloud.Monitoring.status/0","ref":"Raxol.Cloud.Monitoring.html#status/0"},{"type":"function","doc":"Stops the monitoring system.","title":"Raxol.Cloud.Monitoring.stop/0","ref":"Raxol.Cloud.Monitoring.html#stop/0"},{"type":"function","doc":"Triggers an alert with the given type and data.","title":"Raxol.Cloud.Monitoring.trigger_alert/3","ref":"Raxol.Cloud.Monitoring.html#trigger_alert/3"},{"type":"function","doc":"* `:severity` - Severity level of the alert (default: :warning)\n* `:notify` - Whether to send notifications (default: true)","title":"Options - Raxol.Cloud.Monitoring.trigger_alert/3","ref":"Raxol.Cloud.Monitoring.html#trigger_alert/3-options"},{"type":"function","doc":"iex> trigger_alert(:high_cpu_usage, %{value: 0.95}, severity: :critical)\n    :ok","title":"Examples - Raxol.Cloud.Monitoring.trigger_alert/3","ref":"Raxol.Cloud.Monitoring.html#trigger_alert/3-examples"},{"type":"function","doc":"Updates the monitoring configuration.","title":"Raxol.Cloud.Monitoring.update_config/2","ref":"Raxol.Cloud.Monitoring.html#update_config/2"},{"type":"module","doc":"Centralized state management for Raxol cloud components.\n\nThis module provides a centralized way to store and retrieve state\nfor all cloud components, eliminating the need for Process.put/2\nand Process.get/1 in multiple modules.","title":"Raxol.Cloud.StateManager","ref":"Raxol.Cloud.StateManager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Cloud.StateManager.child_spec/1","ref":"Raxol.Cloud.StateManager.html#child_spec/1"},{"type":"function","doc":"Clears the state.","title":"Raxol.Cloud.StateManager.clear/1","ref":"Raxol.Cloud.StateManager.html#clear/1"},{"type":"function","doc":"Gets a value from the state.","title":"Raxol.Cloud.StateManager.get/2","ref":"Raxol.Cloud.StateManager.html#get/2"},{"type":"function","doc":"Gets the entire state.","title":"Raxol.Cloud.StateManager.get_all/1","ref":"Raxol.Cloud.StateManager.html#get_all/1"},{"type":"function","doc":"Puts a value in the state.","title":"Raxol.Cloud.StateManager.put/3","ref":"Raxol.Cloud.StateManager.html#put/3"},{"type":"function","doc":"Starts the state manager.","title":"Raxol.Cloud.StateManager.start_link/1","ref":"Raxol.Cloud.StateManager.html#start_link/1"},{"type":"function","doc":"Updates a value in the state.","title":"Raxol.Cloud.StateManager.update/3","ref":"Raxol.Cloud.StateManager.html#update/3"},{"type":"module","doc":"Provides base functionality and utilities for Raxol components.\n\nThis module contains shared functionality used across different components,\nincluding common validation, styling, and event handling patterns.","title":"Raxol.Components.Base","ref":"Raxol.Components.Base.html"},{"type":"function","doc":"Creates a base style for components with common properties.","title":"Raxol.Components.Base.base_style/1","ref":"Raxol.Components.Base.html#base_style/1"},{"type":"function","doc":"Handles common events like focus, blur, and keyboard navigation.\n\nShould be called from a component's handle_event callback.","title":"Raxol.Components.Base.handle_common_events/2","ref":"Raxol.Components.Base.html#handle_common_events/2"},{"type":"type","doc":"","title":"Raxol.Components.Base.state/0","ref":"Raxol.Components.Base.html#t:state/0"},{"type":"function","doc":"Validates component props against a schema.","title":"Raxol.Components.Base.validate_props/2","ref":"Raxol.Components.Base.html#validate_props/2"},{"type":"function","doc":"def validate_props(props) do\n      Base.validate_props(props, %{\n        required: [:label],\n        optional: [:style, :disabled],\n        types: %{\n          label: :string,\n          style: {:one_of, [:primary, :secondary, :danger]},\n          disabled: :boolean\n        }\n      })\n    end","title":"Example - Raxol.Components.Base.validate_props/2","ref":"Raxol.Components.Base.html#validate_props/2-example"},{"type":"module","doc":"A customizable button component.\n\nThis module provides a more sophisticated button component than the basic\nbutton element, with support for various styles and behaviors.","title":"Raxol.Components.Button","ref":"Raxol.Components.Button.html"},{"type":"module","doc":"```elixir\nalias Raxol.Components.Button\n\nButton.new(\"Save Changes\", on_click: :save_clicked, style: :primary)\n```","title":"Example - Raxol.Components.Button","ref":"Raxol.Components.Button.html#module-example"},{"type":"function","doc":"Creates a new button with the given label and options.","title":"Raxol.Components.Button.new/2","ref":"Raxol.Components.Button.html#new/2"},{"type":"function","doc":"* `:on_click` - Message to send when the button is clicked\n* `:style` - Button style (:primary, :secondary, :danger, :success, or a custom style map)\n* `:disabled` - Whether the button is disabled\n* `:icon` - Icon to display before the label\n* `:full_width` - Whether the button should take full width\n* `:size` - Button size (:small, :medium, :large)\n* `:tooltip` - Tooltip text to show on hover","title":"Options - Raxol.Components.Button.new/2","ref":"Raxol.Components.Button.html#new/2-options"},{"type":"function","doc":"A button component that can be used in a Raxol view.","title":"Returns - Raxol.Components.Button.new/2","ref":"Raxol.Components.Button.html#new/2-returns"},{"type":"function","doc":"```elixir\nButton.new(\"Delete\",\n  on_click: {:delete, item_id},\n  style: :danger,\n  icon: :trash\n)\n```","title":"Example - Raxol.Components.Button.new/2","ref":"Raxol.Components.Button.html#new/2-example"},{"type":"function","doc":"Renders the button as a basic element.\n\nThis is typically called by the renderer, not directly by users.","title":"Raxol.Components.Button.render/1","ref":"Raxol.Components.Button.html#render/1"},{"type":"type","doc":"","title":"Raxol.Components.Button.t/0","ref":"Raxol.Components.Button.html#t:t/0"},{"type":"module","doc":"Renders a block of code with syntax highlighting.\n\nRequires the `makeup_elixir` dependency (and potentially other lexers).\nUses HTML output from Makeup.","title":"Raxol.Components.CodeBlock","ref":"Raxol.Components.CodeBlock.html"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.broadcast/1","ref":"Raxol.Components.CodeBlock.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.command/1","ref":"Raxol.Components.CodeBlock.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.handle_event/3","ref":"Raxol.Components.CodeBlock.html#handle_event/3"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.init/1","ref":"Raxol.Components.CodeBlock.html#init/1"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.mount/1","ref":"Raxol.Components.CodeBlock.html#mount/1"},{"type":"function","doc":"Renders the code block.\n\nProps:\n  * `content` (required): The source code string.\n  * `language` (required): The language name (e.g., \"elixir\", \"html\").\n  * `style`: The Makeup HTML style module (e.g., `Makeup.Styles.GithubLight`). Defaults to `:github_light` style lookup.\n  * `class`: Optional CSS class for the outer `pre` tag.","title":"Raxol.Components.CodeBlock.render/2","ref":"Raxol.Components.CodeBlock.html#render/2"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.schedule/2","ref":"Raxol.Components.CodeBlock.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.unmount/1","ref":"Raxol.Components.CodeBlock.html#unmount/1"},{"type":"function","doc":"","title":"Raxol.Components.CodeBlock.update/2","ref":"Raxol.Components.CodeBlock.html#update/2"},{"type":"module","doc":"A component responsible for rendering a grid-based dashboard layout.\nManages widget placement, drag/drop, and resizing.","title":"Raxol.Components.Dashboard.Dashboard","ref":"Raxol.Components.Dashboard.Dashboard.html"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Dashboard.broadcast/1","ref":"Raxol.Components.Dashboard.Dashboard.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Dashboard.command/1","ref":"Raxol.Components.Dashboard.Dashboard.html#command/1"},{"type":"function","doc":"Initializes the Dashboard state from a saved layout.\nIf no saved layout exists, returns default widgets with the given grid configuration.\n\nThis function loads widget configurations using `LayoutPersistence.load_layout/0` and initializes\nthe dashboard model with those widgets and the provided grid_config.\n\nReturns {:ok, model} on success, or {:error, reason} on failure.","title":"Raxol.Components.Dashboard.Dashboard.init_from_saved_layout/2","ref":"Raxol.Components.Dashboard.Dashboard.html#init_from_saved_layout/2"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Dashboard.mount/1","ref":"Raxol.Components.Dashboard.Dashboard.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Dashboard.schedule/2","ref":"Raxol.Components.Dashboard.Dashboard.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Dashboard.unmount/1","ref":"Raxol.Components.Dashboard.Dashboard.html#unmount/1"},{"type":"function","doc":"Validates a list of widget configurations to ensure they can be properly rendered.\nReturns true if widgets are valid, false otherwise.","title":"Raxol.Components.Dashboard.Dashboard.validate_widgets/1","ref":"Raxol.Components.Dashboard.Dashboard.html#validate_widgets/1"},{"type":"module","doc":"State for the Dashboard component.","title":"Raxol.Components.Dashboard.Dashboard.Model","ref":"Raxol.Components.Dashboard.Dashboard.Model.html"},{"type":"module","doc":"Calculates layout bounds for widgets within a grid configuration.\nThis module provides functions to determine the position and size of widgets\nbased on a grid layout definition (columns, rows, gaps).","title":"Raxol.Components.Dashboard.GridContainer","ref":"Raxol.Components.Dashboard.GridContainer.html"},{"type":"function","doc":"Calculates the absolute bounds for a widget within a grid layout.\n\nParameters:\n  - `widget_config`: Map containing at least `grid_spec: %{col: integer(), row: integer(), col_span: integer(), row_span: integer()}`.\n  - `grid_config`: Map containing `parent_bounds: %{x: integer(), y: integer(), width: integer(), height: integer()}`,\n    and optionally `cols: integer()`, `rows: integer()`, `gap: integer()`.\n\nReturns:\n  - `%{x: integer(), y: integer(), width: integer(), height: integer()}` representing the absolute bounds.","title":"Raxol.Components.Dashboard.GridContainer.calculate_widget_bounds/2","ref":"Raxol.Components.Dashboard.GridContainer.html#calculate_widget_bounds/2"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.GridContainer.default_cols/0","ref":"Raxol.Components.Dashboard.GridContainer.html#default_cols/0"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.GridContainer.default_gap/0","ref":"Raxol.Components.Dashboard.GridContainer.html#default_gap/0"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.GridContainer.default_rows/0","ref":"Raxol.Components.Dashboard.GridContainer.html#default_rows/0"},{"type":"function","doc":"Calculates the dimensions of a single cell in the grid.\n\nParameters:\n  - `grid_config`: Map containing grid configuration including parent_bounds,\n    cols, rows, and gap.\n\nReturns:\n  - `{cell_width, cell_height}` tuple with the dimensions of a single cell.","title":"Raxol.Components.Dashboard.GridContainer.get_cell_dimensions/1","ref":"Raxol.Components.Dashboard.GridContainer.html#get_cell_dimensions/1"},{"type":"function","doc":"Resolves the effective grid parameters (cols, rows) based on breakpoints\ndefined in the grid configuration and the current parent width.\n\nParameters:\n  - `grid_config`: Map containing `parent_bounds: %{width: _}` and `breakpoints: %{...}`.\n                 Breakpoints map should have keys like `:small`, `:medium`, `:large`,\n                 with values like `%{max_width: _, cols: _, rows: _}` or just `%{cols: _, rows: _}`\n                 for the largest/default breakpoint.\n\nReturns:\n  - `%{cols: integer(), rows: integer()}`","title":"Raxol.Components.Dashboard.GridContainer.resolve_grid_params/1","ref":"Raxol.Components.Dashboard.GridContainer.html#resolve_grid_params/1"},{"type":"module","doc":"Handles saving and loading dashboard widget layouts to disk.","title":"Raxol.Components.Dashboard.LayoutPersistence","ref":"Raxol.Components.Dashboard.LayoutPersistence.html"},{"type":"function","doc":"Loads the widget layout from the file.\nReturns the list of widget configurations `[map()]` or `nil` if load fails or file doesn't exist.","title":"Raxol.Components.Dashboard.LayoutPersistence.load_layout/0","ref":"Raxol.Components.Dashboard.LayoutPersistence.html#load_layout/0"},{"type":"function","doc":"Saves the current widget layout (list of widget configs) to a file.\n\nOnly saves fields essential for reconstructing the layout and widget state:\n`:id`, `:type`, `:title`, `:grid_spec`, `:component_opts`, `:data`.","title":"Raxol.Components.Dashboard.LayoutPersistence.save_layout/1","ref":"Raxol.Components.Dashboard.LayoutPersistence.html#save_layout/1"},{"type":"module","doc":"A container component for dashboard widgets.\nProvides a frame, title bar (optional), and potentially drag/resize handles.\nRenders the actual widget content passed to it.","title":"Raxol.Components.Dashboard.WidgetContainer","ref":"Raxol.Components.Dashboard.WidgetContainer.html"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.WidgetContainer.broadcast/1","ref":"Raxol.Components.Dashboard.WidgetContainer.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.WidgetContainer.command/1","ref":"Raxol.Components.Dashboard.WidgetContainer.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.WidgetContainer.mount/1","ref":"Raxol.Components.Dashboard.WidgetContainer.html#mount/1"},{"type":"function","doc":"Renders the widget container frame and its content.\n\nRequires props:\n- `bounds`: %{x, y, width, height} - The absolute bounds calculated by GridContainer.\n- `widget_config`: The configuration map for the widget being rendered.\n                   Used for title, etc. (%{id: _, type: _, title: _, ...}).\n- `content`: The actual View element(s) representing the widget's content.","title":"Raxol.Components.Dashboard.WidgetContainer.render/2","ref":"Raxol.Components.Dashboard.WidgetContainer.html#render/2"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.WidgetContainer.schedule/2","ref":"Raxol.Components.Dashboard.WidgetContainer.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.WidgetContainer.unmount/1","ref":"Raxol.Components.Dashboard.WidgetContainer.html#unmount/1"},{"type":"module","doc":"A dashboard widget that displays a chart using Raxol.Components.Visualization.Chart.\nThis module is responsible for holding the chart's state (data, config)\nand providing a data structure for rendering, rather than rendering directly.","title":"Raxol.Components.Dashboard.Widgets.ChartWidget","ref":"Raxol.Components.Dashboard.Widgets.ChartWidget.html"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.ChartWidget.init/1","ref":"Raxol.Components.Dashboard.Widgets.ChartWidget.html#init/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.ChartWidget.render_data_structure/1","ref":"Raxol.Components.Dashboard.Widgets.ChartWidget.html#render_data_structure/1"},{"type":"module","doc":"A dashboard widget that displays simple text information.","title":"Raxol.Components.Dashboard.Widgets.InfoWidget","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.broadcast/1","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.command/1","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.mount/1","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.schedule/2","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.InfoWidget.unmount/1","ref":"Raxol.Components.Dashboard.Widgets.InfoWidget.html#unmount/1"},{"type":"module","doc":"A dashboard widget that displays a treemap using Raxol.Components.Visualization.TreeMap.\nThis module is responsible for holding the treemap's state (data, config)\nand providing a data structure for rendering, rather than rendering directly.","title":"Raxol.Components.Dashboard.Widgets.TreeMapWidget","ref":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.html"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.init/1","ref":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.html#init/1"},{"type":"function","doc":"","title":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.render_data_structure/1","ref":"Raxol.Components.Dashboard.Widgets.TreeMapWidget.html#render_data_structure/1"},{"type":"module","doc":"Handles drawing the focus ring around focused components.\n\nThis component dynamically styles the focus ring based on:\n- Component state (focused, active, disabled)\n- User preferences (high contrast, reduced motion)\n- Theming settings\n- Animation effects","title":"Raxol.Components.FocusRing","ref":"Raxol.Components.FocusRing.html"},{"type":"function","doc":"","title":"Raxol.Components.FocusRing.broadcast/1","ref":"Raxol.Components.FocusRing.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.FocusRing.command/1","ref":"Raxol.Components.FocusRing.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.FocusRing.mount/1","ref":"Raxol.Components.FocusRing.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.FocusRing.schedule/2","ref":"Raxol.Components.FocusRing.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.FocusRing.unmount/1","ref":"Raxol.Components.FocusRing.html#unmount/1"},{"type":"module","doc":"Displays contextual hints and keyboard shortcuts.","title":"Raxol.Components.HintDisplay","ref":"Raxol.Components.HintDisplay.html"},{"type":"function","doc":"","title":"Raxol.Components.HintDisplay.broadcast/1","ref":"Raxol.Components.HintDisplay.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.HintDisplay.command/1","ref":"Raxol.Components.HintDisplay.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.HintDisplay.mount/1","ref":"Raxol.Components.HintDisplay.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.HintDisplay.schedule/2","ref":"Raxol.Components.HintDisplay.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.HintDisplay.unmount/1","ref":"Raxol.Components.HintDisplay.html#unmount/1"},{"type":"module","doc":"Helper for clipboard operations (copy/cut/paste) in MultiLineInput.","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html"},{"type":"function","doc":"Copies the currently selected text to the clipboard.\nReturns a tuple with the state (unchanged) and a list of commands to execute.","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.copy_selection/1","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html#copy_selection/1"},{"type":"function","doc":"Cuts the selected text (copies then deletes).\nReturns a tuple with the updated state and a list of commands to execute.","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.cut_selection/1","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html#cut_selection/1"},{"type":"function","doc":"Initiates a paste operation from clipboard.\nReturns a tuple with the state (unchanged) and a command to read from clipboard.","title":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.paste/1","ref":"Raxol.Components.Input.MultiLineInput.ClipboardHelper.html#paste/1"},{"type":"module","doc":"A simple single-line text input component.","title":"Raxol.Components.Input.SingleLineInput","ref":"Raxol.Components.Input.SingleLineInput.html"},{"type":"function","doc":"","title":"Raxol.Components.Input.SingleLineInput.broadcast/1","ref":"Raxol.Components.Input.SingleLineInput.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Input.SingleLineInput.command/1","ref":"Raxol.Components.Input.SingleLineInput.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Input.SingleLineInput.mount/1","ref":"Raxol.Components.Input.SingleLineInput.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Input.SingleLineInput.schedule/2","ref":"Raxol.Components.Input.SingleLineInput.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Input.SingleLineInput.unmount/1","ref":"Raxol.Components.Input.SingleLineInput.html#unmount/1"},{"type":"module","doc":"A text input component for single-line text entry.\n\nFeatures:\n* Cursor management\n* Text selection\n* Copy/paste support\n* Password masking\n* Placeholder text","title":"Raxol.Components.Input.TextInput","ref":"Raxol.Components.Input.TextInput.html"},{"type":"function","doc":"","title":"Raxol.Components.Input.TextInput.broadcast/1","ref":"Raxol.Components.Input.TextInput.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Input.TextInput.command/1","ref":"Raxol.Components.Input.TextInput.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Input.TextInput.mount/1","ref":"Raxol.Components.Input.TextInput.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Input.TextInput.schedule/2","ref":"Raxol.Components.Input.TextInput.html#schedule/2"},{"type":"type","doc":"","title":"Raxol.Components.Input.TextInput.state/0","ref":"Raxol.Components.Input.TextInput.html#t:state/0"},{"type":"function","doc":"","title":"Raxol.Components.Input.TextInput.unmount/1","ref":"Raxol.Components.Input.TextInput.html#unmount/1"},{"type":"module","doc":"Handles text manipulation operations for the TextInput component.\nThis includes inserting, deleting, and pasting text.","title":"Raxol.Components.Input.TextInput.Manipulation","ref":"Raxol.Components.Input.TextInput.Manipulation.html"},{"type":"function","doc":"Deletes the character before the cursor.","title":"Raxol.Components.Input.TextInput.Manipulation.delete_char_backward/1","ref":"Raxol.Components.Input.TextInput.Manipulation.html#delete_char_backward/1"},{"type":"function","doc":"Deletes a character forward from the current cursor position.","title":"Raxol.Components.Input.TextInput.Manipulation.delete_char_forward/1","ref":"Raxol.Components.Input.TextInput.Manipulation.html#delete_char_forward/1"},{"type":"function","doc":"Deletes the selected text and updates the cursor position.","title":"Raxol.Components.Input.TextInput.Manipulation.delete_selected_text/3","ref":"Raxol.Components.Input.TextInput.Manipulation.html#delete_selected_text/3"},{"type":"function","doc":"Inserts a character at the current cursor position.","title":"Raxol.Components.Input.TextInput.Manipulation.insert_char/2","ref":"Raxol.Components.Input.TextInput.Manipulation.html#insert_char/2"},{"type":"function","doc":"Pastes text at the specified position, optionally replacing selected text.","title":"Raxol.Components.Input.TextInput.Manipulation.paste_at_position/4","ref":"Raxol.Components.Input.TextInput.Manipulation.html#paste_at_position/4"},{"type":"module","doc":"Handles rendering logic for the TextInput component.\nThis includes display value formatting, style management, and visual feedback.","title":"Raxol.Components.Input.TextInput.Renderer","ref":"Raxol.Components.Input.TextInput.Renderer.html"},{"type":"function","doc":"Renders the text input component with appropriate styling and visual feedback.","title":"Raxol.Components.Input.TextInput.Renderer.render/1","ref":"Raxol.Components.Input.TextInput.Renderer.html#render/1"},{"type":"module","doc":"Handles cursor and text selection operations for the TextInput component.\nThis includes cursor movement, text selection, and selection clearing.","title":"Raxol.Components.Input.TextInput.Selection","ref":"Raxol.Components.Input.TextInput.Selection.html"},{"type":"function","doc":"Clears any existing text selection.","title":"Raxol.Components.Input.TextInput.Selection.clear_selection/1","ref":"Raxol.Components.Input.TextInput.Selection.html#clear_selection/1"},{"type":"function","doc":"Gets the currently selected text, if any.","title":"Raxol.Components.Input.TextInput.Selection.get_selected_text/1","ref":"Raxol.Components.Input.TextInput.Selection.html#get_selected_text/1"},{"type":"function","doc":"Moves the cursor by the specified offset, ensuring it stays within bounds.","title":"Raxol.Components.Input.TextInput.Selection.move_cursor/2","ref":"Raxol.Components.Input.TextInput.Selection.html#move_cursor/2"},{"type":"function","doc":"Moves the cursor to the end of the text.","title":"Raxol.Components.Input.TextInput.Selection.move_to_end/1","ref":"Raxol.Components.Input.TextInput.Selection.html#move_to_end/1"},{"type":"function","doc":"Moves the cursor to the start of the text.","title":"Raxol.Components.Input.TextInput.Selection.move_to_home/1","ref":"Raxol.Components.Input.TextInput.Selection.html#move_to_home/1"},{"type":"function","doc":"Extends or creates a text selection by moving the cursor.","title":"Raxol.Components.Input.TextInput.Selection.select_text/2","ref":"Raxol.Components.Input.TextInput.Selection.html#select_text/2"},{"type":"function","doc":"Selects text from the current cursor position to the end of the text.","title":"Raxol.Components.Input.TextInput.Selection.select_to_end/1","ref":"Raxol.Components.Input.TextInput.Selection.html#select_to_end/1"},{"type":"function","doc":"Selects text from the current cursor position to the start of the text.","title":"Raxol.Components.Input.TextInput.Selection.select_to_home/1","ref":"Raxol.Components.Input.TextInput.Selection.html#select_to_home/1"},{"type":"module","doc":"Handles input validation for the TextInput component.\nThis includes length validation, pattern matching, and error message generation.","title":"Raxol.Components.Input.TextInput.Validation","ref":"Raxol.Components.Input.TextInput.Validation.html"},{"type":"function","doc":"Validates the input value against the component's constraints.\nReturns a new state with any validation errors.","title":"Raxol.Components.Input.TextInput.Validation.validate_input/1","ref":"Raxol.Components.Input.TextInput.Validation.html#validate_input/1"},{"type":"function","doc":"Validates a value's length against a maximum.\nReturns :ok if valid, {:error, reason} if invalid.","title":"Raxol.Components.Input.TextInput.Validation.validate_length/2","ref":"Raxol.Components.Input.TextInput.Validation.html#validate_length/2"},{"type":"function","doc":"Validates a value against a pattern.\nReturns :ok if valid, {:error, reason} if invalid.","title":"Raxol.Components.Input.TextInput.Validation.validate_pattern/2","ref":"Raxol.Components.Input.TextInput.Validation.html#validate_pattern/2"},{"type":"function","doc":"Checks if adding text would exceed the maximum length.","title":"Raxol.Components.Input.TextInput.Validation.would_exceed_max_length?/2","ref":"Raxol.Components.Input.TextInput.Validation.html#would_exceed_max_length?/2"},{"type":"module","doc":"Utility functions for text wrapping.","title":"Raxol.Components.Input.TextWrapping","ref":"Raxol.Components.Input.TextWrapping.html"},{"type":"function","doc":"Wraps a single line of text by character count using recursion.\n\nHandles multi-byte characters correctly.","title":"Raxol.Components.Input.TextWrapping.wrap_line_by_char/2","ref":"Raxol.Components.Input.TextWrapping.html#wrap_line_by_char/2"},{"type":"function","doc":"Wraps a single line of text by word boundaries.","title":"Raxol.Components.Input.TextWrapping.wrap_line_by_word/2","ref":"Raxol.Components.Input.TextWrapping.html#wrap_line_by_word/2"},{"type":"module","doc":"Renders Markdown text into Raxol elements or raw HTML.\n\nRequires the `earmark` dependency.","title":"Raxol.Components.MarkdownRenderer","ref":"Raxol.Components.MarkdownRenderer.html"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.broadcast/1","ref":"Raxol.Components.MarkdownRenderer.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.command/1","ref":"Raxol.Components.MarkdownRenderer.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.handle_event/3","ref":"Raxol.Components.MarkdownRenderer.html#handle_event/3"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.init/1","ref":"Raxol.Components.MarkdownRenderer.html#init/1"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.mount/1","ref":"Raxol.Components.MarkdownRenderer.html#mount/1"},{"type":"function","doc":"Renders the given Markdown string.","title":"Raxol.Components.MarkdownRenderer.render/2","ref":"Raxol.Components.MarkdownRenderer.html#render/2"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.schedule/2","ref":"Raxol.Components.MarkdownRenderer.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.unmount/1","ref":"Raxol.Components.MarkdownRenderer.html#unmount/1"},{"type":"function","doc":"","title":"Raxol.Components.MarkdownRenderer.update/2","ref":"Raxol.Components.MarkdownRenderer.html#update/2"},{"type":"module","doc":"A modal component for displaying overlay dialogs like alerts, prompts, confirmations, and forms.","title":"Raxol.Components.Modal","ref":"Raxol.Components.Modal.html"},{"type":"function","doc":"Creates props for an alert modal.","title":"Raxol.Components.Modal.alert/4","ref":"Raxol.Components.Modal.html#alert/4"},{"type":"function","doc":"","title":"Raxol.Components.Modal.broadcast/1","ref":"Raxol.Components.Modal.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Modal.command/1","ref":"Raxol.Components.Modal.html#command/1"},{"type":"function","doc":"Creates props for a confirmation modal.","title":"Raxol.Components.Modal.confirm/6","ref":"Raxol.Components.Modal.html#confirm/6"},{"type":"function","doc":"Creates props for a form modal.\n\n`fields` should be a list of maps, each defining a form field:\n`%{id: :atom, type: :text_input | :checkbox | :dropdown, label: \"string\", value: initial_value, props: keyword_list, options: list, validate: regex | function}`\n(options only for dropdown)","title":"Raxol.Components.Modal.form/6","ref":"Raxol.Components.Modal.html#form/6"},{"type":"function","doc":"","title":"Raxol.Components.Modal.mount/1","ref":"Raxol.Components.Modal.html#mount/1"},{"type":"function","doc":"Creates props for a prompt modal.","title":"Raxol.Components.Modal.prompt/6","ref":"Raxol.Components.Modal.html#prompt/6"},{"type":"function","doc":"","title":"Raxol.Components.Modal.schedule/2","ref":"Raxol.Components.Modal.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Modal.unmount/1","ref":"Raxol.Components.Modal.html#unmount/1"},{"type":"module","doc":"Provides components for displaying progress, like progress bars and spinners.","title":"Raxol.Components.Progress","ref":"Raxol.Components.Progress.html"},{"type":"function","doc":"Renders a simple progress bar with configurable appearance.","title":"Raxol.Components.Progress.bar/2","ref":"Raxol.Components.Progress.html#bar/2"},{"type":"function","doc":"* `value` - Current progress value (0.0 to 1.0)\n* `opts` - Options for customizing the progress bar","title":"Parameters - Raxol.Components.Progress.bar/2","ref":"Raxol.Components.Progress.html#bar/2-parameters"},{"type":"function","doc":"* `:id` - Unique identifier for the progress bar (default: \"progress_bar\")\n* `:width` - Width of the progress bar in characters (default: 20)\n* `:style` - Style for the progress bar container\n* `:filled_style` - Style for the filled portion of the bar (default: %{bg: :blue})\n* `:empty_style` - Style for the empty portion of the bar (default: %{bg: :black})\n* `:chars` - Characters to use for different parts of the bar\n  * `:filled` - Character for filled sections (default: \" \")\n  * `:empty` - Character for empty sections (default: \" \")","title":"Options - Raxol.Components.Progress.bar/2","ref":"Raxol.Components.Progress.html#bar/2-options"},{"type":"function","doc":"A view element representing the progress bar.","title":"Returns - Raxol.Components.Progress.bar/2","ref":"Raxol.Components.Progress.html#bar/2-returns"},{"type":"function","doc":"```elixir\nProgress.bar(\n  0.75,\n  width: 30,\n  filled_style: %{bg: :green},\n  chars: %{filled: \"█\", empty: \"░\"}\n)\n```","title":"Example - Raxol.Components.Progress.bar/2","ref":"Raxol.Components.Progress.html#bar/2-example"},{"type":"function","doc":"Renders a progress bar with a label and optional percentage display.","title":"Raxol.Components.Progress.bar_with_label/3","ref":"Raxol.Components.Progress.html#bar_with_label/3"},{"type":"function","doc":"* `value` - Current progress value (0.0 to 1.0)\n* `label` - Text label to display\n* `opts` - Options for customizing the progress bar","title":"Parameters - Raxol.Components.Progress.bar_with_label/3","ref":"Raxol.Components.Progress.html#bar_with_label/3-parameters"},{"type":"function","doc":"All options from `bar/2` plus:\n* `:show_percentage` - Whether to show percentage (default: true)\n* `:percentage_style` - Style for the percentage text (default: %{})\n* `:label_style` - Style for the label text (default: %{})\n* `:position` - Position of the label/percentage (:above, :below, :right, default: :above)","title":"Options - Raxol.Components.Progress.bar_with_label/3","ref":"Raxol.Components.Progress.html#bar_with_label/3-options"},{"type":"function","doc":"A view element representing the progress bar with label.","title":"Returns - Raxol.Components.Progress.bar_with_label/3","ref":"Raxol.Components.Progress.html#bar_with_label/3-returns"},{"type":"function","doc":"```elixir\nProgress.bar_with_label(\n  0.35,\n  \"Loading assets...\",\n  show_percentage: true,\n  position: :below,\n  filled_style: %{bg: :cyan}\n)\n```","title":"Example - Raxol.Components.Progress.bar_with_label/3","ref":"Raxol.Components.Progress.html#bar_with_label/3-example"},{"type":"function","doc":"","title":"Raxol.Components.Progress.broadcast/1","ref":"Raxol.Components.Progress.html#broadcast/1"},{"type":"function","doc":"Renders a circular progress indicator.","title":"Raxol.Components.Progress.circular/2","ref":"Raxol.Components.Progress.html#circular/2"},{"type":"function","doc":"* `value` - Current progress value (0.0 to 1.0)\n* `opts` - Options for customizing the progress indicator","title":"Parameters - Raxol.Components.Progress.circular/2","ref":"Raxol.Components.Progress.html#circular/2-parameters"},{"type":"function","doc":"* `:id` - Unique identifier for the indicator (default: \"circular_progress\")\n* `:style` - Style for the indicator\n* `:show_percentage` - Whether to show percentage inside (default: true)\n* `:percentage_style` - Style for the percentage text","title":"Options - Raxol.Components.Progress.circular/2","ref":"Raxol.Components.Progress.html#circular/2-options"},{"type":"function","doc":"A view element representing the circular progress indicator.","title":"Returns - Raxol.Components.Progress.circular/2","ref":"Raxol.Components.Progress.html#circular/2-returns"},{"type":"function","doc":"```elixir\nProgress.circular(\n  0.65,\n  style: %{fg: :green}\n)\n```","title":"Example - Raxol.Components.Progress.circular/2","ref":"Raxol.Components.Progress.html#circular/2-example"},{"type":"function","doc":"","title":"Raxol.Components.Progress.command/1","ref":"Raxol.Components.Progress.html#command/1"},{"type":"function","doc":"Renders an indeterminate progress bar (animated).","title":"Raxol.Components.Progress.indeterminate/2","ref":"Raxol.Components.Progress.html#indeterminate/2"},{"type":"function","doc":"* `frame` - Current animation frame (integer, typically incremented on each render)\n* `opts` - Options for customizing the indeterminate progress bar","title":"Parameters - Raxol.Components.Progress.indeterminate/2","ref":"Raxol.Components.Progress.html#indeterminate/2-parameters"},{"type":"function","doc":"* `:id` - Unique identifier for the progress bar (default: \"indeterminate_progress\")\n* `:width` - Width of the progress bar in characters (default: 20)\n* `:style` - Style for the progress bar container\n* `:bar_style` - Style for the animated bar (default: %{bg: :blue})\n* `:background_style` - Style for the background (default: %{bg: :black})\n* `:segment_size` - Size of the animated segment (default: 5)","title":"Options - Raxol.Components.Progress.indeterminate/2","ref":"Raxol.Components.Progress.html#indeterminate/2-options"},{"type":"function","doc":"A view element representing the indeterminate progress bar.","title":"Returns - Raxol.Components.Progress.indeterminate/2","ref":"Raxol.Components.Progress.html#indeterminate/2-returns"},{"type":"function","doc":"```elixir\nProgress.indeterminate(\n  model.animation_frame,\n  width: 30,\n  bar_style: %{bg: :purple},\n  segment_size: 8\n)\n```","title":"Example - Raxol.Components.Progress.indeterminate/2","ref":"Raxol.Components.Progress.html#indeterminate/2-example"},{"type":"function","doc":"","title":"Raxol.Components.Progress.mount/1","ref":"Raxol.Components.Progress.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.schedule/2","ref":"Raxol.Components.Progress.html#schedule/2"},{"type":"function","doc":"Renders a spinner animation for indicating loading or processing.","title":"Raxol.Components.Progress.spinner/3","ref":"Raxol.Components.Progress.html#spinner/3"},{"type":"function","doc":"* `message` - Optional message to display next to the spinner\n* `frame` - Current animation frame (integer, typically incremented on each render)\n* `opts` - Options for customizing the spinner","title":"Parameters - Raxol.Components.Progress.spinner/3","ref":"Raxol.Components.Progress.html#spinner/3-parameters"},{"type":"function","doc":"* `:id` - Unique identifier for the spinner (default: \"spinner\")\n* `:style` - Style for the spinner container\n* `:spinner_style` - Style for the spinner character\n* `:message_style` - Style for the message text\n* `:type` - Type of spinner animation (default: :dots)","title":"Options - Raxol.Components.Progress.spinner/3","ref":"Raxol.Components.Progress.html#spinner/3-options"},{"type":"function","doc":"A view element representing the spinner.","title":"Returns - Raxol.Components.Progress.spinner/3","ref":"Raxol.Components.Progress.html#spinner/3-returns"},{"type":"function","doc":"```elixir\n# In your update function, increment the frame on each update\ndef update(model, :tick) do\n  %{model | spinner_frame: model.spinner_frame + 1}\nend\n\n# In your view function\nProgress.spinner(\n  \"Processing data...\",\n  model.spinner_frame,\n  type: :braille,\n  spinner_style: %{fg: :cyan}\n)\n```","title":"Example - Raxol.Components.Progress.spinner/3","ref":"Raxol.Components.Progress.html#spinner/3-example"},{"type":"function","doc":"Returns the available spinner types.","title":"Raxol.Components.Progress.spinner_types/0","ref":"Raxol.Components.Progress.html#spinner_types/0"},{"type":"function","doc":"A map of spinner types to their frame sequences.","title":"Returns - Raxol.Components.Progress.spinner_types/0","ref":"Raxol.Components.Progress.html#spinner_types/0-returns"},{"type":"function","doc":"```elixir\nspinner_types = Progress.spinner_types()\n```","title":"Example - Raxol.Components.Progress.spinner_types/0","ref":"Raxol.Components.Progress.html#spinner_types/0-example"},{"type":"function","doc":"","title":"Raxol.Components.Progress.unmount/1","ref":"Raxol.Components.Progress.html#unmount/1"},{"type":"module","doc":"A component to display a progress bar.","title":"Raxol.Components.Progress.ProgressBar","ref":"Raxol.Components.Progress.ProgressBar.html"},{"type":"function","doc":"","title":"Raxol.Components.Progress.ProgressBar.broadcast/1","ref":"Raxol.Components.Progress.ProgressBar.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.ProgressBar.command/1","ref":"Raxol.Components.Progress.ProgressBar.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.ProgressBar.mount/1","ref":"Raxol.Components.Progress.ProgressBar.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.ProgressBar.schedule/2","ref":"Raxol.Components.Progress.ProgressBar.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Progress.ProgressBar.unmount/1","ref":"Raxol.Components.Progress.ProgressBar.html#unmount/1"},{"type":"module","doc":"A spinner component that provides animated loading indicators.","title":"Raxol.Components.Progress.Spinner","ref":"Raxol.Components.Progress.Spinner.html"},{"type":"module","doc":"* `:style` - The animation style to use (default: :dots)\n  * `:dots` - Rotating dots (⠋⠙⠹⠸⠼⠴⠦⠧⠇⠏)\n  * `:line` - Rotating line (|/-\\)\n  * `:bounce` - Bouncing ball (⠁⠂⠄⠂)\n  * `:pulse` - Pulsing circle (●○)\n  * `:custom` - Custom animation using `:frames`\n  * `:frames` - List of characters to use for custom animation\n  * `:colors` - List of colors to transition between\n  * `:speed` - Animation speed in milliseconds (default: 80)\n  * `:text` - Optional text to display next to the spinner\n  * `:text_position` - Position of text relative to spinner (:left or :right, default: :right)","title":"Props - Raxol.Components.Progress.Spinner","ref":"Raxol.Components.Progress.Spinner.html#module-props"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.broadcast/1","ref":"Raxol.Components.Progress.Spinner.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.command/1","ref":"Raxol.Components.Progress.Spinner.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.error/1","ref":"Raxol.Components.Progress.Spinner.html#error/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.loading/1","ref":"Raxol.Components.Progress.Spinner.html#loading/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.mount/1","ref":"Raxol.Components.Progress.Spinner.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.processing/1","ref":"Raxol.Components.Progress.Spinner.html#processing/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.saving/1","ref":"Raxol.Components.Progress.Spinner.html#saving/1"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.schedule/2","ref":"Raxol.Components.Progress.Spinner.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Progress.Spinner.unmount/1","ref":"Raxol.Components.Progress.Spinner.html#unmount/1"},{"type":"module","doc":"A dropdown component that allows selecting one option from a list.","title":"Raxol.Components.Selection.Dropdown","ref":"Raxol.Components.Selection.Dropdown.html"},{"type":"function","doc":"","title":"Raxol.Components.Selection.Dropdown.broadcast/1","ref":"Raxol.Components.Selection.Dropdown.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Selection.Dropdown.command/1","ref":"Raxol.Components.Selection.Dropdown.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Selection.Dropdown.mount/1","ref":"Raxol.Components.Selection.Dropdown.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Selection.Dropdown.schedule/2","ref":"Raxol.Components.Selection.Dropdown.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Selection.Dropdown.unmount/1","ref":"Raxol.Components.Selection.Dropdown.html#unmount/1"},{"type":"module","doc":"A component for displaying a selectable list of items.","title":"Raxol.Components.Selection.List","ref":"Raxol.Components.Selection.List.html"},{"type":"function","doc":"","title":"Raxol.Components.Selection.List.broadcast/1","ref":"Raxol.Components.Selection.List.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Selection.List.command/1","ref":"Raxol.Components.Selection.List.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Selection.List.mount/1","ref":"Raxol.Components.Selection.List.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Selection.List.schedule/2","ref":"Raxol.Components.Selection.List.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Selection.List.unmount/1","ref":"Raxol.Components.Selection.List.html#unmount/1"},{"type":"module","doc":"A tab bar component for Raxol.\n\nA tab bar component for navigating between different sections of a UI.","title":"Raxol.Components.TabBar","ref":"Raxol.Components.TabBar.html"},{"type":"module","doc":"```elixir\nalias Raxol.Components.TabBar\n\n# In your view function\ndef view(model) do\n  tabs = [\n    %{id: :dashboard, label: \"Dashboard\"},\n    %{id: :settings, label: \"Settings\"},\n    %{id: :help, label: \"Help\"}\n  ]\n\n  view do\n    panel do\n      TabBar.render(tabs, model.active_tab, &handle_tab_change/2)\n\n      # Content based on active tab\n      case model.active_tab do\n        :dashboard -> dashboard_view(model)\n        :settings -> settings_view(model)\n        :help -> help_view(model)\n      end\n    end\n  end\nend\n\n# Handler function\ndef handle_tab_change(model, tab_id) do\n  %{model | active_tab: tab_id}\nend\n\n@behaviour Raxol.ComponentBehaviour\n\n@doc \"\"\"\nRenders a tab bar with the given tabs, highlighting the active tab.","title":"Examples - Raxol.Components.TabBar","ref":"Raxol.Components.TabBar.html#module-examples"},{"type":"module","doc":"* `tabs` - A list of tab maps, each containing `:id` and `:label` keys\n* `active_tab` - The ID of the currently active tab\n* `on_change` - A function that takes the model and a tab ID and returns an updated model\n* `opts` - Options for customizing the tab bar appearance","title":"Parameters - Raxol.Components.TabBar","ref":"Raxol.Components.TabBar.html#module-parameters"},{"type":"module","doc":"* `:focus_key` - Key for focusing the tab bar (default: \"tab_bar\")\n* `:style` - Style for the tab bar (default: %{})\n* `:tab_style` - Style for individual tabs (default: %{})\n* `:active_tab_style` - Style for the active tab (default: %{fg: :white, bg: :blue})","title":"Options - Raxol.Components.TabBar","ref":"Raxol.Components.TabBar.html#module-options"},{"type":"module","doc":"A view element representing the tab bar.","title":"Returns - Raxol.Components.TabBar","ref":"Raxol.Components.TabBar.html#module-returns"},{"type":"module","doc":"```elixir\nTabBar.render(\n  [\n    %{id: :tab1, label: \"First Tab\"},\n    %{id: :tab2, label: \"Second Tab\"}\n  ],\n  :tab1,\n  &handle_tab_change/2,\n  active_tab_style: %{fg: :white, bg: :green}\n)\n```","title":"Example - Raxol.Components.TabBar","ref":"Raxol.Components.TabBar.html#module-example"},{"type":"function","doc":"","title":"Raxol.Components.TabBar.render/4","ref":"Raxol.Components.TabBar.html#render/4"},{"type":"function","doc":"Creates a tabbed interface with content.\n\nThis is a higher-level component that combines the tab bar with\ncontent areas for each tab.","title":"Raxol.Components.TabBar.tabbed_view/4","ref":"Raxol.Components.TabBar.html#tabbed_view/4"},{"type":"function","doc":"* `tabs` - A list of tab maps, each containing `:id`, `:label`, and `:content` keys\n* `active_tab` - The ID of the currently active tab\n* `on_change` - A function that takes the model and a tab ID and returns an updated model\n* `opts` - Options for customizing the tabbed interface","title":"Parameters - Raxol.Components.TabBar.tabbed_view/4","ref":"Raxol.Components.TabBar.html#tabbed_view/4-parameters"},{"type":"function","doc":"* `:focus_key` - Key for focusing the tabbed interface (default: \"tabbed_view\")\n* `:style` - Style for the container (default: %{})\n* `:tab_bar_style` - Style for the tab bar (default: %{})\n* `:tab_style` - Style for individual tabs (default: %{})\n* `:active_tab_style` - Style for the active tab (default: %{fg: :white, bg: :blue})\n* `:content_style` - Style for the content area (default: %{})","title":"Options - Raxol.Components.TabBar.tabbed_view/4","ref":"Raxol.Components.TabBar.html#tabbed_view/4-options"},{"type":"function","doc":"A view element representing the complete tabbed interface.","title":"Returns - Raxol.Components.TabBar.tabbed_view/4","ref":"Raxol.Components.TabBar.html#tabbed_view/4-returns"},{"type":"function","doc":"```elixir\nTabBar.tabbed_view(\n  [\n    %{id: :tab1, label: \"First Tab\", content: fn -> View.text(\"First tab content\") end},\n    %{id: :tab2, label: \"Second Tab\", content: fn -> View.text(\"Second tab content\") end}\n  ],\n  :tab1,\n  &handle_tab_change/2\n)\n```","title":"Example - Raxol.Components.TabBar.tabbed_view/4","ref":"Raxol.Components.TabBar.html#tabbed_view/4-example"},{"type":"module","doc":"Table component for displaying and interacting with tabular data.","title":"Raxol.Components.Table","ref":"Raxol.Components.Table.html"},{"type":"module","doc":"* Pagination\n* Sorting\n* Filtering\n* Custom column formatting\n* Row selection\n* **Custom theming and styling** (see below)","title":"Features - Raxol.Components.Table","ref":"Raxol.Components.Table.html#module-features"},{"type":"module","doc":"","title":"Public API - Raxol.Components.Table","ref":"Raxol.Components.Table.html#module-public-api"},{"type":"module","doc":"- `:id` (required): Unique identifier for the table.\n- `:columns` (required): List of column definitions. Each column is a map with:\n  - `:id` (atom, required): Key for the column.\n  - `:label` (string, required): Header label.\n  - `:width` (integer or `:auto`, optional): Column width.\n  - `:align` (`:left` | `:center` | `:right`, optional): Text alignment.\n  - `:format` (function, optional): Custom formatting function for cell values.\n  - `:style` (map, optional): Style overrides for all cells in this column.\n  - `:header_style` (map, optional): Style overrides for this column's header cell.\n- `:data` (required): List of row maps (each map must have keys matching column ids).\n- `:options` (map, optional):\n  - `:paginate` (boolean): Enable pagination.\n  - `:searchable` (boolean): Enable filtering.\n  - `:sortable` (boolean): Enable sorting.\n  - `:page_size` (integer): Rows per page.\n- `:style` (map, optional): Style overrides for the table box and header (see below).\n  - `:header` (map, optional): Style overrides for all header cells.\n- `:theme` (map, optional): Theme map for the table. Keys can include:\n  - `:box` (map): Style for the outer box.\n  - `:header` (map): Style for all header cells.\n  - `:row` (map): Style for all rows.\n  - `:selected_row` (map): Style for the selected row.","title":"Props - Raxol.Components.Table","ref":"Raxol.Components.Table.html#module-props"},{"type":"module","doc":"- Per-column `:style` and `:header_style` override theme and table-level styles for their respective cells.\n- `:style` prop overrides theme for the box and header.\n- `:theme` provides defaults for box, header, row, and selected row.\n- Hardcoded defaults (e.g., header bold, selected row blue/white) are used if not overridden.","title":"Theming and Style Precedence - Raxol.Components.Table","ref":"Raxol.Components.Table.html#module-theming-and-style-precedence"},{"type":"module","doc":"```elixir\ncolumns = [\n  %{id: :id, label: \"ID\", style: %{color: :magenta}, header_style: %{bg: :cyan}},\n  %{id: :name, label: \"Name\"},\n  %{id: :age, label: \"Age\"}\n]\ndata = [%{id: 1, name: \"Alice\", age: 30}, ...]\ntheme = %{\n  box: %{border_color: :green},\n  header: %{underline: true},\n  row: %{bg: :yellow},\n  selected_row: %{bg: :red, fg: :black}\n}\nstyle = %{header: %{italic: true}}\n\nTable.init(%{\n  id: :my_table,\n  columns: columns,\n  data: data,\n  theme: theme,\n  style: style,\n  options: %{paginate: true, page_size: 5}\n})\n```","title":"Example: Custom Theming and Styling - Raxol.Components.Table","ref":"Raxol.Components.Table.html#module-example-custom-theming-and-styling"},{"type":"type","doc":"","title":"Raxol.Components.Table.column/0","ref":"Raxol.Components.Table.html#t:column/0"},{"type":"function","doc":"Handles events for the table component.","title":"Raxol.Components.Table.handle_event/3","ref":"Raxol.Components.Table.html#handle_event/3"},{"type":"function","doc":"Initializes the table component with the given props.","title":"Raxol.Components.Table.init/1","ref":"Raxol.Components.Table.html#init/1"},{"type":"function","doc":"","title":"Raxol.Components.Table.mount/1","ref":"Raxol.Components.Table.html#mount/1"},{"type":"type","doc":"","title":"Raxol.Components.Table.options/0","ref":"Raxol.Components.Table.html#t:options/0"},{"type":"function","doc":"Renders the table component.","title":"Raxol.Components.Table.render/2","ref":"Raxol.Components.Table.html#render/2"},{"type":"function","doc":"","title":"Raxol.Components.Table.unmount/1","ref":"Raxol.Components.Table.html#unmount/1"},{"type":"function","doc":"Updates the table state based on the given message.","title":"Raxol.Components.Table.update/2","ref":"Raxol.Components.Table.html#update/2"},{"type":"module","doc":"A terminal component that emulates a standard terminal within the UI.","title":"Raxol.Components.Terminal","ref":"Raxol.Components.Terminal.html"},{"type":"function","doc":"","title":"Raxol.Components.Terminal.broadcast/1","ref":"Raxol.Components.Terminal.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Components.Terminal.command/1","ref":"Raxol.Components.Terminal.html#command/1"},{"type":"function","doc":"","title":"Raxol.Components.Terminal.mount/1","ref":"Raxol.Components.Terminal.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Components.Terminal.schedule/2","ref":"Raxol.Components.Terminal.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Components.Terminal.unmount/1","ref":"Raxol.Components.Terminal.html#unmount/1"},{"type":"module","doc":"Terminal emulator component wrapping the core emulator logic.","title":"Raxol.Components.Terminal.Emulator","ref":"Raxol.Components.Terminal.Emulator.html"},{"type":"type","doc":"","title":"Raxol.Components.Terminal.Emulator.emulator_state/0","ref":"Raxol.Components.Terminal.Emulator.html#t:emulator_state/0"},{"type":"function","doc":"Gets the visible content from the UI component's state.","title":"Raxol.Components.Terminal.Emulator.get_visible_content/1","ref":"Raxol.Components.Terminal.Emulator.html#get_visible_content/1"},{"type":"function","doc":"Handles terminal resize events.\nTODO: Implement proper resizing by delegating to CoreEmulator or ScreenBuffer","title":"Raxol.Components.Terminal.Emulator.handle_resize/2","ref":"Raxol.Components.Terminal.Emulator.html#handle_resize/2"},{"type":"function","doc":"Initializes a new terminal emulator component state.\nAccepts an optional map of options, currently supporting `:width` and `:height`.","title":"Raxol.Components.Terminal.Emulator.init/1","ref":"Raxol.Components.Terminal.Emulator.html#init/1"},{"type":"function","doc":"Processes input and updates terminal state by delegating to the core emulator.\nReturns a tuple `{updated_state, output_string}`.","title":"Raxol.Components.Terminal.Emulator.process_input/2","ref":"Raxol.Components.Terminal.Emulator.html#process_input/2"},{"type":"module","doc":"A text input component with editing capabilities.\n\nThis module provides a text input field that allows users to enter\nand edit text with cursor positioning, selection, and validation.","title":"Raxol.Components.TextInput","ref":"Raxol.Components.TextInput.html"},{"type":"module","doc":"```elixir\nalias Raxol.Components.TextInput\n\nTextInput.new(\n  value: model.name,\n  placeholder: \"Enter your name\",\n  on_change: fn value -> {:update_name, value} end\n)\n```","title":"Example - Raxol.Components.TextInput","ref":"Raxol.Components.TextInput.html#module-example"},{"type":"function","doc":"Updates the text input based on keyboard input.","title":"Raxol.Components.TextInput.handle_key_event/2","ref":"Raxol.Components.TextInput.html#handle_key_event/2"},{"type":"function","doc":"* `input` - The text input component\n* `key_event` - Keyboard event as `{meta, key}`","title":"Parameters - Raxol.Components.TextInput.handle_key_event/2","ref":"Raxol.Components.TextInput.html#handle_key_event/2-parameters"},{"type":"function","doc":"Updated text input component.","title":"Returns - Raxol.Components.TextInput.handle_key_event/2","ref":"Raxol.Components.TextInput.html#handle_key_event/2-returns"},{"type":"function","doc":"```elixir\nupdated_input = TextInput.handle_key_event(input, {:none, ?a})\n```","title":"Example - Raxol.Components.TextInput.handle_key_event/2","ref":"Raxol.Components.TextInput.html#handle_key_event/2-example"},{"type":"function","doc":"Creates a new text input with the given options.","title":"Raxol.Components.TextInput.new/1","ref":"Raxol.Components.TextInput.html#new/1"},{"type":"function","doc":"* `:value` - Current input value\n* `:placeholder` - Placeholder text when empty\n* `:on_change` - Function to call when value changes\n* `:password` - Whether to mask input as password\n* `:max_length` - Maximum input length\n* `:style` - Custom style for the input\n* `:disabled` - Whether the input is disabled\n* `:validation` - Validation function\n* `:invalid_message` - Message to show when validation fails","title":"Options - Raxol.Components.TextInput.new/1","ref":"Raxol.Components.TextInput.html#new/1-options"},{"type":"function","doc":"A text input component that can be used in a Raxol view.","title":"Returns - Raxol.Components.TextInput.new/1","ref":"Raxol.Components.TextInput.html#new/1-returns"},{"type":"function","doc":"```elixir\nTextInput.new(\n  value: model.email,\n  placeholder: \"example@example.com\",\n  validation: &String.contains?(&1, \"@\"),\n  invalid_message: \"Must be a valid email\"\n)\n```","title":"Example - Raxol.Components.TextInput.new/1","ref":"Raxol.Components.TextInput.html#new/1-example"},{"type":"function","doc":"Renders the text input as a basic element.\n\nThis is typically called by the renderer, not directly by users.","title":"Raxol.Components.TextInput.render/1","ref":"Raxol.Components.TextInput.html#render/1"},{"type":"type","doc":"","title":"Raxol.Components.TextInput.t/0","ref":"Raxol.Components.TextInput.html#t:t/0"},{"type":"module","doc":"Accessibility module for Raxol terminal UI applications.\n\nThis module provides accessibility features including:\n- Screen reader announcements\n- Keyboard navigation enhancements\n- High contrast mode\n- Reduced motion support\n- Focus management\n- Large text support","title":"Raxol.Core.Accessibility","ref":"Raxol.Core.Accessibility.html"},{"type":"module","doc":"```elixir\n# Enable accessibility features\nAccessibility.enable()\n\n# Make an announcement for screen readers\nAccessibility.announce(\"You have selected the search button\")\n\n# Enable high contrast mode\nAccessibility.set_high_contrast(true)\n\n# Enable reduced motion mode\nAccessibility.set_reduced_motion(true)\n\n# Enable large text mode\nAccessibility.set_large_text(true)\n```","title":"Usage - Raxol.Core.Accessibility","ref":"Raxol.Core.Accessibility.html#module-usage"},{"type":"function","doc":"Make an announcement for screen readers.\n\nThis function adds a message to the announcement queue that will be\nread by screen readers.","title":"Raxol.Core.Accessibility.announce/3","ref":"Raxol.Core.Accessibility.html#announce/3"},{"type":"function","doc":"* `message` - The message to announce\n* `opts` - Options for the announcement\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.announce/3","ref":"Raxol.Core.Accessibility.html#announce/3-parameters"},{"type":"function","doc":"* `:priority` - Priority level (`:low`, `:medium`, `:high`) (default: `:medium`)\n* `:interrupt` - Whether to interrupt current announcements (default: `false`)","title":"Options - Raxol.Core.Accessibility.announce/3","ref":"Raxol.Core.Accessibility.html#announce/3-options"},{"type":"function","doc":"iex> Accessibility.announce(\"Button clicked\")\n    :ok\n\n    iex> Accessibility.announce(\"Error occurred\", priority: :high, interrupt: true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.announce/3","ref":"Raxol.Core.Accessibility.html#announce/3-examples"},{"type":"function","doc":"Clear all pending announcements.","title":"Raxol.Core.Accessibility.clear_announcements/0","ref":"Raxol.Core.Accessibility.html#clear_announcements/0"},{"type":"function","doc":"iex> Accessibility.clear_announcements()\n    :ok","title":"Examples - Raxol.Core.Accessibility.clear_announcements/0","ref":"Raxol.Core.Accessibility.html#clear_announcements/0-examples"},{"type":"function","doc":"Gets the current color scheme.","title":"Raxol.Core.Accessibility.color_scheme/1","ref":"Raxol.Core.Accessibility.html#color_scheme/1"},{"type":"function","doc":"Disable accessibility features.","title":"Raxol.Core.Accessibility.disable/1","ref":"Raxol.Core.Accessibility.html#disable/1"},{"type":"function","doc":"iex> Accessibility.disable()\n    :ok","title":"Examples - Raxol.Core.Accessibility.disable/1","ref":"Raxol.Core.Accessibility.html#disable/1-examples"},{"type":"function","doc":"Enable accessibility features with the given options.","title":"Raxol.Core.Accessibility.enable/2","ref":"Raxol.Core.Accessibility.html#enable/2"},{"type":"function","doc":"* `options` - Options to override the default accessibility settings\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.enable/2","ref":"Raxol.Core.Accessibility.html#enable/2-parameters"},{"type":"function","doc":"* `:high_contrast` - Enable high contrast mode (default: `false`)\n* `:reduced_motion` - Enable reduced motion (default: `false`)\n* `:large_text` - Enable large text (default: `false`)\n* `:screen_reader` - Enable screen reader support (default: `true`)\n* `:keyboard_focus` - Enable keyboard focus indicators (default: `true`)\n* `:silence_announcements` - Silence screen reader announcements (default: `false`)","title":"Options - Raxol.Core.Accessibility.enable/2","ref":"Raxol.Core.Accessibility.html#enable/2-options"},{"type":"function","doc":"iex> Accessibility.enable(high_contrast: true)\n    :ok\n\n    iex> Accessibility.enable(reduced_motion: true, screen_reader: false)\n    :ok","title":"Examples - Raxol.Core.Accessibility.enable/2","ref":"Raxol.Core.Accessibility.html#enable/2-examples"},{"type":"function","doc":"Gets the current font size multiplier.","title":"Raxol.Core.Accessibility.font_size_multiplier/1","ref":"Raxol.Core.Accessibility.html#font_size_multiplier/1"},{"type":"function","doc":"Get the current color scheme based on accessibility settings.","title":"Raxol.Core.Accessibility.get_color_scheme/0","ref":"Raxol.Core.Accessibility.html#get_color_scheme/0"},{"type":"function","doc":"iex> Accessibility.get_color_scheme()\n    %{background: ...}  # Returns the current color scheme","title":"Examples - Raxol.Core.Accessibility.get_color_scheme/0","ref":"Raxol.Core.Accessibility.html#get_color_scheme/0-examples"},{"type":"function","doc":"Get style settings for a component type.","title":"Raxol.Core.Accessibility.get_component_style/1","ref":"Raxol.Core.Accessibility.html#get_component_style/1"},{"type":"function","doc":"* `component_type` - Atom representing the component type","title":"Parameters - Raxol.Core.Accessibility.get_component_style/1","ref":"Raxol.Core.Accessibility.html#get_component_style/1-parameters"},{"type":"function","doc":"* The style map for the component type, or empty map if not found","title":"Returns - Raxol.Core.Accessibility.get_component_style/1","ref":"Raxol.Core.Accessibility.html#get_component_style/1-returns"},{"type":"function","doc":"iex> Accessibility.get_component_style(:button)\n    %{background: :blue}","title":"Examples - Raxol.Core.Accessibility.get_component_style/1","ref":"Raxol.Core.Accessibility.html#get_component_style/1-examples"},{"type":"function","doc":"Get metadata for an element.","title":"Raxol.Core.Accessibility.get_element_metadata/1","ref":"Raxol.Core.Accessibility.html#get_element_metadata/1"},{"type":"function","doc":"* `element_id` - Unique identifier for the element","title":"Parameters - Raxol.Core.Accessibility.get_element_metadata/1","ref":"Raxol.Core.Accessibility.html#get_element_metadata/1-parameters"},{"type":"function","doc":"* The metadata map for the element, or `nil` if not found","title":"Returns - Raxol.Core.Accessibility.get_element_metadata/1","ref":"Raxol.Core.Accessibility.html#get_element_metadata/1-returns"},{"type":"function","doc":"iex> Accessibility.get_element_metadata(\"search_button\")\n    %{label: \"Search\"}","title":"Examples - Raxol.Core.Accessibility.get_element_metadata/1","ref":"Raxol.Core.Accessibility.html#get_element_metadata/1-examples"},{"type":"function","doc":"Get the next announcement to be read by screen readers.\n\nThis function is typically called by the screen reader integration.","title":"Raxol.Core.Accessibility.get_next_announcement/0","ref":"Raxol.Core.Accessibility.html#get_next_announcement/0"},{"type":"function","doc":"iex> Accessibility.get_next_announcement()\n    \"Button clicked\"","title":"Examples - Raxol.Core.Accessibility.get_next_announcement/0","ref":"Raxol.Core.Accessibility.html#get_next_announcement/0-examples"},{"type":"function","doc":"Gets an accessibility option value.","title":"Raxol.Core.Accessibility.get_option/3","ref":"Raxol.Core.Accessibility.html#get_option/3"},{"type":"function","doc":"Get the current text scale factor based on the large text setting.","title":"Raxol.Core.Accessibility.get_text_scale/1","ref":"Raxol.Core.Accessibility.html#get_text_scale/1"},{"type":"function","doc":"* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.get_text_scale/1","ref":"Raxol.Core.Accessibility.html#get_text_scale/1-parameters"},{"type":"function","doc":"iex> Accessibility.get_text_scale()\n    1.0 # or 1.5 if large_text is enabled","title":"Examples - Raxol.Core.Accessibility.get_text_scale/1","ref":"Raxol.Core.Accessibility.html#get_text_scale/1-examples"},{"type":"function","doc":"Checks if high contrast mode is enabled.","title":"Raxol.Core.Accessibility.high_contrast_enabled?/1","ref":"Raxol.Core.Accessibility.html#high_contrast_enabled?/1"},{"type":"function","doc":"Register style settings for a component type.","title":"Raxol.Core.Accessibility.register_component_style/2","ref":"Raxol.Core.Accessibility.html#register_component_style/2"},{"type":"function","doc":"* `component_type` - Atom representing the component type\n* `style` - Style map to associate with the component type","title":"Parameters - Raxol.Core.Accessibility.register_component_style/2","ref":"Raxol.Core.Accessibility.html#register_component_style/2-parameters"},{"type":"function","doc":"iex> Accessibility.register_component_style(:button, %{background: :blue})\n    :ok","title":"Examples - Raxol.Core.Accessibility.register_component_style/2","ref":"Raxol.Core.Accessibility.html#register_component_style/2-examples"},{"type":"function","doc":"Register metadata for an element to be used for accessibility features.","title":"Raxol.Core.Accessibility.register_element_metadata/2","ref":"Raxol.Core.Accessibility.html#register_element_metadata/2"},{"type":"function","doc":"* `element_id` - Unique identifier for the element\n* `metadata` - Metadata to associate with the element","title":"Parameters - Raxol.Core.Accessibility.register_element_metadata/2","ref":"Raxol.Core.Accessibility.html#register_element_metadata/2-parameters"},{"type":"function","doc":"iex> Accessibility.register_element_metadata(\"search_button\", %{label: \"Search\"})\n    :ok","title":"Examples - Raxol.Core.Accessibility.register_element_metadata/2","ref":"Raxol.Core.Accessibility.html#register_element_metadata/2-examples"},{"type":"function","doc":"Checks if screen reader support is enabled.","title":"Raxol.Core.Accessibility.screen_reader_enabled?/1","ref":"Raxol.Core.Accessibility.html#screen_reader_enabled?/1"},{"type":"function","doc":"Enable or disable high contrast mode.","title":"Raxol.Core.Accessibility.set_high_contrast/2","ref":"Raxol.Core.Accessibility.html#set_high_contrast/2"},{"type":"function","doc":"* `enabled` - `true` to enable high contrast, `false` to disable.\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.set_high_contrast/2","ref":"Raxol.Core.Accessibility.html#set_high_contrast/2-parameters"},{"type":"function","doc":"iex> Accessibility.set_high_contrast(true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.set_high_contrast/2","ref":"Raxol.Core.Accessibility.html#set_high_contrast/2-examples"},{"type":"function","doc":"Enable or disable large text mode.","title":"Raxol.Core.Accessibility.set_large_text/2","ref":"Raxol.Core.Accessibility.html#set_large_text/2"},{"type":"function","doc":"* `enabled` - `true` to enable large text, `false` to disable.\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.set_large_text/2","ref":"Raxol.Core.Accessibility.html#set_large_text/2-parameters"},{"type":"function","doc":"iex> Accessibility.set_large_text(true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.set_large_text/2","ref":"Raxol.Core.Accessibility.html#set_large_text/2-examples"},{"type":"function","doc":"Sets an accessibility option value.","title":"Raxol.Core.Accessibility.set_option/3","ref":"Raxol.Core.Accessibility.html#set_option/3"},{"type":"function","doc":"Enable or disable reduced motion.","title":"Raxol.Core.Accessibility.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.html#set_reduced_motion/2"},{"type":"function","doc":"* `enabled` - `true` to enable reduced motion, `false` to disable.\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.html#set_reduced_motion/2-parameters"},{"type":"function","doc":"iex> Accessibility.set_reduced_motion(true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.html#set_reduced_motion/2-examples"},{"type":"module","doc":"Handles screen reader announcements and announcement queue management.","title":"Raxol.Core.Accessibility.Announcements","ref":"Raxol.Core.Accessibility.Announcements.html"},{"type":"function","doc":"Make an announcement for screen readers.","title":"Raxol.Core.Accessibility.Announcements.announce/3","ref":"Raxol.Core.Accessibility.Announcements.html#announce/3"},{"type":"function","doc":"* `message` - The message to announce\n* `opts` - Options for the announcement\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.Announcements.announce/3","ref":"Raxol.Core.Accessibility.Announcements.html#announce/3-parameters"},{"type":"function","doc":"* `:priority` - Priority level (`:low`, `:medium`, `:high`) (default: `:medium`)\n* `:interrupt` - Whether to interrupt current announcements (default: `false`)","title":"Options - Raxol.Core.Accessibility.Announcements.announce/3","ref":"Raxol.Core.Accessibility.Announcements.html#announce/3-options"},{"type":"function","doc":"iex> Announcements.announce(\"Button clicked\")\n    :ok\n\n    iex> Announcements.announce(\"Error occurred\", priority: :high, interrupt: true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.Announcements.announce/3","ref":"Raxol.Core.Accessibility.Announcements.html#announce/3-examples"},{"type":"function","doc":"Clear all pending announcements.","title":"Raxol.Core.Accessibility.Announcements.clear_announcements/0","ref":"Raxol.Core.Accessibility.Announcements.html#clear_announcements/0"},{"type":"function","doc":"iex> Announcements.clear_announcements()\n    :ok","title":"Examples - Raxol.Core.Accessibility.Announcements.clear_announcements/0","ref":"Raxol.Core.Accessibility.Announcements.html#clear_announcements/0-examples"},{"type":"function","doc":"Get the next announcement to be read by screen readers.","title":"Raxol.Core.Accessibility.Announcements.get_next_announcement/0","ref":"Raxol.Core.Accessibility.Announcements.html#get_next_announcement/0"},{"type":"function","doc":"iex> Announcements.get_next_announcement()\n    \"Button clicked\"","title":"Examples - Raxol.Core.Accessibility.Announcements.get_next_announcement/0","ref":"Raxol.Core.Accessibility.Announcements.html#get_next_announcement/0-examples"},{"type":"behaviour","doc":"Defines the behaviour for accessibility services.\nThis behaviour outlines the contract for modules that provide accessibility\nfunctionality such as screen reader announcements, feature toggles (high contrast,\nreduced motion, large text), and preference management related to accessibility.","title":"Raxol.Core.Accessibility.Behaviour","ref":"Raxol.Core.Accessibility.Behaviour.html"},{"type":"callback","doc":"Makes an announcement for screen readers.","title":"Raxol.Core.Accessibility.Behaviour.announce/3","ref":"Raxol.Core.Accessibility.Behaviour.html#c:announce/3"},{"type":"callback","doc":"Clears all pending announcements.","title":"Raxol.Core.Accessibility.Behaviour.clear_announcements/0","ref":"Raxol.Core.Accessibility.Behaviour.html#c:clear_announcements/0"},{"type":"callback","doc":"Disables accessibility features.","title":"Raxol.Core.Accessibility.Behaviour.disable/0","ref":"Raxol.Core.Accessibility.Behaviour.html#c:disable/0"},{"type":"callback","doc":"Enables accessibility features with the given options.","title":"Raxol.Core.Accessibility.Behaviour.enable/2","ref":"Raxol.Core.Accessibility.Behaviour.html#c:enable/2"},{"type":"callback","doc":"Gets the current color scheme based on accessibility settings.","title":"Raxol.Core.Accessibility.Behaviour.get_color_scheme/0","ref":"Raxol.Core.Accessibility.Behaviour.html#c:get_color_scheme/0"},{"type":"callback","doc":"Gets style settings for a component type.","title":"Raxol.Core.Accessibility.Behaviour.get_component_style/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:get_component_style/1"},{"type":"callback","doc":"Gets metadata for an element.","title":"Raxol.Core.Accessibility.Behaviour.get_element_metadata/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:get_element_metadata/1"},{"type":"callback","doc":"Gets the next announcement to be read by screen readers.","title":"Raxol.Core.Accessibility.Behaviour.get_next_announcement/0","ref":"Raxol.Core.Accessibility.Behaviour.html#c:get_next_announcement/0"},{"type":"callback","doc":"Gets an accessibility option value.","title":"Raxol.Core.Accessibility.Behaviour.get_option/3","ref":"Raxol.Core.Accessibility.Behaviour.html#c:get_option/3"},{"type":"callback","doc":"Gets the current text scale factor based on the large text setting.","title":"Raxol.Core.Accessibility.Behaviour.get_text_scale/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:get_text_scale/1"},{"type":"callback","doc":"Handles focus change events for accessibility announcements.","title":"Raxol.Core.Accessibility.Behaviour.handle_focus_change/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:handle_focus_change/1"},{"type":"callback","doc":"Checks if high contrast mode is enabled.","title":"Raxol.Core.Accessibility.Behaviour.high_contrast_enabled?/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:high_contrast_enabled?/1"},{"type":"callback","doc":"Checks if large text mode is enabled.","title":"Raxol.Core.Accessibility.Behaviour.large_text_enabled?/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:large_text_enabled?/1"},{"type":"callback","doc":"Checks if reduced motion mode is enabled.","title":"Raxol.Core.Accessibility.Behaviour.reduced_motion_enabled?/1","ref":"Raxol.Core.Accessibility.Behaviour.html#c:reduced_motion_enabled?/1"},{"type":"callback","doc":"Registers style settings for a component type.","title":"Raxol.Core.Accessibility.Behaviour.register_component_style/2","ref":"Raxol.Core.Accessibility.Behaviour.html#c:register_component_style/2"},{"type":"callback","doc":"Registers metadata for an element to be used for accessibility features.","title":"Raxol.Core.Accessibility.Behaviour.register_element_metadata/2","ref":"Raxol.Core.Accessibility.Behaviour.html#c:register_element_metadata/2"},{"type":"callback","doc":"Enables or disables high contrast mode.","title":"Raxol.Core.Accessibility.Behaviour.set_high_contrast/2","ref":"Raxol.Core.Accessibility.Behaviour.html#c:set_high_contrast/2"},{"type":"callback","doc":"Enables or disables large text mode.","title":"Raxol.Core.Accessibility.Behaviour.set_large_text/2","ref":"Raxol.Core.Accessibility.Behaviour.html#c:set_large_text/2"},{"type":"callback","doc":"Sets an accessibility option value.","title":"Raxol.Core.Accessibility.Behaviour.set_option/3","ref":"Raxol.Core.Accessibility.Behaviour.html#c:set_option/3"},{"type":"callback","doc":"Enables or disables reduced motion.","title":"Raxol.Core.Accessibility.Behaviour.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.Behaviour.html#c:set_reduced_motion/2"},{"type":"module","doc":"Handles accessibility-related events and notifications.","title":"Raxol.Core.Accessibility.EventHandlers","ref":"Raxol.Core.Accessibility.EventHandlers.html"},{"type":"function","doc":"Handle focus change events for accessibility announcements.","title":"Raxol.Core.Accessibility.EventHandlers.handle_focus_change/1","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_focus_change/1"},{"type":"function","doc":"iex> EventHandlers.handle_focus_change({:focus_change, nil, \"search_button\"})\n    :ok","title":"Examples - Raxol.Core.Accessibility.EventHandlers.handle_focus_change/1","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_focus_change/1-examples"},{"type":"function","doc":"Handle locale changes.","title":"Raxol.Core.Accessibility.EventHandlers.handle_locale_changed/1","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_locale_changed/1"},{"type":"function","doc":"iex> EventHandlers.handle_locale_changed({:locale_changed, %{locale: \"en\"}})\n    :ok","title":"Examples - Raxol.Core.Accessibility.EventHandlers.handle_locale_changed/1","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_locale_changed/1-examples"},{"type":"function","doc":"Handle preference changes triggered internally or via EventManager.","title":"Raxol.Core.Accessibility.EventHandlers.handle_preference_changed/2","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_preference_changed/2"},{"type":"function","doc":"iex> EventHandlers.handle_preference_changed({:preference_changed, [:accessibility, :high_contrast], true})\n    :ok","title":"Examples - Raxol.Core.Accessibility.EventHandlers.handle_preference_changed/2","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_preference_changed/2-examples"},{"type":"function","doc":"Handle theme changes.","title":"Raxol.Core.Accessibility.EventHandlers.handle_theme_changed/2","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_theme_changed/2"},{"type":"function","doc":"iex> EventHandlers.handle_theme_changed({:theme_changed, %{theme: \"dark\"}})\n    :ok","title":"Examples - Raxol.Core.Accessibility.EventHandlers.handle_theme_changed/2","ref":"Raxol.Core.Accessibility.EventHandlers.html#handle_theme_changed/2-examples"},{"type":"module","doc":"Legacy functions for backwards compatibility.\nThese functions are deprecated and will be removed in a future version.","title":"Raxol.Core.Accessibility.Legacy","ref":"Raxol.Core.Accessibility.Legacy.html"},{"type":"function","doc":"Check if high contrast mode is enabled.","title":"Raxol.Core.Accessibility.Legacy.high_contrast_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#high_contrast_enabled?/1"},{"type":"function","doc":"* `true` if high contrast mode is enabled, `false` otherwise.","title":"Returns - Raxol.Core.Accessibility.Legacy.high_contrast_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#high_contrast_enabled?/1-returns"},{"type":"function","doc":"iex> Legacy.high_contrast_enabled?()\n    false","title":"Examples - Raxol.Core.Accessibility.Legacy.high_contrast_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#high_contrast_enabled?/1-examples"},{"type":"function","doc":"Check if large text mode is enabled.","title":"Raxol.Core.Accessibility.Legacy.large_text_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#large_text_enabled?/1"},{"type":"function","doc":"* `true` if large text mode is enabled, `false` otherwise.","title":"Returns - Raxol.Core.Accessibility.Legacy.large_text_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#large_text_enabled?/1-returns"},{"type":"function","doc":"iex> Legacy.large_text_enabled?()\n    false","title":"Examples - Raxol.Core.Accessibility.Legacy.large_text_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#large_text_enabled?/1-examples"},{"type":"function","doc":"Check if reduced motion mode is enabled.","title":"Raxol.Core.Accessibility.Legacy.reduced_motion_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#reduced_motion_enabled?/1"},{"type":"function","doc":"* `true` if reduced motion mode is enabled, `false` otherwise.","title":"Returns - Raxol.Core.Accessibility.Legacy.reduced_motion_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#reduced_motion_enabled?/1-returns"},{"type":"function","doc":"iex> Legacy.reduced_motion_enabled?()\n    false","title":"Examples - Raxol.Core.Accessibility.Legacy.reduced_motion_enabled?/1","ref":"Raxol.Core.Accessibility.Legacy.html#reduced_motion_enabled?/1-examples"},{"type":"module","doc":"Handles accessibility metadata for UI elements and component styles.","title":"Raxol.Core.Accessibility.Metadata","ref":"Raxol.Core.Accessibility.Metadata.html"},{"type":"function","doc":"Get the accessible name for an element.","title":"Raxol.Core.Accessibility.Metadata.get_accessible_name/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_accessible_name/1"},{"type":"function","doc":"* `element` - The element to get the accessible name for","title":"Parameters - Raxol.Core.Accessibility.Metadata.get_accessible_name/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_accessible_name/1-parameters"},{"type":"function","doc":"* The accessible name as a string, or nil if not found","title":"Returns - Raxol.Core.Accessibility.Metadata.get_accessible_name/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_accessible_name/1-returns"},{"type":"function","doc":"iex> Metadata.get_accessible_name(\"search_button\")\n    \"Search\"","title":"Examples - Raxol.Core.Accessibility.Metadata.get_accessible_name/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_accessible_name/1-examples"},{"type":"function","doc":"Get style settings for a component type.","title":"Raxol.Core.Accessibility.Metadata.get_component_style/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_component_style/1"},{"type":"function","doc":"* `component_type` - Atom representing the component type","title":"Parameters - Raxol.Core.Accessibility.Metadata.get_component_style/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_component_style/1-parameters"},{"type":"function","doc":"* The style map for the component type, or empty map if not found","title":"Returns - Raxol.Core.Accessibility.Metadata.get_component_style/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_component_style/1-returns"},{"type":"function","doc":"iex> Metadata.get_component_style(:button)\n    %{background: :blue}","title":"Examples - Raxol.Core.Accessibility.Metadata.get_component_style/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_component_style/1-examples"},{"type":"function","doc":"Get metadata for an element.","title":"Raxol.Core.Accessibility.Metadata.get_element_metadata/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_element_metadata/1"},{"type":"function","doc":"* `element_id` - Unique identifier for the element","title":"Parameters - Raxol.Core.Accessibility.Metadata.get_element_metadata/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_element_metadata/1-parameters"},{"type":"function","doc":"* The metadata map for the element, or `nil` if not found","title":"Returns - Raxol.Core.Accessibility.Metadata.get_element_metadata/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_element_metadata/1-returns"},{"type":"function","doc":"iex> Metadata.get_element_metadata(\"search_button\")\n    %{label: \"Search\"}","title":"Examples - Raxol.Core.Accessibility.Metadata.get_element_metadata/1","ref":"Raxol.Core.Accessibility.Metadata.html#get_element_metadata/1-examples"},{"type":"function","doc":"Register style settings for a component type.","title":"Raxol.Core.Accessibility.Metadata.register_component_style/2","ref":"Raxol.Core.Accessibility.Metadata.html#register_component_style/2"},{"type":"function","doc":"* `component_type` - Atom representing the component type\n* `style` - Style map to associate with the component type","title":"Parameters - Raxol.Core.Accessibility.Metadata.register_component_style/2","ref":"Raxol.Core.Accessibility.Metadata.html#register_component_style/2-parameters"},{"type":"function","doc":"iex> Metadata.register_component_style(:button, %{background: :blue})\n    :ok","title":"Examples - Raxol.Core.Accessibility.Metadata.register_component_style/2","ref":"Raxol.Core.Accessibility.Metadata.html#register_component_style/2-examples"},{"type":"function","doc":"Register metadata for an element to be used for accessibility features.","title":"Raxol.Core.Accessibility.Metadata.register_element_metadata/2","ref":"Raxol.Core.Accessibility.Metadata.html#register_element_metadata/2"},{"type":"function","doc":"* `element_id` - Unique identifier for the element\n* `metadata` - Metadata to associate with the element","title":"Parameters - Raxol.Core.Accessibility.Metadata.register_element_metadata/2","ref":"Raxol.Core.Accessibility.Metadata.html#register_element_metadata/2-parameters"},{"type":"function","doc":"iex> Metadata.register_element_metadata(\"search_button\", %{label: \"Search\"})\n    :ok","title":"Examples - Raxol.Core.Accessibility.Metadata.register_element_metadata/2","ref":"Raxol.Core.Accessibility.Metadata.html#register_element_metadata/2-examples"},{"type":"module","doc":"Mock implementation for Raxol.Core.Accessibility.\n\nThis module provides manual definitions for functions expected to be\ncalled during tests when Raxol.Core.Accessibility is replaced\nusing Mox.stub_with/2.","title":"Raxol.Core.Accessibility.Mock","ref":"Raxol.Core.Accessibility.Mock.html"},{"type":"function","doc":"","title":"Raxol.Core.Accessibility.Mock.announce/2","ref":"Raxol.Core.Accessibility.Mock.html#announce/2"},{"type":"module","doc":"Manages accessibility preferences and settings.","title":"Raxol.Core.Accessibility.Preferences","ref":"Raxol.Core.Accessibility.Preferences.html"},{"type":"function","doc":"Get the default preferences name.","title":"Raxol.Core.Accessibility.Preferences.default_prefs_name/0","ref":"Raxol.Core.Accessibility.Preferences.html#default_prefs_name/0"},{"type":"function","doc":"iex> Preferences.default_prefs_name()\n    Raxol.Core.UserPreferences","title":"Examples - Raxol.Core.Accessibility.Preferences.default_prefs_name/0","ref":"Raxol.Core.Accessibility.Preferences.html#default_prefs_name/0-examples"},{"type":"function","doc":"Get an accessibility option value.","title":"Raxol.Core.Accessibility.Preferences.get_option/3","ref":"Raxol.Core.Accessibility.Preferences.html#get_option/3"},{"type":"function","doc":"* `option_name` - The atom representing the accessibility option (e.g., `:high_contrast`).\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).\n* `default` - The default value to return if the option is not set (optional).","title":"Parameters - Raxol.Core.Accessibility.Preferences.get_option/3","ref":"Raxol.Core.Accessibility.Preferences.html#get_option/3-parameters"},{"type":"function","doc":"iex> Preferences.get_option(:high_contrast)\n    false","title":"Examples - Raxol.Core.Accessibility.Preferences.get_option/3","ref":"Raxol.Core.Accessibility.Preferences.html#get_option/3-examples"},{"type":"function","doc":"Get the current text scale factor based on the large text setting.","title":"Raxol.Core.Accessibility.Preferences.get_text_scale/1","ref":"Raxol.Core.Accessibility.Preferences.html#get_text_scale/1"},{"type":"function","doc":"* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.Preferences.get_text_scale/1","ref":"Raxol.Core.Accessibility.Preferences.html#get_text_scale/1-parameters"},{"type":"function","doc":"iex> Preferences.get_text_scale()\n    1.0 # or 1.5 if large_text is enabled","title":"Examples - Raxol.Core.Accessibility.Preferences.get_text_scale/1","ref":"Raxol.Core.Accessibility.Preferences.html#get_text_scale/1-examples"},{"type":"function","doc":"","title":"Raxol.Core.Accessibility.Preferences.handle_preference_changed/2","ref":"Raxol.Core.Accessibility.Preferences.html#handle_preference_changed/2"},{"type":"function","doc":"Enable or disable high contrast mode.","title":"Raxol.Core.Accessibility.Preferences.set_high_contrast/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_high_contrast/2"},{"type":"function","doc":"* `enabled` - `true` to enable high contrast, `false` to disable.\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.Preferences.set_high_contrast/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_high_contrast/2-parameters"},{"type":"function","doc":"iex> Preferences.set_high_contrast(true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.Preferences.set_high_contrast/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_high_contrast/2-examples"},{"type":"function","doc":"Enable or disable large text mode.","title":"Raxol.Core.Accessibility.Preferences.set_large_text/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_large_text/2"},{"type":"function","doc":"* `enabled` - `true` to enable large text, `false` to disable.\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.Preferences.set_large_text/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_large_text/2-parameters"},{"type":"function","doc":"iex> Preferences.set_large_text(true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.Preferences.set_large_text/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_large_text/2-examples"},{"type":"function","doc":"Set an accessibility option value.","title":"Raxol.Core.Accessibility.Preferences.set_option/3","ref":"Raxol.Core.Accessibility.Preferences.html#set_option/3"},{"type":"function","doc":"* `key` - The option key to set\n* `value` - The value to set\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.Preferences.set_option/3","ref":"Raxol.Core.Accessibility.Preferences.html#set_option/3-parameters"},{"type":"function","doc":"iex> Preferences.set_option(:high_contrast, true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.Preferences.set_option/3","ref":"Raxol.Core.Accessibility.Preferences.html#set_option/3-examples"},{"type":"function","doc":"Enable or disable reduced motion.","title":"Raxol.Core.Accessibility.Preferences.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_reduced_motion/2"},{"type":"function","doc":"* `enabled` - `true` to enable reduced motion, `false` to disable.\n* `user_preferences_pid_or_name` - The PID or registered name of the UserPreferences process to use (optional).","title":"Parameters - Raxol.Core.Accessibility.Preferences.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_reduced_motion/2-parameters"},{"type":"function","doc":"iex> Preferences.set_reduced_motion(true)\n    :ok","title":"Examples - Raxol.Core.Accessibility.Preferences.set_reduced_motion/2","ref":"Raxol.Core.Accessibility.Preferences.html#set_reduced_motion/2-examples"},{"type":"module","doc":"Manages the integration between accessibility settings and the active theme.\n\nListens for accessibility changes (e.g., high contrast toggle) and\nupdates the active theme accordingly.","title":"Raxol.Core.Accessibility.ThemeIntegration","ref":"Raxol.Core.Accessibility.ThemeIntegration.html"},{"type":"function","doc":"Apply the current accessibility settings to components.\nThis function is typically called during initialization to ensure components\nreflect the persisted preferences.\nAccepts a keyword list of options (e.g., `[high_contrast: true, ...]`).","title":"Raxol.Core.Accessibility.ThemeIntegration.apply_settings/1","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#apply_settings/1"},{"type":"function","doc":"Clean up the theme integration.\n\nUnregisters event handlers.","title":"Raxol.Core.Accessibility.ThemeIntegration.cleanup/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#cleanup/0"},{"type":"function","doc":"iex> ThemeIntegration.cleanup()\n    :ok","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.cleanup/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#cleanup/0-examples"},{"type":"function","doc":"Returns the current accessibility mode based on settings.\nDefaults to `:normal` if high contrast is off.","title":"Raxol.Core.Accessibility.ThemeIntegration.get_accessibility_mode/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#get_accessibility_mode/0"},{"type":"function","doc":"Returns the current active theme variant for accessibility-aware theming.\nUsed by the renderer and theming system to select the correct theme variant.","title":"Raxol.Core.Accessibility.ThemeIntegration.get_active_variant/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#get_active_variant/0"},{"type":"function","doc":"iex> ThemeIntegration.get_active_variant()\n    :normal | :high_contrast","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.get_active_variant/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#get_active_variant/0-examples"},{"type":"function","doc":"Get the current theme based on accessibility settings.","title":"Raxol.Core.Accessibility.ThemeIntegration.get_theme/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#get_theme/0"},{"type":"function","doc":"iex> ThemeIntegration.get_theme()\n    %Theme{}  # Returns the current theme with accessibility adjustments","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.get_theme/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#get_theme/0-examples"},{"type":"function","doc":"Handle high contrast mode changes.\nUpdates the theme based on high contrast setting.","title":"Raxol.Core.Accessibility.ThemeIntegration.handle_high_contrast/1","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_high_contrast/1"},{"type":"function","doc":"Handle large text setting changes.","title":"Raxol.Core.Accessibility.ThemeIntegration.handle_large_text/1","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_large_text/1"},{"type":"function","doc":"iex> ThemeIntegration.handle_large_text({:accessibility_large_text, true})\n    :ok","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.handle_large_text/1","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_large_text/1-examples"},{"type":"function","doc":"Handle reduced motion setting changes.","title":"Raxol.Core.Accessibility.ThemeIntegration.handle_reduced_motion/1","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_reduced_motion/1"},{"type":"function","doc":"iex> ThemeIntegration.handle_reduced_motion({:accessibility_reduced_motion, true})\n    :ok","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.handle_reduced_motion/1","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#handle_reduced_motion/1-examples"},{"type":"function","doc":"Initialize the theme integration.\n\nRegisters event handlers for accessibility setting changes.","title":"Raxol.Core.Accessibility.ThemeIntegration.init/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#init/0"},{"type":"function","doc":"iex> ThemeIntegration.init()\n    :ok","title":"Examples - Raxol.Core.Accessibility.ThemeIntegration.init/0","ref":"Raxol.Core.Accessibility.ThemeIntegration.html#init/0-examples"},{"type":"module","doc":"Core color system for Raxol.\n\nThis module provides a unified interface for managing colors and themes\nthroughout the application. It integrates with the Style.Colors modules\nto provide a consistent color experience.","title":"Raxol.Core.ColorSystem","ref":"Raxol.Core.ColorSystem.html"},{"type":"module","doc":"- Theme management with semantic color naming\n- Color format conversion and validation\n- Accessibility checks and adjustments","title":"Features - Raxol.Core.ColorSystem","ref":"Raxol.Core.ColorSystem.html#module-features"},{"type":"function","doc":"Adjusts a color to meet contrast requirements with another color.","title":"Raxol.Core.ColorSystem.adjust_for_contrast/5","ref":"Raxol.Core.ColorSystem.html#adjust_for_contrast/5"},{"type":"function","doc":"iex> theme = create_theme(\"dark\", %{\n    ...>   text: \"#808080\",\n    ...>   background: \"#000000\"\n    ...> })\n    iex> adjusted = adjust_for_contrast(theme, :text, :background, :AA, :normal)\n    iex> meets_contrast_requirements?(adjusted, :text, :background, :AA, :normal)\n    true","title":"Examples - Raxol.Core.ColorSystem.adjust_for_contrast/5","ref":"Raxol.Core.ColorSystem.html#adjust_for_contrast/5-examples"},{"type":"function","doc":"Creates a new theme with the given name and colors.","title":"Raxol.Core.ColorSystem.create_theme/2","ref":"Raxol.Core.ColorSystem.html#create_theme/2"},{"type":"function","doc":"iex> theme = create_theme(\"dark\", %{\n    ...>   primary: \"#FF0000\",\n    ...>   background: \"#000000\",\n    ...>   text: \"#FFFFFF\"\n    ...> })\n    iex> theme.name\n    \"dark\"","title":"Examples - Raxol.Core.ColorSystem.create_theme/2","ref":"Raxol.Core.ColorSystem.html#create_theme/2-examples"},{"type":"function","doc":"Gets the effective color value for a given semantic color name.\n\nIt retrieves the color from the specified theme (by ID), automatically considering\nwhether a high contrast variant is active based on accessibility settings.\n\nArgs:\n  - `theme_id`: The atom ID of the theme to use (e.g., :default, :dark).\n  - `color_name`: The semantic name of the color (e.g., :primary, :background).\n\nReturns the color value (e.g., :red, {:rgb, r, g, b}) or nil if not found.","title":"Raxol.Core.ColorSystem.get/2","ref":"Raxol.Core.ColorSystem.html#get/2"},{"type":"function","doc":"Gets a color value and ensures it's returned in a specific format (e.g., RGB tuple).\nUseful when a specific color representation is required for rendering.\n\nArgs:\n  - `theme_id`: The atom ID of the theme to use.\n  - `color_name`: The semantic name of the color.\n  - `format`: The desired output format (:rgb_tuple, :hex_string, :term).\n\nSupported formats: :rgb_tuple, :hex_string, :term","title":"Raxol.Core.ColorSystem.get_as/3","ref":"Raxol.Core.ColorSystem.html#get_as/3"},{"type":"function","doc":"Gets a color from the theme by its semantic name.","title":"Raxol.Core.ColorSystem.get_color/2","ref":"Raxol.Core.ColorSystem.html#get_color/2"},{"type":"function","doc":"iex> theme = create_theme(\"dark\", %{primary: \"#FF0000\"})\n    iex> get_color(theme, :primary)\n    %Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}","title":"Examples - Raxol.Core.ColorSystem.get_color/2","ref":"Raxol.Core.ColorSystem.html#get_color/2-examples"},{"type":"function","doc":"Checks if two colors meet WCAG contrast requirements.","title":"Raxol.Core.ColorSystem.meets_contrast_requirements?/5","ref":"Raxol.Core.ColorSystem.html#meets_contrast_requirements?/5"},{"type":"function","doc":"iex> theme = create_theme(\"dark\", %{\n    ...>   text: \"#FFFFFF\",\n    ...>   background: \"#000000\"\n    ...> })\n    iex> meets_contrast_requirements?(theme, :text, :background, :AA, :normal)\n    true","title":"Examples - Raxol.Core.ColorSystem.meets_contrast_requirements?/5","ref":"Raxol.Core.ColorSystem.html#meets_contrast_requirements?/5-examples"},{"type":"function","doc":"Converts a color to its ANSI representation.","title":"Raxol.Core.ColorSystem.to_ansi/3","ref":"Raxol.Core.ColorSystem.html#to_ansi/3"},{"type":"function","doc":"iex> theme = create_theme(\"dark\", %{primary: \"#FF0000\"})\n    iex> to_ansi(theme, :primary, :foreground)\n    196","title":"Examples - Raxol.Core.ColorSystem.to_ansi/3","ref":"Raxol.Core.ColorSystem.html#to_ansi/3-examples"},{"type":"module","doc":"Defines the structure for events in the Raxol system, providing a standardized format\nfor key presses, mouse actions, and other UI events that components need to process.\n\nEvents are structs with a :type and :data field, where :type indicates the event category\n(e.g., :key, :mouse, :resize) and :data contains the event-specific details.","title":"Raxol.Core.Events.Event","ref":"Raxol.Core.Events.Event.html"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.cursor_event/0","ref":"Raxol.Core.Events.Event.html#t:cursor_event/0"},{"type":"function","doc":"Creates a cursor event.","title":"Raxol.Core.Events.Event.cursor_event/4","ref":"Raxol.Core.Events.Event.html#cursor_event/4"},{"type":"function","doc":"* `visible` - Whether cursor is visible\n  * `style` - Cursor style\n  * `blink` - Whether cursor should blink\n  * `position` - Cursor position","title":"Parameters - Raxol.Core.Events.Event.cursor_event/4","ref":"Raxol.Core.Events.Event.html#cursor_event/4-parameters"},{"type":"function","doc":"Creates a simple custom event.","title":"Raxol.Core.Events.Event.custom/1","ref":"Raxol.Core.Events.Event.html#custom/1"},{"type":"function","doc":"Creates a custom event.","title":"Raxol.Core.Events.Event.custom_event/1","ref":"Raxol.Core.Events.Event.html#custom_event/1"},{"type":"function","doc":"* `data` - Custom event data","title":"Parameters - Raxol.Core.Events.Event.custom_event/1","ref":"Raxol.Core.Events.Event.html#custom_event/1-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.event_data/0","ref":"Raxol.Core.Events.Event.html#t:event_data/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.event_type/0","ref":"Raxol.Core.Events.Event.html#t:event_type/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.focus_event/0","ref":"Raxol.Core.Events.Event.html#t:focus_event/0"},{"type":"function","doc":"Creates a focus event.","title":"Raxol.Core.Events.Event.focus_event/2","ref":"Raxol.Core.Events.Event.html#focus_event/2"},{"type":"function","doc":"* `target` - What received/lost focus\n  * `focused` - Whether focus was gained (true) or lost (false)","title":"Parameters - Raxol.Core.Events.Event.focus_event/2","ref":"Raxol.Core.Events.Event.html#focus_event/2-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.focus_target/0","ref":"Raxol.Core.Events.Event.html#t:focus_target/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.key/0","ref":"Raxol.Core.Events.Event.html#t:key/0"},{"type":"function","doc":"Creates a simple key event with pressed state and no modifiers.","title":"Raxol.Core.Events.Event.key/1","ref":"Raxol.Core.Events.Event.html#key/1"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.key_event/0","ref":"Raxol.Core.Events.Event.html#t:key_event/0"},{"type":"function","doc":"Creates a keyboard event.","title":"Raxol.Core.Events.Event.key_event/3","ref":"Raxol.Core.Events.Event.html#key_event/3"},{"type":"function","doc":"* `key` - The key that was pressed/released (e.g. :enter, :backspace, \"a\")\n  * `state` - The state of the key (:pressed, :released, :repeat)\n  * `modifiers` - List of active modifiers (e.g. [:shift, :ctrl])","title":"Parameters - Raxol.Core.Events.Event.key_event/3","ref":"Raxol.Core.Events.Event.html#key_event/3-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.key_state/0","ref":"Raxol.Core.Events.Event.html#t:key_state/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.modifiers/0","ref":"Raxol.Core.Events.Event.html#t:modifiers/0"},{"type":"function","doc":"Creates a simple mouse event with pressed state and no modifiers.","title":"Raxol.Core.Events.Event.mouse/2","ref":"Raxol.Core.Events.Event.html#mouse/2"},{"type":"function","doc":"Creates a mouse event with drag state.","title":"Raxol.Core.Events.Event.mouse/3","ref":"Raxol.Core.Events.Event.html#mouse/3"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.mouse_button/0","ref":"Raxol.Core.Events.Event.html#t:mouse_button/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.mouse_event/0","ref":"Raxol.Core.Events.Event.html#t:mouse_event/0"},{"type":"function","doc":"Creates a mouse event.","title":"Raxol.Core.Events.Event.mouse_event/4","ref":"Raxol.Core.Events.Event.html#mouse_event/4"},{"type":"function","doc":"* `button` - The mouse button (:left, :right, :middle)\n  * `position` - The mouse position as {x, y}\n  * `state` - The button state (:pressed, :released, :double_click)\n  * `modifiers` - List of active modifiers (e.g. [:shift, :ctrl])","title":"Parameters - Raxol.Core.Events.Event.mouse_event/4","ref":"Raxol.Core.Events.Event.html#mouse_event/4-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.mouse_position/0","ref":"Raxol.Core.Events.Event.html#t:mouse_position/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.mouse_state/0","ref":"Raxol.Core.Events.Event.html#t:mouse_state/0"},{"type":"function","doc":"Creates a new event with the given type and data. Optionally accepts a timestamp (defaults to now).","title":"Raxol.Core.Events.Event.new/3","ref":"Raxol.Core.Events.Event.html#new/3"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.paste_event/0","ref":"Raxol.Core.Events.Event.html#t:paste_event/0"},{"type":"function","doc":"Creates a paste event.","title":"Raxol.Core.Events.Event.paste_event/2","ref":"Raxol.Core.Events.Event.html#paste_event/2"},{"type":"function","doc":"* `text` - Pasted text\n  * `position` - Paste position","title":"Parameters - Raxol.Core.Events.Event.paste_event/2","ref":"Raxol.Core.Events.Event.html#paste_event/2-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.scroll_direction/0","ref":"Raxol.Core.Events.Event.html#t:scroll_direction/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.scroll_event/0","ref":"Raxol.Core.Events.Event.html#t:scroll_event/0"},{"type":"function","doc":"Creates a scroll event.","title":"Raxol.Core.Events.Event.scroll_event/3","ref":"Raxol.Core.Events.Event.html#scroll_event/3"},{"type":"function","doc":"* `direction` - Scroll direction\n  * `delta` - Amount scrolled (positive or negative)\n  * `position` - Current scroll position","title":"Parameters - Raxol.Core.Events.Event.scroll_event/3","ref":"Raxol.Core.Events.Event.html#scroll_event/3-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.selection_event/0","ref":"Raxol.Core.Events.Event.html#t:selection_event/0"},{"type":"function","doc":"Creates a selection event.","title":"Raxol.Core.Events.Event.selection_event/3","ref":"Raxol.Core.Events.Event.html#selection_event/3"},{"type":"function","doc":"* `start_pos` - Selection start position\n  * `end_pos` - Selection end position\n  * `text` - Selected text","title":"Parameters - Raxol.Core.Events.Event.selection_event/3","ref":"Raxol.Core.Events.Event.html#selection_event/3-parameters"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.t/0","ref":"Raxol.Core.Events.Event.html#t:t/0"},{"type":"function","doc":"Creates a simple timer event.","title":"Raxol.Core.Events.Event.timer/1","ref":"Raxol.Core.Events.Event.html#timer/1"},{"type":"function","doc":"Creates a timer event.","title":"Raxol.Core.Events.Event.timer_event/1","ref":"Raxol.Core.Events.Event.html#timer_event/1"},{"type":"function","doc":"* `data` - Timer-specific data","title":"Parameters - Raxol.Core.Events.Event.timer_event/1","ref":"Raxol.Core.Events.Event.html#timer_event/1-parameters"},{"type":"function","doc":"Creates a simple window event.","title":"Raxol.Core.Events.Event.window/3","ref":"Raxol.Core.Events.Event.html#window/3"},{"type":"type","doc":"","title":"Raxol.Core.Events.Event.window_event/0","ref":"Raxol.Core.Events.Event.html#t:window_event/0"},{"type":"function","doc":"Creates a window event.","title":"Raxol.Core.Events.Event.window_event/3","ref":"Raxol.Core.Events.Event.html#window_event/3"},{"type":"function","doc":"* `width` - The window width\n  * `height` - The window height\n  * `action` - The window action (:resize, :focus, :blur)","title":"Parameters - Raxol.Core.Events.Event.window_event/3","ref":"Raxol.Core.Events.Event.html#window_event/3-parameters"},{"type":"module","doc":"Event manager for handling and dispatching events in Raxol applications.\n\nThis module provides a simple event system that allows:\n- Registering event handlers\n- Dispatching events\n- Handling events\n- Managing subscriptions","title":"Raxol.Core.Events.Manager","ref":"Raxol.Core.Events.Manager.html"},{"type":"module","doc":"```elixir\n# Initialize the event manager\nEventManager.init()\n\n# Register an event handler\nEventManager.register_handler(:click, MyModule, :handle_click)\n\n# Subscribe to events\n{:ok, ref} = EventManager.subscribe([:click, :key_press])\n\n# Dispatch an event\nEventManager.dispatch({:click, %{x: 10, y: 20}})\n\n# Unsubscribe\nEventManager.unsubscribe(ref)\n```","title":"Usage - Raxol.Core.Events.Manager","ref":"Raxol.Core.Events.Manager.html#module-usage"},{"type":"function","doc":"Broadcast an event to all subscribers.","title":"Raxol.Core.Events.Manager.broadcast/1","ref":"Raxol.Core.Events.Manager.html#broadcast/1"},{"type":"function","doc":"iex> EventManager.broadcast({:system_event, :shutdown})\n    :ok","title":"Examples - Raxol.Core.Events.Manager.broadcast/1","ref":"Raxol.Core.Events.Manager.html#broadcast/1-examples"},{"type":"function","doc":"Cleans up the event manager state.","title":"Raxol.Core.Events.Manager.cleanup/0","ref":"Raxol.Core.Events.Manager.html#cleanup/0"},{"type":"function","doc":"Clear all event handlers.","title":"Raxol.Core.Events.Manager.clear_handlers/0","ref":"Raxol.Core.Events.Manager.html#clear_handlers/0"},{"type":"function","doc":"iex> EventManager.clear_handlers()\n    :ok","title":"Examples - Raxol.Core.Events.Manager.clear_handlers/0","ref":"Raxol.Core.Events.Manager.html#clear_handlers/0-examples"},{"type":"function","doc":"Dispatch an event to all registered handlers and subscribers.","title":"Raxol.Core.Events.Manager.dispatch/1","ref":"Raxol.Core.Events.Manager.html#dispatch/1"},{"type":"function","doc":"* `event` - The event to dispatch","title":"Parameters - Raxol.Core.Events.Manager.dispatch/1","ref":"Raxol.Core.Events.Manager.html#dispatch/1-parameters"},{"type":"function","doc":"iex> EventManager.dispatch({:click, %{x: 10, y: 20}})\n    :ok\n\n    iex> EventManager.dispatch(:accessibility_high_contrast)\n    :ok","title":"Examples - Raxol.Core.Events.Manager.dispatch/1","ref":"Raxol.Core.Events.Manager.html#dispatch/1-examples"},{"type":"function","doc":"Get all registered event handlers.","title":"Raxol.Core.Events.Manager.get_handlers/0","ref":"Raxol.Core.Events.Manager.html#get_handlers/0"},{"type":"function","doc":"iex> EventManager.get_handlers()\n    %{click: [{MyModule, :handle_click}]}","title":"Examples - Raxol.Core.Events.Manager.get_handlers/0","ref":"Raxol.Core.Events.Manager.html#get_handlers/0-examples"},{"type":"function","doc":"Initialize the event manager.","title":"Raxol.Core.Events.Manager.init/0","ref":"Raxol.Core.Events.Manager.html#init/0"},{"type":"function","doc":"iex> EventManager.init()\n    :ok","title":"Examples - Raxol.Core.Events.Manager.init/0","ref":"Raxol.Core.Events.Manager.html#init/0-examples"},{"type":"function","doc":"Register an event handler.","title":"Raxol.Core.Events.Manager.register_handler/3","ref":"Raxol.Core.Events.Manager.html#register_handler/3"},{"type":"function","doc":"* `event_type` - The type of event to handle\n* `module` - The module containing the handler function\n* `function` - The function to call when the event occurs","title":"Parameters - Raxol.Core.Events.Manager.register_handler/3","ref":"Raxol.Core.Events.Manager.html#register_handler/3-parameters"},{"type":"function","doc":"iex> EventManager.register_handler(:click, MyModule, :handle_click)\n    :ok","title":"Examples - Raxol.Core.Events.Manager.register_handler/3","ref":"Raxol.Core.Events.Manager.html#register_handler/3-examples"},{"type":"function","doc":"Subscribe to events with optional filters.","title":"Raxol.Core.Events.Manager.subscribe/2","ref":"Raxol.Core.Events.Manager.html#subscribe/2"},{"type":"function","doc":"* `event_types` - List of event types to subscribe to\n* `opts` - Optional filters and options","title":"Parameters - Raxol.Core.Events.Manager.subscribe/2","ref":"Raxol.Core.Events.Manager.html#subscribe/2-parameters"},{"type":"function","doc":"iex> EventManager.subscribe([:click, :key_press])\n    {:ok, ref}\n\n    iex> EventManager.subscribe([:mouse], button: :left)\n    {:ok, ref}","title":"Examples - Raxol.Core.Events.Manager.subscribe/2","ref":"Raxol.Core.Events.Manager.html#subscribe/2-examples"},{"type":"function","doc":"Unregister an event handler.","title":"Raxol.Core.Events.Manager.unregister_handler/3","ref":"Raxol.Core.Events.Manager.html#unregister_handler/3"},{"type":"function","doc":"* `event_type` - The type of event\n* `module` - The module containing the handler function\n* `function` - The function that was registered","title":"Parameters - Raxol.Core.Events.Manager.unregister_handler/3","ref":"Raxol.Core.Events.Manager.html#unregister_handler/3-parameters"},{"type":"function","doc":"iex> EventManager.unregister_handler(:click, MyModule, :handle_click)\n    :ok","title":"Examples - Raxol.Core.Events.Manager.unregister_handler/3","ref":"Raxol.Core.Events.Manager.html#unregister_handler/3-examples"},{"type":"function","doc":"Unsubscribe from events using the subscription reference.","title":"Raxol.Core.Events.Manager.unsubscribe/1","ref":"Raxol.Core.Events.Manager.html#unsubscribe/1"},{"type":"function","doc":"iex> EventManager.unsubscribe(ref)\n    :ok","title":"Examples - Raxol.Core.Events.Manager.unsubscribe/1","ref":"Raxol.Core.Events.Manager.html#unsubscribe/1-examples"},{"type":"behaviour","doc":"","title":"Raxol.Core.Events.Manager.Behaviour","ref":"Raxol.Core.Events.Manager.Behaviour.html"},{"type":"callback","doc":"","title":"Raxol.Core.Events.Manager.Behaviour.dispatch/1","ref":"Raxol.Core.Events.Manager.Behaviour.html#c:dispatch/1"},{"type":"module","doc":"Provides helpers for managing event subscriptions.\n\nThis module makes it easy to:\n* Subscribe to specific event types\n* Filter events based on criteria\n* Handle event cleanup\n* Manage multiple subscriptions","title":"Raxol.Core.Events.Subscription","ref":"Raxol.Core.Events.Subscription.html"},{"type":"function","doc":"Subscribes to a list of event types.","title":"Raxol.Core.Events.Subscription.events/1","ref":"Raxol.Core.Events.Subscription.html#events/1"},{"type":"function","doc":"- `event_types` - A list of event type atoms (e.g., `[:key, :mouse, :window]`).\n                   Can also include tuples like `{:key, opts}` or `{:mouse, opts}`\n                   to pass specific options to the individual subscription functions.","title":"Parameters - Raxol.Core.Events.Subscription.events/1","ref":"Raxol.Core.Events.Subscription.html#events/1-parameters"},{"type":"function","doc":"- `{:ok, list(subscription_ref())}` on success, containing a list of references for each subscription.\n- `{:error, reason}` if any subscription fails. Successfully created subscriptions before the failure will be automatically unsubscribed.","title":"Returns - Raxol.Core.Events.Subscription.events/1","ref":"Raxol.Core.Events.Subscription.html#events/1-returns"},{"type":"function","doc":"Subscribes to custom events with data matching.","title":"Raxol.Core.Events.Subscription.subscribe_custom/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_custom/1"},{"type":"function","doc":"* `:match` - Pattern to match against custom event data","title":"Options - Raxol.Core.Events.Subscription.subscribe_custom/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_custom/1-options"},{"type":"function","doc":"subscribe_custom(match: {:user_action, _})","title":"Example - Raxol.Core.Events.Subscription.subscribe_custom/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_custom/1-example"},{"type":"function","doc":"Subscribes to keyboard events with optional key filters.","title":"Raxol.Core.Events.Subscription.subscribe_keyboard/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_keyboard/1"},{"type":"function","doc":"* `:keys` - List of specific keys to match\n* `:exclude_keys` - List of keys to ignore","title":"Options - Raxol.Core.Events.Subscription.subscribe_keyboard/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_keyboard/1-options"},{"type":"function","doc":"subscribe_keyboard(keys: [:enter, :esc])\n    subscribe_keyboard(exclude_keys: [:tab])","title":"Example - Raxol.Core.Events.Subscription.subscribe_keyboard/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_keyboard/1-example"},{"type":"function","doc":"Subscribes to mouse events with optional button and position filters.","title":"Raxol.Core.Events.Subscription.subscribe_mouse/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_mouse/1"},{"type":"function","doc":"* `:buttons` - List of mouse buttons to match\n* `:drag_only` - Only match drag events\n* `:click_only` - Only match click events\n* `:area` - Tuple of {x, y, width, height} to match position","title":"Options - Raxol.Core.Events.Subscription.subscribe_mouse/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_mouse/1-options"},{"type":"function","doc":"subscribe_mouse(buttons: [:left, :right])\n    subscribe_mouse(area: {0, 0, 10, 10})","title":"Example - Raxol.Core.Events.Subscription.subscribe_mouse/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_mouse/1-example"},{"type":"function","doc":"Subscribes to timer events with optional data matching.","title":"Raxol.Core.Events.Subscription.subscribe_timer/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_timer/1"},{"type":"function","doc":"* `:match` - Pattern to match against timer data","title":"Options - Raxol.Core.Events.Subscription.subscribe_timer/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_timer/1-options"},{"type":"function","doc":"subscribe_timer(match: :tick)","title":"Example - Raxol.Core.Events.Subscription.subscribe_timer/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_timer/1-example"},{"type":"function","doc":"Subscribes to window events with optional action filters.","title":"Raxol.Core.Events.Subscription.subscribe_window/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_window/1"},{"type":"function","doc":"* `:actions` - List of window actions to match (:resize, :focus, :blur)","title":"Options - Raxol.Core.Events.Subscription.subscribe_window/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_window/1-options"},{"type":"function","doc":"subscribe_window(actions: [:resize])","title":"Example - Raxol.Core.Events.Subscription.subscribe_window/1","ref":"Raxol.Core.Events.Subscription.html#subscribe_window/1-example"},{"type":"type","doc":"","title":"Raxol.Core.Events.Subscription.subscription_opts/0","ref":"Raxol.Core.Events.Subscription.html#t:subscription_opts/0"},{"type":"type","doc":"","title":"Raxol.Core.Events.Subscription.subscription_ref/0","ref":"Raxol.Core.Events.Subscription.html#t:subscription_ref/0"},{"type":"function","doc":"Unsubscribes from events using the subscription reference.","title":"Raxol.Core.Events.Subscription.unsubscribe/1","ref":"Raxol.Core.Events.Subscription.html#unsubscribe/1"},{"type":"function","doc":"Unsubscribes from multiple subscriptions.","title":"Raxol.Core.Events.Subscription.unsubscribe_all/1","ref":"Raxol.Core.Events.Subscription.html#unsubscribe_all/1"},{"type":"module","doc":"Converts rrex_termbox v2.0.1 NIF events to Raxol.Core.Events.Event structs.\n\nThis module handles the translation from the low-level rrex_termbox event format\nto the Raxol event system format.","title":"Raxol.Core.Events.TermboxConverter","ref":"Raxol.Core.Events.TermboxConverter.html"},{"type":"function","doc":"Converts a rrex_termbox v2.0.1 event map to a Raxol Event struct.","title":"Raxol.Core.Events.TermboxConverter.convert/1","ref":"Raxol.Core.Events.TermboxConverter.html#convert/1"},{"type":"function","doc":"- event_map: The event map from rrex_termbox","title":"Parameters - Raxol.Core.Events.TermboxConverter.convert/1","ref":"Raxol.Core.Events.TermboxConverter.html#convert/1-parameters"},{"type":"function","doc":"- `{:ok, %Event{}}` if the conversion was successful\n- `:ignore` if the event should be ignored\n- `{:error, reason}` if the conversion failed","title":"Returns - Raxol.Core.Events.TermboxConverter.convert/1","ref":"Raxol.Core.Events.TermboxConverter.html#convert/1-returns"},{"type":"module","doc":"Focus management system for Raxol terminal UI applications.\n\nThis module provides utilities for managing focus between interactive components:\n- Tab-based keyboard navigation\n- Focus history tracking\n- Focus ring rendering\n- Screen reader announcements","title":"Raxol.Core.FocusManager","ref":"Raxol.Core.FocusManager.html"},{"type":"module","doc":"```elixir\n# Register focusable components in your view\nFocusManager.register_focusable(\"search_input\", 1)\nFocusManager.register_focusable(\"submit_button\", 2)\n\n# Initialize the focus manager with the first focusable element\nFocusManager.set_initial_focus(\"search_input\")\n```","title":"Usage - Raxol.Core.FocusManager","ref":"Raxol.Core.FocusManager.html#module-usage"},{"type":"function","doc":"Disable a focusable component, preventing it from receiving focus.","title":"Raxol.Core.FocusManager.disable_component/1","ref":"Raxol.Core.FocusManager.html#disable_component/1"},{"type":"function","doc":"iex> FocusManager.disable_component(\"submit_button\")\n    :ok","title":"Examples - Raxol.Core.FocusManager.disable_component/1","ref":"Raxol.Core.FocusManager.html#disable_component/1-examples"},{"type":"function","doc":"Enable a previously disabled focusable component.","title":"Raxol.Core.FocusManager.enable_component/1","ref":"Raxol.Core.FocusManager.html#enable_component/1"},{"type":"function","doc":"iex> FocusManager.enable_component(\"submit_button\")\n    :ok","title":"Examples - Raxol.Core.FocusManager.enable_component/1","ref":"Raxol.Core.FocusManager.html#enable_component/1-examples"},{"type":"function","doc":"Move focus to the next focusable element.","title":"Raxol.Core.FocusManager.focus_next/1","ref":"Raxol.Core.FocusManager.html#focus_next/1"},{"type":"function","doc":"* `:group` - Only navigate within this group (default: `nil` - use current group)\n* `:wrap` - Wrap around to first element when at the end (default: `true`)","title":"Options - Raxol.Core.FocusManager.focus_next/1","ref":"Raxol.Core.FocusManager.html#focus_next/1-options"},{"type":"function","doc":"iex> FocusManager.focus_next()\n    :ok\n\n    iex> FocusManager.focus_next(group: :form_actions)\n    :ok","title":"Examples - Raxol.Core.FocusManager.focus_next/1","ref":"Raxol.Core.FocusManager.html#focus_next/1-examples"},{"type":"function","doc":"Move focus to the previous focusable element.","title":"Raxol.Core.FocusManager.focus_previous/1","ref":"Raxol.Core.FocusManager.html#focus_previous/1"},{"type":"function","doc":"* `:group` - Only navigate within this group (default: `nil` - use current group)\n* `:wrap` - Wrap around to last element when at the beginning (default: `true`)","title":"Options - Raxol.Core.FocusManager.focus_previous/1","ref":"Raxol.Core.FocusManager.html#focus_previous/1-options"},{"type":"function","doc":"iex> FocusManager.focus_previous()\n    :ok","title":"Examples - Raxol.Core.FocusManager.focus_previous/1","ref":"Raxol.Core.FocusManager.html#focus_previous/1-examples"},{"type":"function","doc":"Alias for get_focused_element/0.","title":"Raxol.Core.FocusManager.get_current_focus/0","ref":"Raxol.Core.FocusManager.html#get_current_focus/0"},{"type":"function","doc":"Get the ID of the currently focused element.","title":"Raxol.Core.FocusManager.get_focused_element/0","ref":"Raxol.Core.FocusManager.html#get_focused_element/0"},{"type":"function","doc":"iex> FocusManager.set_initial_focus(\"my_button\")\n    iex> FocusManager.get_focused_element()\n    \"my_button\"","title":"Examples - Raxol.Core.FocusManager.get_focused_element/0","ref":"Raxol.Core.FocusManager.html#get_focused_element/0-examples"},{"type":"function","doc":"Get the next focusable element after the given one.\n(Placeholder implementation - mirrors focus_next logic)","title":"Raxol.Core.FocusManager.get_next_focusable/1","ref":"Raxol.Core.FocusManager.html#get_next_focusable/1"},{"type":"function","doc":"Get the previous focusable element before the given one.\nMirrors the logic of `get_next_focusable/1` but searches backwards.","title":"Raxol.Core.FocusManager.get_previous_focusable/1","ref":"Raxol.Core.FocusManager.html#get_previous_focusable/1"},{"type":"function","doc":"Check if a component has focus.","title":"Raxol.Core.FocusManager.has_focus?/1","ref":"Raxol.Core.FocusManager.html#has_focus?/1"},{"type":"function","doc":"iex> FocusManager.has_focus?(\"search_input\")\n    true","title":"Examples - Raxol.Core.FocusManager.has_focus?/1","ref":"Raxol.Core.FocusManager.html#has_focus?/1-examples"},{"type":"function","doc":"Register a handler function to be called when focus changes.\n\nThe handler function should accept two arguments: `old_focus` and `new_focus`.\n(Placeholder implementation)","title":"Raxol.Core.FocusManager.register_focus_change_handler/1","ref":"Raxol.Core.FocusManager.html#register_focus_change_handler/1"},{"type":"function","doc":"Register a focusable component with the focus manager.","title":"Raxol.Core.FocusManager.register_focusable/3","ref":"Raxol.Core.FocusManager.html#register_focusable/3"},{"type":"function","doc":"* `component_id` - Unique identifier for the component\n* `tab_index` - Tab order index (lower numbers are focused first)\n* `opts` - Additional options","title":"Parameters - Raxol.Core.FocusManager.register_focusable/3","ref":"Raxol.Core.FocusManager.html#register_focusable/3-parameters"},{"type":"function","doc":"* `:group` - Focus group name for grouped navigation (default: `:default`)\n* `:disabled` - Whether the component is initially disabled (default: `false`)\n* `:announce` - Announcement text for screen readers when focused (default: `nil`)","title":"Options - Raxol.Core.FocusManager.register_focusable/3","ref":"Raxol.Core.FocusManager.html#register_focusable/3-options"},{"type":"function","doc":"iex> FocusManager.register_focusable(\"search_input\", 1)\n    :ok\n\n    iex> FocusManager.register_focusable(\"submit_button\", 2, group: :form_actions)\n    :ok","title":"Examples - Raxol.Core.FocusManager.register_focusable/3","ref":"Raxol.Core.FocusManager.html#register_focusable/3-examples"},{"type":"function","doc":"Return to the previously focused element.","title":"Raxol.Core.FocusManager.return_to_previous/0","ref":"Raxol.Core.FocusManager.html#return_to_previous/0"},{"type":"function","doc":"iex> FocusManager.return_to_previous()\n    :ok","title":"Examples - Raxol.Core.FocusManager.return_to_previous/0","ref":"Raxol.Core.FocusManager.html#return_to_previous/0-examples"},{"type":"function","doc":"Set focus to a specific component.","title":"Raxol.Core.FocusManager.set_focus/1","ref":"Raxol.Core.FocusManager.html#set_focus/1"},{"type":"function","doc":"iex> FocusManager.set_focus(\"submit_button\")\n    :ok","title":"Examples - Raxol.Core.FocusManager.set_focus/1","ref":"Raxol.Core.FocusManager.html#set_focus/1-examples"},{"type":"function","doc":"Set the initial focus to a specific component.","title":"Raxol.Core.FocusManager.set_initial_focus/1","ref":"Raxol.Core.FocusManager.html#set_initial_focus/1"},{"type":"function","doc":"iex> FocusManager.set_initial_focus(\"search_input\")\n    :ok","title":"Examples - Raxol.Core.FocusManager.set_initial_focus/1","ref":"Raxol.Core.FocusManager.html#set_initial_focus/1-examples"},{"type":"function","doc":"Unregister a focus change handler function.\n(Placeholder implementation)","title":"Raxol.Core.FocusManager.unregister_focus_change_handler/1","ref":"Raxol.Core.FocusManager.html#unregister_focus_change_handler/1"},{"type":"function","doc":"Unregister a focusable component.","title":"Raxol.Core.FocusManager.unregister_focusable/1","ref":"Raxol.Core.FocusManager.html#unregister_focusable/1"},{"type":"function","doc":"iex> FocusManager.unregister_focusable(\"search_input\")\n    :ok","title":"Examples - Raxol.Core.FocusManager.unregister_focusable/1","ref":"Raxol.Core.FocusManager.html#unregister_focusable/1-examples"},{"type":"behaviour","doc":"Defines the behaviour for focus management services.","title":"Raxol.Core.FocusManager.Behaviour","ref":"Raxol.Core.FocusManager.Behaviour.html"},{"type":"callback","doc":"Disables a focusable component.","title":"Raxol.Core.FocusManager.Behaviour.disable_component/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:disable_component/1"},{"type":"callback","doc":"Enables a previously disabled focusable component.","title":"Raxol.Core.FocusManager.Behaviour.enable_component/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:enable_component/1"},{"type":"callback","doc":"Moves focus to the next focusable element.","title":"Raxol.Core.FocusManager.Behaviour.focus_next/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:focus_next/1"},{"type":"callback","doc":"Moves focus to the previous focusable element.","title":"Raxol.Core.FocusManager.Behaviour.focus_previous/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:focus_previous/1"},{"type":"callback","doc":"Alias for get_focused_element/0.","title":"Raxol.Core.FocusManager.Behaviour.get_current_focus/0","ref":"Raxol.Core.FocusManager.Behaviour.html#c:get_current_focus/0"},{"type":"callback","doc":"Gets the ID of the currently focused element.","title":"Raxol.Core.FocusManager.Behaviour.get_focused_element/0","ref":"Raxol.Core.FocusManager.Behaviour.html#c:get_focused_element/0"},{"type":"callback","doc":"Gets the next focusable element after the given one.","title":"Raxol.Core.FocusManager.Behaviour.get_next_focusable/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:get_next_focusable/1"},{"type":"callback","doc":"Gets the previous focusable element before the given one.","title":"Raxol.Core.FocusManager.Behaviour.get_previous_focusable/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:get_previous_focusable/1"},{"type":"callback","doc":"Checks if a component has focus.","title":"Raxol.Core.FocusManager.Behaviour.has_focus?/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:has_focus?/1"},{"type":"callback","doc":"Registers a handler function to be called when focus changes.\nThe handler function should accept two arguments: `old_focus` and `new_focus`.","title":"Raxol.Core.FocusManager.Behaviour.register_focus_change_handler/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:register_focus_change_handler/1"},{"type":"callback","doc":"Registers a focusable component.","title":"Raxol.Core.FocusManager.Behaviour.register_focusable/3","ref":"Raxol.Core.FocusManager.Behaviour.html#c:register_focusable/3"},{"type":"callback","doc":"Returns to the previously focused element.","title":"Raxol.Core.FocusManager.Behaviour.return_to_previous/0","ref":"Raxol.Core.FocusManager.Behaviour.html#c:return_to_previous/0"},{"type":"callback","doc":"Sets focus to a specific component.","title":"Raxol.Core.FocusManager.Behaviour.set_focus/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:set_focus/1"},{"type":"callback","doc":"Sets the initial focus to a specific component.","title":"Raxol.Core.FocusManager.Behaviour.set_initial_focus/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:set_initial_focus/1"},{"type":"callback","doc":"Unregisters a focus change handler function.","title":"Raxol.Core.FocusManager.Behaviour.unregister_focus_change_handler/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:unregister_focus_change_handler/1"},{"type":"callback","doc":"Unregisters a focusable component.","title":"Raxol.Core.FocusManager.Behaviour.unregister_focusable/1","ref":"Raxol.Core.FocusManager.Behaviour.html#c:unregister_focusable/1"},{"type":"module","doc":"Internationalization framework for Raxol terminal UI applications.\n\nThis module provides comprehensive internationalization (i18n) support:\n- Translation of UI text to multiple languages\n- Right-to-left (RTL) language support\n- Integration with accessibility features\n- Language detection and selection\n- Translation fallbacks\n- Dynamic language switching\n\nThe framework works seamlessly with the accessibility module to provide\nscreen reader announcements in the user's preferred language.","title":"Raxol.Core.I18n","ref":"Raxol.Core.I18n.html"},{"type":"module","doc":"```elixir\n# Initialize with default locale\nI18n.init(default_locale: \"en\")\n\n# Get a translated string\nmessage = I18n.t(\"welcome_message\")\n\n# Get a translated string with variables\ngreeting = I18n.t(\"hello_name\", %{name: \"John\"})\n\n# Switch to a different locale\nI18n.set_locale(\"fr\")\n\n# Check if the current locale is RTL\nis_rtl = I18n.rtl?()\n```","title":"Usage - Raxol.Core.I18n","ref":"Raxol.Core.I18n.html#module-usage"},{"type":"function","doc":"Format a screen reader announcement in the current locale.\n\nThis integrates with the accessibility module to provide\nscreen reader announcements in the user's preferred language.","title":"Raxol.Core.I18n.announce/3","ref":"Raxol.Core.I18n.html#announce/3"},{"type":"function","doc":"* `key` - The translation key for the announcement\n* `bindings` - Map of variable bindings (default: %{})\n* `opts` - Additional options","title":"Parameters - Raxol.Core.I18n.announce/3","ref":"Raxol.Core.I18n.html#announce/3-parameters"},{"type":"function","doc":"iex> I18n.announce(\"file_saved\")\n    :ok\n\n    iex> I18n.announce(\"item_selected\", %{item: \"Document\"})\n    :ok","title":"Examples - Raxol.Core.I18n.announce/3","ref":"Raxol.Core.I18n.html#announce/3-examples"},{"type":"function","doc":"Get a list of available locales.","title":"Raxol.Core.I18n.available_locales/0","ref":"Raxol.Core.I18n.html#available_locales/0"},{"type":"function","doc":"iex> I18n.available_locales()\n    [\"en\", \"fr\", \"es\"]","title":"Examples - Raxol.Core.I18n.available_locales/0","ref":"Raxol.Core.I18n.html#available_locales/0-examples"},{"type":"function","doc":"Get the current locale.","title":"Raxol.Core.I18n.get_locale/0","ref":"Raxol.Core.I18n.html#get_locale/0"},{"type":"function","doc":"iex> I18n.get_locale()\n    \"en\"","title":"Examples - Raxol.Core.I18n.get_locale/0","ref":"Raxol.Core.I18n.html#get_locale/0-examples"},{"type":"function","doc":"Handle locale changed events.","title":"Raxol.Core.I18n.handle_locale_changed/1","ref":"Raxol.Core.I18n.html#handle_locale_changed/1"},{"type":"function","doc":"Initialize the internationalization system.","title":"Raxol.Core.I18n.init/1","ref":"Raxol.Core.I18n.html#init/1"},{"type":"function","doc":"* `:default_locale` - The default locale to use (default: \"en\")\n* `:available_locales` - List of available locales (default: [\"en\"])\n* `:fallback_locale` - Fallback locale when translation is missing (default: \"en\")\n* `:translations_dir` - Directory containing translation files (default: \"./priv/locales\")","title":"Options - Raxol.Core.I18n.init/1","ref":"Raxol.Core.I18n.html#init/1-options"},{"type":"function","doc":"iex> I18n.init()\n    :ok\n\n    iex> I18n.init(default_locale: \"fr\", available_locales: [\"en\", \"fr\", \"es\"])\n    :ok","title":"Examples - Raxol.Core.I18n.init/1","ref":"Raxol.Core.I18n.html#init/1-examples"},{"type":"function","doc":"Register translations for a specific locale.","title":"Raxol.Core.I18n.register_translations/2","ref":"Raxol.Core.I18n.html#register_translations/2"},{"type":"function","doc":"* `locale` - The locale for these translations\n* `translations` - Map of translation keys to translated strings","title":"Parameters - Raxol.Core.I18n.register_translations/2","ref":"Raxol.Core.I18n.html#register_translations/2-parameters"},{"type":"function","doc":"iex> I18n.register_translations(\"fr\", %{\n    ...>   \"welcome_message\" => \"Bienvenue dans l'application\",\n    ...>   \"hello_name\" => \"Bonjour, {{name}}!\"\n    ...> })\n    :ok","title":"Examples - Raxol.Core.I18n.register_translations/2","ref":"Raxol.Core.I18n.html#register_translations/2-examples"},{"type":"function","doc":"Check if the current locale is right-to-left (RTL).","title":"Raxol.Core.I18n.rtl?/1","ref":"Raxol.Core.I18n.html#rtl?/1"},{"type":"function","doc":"* `:locale` - Check a specific locale instead of the current one","title":"Options - Raxol.Core.I18n.rtl?/1","ref":"Raxol.Core.I18n.html#rtl?/1-options"},{"type":"function","doc":"iex> I18n.rtl?()\n    false\n\n    iex> I18n.rtl?(locale: \"ar\")\n    true","title":"Examples - Raxol.Core.I18n.rtl?/1","ref":"Raxol.Core.I18n.html#rtl?/1-examples"},{"type":"function","doc":"Set the current locale.","title":"Raxol.Core.I18n.set_locale/1","ref":"Raxol.Core.I18n.html#set_locale/1"},{"type":"function","doc":"* `locale` - The locale to set as current","title":"Parameters - Raxol.Core.I18n.set_locale/1","ref":"Raxol.Core.I18n.html#set_locale/1-parameters"},{"type":"function","doc":"iex> I18n.set_locale(\"fr\")\n    :ok\n\n    iex> I18n.set_locale(\"invalid\")\n    {:error, :invalid_locale}","title":"Examples - Raxol.Core.I18n.set_locale/1","ref":"Raxol.Core.I18n.html#set_locale/1-examples"},{"type":"function","doc":"Get a translated string for the current locale.","title":"Raxol.Core.I18n.t/3","ref":"Raxol.Core.I18n.html#t/3"},{"type":"function","doc":"* `key` - The translation key\n* `bindings` - Map of variable bindings (default: %{})\n* `opts` - Additional options","title":"Parameters - Raxol.Core.I18n.t/3","ref":"Raxol.Core.I18n.html#t/3-parameters"},{"type":"function","doc":"* `:locale` - Override the current locale\n* `:default` - Default text if translation is missing","title":"Options - Raxol.Core.I18n.t/3","ref":"Raxol.Core.I18n.html#t/3-options"},{"type":"function","doc":"iex> I18n.t(\"welcome_message\")\n    \"Welcome to the application\"\n\n    iex> I18n.t(\"hello_name\", %{name: \"John\"})\n    \"Hello, John!\"\n\n    iex> I18n.t(\"missing_key\", %{}, default: \"Missing translation\")\n    \"Missing translation\"","title":"Examples - Raxol.Core.I18n.t/3","ref":"Raxol.Core.I18n.html#t/3-examples"},{"type":"module","doc":"Provides functions for generating unique identifiers.","title":"Raxol.Core.ID","ref":"Raxol.Core.ID.html"},{"type":"function","doc":"Generates a unique string identifier.\n\nUses Erlang's `make_ref` and converts it to a string representation.\nWhile unique within the runtime, refs are not guaranteed universally unique\nlike UUIDs.","title":"Raxol.Core.ID.generate/0","ref":"Raxol.Core.ID.html#generate/0"},{"type":"module","doc":"Keyboard navigation handler for Raxol terminal UI applications.\n\nThis module integrates with the FocusManager to provide keyboard navigation between\ninteractive components using standard key bindings:\n\n- Tab: Move to next focusable element\n- Shift+Tab: Move to previous focusable element\n- Arrow keys: Navigate between elements in a component group\n- Escape: Return to previous focus or dismiss dialogs\n- Enter/Space: Activate currently focused element","title":"Raxol.Core.KeyboardNavigator","ref":"Raxol.Core.KeyboardNavigator.html"},{"type":"module","doc":"```elixir\n# Initialize keyboard navigation in your application\nKeyboardNavigator.init()\n\n# Customize keybindings\nKeyboardNavigator.configure(next_key: :right, previous_key: :left)\n```","title":"Usage - Raxol.Core.KeyboardNavigator","ref":"Raxol.Core.KeyboardNavigator.html#module-usage"},{"type":"function","doc":"Configure keyboard navigation behavior.","title":"Raxol.Core.KeyboardNavigator.configure/1","ref":"Raxol.Core.KeyboardNavigator.html#configure/1"},{"type":"function","doc":"* `:next_key` - Key to move to next element (default: `:tab`)\n* `:previous_key` - Key to move to previous element (default: `:tab` with shift)\n* `:activate_keys` - Keys to activate elements (default: `[:enter, :space]`)\n* `:dismiss_key` - Key to dismiss or go back (default: `:escape`)\n* `:arrow_navigation` - Enable arrow key navigation (default: `true`)\n* `:vim_keys` - Enable vim-style navigation with h,j,k,l (default: `false`)\n* `:group_navigation` - Enable group-based navigation (default: `true`)\n* `:spatial_navigation` - Enable spatial navigation for grid layouts (default: `false`)\n* `:tab_navigation` - Enable tab-based navigation (default: `true`)","title":"Options - Raxol.Core.KeyboardNavigator.configure/1","ref":"Raxol.Core.KeyboardNavigator.html#configure/1-options"},{"type":"function","doc":"iex> KeyboardNavigator.configure(vim_keys: true)\n    :ok","title":"Examples - Raxol.Core.KeyboardNavigator.configure/1","ref":"Raxol.Core.KeyboardNavigator.html#configure/1-examples"},{"type":"function","doc":"Define explicit navigation paths between components.\n\nThis allows customizing navigation beyond spatial or tab order.","title":"Raxol.Core.KeyboardNavigator.define_navigation_path/3","ref":"Raxol.Core.KeyboardNavigator.html#define_navigation_path/3"},{"type":"function","doc":"* `from_id` - Component ID to navigate from\n* `direction` - Navigation direction (`:up`, `:down`, `:left`, `:right`)\n* `to_id` - Component ID to navigate to","title":"Parameters - Raxol.Core.KeyboardNavigator.define_navigation_path/3","ref":"Raxol.Core.KeyboardNavigator.html#define_navigation_path/3-parameters"},{"type":"function","doc":"iex> KeyboardNavigator.define_navigation_path(\"search_input\", :down, \"submit_button\")\n    :ok","title":"Examples - Raxol.Core.KeyboardNavigator.define_navigation_path/3","ref":"Raxol.Core.KeyboardNavigator.html#define_navigation_path/3-examples"},{"type":"function","doc":"Handle keyboard events for navigation.\n\nThis function is called by the EventManager when keyboard events occur.","title":"Raxol.Core.KeyboardNavigator.handle_keyboard_event/1","ref":"Raxol.Core.KeyboardNavigator.html#handle_keyboard_event/1"},{"type":"function","doc":"* `event` - The keyboard event to handle","title":"Parameters - Raxol.Core.KeyboardNavigator.handle_keyboard_event/1","ref":"Raxol.Core.KeyboardNavigator.html#handle_keyboard_event/1-parameters"},{"type":"function","doc":"* `:handled` - If the event was handled by the navigator\n* `:unhandled` - If the event was not handled","title":"Returns - Raxol.Core.KeyboardNavigator.handle_keyboard_event/1","ref":"Raxol.Core.KeyboardNavigator.html#handle_keyboard_event/1-returns"},{"type":"function","doc":"Initialize the keyboard navigator.\n\nThis registers event handlers for keyboard navigation.","title":"Raxol.Core.KeyboardNavigator.init/0","ref":"Raxol.Core.KeyboardNavigator.html#init/0"},{"type":"function","doc":"iex> KeyboardNavigator.init()\n    :ok","title":"Examples - Raxol.Core.KeyboardNavigator.init/0","ref":"Raxol.Core.KeyboardNavigator.html#init/0-examples"},{"type":"function","doc":"Register component positions for spatial navigation.\n\nThis allows arrow keys to navigate components based on their physical layout.","title":"Raxol.Core.KeyboardNavigator.register_component_position/5","ref":"Raxol.Core.KeyboardNavigator.html#register_component_position/5"},{"type":"function","doc":"* `component_id` - Unique identifier for the component\n* `x` - X coordinate\n* `y` - Y coordinate\n* `width` - Width of the component\n* `height` - Height of the component","title":"Parameters - Raxol.Core.KeyboardNavigator.register_component_position/5","ref":"Raxol.Core.KeyboardNavigator.html#register_component_position/5-parameters"},{"type":"function","doc":"iex> KeyboardNavigator.register_component_position(\"search_input\", 10, 5, 30, 3)\n    :ok","title":"Examples - Raxol.Core.KeyboardNavigator.register_component_position/5","ref":"Raxol.Core.KeyboardNavigator.html#register_component_position/5-examples"},{"type":"function","doc":"Register a custom shortcut handler.","title":"Raxol.Core.KeyboardNavigator.register_shortcut/3","ref":"Raxol.Core.KeyboardNavigator.html#register_shortcut/3"},{"type":"function","doc":"* `key` - The key to handle\n* `modifiers` - List of modifier keys (e.g., [:ctrl, :shift])\n* `handler` - Function to call when shortcut is pressed","title":"Parameters - Raxol.Core.KeyboardNavigator.register_shortcut/3","ref":"Raxol.Core.KeyboardNavigator.html#register_shortcut/3-parameters"},{"type":"function","doc":"iex> KeyboardNavigator.register_shortcut(:f1, [], &show_help/0)\n    :ok","title":"Examples - Raxol.Core.KeyboardNavigator.register_shortcut/3","ref":"Raxol.Core.KeyboardNavigator.html#register_shortcut/3-examples"},{"type":"module","doc":"Keyboard shortcuts manager for Raxol applications.\n\nThis module provides functionality to register, manage, and handle keyboard shortcuts\nthroughout the application. It integrates with the accessibility features to provide\nbetter keyboard navigation and interaction.","title":"Raxol.Core.KeyboardShortcuts","ref":"Raxol.Core.KeyboardShortcuts.html"},{"type":"module","doc":"* Register global and context-specific shortcuts\n* Handle keyboard shortcuts with custom callbacks\n* Display available shortcuts based on current context\n* Integration with accessibility features\n* Support for shortcut combinations (Ctrl, Alt, Shift modifiers)","title":"Features - Raxol.Core.KeyboardShortcuts","ref":"Raxol.Core.KeyboardShortcuts.html#module-features"},{"type":"module","doc":"# Initialize the keyboard shortcuts manager\n    KeyboardShortcuts.init()\n\n    # Register a global shortcut\n    KeyboardShortcuts.register_shortcut(\"Ctrl+F\", :search, fn ->\n      # Search functionality\n      search_content()\n    end)\n\n    # Register a context-specific shortcut\n    KeyboardShortcuts.register_shortcut(\"Alt+S\", :save, fn ->\n      # Save functionality\n      save_document()\n    end, context: :editor)\n\n    # Get all available shortcuts for current context\n    shortcuts = KeyboardShortcuts.get_shortcuts_for_context(:editor)\n\n    # Display help for available shortcuts\n    KeyboardShortcuts.show_shortcuts_help()","title":"Examples - Raxol.Core.KeyboardShortcuts","ref":"Raxol.Core.KeyboardShortcuts.html#module-examples"},{"type":"function","doc":"Clean up the keyboard shortcuts manager.\n\nThis function cleans up any resources used by the keyboard shortcuts manager\nand unregisters event handlers.","title":"Raxol.Core.KeyboardShortcuts.cleanup/0","ref":"Raxol.Core.KeyboardShortcuts.html#cleanup/0"},{"type":"function","doc":"iex> KeyboardShortcuts.cleanup()\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.cleanup/0","ref":"Raxol.Core.KeyboardShortcuts.html#cleanup/0-examples"},{"type":"function","doc":"Get the current active context for shortcuts.","title":"Raxol.Core.KeyboardShortcuts.get_current_context/0","ref":"Raxol.Core.KeyboardShortcuts.html#get_current_context/0"},{"type":"function","doc":"iex> KeyboardShortcuts.get_current_context()\n    :editor","title":"Examples - Raxol.Core.KeyboardShortcuts.get_current_context/0","ref":"Raxol.Core.KeyboardShortcuts.html#get_current_context/0-examples"},{"type":"function","doc":"Get all shortcuts for a specific context.","title":"Raxol.Core.KeyboardShortcuts.get_shortcuts_for_context/1","ref":"Raxol.Core.KeyboardShortcuts.html#get_shortcuts_for_context/1"},{"type":"function","doc":"* `context` - The context to get shortcuts for (default: current context)","title":"Parameters - Raxol.Core.KeyboardShortcuts.get_shortcuts_for_context/1","ref":"Raxol.Core.KeyboardShortcuts.html#get_shortcuts_for_context/1-parameters"},{"type":"function","doc":"iex> KeyboardShortcuts.get_shortcuts_for_context(:editor)\n    [\n      %{name: :save, key_combo: \"Ctrl+S\", description: \"Save document\"},\n      %{name: :find, key_combo: \"Ctrl+F\", description: \"Find in document\"}\n    ]","title":"Examples - Raxol.Core.KeyboardShortcuts.get_shortcuts_for_context/1","ref":"Raxol.Core.KeyboardShortcuts.html#get_shortcuts_for_context/1-examples"},{"type":"function","doc":"Initialize the keyboard shortcuts manager.\n\nThis function sets up the necessary state for managing keyboard shortcuts\nand registers event handlers for keyboard events.","title":"Raxol.Core.KeyboardShortcuts.init/0","ref":"Raxol.Core.KeyboardShortcuts.html#init/0"},{"type":"function","doc":"iex> KeyboardShortcuts.init()\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.init/0","ref":"Raxol.Core.KeyboardShortcuts.html#init/0-examples"},{"type":"function","doc":"Register a keyboard shortcut with a callback function.","title":"Raxol.Core.KeyboardShortcuts.register_shortcut/4","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4"},{"type":"function","doc":"* `shortcut` - The keyboard shortcut string (e.g., \"Ctrl+S\", \"Alt+F4\")\n* `name` - A unique identifier for the shortcut (atom or string)\n* `callback` - A function to be called when the shortcut is triggered\n* `opts` - Options for the shortcut","title":"Parameters - Raxol.Core.KeyboardShortcuts.register_shortcut/4","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4-parameters"},{"type":"function","doc":"* `:context` - The context in which this shortcut is active (default: `:global`)\n* `:description` - A description of what the shortcut does\n* `:priority` - Priority level (`:high`, `:medium`, `:low`), affects precedence","title":"Options - Raxol.Core.KeyboardShortcuts.register_shortcut/4","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4-options"},{"type":"function","doc":"iex> KeyboardShortcuts.register_shortcut(\"Ctrl+S\", :save, fn -> save_document() end)\n    :ok\n\n    iex> KeyboardShortcuts.register_shortcut(\"Alt+F\", :file_menu, fn -> open_file_menu() end,\n    ...>   context: :main_menu, description: \"Open File menu\")\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.register_shortcut/4","ref":"Raxol.Core.KeyboardShortcuts.html#register_shortcut/4-examples"},{"type":"function","doc":"Set the current context for shortcuts.\n\nThis affects which shortcuts are active and will be triggered by keyboard events.","title":"Raxol.Core.KeyboardShortcuts.set_context/1","ref":"Raxol.Core.KeyboardShortcuts.html#set_context/1"},{"type":"function","doc":"* `context` - The context to set as active","title":"Parameters - Raxol.Core.KeyboardShortcuts.set_context/1","ref":"Raxol.Core.KeyboardShortcuts.html#set_context/1-parameters"},{"type":"function","doc":"iex> KeyboardShortcuts.set_context(:editor)\n    :ok\n\n    iex> KeyboardShortcuts.set_context(:file_browser)\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.set_context/1","ref":"Raxol.Core.KeyboardShortcuts.html#set_context/1-examples"},{"type":"function","doc":"Display help for available shortcuts.\n\nThis function generates a help message for all shortcuts available in the current context\nand announces it through the accessibility system if enabled.","title":"Raxol.Core.KeyboardShortcuts.show_shortcuts_help/0","ref":"Raxol.Core.KeyboardShortcuts.html#show_shortcuts_help/0"},{"type":"function","doc":"iex> KeyboardShortcuts.show_shortcuts_help()\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.show_shortcuts_help/0","ref":"Raxol.Core.KeyboardShortcuts.html#show_shortcuts_help/0-examples"},{"type":"function","doc":"Trigger a shortcut programmatically.","title":"Raxol.Core.KeyboardShortcuts.trigger_shortcut/2","ref":"Raxol.Core.KeyboardShortcuts.html#trigger_shortcut/2"},{"type":"function","doc":"* `name` - The unique identifier for the shortcut\n* `context` - The context in which the shortcut was registered (default: current context)","title":"Parameters - Raxol.Core.KeyboardShortcuts.trigger_shortcut/2","ref":"Raxol.Core.KeyboardShortcuts.html#trigger_shortcut/2-parameters"},{"type":"function","doc":"iex> KeyboardShortcuts.trigger_shortcut(:save)\n    :ok\n\n    iex> KeyboardShortcuts.trigger_shortcut(:file_menu, :main_menu)\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.trigger_shortcut/2","ref":"Raxol.Core.KeyboardShortcuts.html#trigger_shortcut/2-examples"},{"type":"function","doc":"Unregister a keyboard shortcut.","title":"Raxol.Core.KeyboardShortcuts.unregister_shortcut/2","ref":"Raxol.Core.KeyboardShortcuts.html#unregister_shortcut/2"},{"type":"function","doc":"* `name` - The unique identifier for the shortcut\n* `context` - The context in which the shortcut was registered (default: `:global`)","title":"Parameters - Raxol.Core.KeyboardShortcuts.unregister_shortcut/2","ref":"Raxol.Core.KeyboardShortcuts.html#unregister_shortcut/2-parameters"},{"type":"function","doc":"iex> KeyboardShortcuts.unregister_shortcut(:save)\n    :ok\n\n    iex> KeyboardShortcuts.unregister_shortcut(:file_menu, :main_menu)\n    :ok","title":"Examples - Raxol.Core.KeyboardShortcuts.unregister_shortcut/2","ref":"Raxol.Core.KeyboardShortcuts.html#unregister_shortcut/2-examples"},{"type":"behaviour","doc":"Behaviour for the KeyboardShortcuts module.\nThis allows for mocking the KeyboardShortcuts module in tests.","title":"Raxol.Core.KeyboardShortcutsBehaviour","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.cleanup/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:cleanup/0"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.get_current_context/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:get_current_context/0"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.get_shortcuts_for_context/1","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:get_shortcuts_for_context/1"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.handle_keyboard_event/1","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:handle_keyboard_event/1"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.init/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:init/0"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.register_shortcut/4","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:register_shortcut/4"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.set_context/1","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:set_context/1"},{"type":"type","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.shortcut/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#t:shortcut/0"},{"type":"type","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.shortcut_callback/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#t:shortcut_callback/0"},{"type":"type","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.shortcut_context/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#t:shortcut_context/0"},{"type":"type","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.shortcut_name/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#t:shortcut_name/0"},{"type":"type","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.shortcut_opts/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#t:shortcut_opts/0"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.show_shortcuts_help/0","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:show_shortcuts_help/0"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.trigger_shortcut/2","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:trigger_shortcut/2"},{"type":"callback","doc":"","title":"Raxol.Core.KeyboardShortcutsBehaviour.unregister_shortcut/2","ref":"Raxol.Core.KeyboardShortcutsBehaviour.html#c:unregister_shortcut/2"},{"type":"module","doc":"Handles AI-based analysis of performance metrics and generates optimization recommendations.\nThis module integrates with an AI agent to provide deep insights and actionable suggestions.","title":"Raxol.Core.Performance.AIAnalyzer","ref":"Raxol.Core.Performance.AIAnalyzer.html"},{"type":"function","doc":"Analyzes performance metrics using AI and returns detailed insights and recommendations.","title":"Raxol.Core.Performance.AIAnalyzer.analyze/2","ref":"Raxol.Core.Performance.AIAnalyzer.html#analyze/2"},{"type":"function","doc":"- metrics: Map containing performance metrics from the monitor\n  - options: Map of analysis options\n    - :depth (atom) - Analysis depth (:basic, :detailed, :comprehensive)\n    - :focus (list) - Areas to focus on ([:fps, :memory, :jank, :gc])\n    - :historical_data (list) - Optional historical metrics for trend analysis","title":"Parameters - Raxol.Core.Performance.AIAnalyzer.analyze/2","ref":"Raxol.Core.Performance.AIAnalyzer.html#analyze/2-parameters"},{"type":"function","doc":"- Map containing:\n    - :insights - Detailed performance insights\n    - :recommendations - Prioritized optimization suggestions\n    - :risk_assessment - Performance risk analysis\n    - :optimization_impact - Expected impact of suggested optimizations\n    - :ai_confidence - AI's confidence in the analysis","title":"Returns - Raxol.Core.Performance.AIAnalyzer.analyze/2","ref":"Raxol.Core.Performance.AIAnalyzer.html#analyze/2-returns"},{"type":"function","doc":"Generates a performance report with AI insights and recommendations.","title":"Raxol.Core.Performance.AIAnalyzer.generate_report/2","ref":"Raxol.Core.Performance.AIAnalyzer.html#generate_report/2"},{"type":"function","doc":"- metrics: Map containing performance metrics\n  - options: Map of report options\n    - :format (atom) - Report format (:text, :json, :html)\n    - :include_graphs (boolean) - Whether to include performance graphs\n    - :include_code_samples (boolean) - Whether to include code optimization examples","title":"Parameters - Raxol.Core.Performance.AIAnalyzer.generate_report/2","ref":"Raxol.Core.Performance.AIAnalyzer.html#generate_report/2-parameters"},{"type":"function","doc":"- Map containing the formatted report and additional data","title":"Returns - Raxol.Core.Performance.AIAnalyzer.generate_report/2","ref":"Raxol.Core.Performance.AIAnalyzer.html#generate_report/2-returns"},{"type":"module","doc":"Analyzes performance metrics and generates insights for AI analysis.\n\nThis module:\n- Processes performance metrics\n- Identifies performance patterns\n- Generates optimization suggestions\n- Formats data for AI analysis","title":"Raxol.Core.Performance.Analyzer","ref":"Raxol.Core.Performance.Analyzer.html"},{"type":"module","doc":"```elixir\n# Get metrics from monitor\nmetrics = Monitor.get_metrics(monitor)\n\n# Analyze metrics\nanalysis = Analyzer.analyze(metrics)\n\n# Get AI-ready data\nai_data = Analyzer.prepare_ai_data(analysis)\n```","title":"Usage - Raxol.Core.Performance.Analyzer","ref":"Raxol.Core.Performance.Analyzer.html#module-usage"},{"type":"function","doc":"Analyzes performance metrics and generates insights.","title":"Raxol.Core.Performance.Analyzer.analyze/1","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1"},{"type":"function","doc":"* `metrics` - Map of performance metrics from Monitor","title":"Parameters - Raxol.Core.Performance.Analyzer.analyze/1","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1-parameters"},{"type":"function","doc":"Map containing analysis results:\n* `:performance_score` - Overall performance score (0-100)\n* `:issues` - List of identified performance issues\n* `:suggestions` - List of optimization suggestions\n* `:patterns` - Identified performance patterns\n* `:trends` - Performance trends over time","title":"Returns - Raxol.Core.Performance.Analyzer.analyze/1","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1-returns"},{"type":"function","doc":"iex> metrics = %{\n      fps: 60,\n      avg_frame_time: 16.5,\n      jank_count: 2,\n      memory_usage: 1234567,\n      gc_stats: %{...}\n    }\n    iex> Analyzer.analyze(metrics)\n    %{\n      performance_score: 85,\n      issues: [\"High memory usage\", \"Occasional jank\"],\n      suggestions: [\"Optimize memory allocation\", \"Profile render loop\"],\n      patterns: %{...},\n      trends: %{...}\n    }","title":"Examples - Raxol.Core.Performance.Analyzer.analyze/1","ref":"Raxol.Core.Performance.Analyzer.html#analyze/1-examples"},{"type":"function","doc":"Prepares performance data for AI analysis.","title":"Raxol.Core.Performance.Analyzer.prepare_ai_data/1","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1"},{"type":"function","doc":"* `analysis` - Analysis results from analyze/1","title":"Parameters - Raxol.Core.Performance.Analyzer.prepare_ai_data/1","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1-parameters"},{"type":"function","doc":"Map containing AI-ready data:\n* `:metrics` - Raw performance metrics\n* `:analysis` - Analysis results\n* `:context` - Additional context for AI\n* `:format` - Data format specification","title":"Returns - Raxol.Core.Performance.Analyzer.prepare_ai_data/1","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1-returns"},{"type":"function","doc":"iex> metrics = %{fps: 60, ...}\n    iex> analysis = Analyzer.analyze(metrics)\n    iex> ai_data = Analyzer.prepare_ai_data(analysis)\n    iex> Map.has_key?(ai_data, :metrics)\n    true","title":"Examples - Raxol.Core.Performance.Analyzer.prepare_ai_data/1","ref":"Raxol.Core.Performance.Analyzer.html#prepare_ai_data/1-examples"},{"type":"module","doc":"Detects UI jank by analyzing frame timing.\n\nA frame is considered janky if it takes longer than the jank threshold\nto render. The detector maintains a rolling window of frame times to\nidentify patterns of jank.","title":"Raxol.Core.Performance.JankDetector","ref":"Raxol.Core.Performance.JankDetector.html"},{"type":"module","doc":"```elixir\n# Create a new detector\ndetector = JankDetector.new(16, 60)  # 16ms threshold, 60 frame window\n\n# Record a frame\ndetector = JankDetector.record_frame(detector, 20)\n\n# Check for jank\nif JankDetector.detect_jank?(detector) do\n  Logger.warning(\"Jank detected\")\nend\n```","title":"Usage - Raxol.Core.Performance.JankDetector","ref":"Raxol.Core.Performance.JankDetector.html#module-usage"},{"type":"function","doc":"Checks if jank was detected in the last frame.","title":"Raxol.Core.Performance.JankDetector.detect_jank?/1","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1"},{"type":"function","doc":"* `detector` - The jank detector","title":"Parameters - Raxol.Core.Performance.JankDetector.detect_jank?/1","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1-parameters"},{"type":"function","doc":"* `true` if the last frame was janky\n* `false` otherwise","title":"Returns - Raxol.Core.Performance.JankDetector.detect_jank?/1","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1-returns"},{"type":"function","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.detect_jank?(detector)\n    true","title":"Examples - Raxol.Core.Performance.JankDetector.detect_jank?/1","ref":"Raxol.Core.Performance.JankDetector.html#detect_jank?/1-examples"},{"type":"function","doc":"Gets the average frame time in the current window.","title":"Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1"},{"type":"function","doc":"* `detector` - The jank detector","title":"Parameters - Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1-parameters"},{"type":"function","doc":"Average frame time in milliseconds.","title":"Returns - Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1-returns"},{"type":"function","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.get_avg_frame_time(detector)\n    20.0","title":"Examples - Raxol.Core.Performance.JankDetector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_avg_frame_time/1-examples"},{"type":"function","doc":"Gets the number of janky frames in the current window.","title":"Raxol.Core.Performance.JankDetector.get_jank_count/1","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1"},{"type":"function","doc":"* `detector` - The jank detector","title":"Parameters - Raxol.Core.Performance.JankDetector.get_jank_count/1","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1-parameters"},{"type":"function","doc":"Number of janky frames.","title":"Returns - Raxol.Core.Performance.JankDetector.get_jank_count/1","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1-returns"},{"type":"function","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.get_jank_count(detector)\n    1","title":"Examples - Raxol.Core.Performance.JankDetector.get_jank_count/1","ref":"Raxol.Core.Performance.JankDetector.html#get_jank_count/1-examples"},{"type":"function","doc":"Gets the maximum frame time in the current window.","title":"Raxol.Core.Performance.JankDetector.get_max_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1"},{"type":"function","doc":"* `detector` - The jank detector","title":"Parameters - Raxol.Core.Performance.JankDetector.get_max_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1-parameters"},{"type":"function","doc":"Maximum frame time in milliseconds.","title":"Returns - Raxol.Core.Performance.JankDetector.get_max_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1-returns"},{"type":"function","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> JankDetector.get_max_frame_time(detector)\n    20","title":"Examples - Raxol.Core.Performance.JankDetector.get_max_frame_time/1","ref":"Raxol.Core.Performance.JankDetector.html#get_max_frame_time/1-examples"},{"type":"function","doc":"Creates a new jank detector.","title":"Raxol.Core.Performance.JankDetector.new/2","ref":"Raxol.Core.Performance.JankDetector.html#new/2"},{"type":"function","doc":"* `threshold` - Time in milliseconds above which a frame is considered janky\n* `window_size` - Number of frames to keep in the rolling window","title":"Parameters - Raxol.Core.Performance.JankDetector.new/2","ref":"Raxol.Core.Performance.JankDetector.html#new/2-parameters"},{"type":"function","doc":"A new jank detector struct.","title":"Returns - Raxol.Core.Performance.JankDetector.new/2","ref":"Raxol.Core.Performance.JankDetector.html#new/2-returns"},{"type":"function","doc":"iex> JankDetector.new(16, 60)\n    %JankDetector{\n      threshold: 16,\n      window_size: 60,\n      frame_times: [],\n      jank_count: 0\n    }","title":"Examples - Raxol.Core.Performance.JankDetector.new/2","ref":"Raxol.Core.Performance.JankDetector.html#new/2-examples"},{"type":"function","doc":"Records a frame's timing.","title":"Raxol.Core.Performance.JankDetector.record_frame/2","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2"},{"type":"function","doc":"* `detector` - The jank detector\n* `frame_time` - Time taken to render the frame in milliseconds","title":"Parameters - Raxol.Core.Performance.JankDetector.record_frame/2","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2-parameters"},{"type":"function","doc":"Updated jank detector.","title":"Returns - Raxol.Core.Performance.JankDetector.record_frame/2","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2-returns"},{"type":"function","doc":"iex> detector = JankDetector.new(16, 60)\n    iex> detector = JankDetector.record_frame(detector, 20)\n    iex> detector.jank_count\n    1","title":"Examples - Raxol.Core.Performance.JankDetector.record_frame/2","ref":"Raxol.Core.Performance.JankDetector.html#record_frame/2-examples"},{"type":"module","doc":"Collects and calculates performance metrics.\n\nThis module tracks:\n- Frame rate (FPS)\n- Frame timing statistics\n- Memory usage\n- Garbage collection statistics","title":"Raxol.Core.Performance.MetricsCollector","ref":"Raxol.Core.Performance.MetricsCollector.html"},{"type":"module","doc":"```elixir\n# Create a new collector\ncollector = MetricsCollector.new()\n\n# Record a frame\ncollector = MetricsCollector.record_frame(collector, 16)\n\n# Get current FPS\nfps = MetricsCollector.get_fps(collector)\n\n# Update memory metrics\ncollector = MetricsCollector.update_memory_usage(collector)\n```","title":"Usage - Raxol.Core.Performance.MetricsCollector","ref":"Raxol.Core.Performance.MetricsCollector.html#module-usage"},{"type":"function","doc":"Gets the average frame time.","title":"Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1"},{"type":"function","doc":"* `collector` - The metrics collector","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1-parameters"},{"type":"function","doc":"Average frame time in milliseconds.","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1-returns"},{"type":"function","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.record_frame(collector, 16)\n    iex> MetricsCollector.get_avg_frame_time(collector)\n    16.0","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_avg_frame_time/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_avg_frame_time/1-examples"},{"type":"function","doc":"Gets the current frames per second.","title":"Raxol.Core.Performance.MetricsCollector.get_fps/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1"},{"type":"function","doc":"* `collector` - The metrics collector","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_fps/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1-parameters"},{"type":"function","doc":"Current FPS as a float.","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_fps/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1-returns"},{"type":"function","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.record_frame(collector, 16)\n    iex> MetricsCollector.get_fps(collector)\n    62.5","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_fps/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_fps/1-examples"},{"type":"function","doc":"Gets garbage collection statistics.","title":"Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1"},{"type":"function","doc":"* `collector` - The metrics collector","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1-parameters"},{"type":"function","doc":"Map containing GC statistics:\n* `:number_of_gcs` - Total number of garbage collections\n* `:words_reclaimed` - Total words reclaimed\n* `:heap_size` - Current heap size\n* `:heap_limit` - Maximum heap size","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1-returns"},{"type":"function","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> gc_stats = MetricsCollector.get_gc_stats(collector)\n    iex> Map.has_key?(gc_stats, :number_of_gcs)\n    true","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_gc_stats/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_gc_stats/1-examples"},{"type":"function","doc":"Gets the memory usage trend.","title":"Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1"},{"type":"function","doc":"* `collector` - The metrics collector","title":"Parameters - Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1-parameters"},{"type":"function","doc":"Memory usage trend as a percentage change.","title":"Returns - Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1-returns"},{"type":"function","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> MetricsCollector.get_memory_trend(collector)\n    0.0","title":"Examples - Raxol.Core.Performance.MetricsCollector.get_memory_trend/1","ref":"Raxol.Core.Performance.MetricsCollector.html#get_memory_trend/1-examples"},{"type":"function","doc":"Creates a new metrics collector.","title":"Raxol.Core.Performance.MetricsCollector.new/0","ref":"Raxol.Core.Performance.MetricsCollector.html#new/0"},{"type":"function","doc":"A new metrics collector struct.","title":"Returns - Raxol.Core.Performance.MetricsCollector.new/0","ref":"Raxol.Core.Performance.MetricsCollector.html#new/0-returns"},{"type":"function","doc":"iex> MetricsCollector.new()\n    %MetricsCollector{\n      frame_times: [],\n      memory_usage: 0,\n      gc_stats: %{},\n      last_gc_time: 0\n    }","title":"Examples - Raxol.Core.Performance.MetricsCollector.new/0","ref":"Raxol.Core.Performance.MetricsCollector.html#new/0-examples"},{"type":"function","doc":"Records a frame's timing.","title":"Raxol.Core.Performance.MetricsCollector.record_frame/2","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2"},{"type":"function","doc":"* `collector` - The metrics collector\n* `frame_time` - Time taken to render the frame in milliseconds","title":"Parameters - Raxol.Core.Performance.MetricsCollector.record_frame/2","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2-parameters"},{"type":"function","doc":"Updated metrics collector.","title":"Returns - Raxol.Core.Performance.MetricsCollector.record_frame/2","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2-returns"},{"type":"function","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.record_frame(collector, 16)\n    iex> length(collector.frame_times)\n    1","title":"Examples - Raxol.Core.Performance.MetricsCollector.record_frame/2","ref":"Raxol.Core.Performance.MetricsCollector.html#record_frame/2-examples"},{"type":"function","doc":"Updates memory usage metrics.","title":"Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1"},{"type":"function","doc":"* `collector` - The metrics collector","title":"Parameters - Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1-parameters"},{"type":"function","doc":"Updated metrics collector with current memory usage and GC stats.","title":"Returns - Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1-returns"},{"type":"function","doc":"iex> collector = MetricsCollector.new()\n    iex> collector = MetricsCollector.update_memory_usage(collector)\n    iex> collector.memory_usage > 0\n    true","title":"Examples - Raxol.Core.Performance.MetricsCollector.update_memory_usage/1","ref":"Raxol.Core.Performance.MetricsCollector.html#update_memory_usage/1-examples"},{"type":"module","doc":"Performance monitoring system for Raxol applications.\n\nThis module provides tools for:\n- Frame rate monitoring\n- Memory usage tracking\n- UI jank detection\n- Performance metrics collection\n- Performance visualization","title":"Raxol.Core.Performance.Monitor","ref":"Raxol.Core.Performance.Monitor.html"},{"type":"module","doc":"```elixir\n# Start monitoring\n{:ok, monitor} = Monitor.start_link()\n\n# Record frame timing\nMonitor.record_frame(monitor, 16)  # 16ms frame time\n\n# Check for jank\nif Monitor.detect_jank?(monitor) do\n  Logger.warning(\"UI jank detected\")\nend\n\n# Get performance metrics\nmetrics = Monitor.get_metrics(monitor)\n```","title":"Usage - Raxol.Core.Performance.Monitor","ref":"Raxol.Core.Performance.Monitor.html#module-usage"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Performance.Monitor.child_spec/1","ref":"Raxol.Core.Performance.Monitor.html#child_spec/1"},{"type":"function","doc":"Checks if jank was detected in the last frame.","title":"Raxol.Core.Performance.Monitor.detect_jank?/1","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1"},{"type":"function","doc":"* `monitor` - The monitor process","title":"Parameters - Raxol.Core.Performance.Monitor.detect_jank?/1","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1-parameters"},{"type":"function","doc":"* `true` if jank was detected\n* `false` otherwise","title":"Returns - Raxol.Core.Performance.Monitor.detect_jank?/1","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1-returns"},{"type":"function","doc":"iex> Monitor.detect_jank?(monitor)\n    false","title":"Examples - Raxol.Core.Performance.Monitor.detect_jank?/1","ref":"Raxol.Core.Performance.Monitor.html#detect_jank?/1-examples"},{"type":"function","doc":"Gets current performance metrics.","title":"Raxol.Core.Performance.Monitor.get_metrics/1","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1"},{"type":"function","doc":"* `monitor` - The monitor process","title":"Parameters - Raxol.Core.Performance.Monitor.get_metrics/1","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1-parameters"},{"type":"function","doc":"Map containing performance metrics:\n* `:fps` - Current frames per second\n* `:avg_frame_time` - Average frame time in milliseconds\n* `:jank_count` - Number of janky frames in the sample window\n* `:memory_usage` - Current memory usage in bytes\n* `:gc_stats` - Garbage collection statistics","title":"Returns - Raxol.Core.Performance.Monitor.get_metrics/1","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1-returns"},{"type":"function","doc":"iex> Monitor.get_metrics(monitor)\n    %{\n      fps: 60,\n      avg_frame_time: 16.5,\n      jank_count: 2,\n      memory_usage: 1234567,\n      gc_stats: %{...}\n    }","title":"Examples - Raxol.Core.Performance.Monitor.get_metrics/1","ref":"Raxol.Core.Performance.Monitor.html#get_metrics/1-examples"},{"type":"function","doc":"Records a frame's timing.","title":"Raxol.Core.Performance.Monitor.record_frame/2","ref":"Raxol.Core.Performance.Monitor.html#record_frame/2"},{"type":"function","doc":"* `monitor` - The monitor process\n* `frame_time` - Time taken to render the frame in milliseconds","title":"Parameters - Raxol.Core.Performance.Monitor.record_frame/2","ref":"Raxol.Core.Performance.Monitor.html#record_frame/2-parameters"},{"type":"function","doc":"iex> Monitor.record_frame(monitor, 16)\n    :ok","title":"Examples - Raxol.Core.Performance.Monitor.record_frame/2","ref":"Raxol.Core.Performance.Monitor.html#record_frame/2-examples"},{"type":"function","doc":"Starts a new performance monitor.","title":"Raxol.Core.Performance.Monitor.start_link/1","ref":"Raxol.Core.Performance.Monitor.html#start_link/1"},{"type":"function","doc":"* `:jank_threshold` - Time in milliseconds above which a frame is considered janky (default: 16)\n* `:sample_size` - Number of frames to keep in the rolling window (default: 60)\n* `:memory_check_interval` - How often to check memory usage in milliseconds (default: 5000)","title":"Options - Raxol.Core.Performance.Monitor.start_link/1","ref":"Raxol.Core.Performance.Monitor.html#start_link/1-options"},{"type":"function","doc":"iex> {:ok, monitor} = Monitor.start_link()\n    {:ok, #PID<0.123.0>}\n\n    iex> {:ok, monitor} = Monitor.start_link(jank_threshold: 20)\n    {:ok, #PID<0.124.0>}","title":"Examples - Raxol.Core.Performance.Monitor.start_link/1","ref":"Raxol.Core.Performance.Monitor.html#start_link/1-examples"},{"type":"module","doc":"Core plugin providing clipboard read/write commands.\nDelegates to the configured system clipboard implementation.","title":"Raxol.Core.Plugins.Core.ClipboardPlugin","ref":"Raxol.Core.Plugins.Core.ClipboardPlugin.html"},{"type":"module","doc":"Core plugin responsible for handling notifications (:notify).\nRelies on an implementation of Raxol.System.Interaction for OS interactions.","title":"Raxol.Core.Plugins.Core.NotificationPlugin","ref":"Raxol.Core.Plugins.Core.NotificationPlugin.html"},{"type":"function","doc":"","title":"Raxol.Core.Plugins.Core.NotificationPlugin.handle_command/2","ref":"Raxol.Core.Plugins.Core.NotificationPlugin.html#handle_command/2"},{"type":"module","doc":"Handles persistence (loading/saving) of user preferences to a file.","title":"Raxol.Core.Preferences.Persistence","ref":"Raxol.Core.Preferences.Persistence.html"},{"type":"function","doc":"Loads user preferences from the designated file.\n\nReturns:\n  - `{:ok, preferences_map}` if successful.\n  - `{:error, :file_not_found}` if the file doesn't exist.\n  - `{:error, reason}` for other file or decoding errors.","title":"Raxol.Core.Preferences.Persistence.load/0","ref":"Raxol.Core.Preferences.Persistence.html#load/0"},{"type":"function","doc":"Returns the full path to the user preferences file.\nUses an application-specific directory.","title":"Raxol.Core.Preferences.Persistence.preferences_path/0","ref":"Raxol.Core.Preferences.Persistence.html#preferences_path/0"},{"type":"function","doc":"Saves the given preferences map to the designated file.\n\nSerializes the map using `:erlang.term_to_binary`.\n\nReturns:\n  - `:ok` on success.\n  - `{:error, reason}` on failure.","title":"Raxol.Core.Preferences.Persistence.save/1","ref":"Raxol.Core.Preferences.Persistence.html#save/1"},{"type":"module","doc":"Handles storage and retrieval of user preferences.","title":"Raxol.Core.Preferences.Store","ref":"Raxol.Core.Preferences.Store.html"},{"type":"function","doc":"","title":"Raxol.Core.Preferences.Store.save_to_preferences/1","ref":"Raxol.Core.Preferences.Store.html#save_to_preferences/1"},{"type":"module","doc":"Manages terminal buffer rendering with double buffering and damage tracking.\n\nThis module provides efficient terminal rendering by:\n* Using double buffering to prevent screen flicker\n* Tracking damaged regions to minimize updates\n* Supporting partial screen updates\n* Managing frame timing","title":"Raxol.Core.Renderer.Buffer","ref":"Raxol.Core.Renderer.Buffer.html"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Buffer.buffer/0","ref":"Raxol.Core.Renderer.Buffer.html#t:buffer/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Buffer.cell/0","ref":"Raxol.Core.Renderer.Buffer.html#t:cell/0"},{"type":"function","doc":"Clears the entire buffer and marks all cells as damaged.","title":"Raxol.Core.Renderer.Buffer.clear/1","ref":"Raxol.Core.Renderer.Buffer.html#clear/1"},{"type":"function","doc":"Gets the damaged regions that need to be redrawn.\nReturns a list of {position, cell} tuples.","title":"Raxol.Core.Renderer.Buffer.get_damage/1","ref":"Raxol.Core.Renderer.Buffer.html#get_damage/1"},{"type":"function","doc":"Creates a new buffer manager with the given size and FPS.","title":"Raxol.Core.Renderer.Buffer.new/3","ref":"Raxol.Core.Renderer.Buffer.html#new/3"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Buffer.position/0","ref":"Raxol.Core.Renderer.Buffer.html#t:position/0"},{"type":"function","doc":"Updates a cell in the back buffer and marks it as damaged.","title":"Raxol.Core.Renderer.Buffer.put_cell/4","ref":"Raxol.Core.Renderer.Buffer.html#put_cell/4"},{"type":"function","doc":"Resizes the buffer to the new dimensions.\nPreserves content where possible and marks all changed cells as damaged.","title":"Raxol.Core.Renderer.Buffer.resize/3","ref":"Raxol.Core.Renderer.Buffer.html#resize/3"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Buffer.size/0","ref":"Raxol.Core.Renderer.Buffer.html#t:size/0"},{"type":"function","doc":"Swaps the front and back buffers if enough time has passed since the last frame.\nReturns {buffer, should_render}, where should_render indicates if a new frame should be drawn.","title":"Raxol.Core.Renderer.Buffer.swap_buffers/1","ref":"Raxol.Core.Renderer.Buffer.html#swap_buffers/1"},{"type":"module","doc":"Provides comprehensive color support for terminal rendering.\n\nSupports:\n* ANSI 16 colors (4-bit)\n* ANSI 256 colors (8-bit)\n* True Color (24-bit)\n* Color themes\n* Terminal background detection","title":"Raxol.Core.Renderer.Color","ref":"Raxol.Core.Renderer.Color.html"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Color.ansi_16/0","ref":"Raxol.Core.Renderer.Color.html#t:ansi_16/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Color.ansi_256/0","ref":"Raxol.Core.Renderer.Color.html#t:ansi_256/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Color.color/0","ref":"Raxol.Core.Renderer.Color.html#t:color/0"},{"type":"function","doc":"Creates a color theme map.","title":"Raxol.Core.Renderer.Color.create_theme/1","ref":"Raxol.Core.Renderer.Color.html#create_theme/1"},{"type":"function","doc":"Returns the default color theme.","title":"Raxol.Core.Renderer.Color.default_theme/0","ref":"Raxol.Core.Renderer.Color.html#default_theme/0"},{"type":"function","doc":"Detects the terminal's background color.\nReturns :light or :dark.","title":"Raxol.Core.Renderer.Color.detect_background/0","ref":"Raxol.Core.Renderer.Color.html#detect_background/0"},{"type":"function","doc":"Converts a hex color string to RGB.","title":"Raxol.Core.Renderer.Color.hex_to_rgb/1","ref":"Raxol.Core.Renderer.Color.html#hex_to_rgb/1"},{"type":"function","doc":"Converts RGB values to the nearest ANSI 256 color code.","title":"Raxol.Core.Renderer.Color.rgb_to_ansi256/1","ref":"Raxol.Core.Renderer.Color.html#rgb_to_ansi256/1"},{"type":"function","doc":"Converts a color representation to its ANSI foreground escape code.","title":"Raxol.Core.Renderer.Color.to_ansi/1","ref":"Raxol.Core.Renderer.Color.html#to_ansi/1"},{"type":"function","doc":"Converts a color representation to its ANSI background escape code.","title":"Raxol.Core.Renderer.Color.to_bg_ansi/1","ref":"Raxol.Core.Renderer.Color.html#to_bg_ansi/1"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Color.true_color/0","ref":"Raxol.Core.Renderer.Color.html#t:true_color/0"},{"type":"module","doc":"Defines the core element structure for the rendering system.\n\nElements are the building blocks of Raxol's UI system. Each element\nrepresents a renderable component with:\n* A tag identifying its type\n* Attributes controlling its appearance and behavior\n* Optional children forming a tree structure","title":"Raxol.Core.Renderer.Element","ref":"Raxol.Core.Renderer.Element.html"},{"type":"function","doc":"Adds children to an existing element.","title":"Raxol.Core.Renderer.Element.add_children/2","ref":"Raxol.Core.Renderer.Element.html#add_children/2"},{"type":"function","doc":"Creates a new element with the given tag and attributes.","title":"Raxol.Core.Renderer.Element.new/3","ref":"Raxol.Core.Renderer.Element.html#new/3"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Element.t/0","ref":"Raxol.Core.Renderer.Element.html#t:t/0"},{"type":"function","doc":"Updates an element's attributes while preserving its structure.","title":"Raxol.Core.Renderer.Element.update_attrs/2","ref":"Raxol.Core.Renderer.Element.html#update_attrs/2"},{"type":"function","doc":"Validates that an element tree follows the component rules.","title":"Raxol.Core.Renderer.Element.validate/1","ref":"Raxol.Core.Renderer.Element.html#validate/1"},{"type":"module","doc":"Manages the rendering system for Raxol applications.\n\nThis module coordinates:\n* Frame-based rendering\n* Terminal buffer management\n* Component rendering\n* Screen updates","title":"Raxol.Core.Renderer.Manager","ref":"Raxol.Core.Renderer.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Renderer.Manager.child_spec/1","ref":"Raxol.Core.Renderer.Manager.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Core.Renderer.Manager.cleanup/0","ref":"Raxol.Core.Renderer.Manager.html#cleanup/0"},{"type":"function","doc":"","title":"Raxol.Core.Renderer.Manager.initialize/1","ref":"Raxol.Core.Renderer.Manager.html#initialize/1"},{"type":"function","doc":"","title":"Raxol.Core.Renderer.Manager.render/1","ref":"Raxol.Core.Renderer.Manager.html#render/1"},{"type":"function","doc":"","title":"Raxol.Core.Renderer.Manager.start_link/1","ref":"Raxol.Core.Renderer.Manager.html#start_link/1"},{"type":"module","doc":"Main facade module for the Raxol view system.\nProvides a unified interface for creating and managing views.","title":"Raxol.Core.Renderer.View","ref":"Raxol.Core.Renderer.View.html"},{"type":"function","doc":"Wraps a view with a border using a block style.","title":"Raxol.Core.Renderer.View.block_border/2","ref":"Raxol.Core.Renderer.View.html#block_border/2"},{"type":"function","doc":"* `view` - The view to wrap with a border\n  * `opts` - Options for the border\n    * `:title` - Optional title to display in the border\n    * `:align` - Title alignment (`:left`, `:center`, `:right`)","title":"Parameters - Raxol.Core.Renderer.View.block_border/2","ref":"Raxol.Core.Renderer.View.html#block_border/2-parameters"},{"type":"function","doc":"View.block_border(view)\n    View.block_border(view, title: \"Title\")","title":"Examples - Raxol.Core.Renderer.View.block_border/2","ref":"Raxol.Core.Renderer.View.html#block_border/2-examples"},{"type":"function","doc":"Wraps a view with a border using a bold style.","title":"Raxol.Core.Renderer.View.bold_border/2","ref":"Raxol.Core.Renderer.View.html#bold_border/2"},{"type":"function","doc":"* `view` - The view to wrap with a border\n  * `opts` - Options for the border\n    * `:title` - Optional title to display in the border\n    * `:align` - Title alignment (`:left`, `:center`, `:right`)","title":"Parameters - Raxol.Core.Renderer.View.bold_border/2","ref":"Raxol.Core.Renderer.View.html#bold_border/2-parameters"},{"type":"function","doc":"View.bold_border(view)\n    View.bold_border(view, title: \"Title\")","title":"Examples - Raxol.Core.Renderer.View.bold_border/2","ref":"Raxol.Core.Renderer.View.html#bold_border/2-examples"},{"type":"function","doc":"Creates a new border around a view.","title":"Raxol.Core.Renderer.View.border/2","ref":"Raxol.Core.Renderer.View.html#border/2"},{"type":"function","doc":"* `:style` - Border style\n  * `:title` - Title for the border\n  * `:fg` - Foreground color\n  * `:bg` - Background color","title":"Options - Raxol.Core.Renderer.View.border/2","ref":"Raxol.Core.Renderer.View.html#border/2-options"},{"type":"function","doc":"View.border(view, style: :single)\n    View.border(view, title: \"Title\", style: :double)","title":"Examples - Raxol.Core.Renderer.View.border/2","ref":"Raxol.Core.Renderer.View.html#border/2-examples"},{"type":"macro","doc":"Macro for creating a border around a view with a do-block for children.","title":"Raxol.Core.Renderer.View.border_wrap/2","ref":"Raxol.Core.Renderer.View.html#border_wrap/2"},{"type":"macro","doc":"View.border_wrap style: [:bold] do\n      [View.text(\"A\"), View.text(\"B\")]\n    end\n\n    View.border_wrap :single, style: [:bold] do\n      [View.text(\"A\"), View.text(\"B\")]\n    end","title":"Examples - Raxol.Core.Renderer.View.border_wrap/2","ref":"Raxol.Core.Renderer.View.html#border_wrap/2-examples"},{"type":"macro","doc":"","title":"Raxol.Core.Renderer.View.border_wrap/3","ref":"Raxol.Core.Renderer.View.html#border_wrap/3"},{"type":"function","doc":"Creates a new box view with padding and optional border.","title":"Raxol.Core.Renderer.View.box/1","ref":"Raxol.Core.Renderer.View.html#box/1"},{"type":"function","doc":"* `opts` - Options for the box\n    * `:padding` - Padding around the content (default: 0)\n    * `:border` - Border style (`:none`, `:single`, `:double`, `:rounded`, `:bold`, `:block`, `:simple`)","title":"Parameters - Raxol.Core.Renderer.View.box/1","ref":"Raxol.Core.Renderer.View.html#box/1-parameters"},{"type":"function","doc":"View.box(padding: 2)\n    View.box(padding: 2, border: :single)","title":"Examples - Raxol.Core.Renderer.View.box/1","ref":"Raxol.Core.Renderer.View.html#box/1-examples"},{"type":"function","doc":"Wraps a view with a border using a double line style.","title":"Raxol.Core.Renderer.View.double_border/2","ref":"Raxol.Core.Renderer.View.html#double_border/2"},{"type":"function","doc":"* `view` - The view to wrap with a border\n  * `opts` - Options for the border\n    * `:title` - Optional title to display in the border\n    * `:align` - Title alignment (`:left`, `:center`, `:right`)","title":"Parameters - Raxol.Core.Renderer.View.double_border/2","ref":"Raxol.Core.Renderer.View.html#double_border/2-parameters"},{"type":"function","doc":"View.double_border(view)\n    View.double_border(view, title: \"Title\")","title":"Examples - Raxol.Core.Renderer.View.double_border/2","ref":"Raxol.Core.Renderer.View.html#double_border/2-examples"},{"type":"function","doc":"Creates a new flex container.","title":"Raxol.Core.Renderer.View.flex/1","ref":"Raxol.Core.Renderer.View.html#flex/1"},{"type":"function","doc":"* `:direction` - Flex direction (:row or :column)\n  * `:children` - Child views\n  * `:align` - Alignment of children\n  * `:justify` - Justification of children\n  * `:gap` - Gap between children\n  * `:wrap` - Whether to wrap children","title":"Options - Raxol.Core.Renderer.View.flex/1","ref":"Raxol.Core.Renderer.View.html#flex/1-options"},{"type":"function","doc":"View.flex(direction: :column, children: [text(\"Hello\"), text(\"World\")])\n    View.flex(align: :center, gap: 2, wrap: true)","title":"Examples - Raxol.Core.Renderer.View.flex/1","ref":"Raxol.Core.Renderer.View.html#flex/1-examples"},{"type":"function","doc":"Creates a new grid layout.","title":"Raxol.Core.Renderer.View.grid/1","ref":"Raxol.Core.Renderer.View.html#grid/1"},{"type":"function","doc":"* `:columns` - Number of columns or list of column sizes\n  * `:rows` - Number of rows or list of row sizes\n  * `:gap` - Gap between grid items\n  * `:align` - Alignment of items within cells\n  * `:justify` - Justification of items within cells\n  * `:children` - Child views","title":"Options - Raxol.Core.Renderer.View.grid/1","ref":"Raxol.Core.Renderer.View.html#grid/1-options"},{"type":"function","doc":"View.grid(columns: 3, rows: 2)\n    View.grid(columns: [1, 2, 1], rows: [\"auto\", \"1fr\"])","title":"Examples - Raxol.Core.Renderer.View.grid/1","ref":"Raxol.Core.Renderer.View.html#grid/1-examples"},{"type":"macro","doc":"Macro for creating a grid layout with a do-block for children.","title":"Raxol.Core.Renderer.View.grid/2","ref":"Raxol.Core.Renderer.View.html#grid/2"},{"type":"macro","doc":"View.grid columns: 3 do\n      [View.text(\"A\"), View.text(\"B\"), View.text(\"C\")]\n    end","title":"Examples - Raxol.Core.Renderer.View.grid/2","ref":"Raxol.Core.Renderer.View.html#grid/2-examples"},{"type":"function","doc":"Creates a new view with the specified type and options.","title":"Raxol.Core.Renderer.View.new/2","ref":"Raxol.Core.Renderer.View.html#new/2"},{"type":"function","doc":"* `:type` - The type of view to create\n  * `:position` - Position of the view {x, y}\n  * `:z_index` - Z-index for layering\n  * `:size` - Size of the view {width, height}\n  * `:style` - Style options for the view\n  * `:fg` - Foreground color\n  * `:bg` - Background color\n  * `:border` - Border style\n  * `:padding` - Padding around the view\n  * `:margin` - Margin around the view\n  * `:children` - Child views\n  * `:content` - Content for the view","title":"Options - Raxol.Core.Renderer.View.new/2","ref":"Raxol.Core.Renderer.View.html#new/2-options"},{"type":"function","doc":"View.new(:box, size: {80, 24})\n    View.new(:text, content: \"Hello\", fg: :red)","title":"Examples - Raxol.Core.Renderer.View.new/2","ref":"Raxol.Core.Renderer.View.html#new/2-examples"},{"type":"function","doc":"Creates a new panel view (box with border and children).","title":"Raxol.Core.Renderer.View.panel/1","ref":"Raxol.Core.Renderer.View.html#panel/1"},{"type":"function","doc":"* `:children` - Child views\n  * `:border` - Border style (default: :single)\n  * `:padding` - Padding inside the panel (default: 1)\n  * `:style` - Additional style options\n  * `:title` - Optional title for the panel\n  * `:fg` - Foreground color\n  * `:bg` - Background color","title":"Options - Raxol.Core.Renderer.View.panel/1","ref":"Raxol.Core.Renderer.View.html#panel/1-options"},{"type":"function","doc":"View.panel(children: [View.text(\"Hello\")])\n    View.panel(border: :double, title: \"Panel\")","title":"Examples - Raxol.Core.Renderer.View.panel/1","ref":"Raxol.Core.Renderer.View.html#panel/1-examples"},{"type":"function","doc":"Wraps a view with a border using a rounded style.","title":"Raxol.Core.Renderer.View.rounded_border/2","ref":"Raxol.Core.Renderer.View.html#rounded_border/2"},{"type":"function","doc":"* `view` - The view to wrap with a border\n  * `opts` - Options for the border\n    * `:title` - Optional title to display in the border\n    * `:align` - Title alignment (`:left`, `:center`, `:right`)","title":"Parameters - Raxol.Core.Renderer.View.rounded_border/2","ref":"Raxol.Core.Renderer.View.html#rounded_border/2-parameters"},{"type":"function","doc":"View.rounded_border(view)\n    View.rounded_border(view, title: \"Title\")","title":"Examples - Raxol.Core.Renderer.View.rounded_border/2","ref":"Raxol.Core.Renderer.View.html#rounded_border/2-examples"},{"type":"function","doc":"Creates a new row layout.","title":"Raxol.Core.Renderer.View.row/1","ref":"Raxol.Core.Renderer.View.html#row/1"},{"type":"function","doc":"* `:children` - Child views\n  * `:align` - Alignment of children\n  * `:justify` - Justification of children\n  * `:gap` - Gap between children","title":"Options - Raxol.Core.Renderer.View.row/1","ref":"Raxol.Core.Renderer.View.html#row/1-options"},{"type":"function","doc":"View.row(children: [text(\"Hello\"), text(\"World\")])\n    View.row(align: :center, gap: 2)","title":"Examples - Raxol.Core.Renderer.View.row/1","ref":"Raxol.Core.Renderer.View.html#row/1-examples"},{"type":"macro","doc":"Macro for creating a row layout with a do-block for children.","title":"Raxol.Core.Renderer.View.row/2","ref":"Raxol.Core.Renderer.View.html#row/2"},{"type":"macro","doc":"View.row style: [:bold] do\n      [View.text(\"A\"), View.text(\"B\")]\n    end","title":"Examples - Raxol.Core.Renderer.View.row/2","ref":"Raxol.Core.Renderer.View.html#row/2-examples"},{"type":"function","doc":"Creates a new scrollable view.","title":"Raxol.Core.Renderer.View.scroll/2","ref":"Raxol.Core.Renderer.View.html#scroll/2"},{"type":"function","doc":"* `:viewport` - Viewport size {width, height}\n  * `:offset` - Initial scroll offset {x, y}\n  * `:scrollbars` - Whether to show scrollbars\n  * `:fg` - Foreground color\n  * `:bg` - Background color","title":"Options - Raxol.Core.Renderer.View.scroll/2","ref":"Raxol.Core.Renderer.View.html#scroll/2-options"},{"type":"function","doc":"View.scroll(view, viewport: {80, 24})\n    View.scroll(view, offset: {0, 10}, scrollbars: true)","title":"Examples - Raxol.Core.Renderer.View.scroll/2","ref":"Raxol.Core.Renderer.View.html#scroll/2-examples"},{"type":"macro","doc":"Macro for creating a scrollable view with a do-block for children.","title":"Raxol.Core.Renderer.View.scroll_wrap/2","ref":"Raxol.Core.Renderer.View.html#scroll_wrap/2"},{"type":"macro","doc":"View.scroll_wrap viewport: {80, 24} do\n      [View.text(\"A\"), View.text(\"B\")]\n    end","title":"Examples - Raxol.Core.Renderer.View.scroll_wrap/2","ref":"Raxol.Core.Renderer.View.html#scroll_wrap/2-examples"},{"type":"function","doc":"Wraps a view with a border using a simple style.","title":"Raxol.Core.Renderer.View.simple_border/2","ref":"Raxol.Core.Renderer.View.html#simple_border/2"},{"type":"function","doc":"* `view` - The view to wrap with a border\n  * `opts` - Options for the border\n    * `:title` - Optional title to display in the border\n    * `:align` - Title alignment (`:left`, `:center`, `:right`)","title":"Parameters - Raxol.Core.Renderer.View.simple_border/2","ref":"Raxol.Core.Renderer.View.html#simple_border/2-parameters"},{"type":"function","doc":"View.simple_border(view)\n    View.simple_border(view, title: \"Title\")","title":"Examples - Raxol.Core.Renderer.View.simple_border/2","ref":"Raxol.Core.Renderer.View.html#simple_border/2-examples"},{"type":"function","doc":"Creates a new text view.","title":"Raxol.Core.Renderer.View.text/2","ref":"Raxol.Core.Renderer.View.html#text/2"},{"type":"function","doc":"* `:content` - The text content\n  * `:fg` - Foreground color\n  * `:bg` - Background color\n  * `:style` - Text style options\n  * `:align` - Text alignment\n  * `:wrap` - Text wrapping mode","title":"Options - Raxol.Core.Renderer.View.text/2","ref":"Raxol.Core.Renderer.View.html#text/2-options"},{"type":"function","doc":"View.text(\"Hello\", fg: :red)\n    View.text(\"World\", style: [bold: true, underline: true])","title":"Examples - Raxol.Core.Renderer.View.text/2","ref":"Raxol.Core.Renderer.View.html#text/2-examples"},{"type":"function","doc":"Wraps a view with a border, optionally with a title and style.","title":"Raxol.Core.Renderer.View.wrap_with_border/2","ref":"Raxol.Core.Renderer.View.html#wrap_with_border/2"},{"type":"function","doc":"* `view` - The view to wrap with a border\n  * `opts` - Options for the border\n    * `:title` - Optional title to display in the border\n    * `:style` - Border style (`:single`, `:double`, `:rounded`, `:bold`, `:block`, `:simple`)\n    * `:align` - Title alignment (`:left`, `:center`, `:right`)","title":"Parameters - Raxol.Core.Renderer.View.wrap_with_border/2","ref":"Raxol.Core.Renderer.View.html#wrap_with_border/2-parameters"},{"type":"function","doc":"View.border_wrap(view, style: :single)\n    View.border_wrap(view, title: \"Title\", style: :double)","title":"Examples - Raxol.Core.Renderer.View.wrap_with_border/2","ref":"Raxol.Core.Renderer.View.html#wrap_with_border/2-examples"},{"type":"module","doc":"Handles box layout functionality for the Raxol view system.\nProvides box model layout with content, padding, border, and margin.","title":"Raxol.Core.Renderer.View.Components.Box","ref":"Raxol.Core.Renderer.View.Components.Box.html"},{"type":"function","doc":"Calculates the layout of a box and its children.","title":"Raxol.Core.Renderer.View.Components.Box.calculate_layout/2","ref":"Raxol.Core.Renderer.View.Components.Box.html#calculate_layout/2"},{"type":"function","doc":"Creates a new box view.","title":"Raxol.Core.Renderer.View.Components.Box.new/1","ref":"Raxol.Core.Renderer.View.Components.Box.html#new/1"},{"type":"function","doc":"* `:children` - List of child views\n  * `:padding` - Padding around content (integer or {top, right, bottom, left})\n  * `:margin` - Margin around box (integer or {top, right, bottom, left})\n  * `:border` - Border style (:none, :single, :double, :rounded, :bold, :dashed)\n  * `:fg` - Foreground color\n  * `:bg` - Background color\n  * `:size` - Box size {width, height}","title":"Options - Raxol.Core.Renderer.View.Components.Box.new/1","ref":"Raxol.Core.Renderer.View.Components.Box.html#new/1-options"},{"type":"function","doc":"Box.new(children: [view1, view2], padding: 1)\n    Box.new(padding: {1, 2, 1, 2}, border: :single)","title":"Examples - Raxol.Core.Renderer.View.Components.Box.new/1","ref":"Raxol.Core.Renderer.View.Components.Box.html#new/1-examples"},{"type":"module","doc":"Handles scrollable views for the Raxol view system.\nProvides viewport management, scrollbar rendering, and content scrolling.","title":"Raxol.Core.Renderer.View.Components.Scroll","ref":"Raxol.Core.Renderer.View.Components.Scroll.html"},{"type":"function","doc":"Calculates the layout of a scrollable view.","title":"Raxol.Core.Renderer.View.Components.Scroll.calculate_layout/2","ref":"Raxol.Core.Renderer.View.Components.Scroll.html#calculate_layout/2"},{"type":"function","doc":"Creates a new scrollable view.","title":"Raxol.Core.Renderer.View.Components.Scroll.new/2","ref":"Raxol.Core.Renderer.View.Components.Scroll.html#new/2"},{"type":"function","doc":"* `:viewport` - Viewport size {width, height}\n  * `:offset` - Initial scroll offset {x, y}\n  * `:scrollbars` - Whether to show scrollbars (boolean)\n  * `:fg` - Foreground color\n  * `:bg` - Background color","title":"Options - Raxol.Core.Renderer.View.Components.Scroll.new/2","ref":"Raxol.Core.Renderer.View.Components.Scroll.html#new/2-options"},{"type":"function","doc":"Scroll.new(content, viewport: {80, 24})\n    Scroll.new(content, offset: {0, 10}, scrollbars: true)","title":"Examples - Raxol.Core.Renderer.View.Components.Scroll.new/2","ref":"Raxol.Core.Renderer.View.Components.Scroll.html#new/2-examples"},{"type":"function","doc":"Updates the scroll offset of a view.","title":"Raxol.Core.Renderer.View.Components.Scroll.update_offset/2","ref":"Raxol.Core.Renderer.View.Components.Scroll.html#update_offset/2"},{"type":"module","doc":"Handles text rendering for the Raxol view system.\nProvides text styling, wrapping, and alignment functionality.","title":"Raxol.Core.Renderer.View.Components.Text","ref":"Raxol.Core.Renderer.View.Components.Text.html"},{"type":"function","doc":"Creates a new text view.","title":"Raxol.Core.Renderer.View.Components.Text.new/2","ref":"Raxol.Core.Renderer.View.Components.Text.html#new/2"},{"type":"function","doc":"* `:fg` - Foreground color\n  * `:bg` - Background color\n  * `:style` - List of style atoms (e.g., [:bold, :underline])\n  * `:align` - Text alignment (:left, :center, :right)\n  * `:wrap` - Text wrapping mode (:none, :char, :word)","title":"Options - Raxol.Core.Renderer.View.Components.Text.new/2","ref":"Raxol.Core.Renderer.View.Components.Text.html#new/2-options"},{"type":"function","doc":"Text.new(\"Hello, World!\", fg: :red, style: [:bold])\n    Text.new(\"Centered text\", align: :center)","title":"Examples - Raxol.Core.Renderer.View.Components.Text.new/2","ref":"Raxol.Core.Renderer.View.Components.Text.html#new/2-examples"},{"type":"function","doc":"Renders text with the given options and width.","title":"Raxol.Core.Renderer.View.Components.Text.render/2","ref":"Raxol.Core.Renderer.View.Components.Text.html#render/2"},{"type":"module","doc":"Handles flex layout functionality for the Raxol view system.\nProvides row and column layouts with various alignment and justification options.","title":"Raxol.Core.Renderer.View.Layout.Flex","ref":"Raxol.Core.Renderer.View.Layout.Flex.html"},{"type":"function","doc":"Calculates the layout of flex children based on container size and options.","title":"Raxol.Core.Renderer.View.Layout.Flex.calculate_layout/2","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#calculate_layout/2"},{"type":"function","doc":"Creates a flex container that arranges its children in the specified direction.","title":"Raxol.Core.Renderer.View.Layout.Flex.container/1","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#container/1"},{"type":"function","doc":"* `:direction` - Direction of flex layout (:row or :column)\n  * `:children` - List of child views\n  * `:align` - Alignment of children (:start, :center, :end)\n  * `:justify` - Justification of children (:start, :center, :end, :space_between)\n  * `:gap` - Space between children (integer)\n  * `:wrap` - Whether to wrap children (boolean)","title":"Options - Raxol.Core.Renderer.View.Layout.Flex.container/1","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#container/1-options"},{"type":"function","doc":"Flex.container(direction: :row, children: [view1, view2])\n    Flex.container(direction: :column, align: :center, children: [view1, view2])","title":"Examples - Raxol.Core.Renderer.View.Layout.Flex.container/1","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#container/1-examples"},{"type":"function","doc":"Creates a row layout container that arranges its children horizontally.","title":"Raxol.Core.Renderer.View.Layout.Flex.row/1","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#row/1"},{"type":"function","doc":"* `:children` - List of child views to arrange horizontally\n  * `:align` - Alignment of children (:start, :center, :end)\n  * `:justify` - Justification of children (:start, :center, :end, :space_between)\n  * `:gap` - Space between children (integer)","title":"Options - Raxol.Core.Renderer.View.Layout.Flex.row/1","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#row/1-options"},{"type":"function","doc":"Flex.row(children: [view1, view2])\n    Flex.row(align: :center, justify: :space_between, children: [view1, view2])","title":"Examples - Raxol.Core.Renderer.View.Layout.Flex.row/1","ref":"Raxol.Core.Renderer.View.Layout.Flex.html#row/1-examples"},{"type":"module","doc":"Handles grid-based layouts for the Raxol view system.\nProvides functionality for creating and managing grid layouts with customizable columns and rows.","title":"Raxol.Core.Renderer.View.Layout.Grid","ref":"Raxol.Core.Renderer.View.Layout.Grid.html"},{"type":"function","doc":"Adds a child to the grid at the specified position.","title":"Raxol.Core.Renderer.View.Layout.Grid.add_child/3","ref":"Raxol.Core.Renderer.View.Layout.Grid.html#add_child/3"},{"type":"function","doc":"Calculates the layout of a grid.","title":"Raxol.Core.Renderer.View.Layout.Grid.calculate_layout/2","ref":"Raxol.Core.Renderer.View.Layout.Grid.html#calculate_layout/2"},{"type":"function","doc":"Creates a new grid layout.","title":"Raxol.Core.Renderer.View.Layout.Grid.new/1","ref":"Raxol.Core.Renderer.View.Layout.Grid.html#new/1"},{"type":"function","doc":"* `:columns` - Number of columns or list of column sizes\n  * `:rows` - Number of rows or list of row sizes\n  * `:gap` - Gap between grid items {x, y}\n  * `:align` - Alignment of items within grid cells\n  * `:justify` - Justification of items within grid cells\n  * `:children` - List of child views to place in the grid","title":"Options - Raxol.Core.Renderer.View.Layout.Grid.new/1","ref":"Raxol.Core.Renderer.View.Layout.Grid.html#new/1-options"},{"type":"function","doc":"Grid.new(columns: 3, rows: 2)\n    Grid.new(columns: [1, 2, 1], rows: [\"auto\", \"1fr\"])","title":"Examples - Raxol.Core.Renderer.View.Layout.Grid.new/1","ref":"Raxol.Core.Renderer.View.Layout.Grid.html#new/1-examples"},{"type":"module","doc":"Handles border rendering for the Raxol view system.\nProvides various border styles and rendering functionality.","title":"Raxol.Core.Renderer.View.Style.Border","ref":"Raxol.Core.Renderer.View.Style.Border.html"},{"type":"function","doc":"Renders a border around a view with the given style and dimensions.","title":"Raxol.Core.Renderer.View.Style.Border.render_border/3","ref":"Raxol.Core.Renderer.View.Style.Border.html#render_border/3"},{"type":"function","doc":"Creates a border around a view.","title":"Raxol.Core.Renderer.View.Style.Border.wrap/2","ref":"Raxol.Core.Renderer.View.Style.Border.html#wrap/2"},{"type":"function","doc":"* `:style` - Border style (:single, :double, :rounded, :bold, :dashed)\n  * `:title` - Optional title to display in the border\n  * `:fg` - Foreground color\n  * `:bg` - Background color","title":"Options - Raxol.Core.Renderer.View.Style.Border.wrap/2","ref":"Raxol.Core.Renderer.View.Style.Border.html#wrap/2-options"},{"type":"function","doc":"Border.wrap(view, style: :single)\n    Border.wrap(view, style: :double, title: \"Title\")","title":"Examples - Raxol.Core.Renderer.View.Style.Border.wrap/2","ref":"Raxol.Core.Renderer.View.Style.Border.html#wrap/2-examples"},{"type":"module","doc":"Type definitions for the Raxol view system.","title":"Raxol.Core.Renderer.View.Types","ref":"Raxol.Core.Renderer.View.Types.html"},{"type":"function","doc":"Returns the border characters for different border styles.","title":"Raxol.Core.Renderer.View.Types.border_chars/0","ref":"Raxol.Core.Renderer.View.Types.html#border_chars/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.border_style/0","ref":"Raxol.Core.Renderer.View.Types.html#t:border_style/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.color/0","ref":"Raxol.Core.Renderer.View.Types.html#t:color/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.layout_type/0","ref":"Raxol.Core.Renderer.View.Types.html#t:layout_type/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.margin/0","ref":"Raxol.Core.Renderer.View.Types.html#t:margin/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.padding/0","ref":"Raxol.Core.Renderer.View.Types.html#t:padding/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.position/0","ref":"Raxol.Core.Renderer.View.Types.html#t:position/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.position_type/0","ref":"Raxol.Core.Renderer.View.Types.html#t:position_type/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.size/0","ref":"Raxol.Core.Renderer.View.Types.html#t:size/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.style/0","ref":"Raxol.Core.Renderer.View.Types.html#t:style/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.view/0","ref":"Raxol.Core.Renderer.View.Types.html#t:view/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.View.Types.z_index/0","ref":"Raxol.Core.Renderer.View.Types.html#t:z_index/0"},{"type":"module","doc":"Provides utility functions for common view operations in the Raxol view system.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html"},{"type":"function","doc":"Applies foreground and background colors to text.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils.apply_colors/2","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#apply_colors/2"},{"type":"function","doc":"apply_colors(\"Hello\", fg: :red, bg: :blue)\n    apply_colors(\"World\", fg: {255, 0, 0}, bg: {0, 0, 255})","title":"Examples - Raxol.Core.Renderer.View.Utils.ViewUtils.apply_colors/2","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#apply_colors/2-examples"},{"type":"function","doc":"Applies styles to a string of text.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils.apply_styles/2","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#apply_styles/2"},{"type":"function","doc":"* `:bold` - Makes text bold\n  * `:underline` - Underlines text\n  * `:italic` - Makes text italic\n  * `:strikethrough` - Adds strikethrough to text","title":"Options - Raxol.Core.Renderer.View.Utils.ViewUtils.apply_styles/2","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#apply_styles/2-options"},{"type":"function","doc":"Calculates the dimensions of a view based on its content and constraints.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils.calculate_dimensions/2","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#calculate_dimensions/2"},{"type":"function","doc":"Converts a color name to its ANSI color code.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils.color_to_code/1","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#color_to_code/1"},{"type":"function","doc":"Merges two views, with the second view's properties taking precedence.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils.merge_views/2","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#merge_views/2"},{"type":"function","doc":"Normalizes spacing values for padding and margin.\nAccepts various input formats and converts them to a standardized format.","title":"Raxol.Core.Renderer.View.Utils.ViewUtils.normalize_spacing/1","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#normalize_spacing/1"},{"type":"function","doc":"normalize_spacing(5)           # {5, 5, 5, 5}\n    normalize_spacing({10, 20})    # {10, 20, 10, 20}\n    normalize_spacing({1, 2, 3, 4}) # {1, 2, 3, 4}","title":"Examples - Raxol.Core.Renderer.View.Utils.ViewUtils.normalize_spacing/1","ref":"Raxol.Core.Renderer.View.Utils.ViewUtils.html#normalize_spacing/1-examples"},{"type":"module","doc":"Chart view component for data visualization.\n\nSupports:\n* Bar charts (vertical and horizontal)\n* Line charts\n* Sparklines\n* Axes and labels\n* Multiple series\n* Custom styling","title":"Raxol.Core.Renderer.Views.Chart","ref":"Raxol.Core.Renderer.Views.Chart.html"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Views.Chart.chart_type/0","ref":"Raxol.Core.Renderer.Views.Chart.html#t:chart_type/0"},{"type":"function","doc":"Creates a new chart view.","title":"Raxol.Core.Renderer.Views.Chart.new/1","ref":"Raxol.Core.Renderer.Views.Chart.html#new/1"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Views.Chart.options/0","ref":"Raxol.Core.Renderer.Views.Chart.html#t:options/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Views.Chart.orientation/0","ref":"Raxol.Core.Renderer.Views.Chart.html#t:orientation/0"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Views.Chart.series/0","ref":"Raxol.Core.Renderer.Views.Chart.html#t:series/0"},{"type":"module","doc":"Table view component for displaying tabular data.\n\nFeatures:\n* Column headers\n* Row striping\n* Column alignment\n* Border styles\n* Column resizing\n* Row selection","title":"Raxol.Core.Renderer.Views.Table","ref":"Raxol.Core.Renderer.Views.Table.html"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Views.Table.column/0","ref":"Raxol.Core.Renderer.Views.Table.html#t:column/0"},{"type":"function","doc":"Handles dispatched events.","title":"Raxol.Core.Renderer.Views.Table.handle_event/2","ref":"Raxol.Core.Renderer.Views.Table.html#handle_event/2"},{"type":"function","doc":"Initializes the Table component with props.\nProps are expected to be a map.","title":"Raxol.Core.Renderer.Views.Table.init/1","ref":"Raxol.Core.Renderer.Views.Table.html#init/1"},{"type":"function","doc":"Called when the component is mounted.","title":"Raxol.Core.Renderer.Views.Table.mount/1","ref":"Raxol.Core.Renderer.Views.Table.html#mount/1"},{"type":"type","doc":"","title":"Raxol.Core.Renderer.Views.Table.props/0","ref":"Raxol.Core.Renderer.Views.Table.html#t:props/0"},{"type":"function","doc":"Renders the Table component based on its current state.","title":"Raxol.Core.Renderer.Views.Table.render/1","ref":"Raxol.Core.Renderer.Views.Table.html#render/1"},{"type":"function","doc":"Called when the component is about to be unmounted.","title":"Raxol.Core.Renderer.Views.Table.unmount/1","ref":"Raxol.Core.Renderer.Views.Table.html#unmount/1"},{"type":"function","doc":"Handles updates to the component state.","title":"Raxol.Core.Renderer.Views.Table.update/2","ref":"Raxol.Core.Renderer.Views.Table.html#update/2"},{"type":"behaviour","doc":"Defines the behaviour for Raxol applications following The Elm Architecture (TEA).\n\nThis module provides the core structure for building terminal applications using\na pure functional approach with unidirectional data flow. The architecture is\ncomposed of three main parts:\n\n1. **Model** - The complete state of your application\n2. **Update** - A way to update your state\n3. **View** - A way to view your state as UI elements","title":"Raxol.Core.Runtime.Application","ref":"Raxol.Core.Runtime.Application.html"},{"type":"behaviour","doc":"defmodule MyApp do\n      use Raxol.Core.Runtime.Application\n\n      def init(_context) do\n        %{count: 0}\n      end\n\n      def update(msg, model) do\n        case msg do\n          :increment ->\n            {%{model | count: model.count + 1}, []}\n          :decrement ->\n            {%{model | count: model.count - 1}, []}\n          _ ->\n            {model, []}\n        end\n      end\n\n      def view(model) do\n        view do\n          panel title: \"Counter\" do\n            row do\n              button(label: \"-\", on_click: :decrement)\n              text(content: \"Count: #{model.count}\")\n              button(label: \"+\", on_click: :increment)\n            end\n          end\n        end\n      end\n\n      def subscribe(_model) do\n        # Optional subscriptions to time-based or external events\n        []\n      end\n    end","title":"Example - Raxol.Core.Runtime.Application","ref":"Raxol.Core.Runtime.Application.html#module-example"},{"type":"behaviour","doc":"1. The application starts with `init/1`, which sets up the initial state\n2. Events or messages trigger `update/2`, which computes the new state\n3. State changes cause `view/1` to re-render the UI\n4. `subscribe/1` can set up recurring updates or external event subscriptions","title":"Lifecycle - Raxol.Core.Runtime.Application","ref":"Raxol.Core.Runtime.Application.html#module-lifecycle"},{"type":"behaviour","doc":"The update function returns a tuple of `{new_state, commands}`, where commands\nare used to handle side effects like:\n- API calls\n- File operations\n- Timer operations\n- Inter-process communication\n\nCommands are executed by the runtime system, keeping the update function pure.","title":"Commands and Effects - Raxol.Core.Runtime.Application","ref":"Raxol.Core.Runtime.Application.html#module-commands-and-effects"},{"type":"behaviour","doc":"Subscriptions allow your application to receive messages over time, such as:\n- Timer-based updates\n- System events\n- External data streams\n\nDefine subscriptions in the `subscribe/1` callback, which is called after\ninitialization and after each state update.","title":"Subscriptions - Raxol.Core.Runtime.Application","ref":"Raxol.Core.Runtime.Application.html#module-subscriptions"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.command/0","ref":"Raxol.Core.Runtime.Application.html#t:command/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.context/0","ref":"Raxol.Core.Runtime.Application.html#t:context/0"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Application.delegate_init/2","ref":"Raxol.Core.Runtime.Application.html#delegate_init/2"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Application.delegate_update/3","ref":"Raxol.Core.Runtime.Application.html#delegate_update/3"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.element/0","ref":"Raxol.Core.Runtime.Application.html#t:element/0"},{"type":"function","doc":"Placeholder for getting environment configuration.","title":"Raxol.Core.Runtime.Application.get_env/3","ref":"Raxol.Core.Runtime.Application.html#get_env/3"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Application.handle_event/1","ref":"Raxol.Core.Runtime.Application.html#c:handle_event/1"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Application.handle_message/2","ref":"Raxol.Core.Runtime.Application.html#c:handle_message/2"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Application.handle_tick/1","ref":"Raxol.Core.Runtime.Application.html#c:handle_tick/1"},{"type":"callback","doc":"Initializes the application state.\n\nCalled once when the application starts. The context map contains runtime\ninformation such as terminal dimensions, environment variables, and startup\narguments.\n\nReturns either:\n- Initial state: `state()`\n- State and commands: `{state(), [command()]}`","title":"Raxol.Core.Runtime.Application.init/1","ref":"Raxol.Core.Runtime.Application.html#c:init/1"},{"type":"function","doc":"Initializes the application state.\n\nCalled once when the application starts. The context map contains runtime\ninformation such as terminal dimensions, environment variables, and startup\narguments.\n\nReturns either:\n- Initial state: `state()`\n- State and commands: `{state(), [command()]}`","title":"Raxol.Core.Runtime.Application.init/2","ref":"Raxol.Core.Runtime.Application.html#init/2"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.message/0","ref":"Raxol.Core.Runtime.Application.html#t:message/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.model/0","ref":"Raxol.Core.Runtime.Application.html#t:model/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.state/0","ref":"Raxol.Core.Runtime.Application.html#t:state/0"},{"type":"callback","doc":"Sets up subscriptions based on the current state.\n\nCalled after initialization and after each state update. Use this to\nset up recurring updates or subscribe to external events.\n\nReturns a list of subscription specifications.","title":"Raxol.Core.Runtime.Application.subscribe/1","ref":"Raxol.Core.Runtime.Application.html#c:subscribe/1"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Application.subscription/0","ref":"Raxol.Core.Runtime.Application.html#t:subscription/0"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Application.subscriptions/1","ref":"Raxol.Core.Runtime.Application.html#c:subscriptions/1"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Application.terminate/2","ref":"Raxol.Core.Runtime.Application.html#c:terminate/2"},{"type":"callback","doc":"Updates the application state in response to messages.\n\nCalled whenever a message is received, either from events, commands, or\nsubscriptions. Should be a pure function that computes the new state\nbased on the current state and message.\n\nReturns a tuple of the new state and any commands to be executed:\n`{state(), [command()]}`","title":"Raxol.Core.Runtime.Application.update/2","ref":"Raxol.Core.Runtime.Application.html#c:update/2"},{"type":"function","doc":"Handles incoming events or messages and updates the application state.\n\nReturns the updated model and optional commands to execute.","title":"Raxol.Core.Runtime.Application.update/3","ref":"Raxol.Core.Runtime.Application.html#update/3"},{"type":"callback","doc":"Renders the current state as UI elements.\n\nCalled after every state update to generate the new view. Should be a\npure function that converts the state into UI elements.\n\nReturns an element tree that will be rendered to the terminal.","title":"Raxol.Core.Runtime.Application.view/1","ref":"Raxol.Core.Runtime.Application.html#c:view/1"},{"type":"module","doc":"Provides a way to handle side effects in a pure functional way.\n\nCommands are used to describe side effects that should be performed by the\nruntime system. This keeps the application's update function pure while still\nallowing necessary side effects to occur.","title":"Raxol.Core.Runtime.Command","ref":"Raxol.Core.Runtime.Command.html"},{"type":"module","doc":"* `:none` - No side effect\n* `:task` - Asynchronous task that will send a message when complete\n* `:batch` - Multiple commands to be executed in sequence\n* `:delay` - Delayed message delivery\n* `:broadcast` - Send a message to all components\n* `:system` - System-level operations (file, network, etc.)\n* `:quit` - Signals the runtime to quit\n* `:clipboard_write` - Write text to the system clipboard\n* `:clipboard_read` - Request text from the system clipboard (will result in a message)\n* `:notify` - Send a system notification","title":"Types of Commands - Raxol.Core.Runtime.Command","ref":"Raxol.Core.Runtime.Command.html#module-types-of-commands"},{"type":"module","doc":"# No side effect\n    Command.none()\n\n    # Run an async task\n    Command.task(fn ->\n      # Do something expensive\n      result = expensive_operation()\n      {:operation_complete, result}\n    end)\n\n    # Multiple commands\n    Command.batch([\n      Command.task(fn -> {:fetch_data, api_call()} end),\n      Command.delay(:refresh, 1000)\n    ])\n\n    # Delayed message\n    Command.delay(:timeout, 5000)\n\n    # Broadcast to all components\n    Command.broadcast(:data_updated)\n\n    # System operation\n    Command.system(:file_write, path: \"data.txt\", content: \"Hello\")\n\n    # Signal the runtime to quit\n    Command.quit()\n\n    # Write to clipboard\n    Command.clipboard_write(\"Copied text\")\n\n    # Read from clipboard (expects a {:clipboard_content, text} message later)\n    Command.clipboard_read()\n\n    # Send notification\n    Command.notify(\"Task Complete\", \"Your background job finished.\")","title":"Examples - Raxol.Core.Runtime.Command","ref":"Raxol.Core.Runtime.Command.html#module-examples"},{"type":"function","doc":"Creates a command that will execute multiple commands in sequence.","title":"Raxol.Core.Runtime.Command.batch/1","ref":"Raxol.Core.Runtime.Command.html#batch/1"},{"type":"function","doc":"Creates a command that will broadcast a message to all components.","title":"Raxol.Core.Runtime.Command.broadcast/1","ref":"Raxol.Core.Runtime.Command.html#broadcast/1"},{"type":"function","doc":"Creates a command to read text from the system clipboard.\nThis will eventually result in a `{:command_result, {:clipboard_content, content}}`\nmessage being sent back to the application's update function.","title":"Raxol.Core.Runtime.Command.clipboard_read/0","ref":"Raxol.Core.Runtime.Command.html#clipboard_read/0"},{"type":"function","doc":"Creates a command to write text to the system clipboard.","title":"Raxol.Core.Runtime.Command.clipboard_write/1","ref":"Raxol.Core.Runtime.Command.html#clipboard_write/1"},{"type":"function","doc":"Creates a command that will send a message after the specified delay\nin milliseconds.","title":"Raxol.Core.Runtime.Command.delay/2","ref":"Raxol.Core.Runtime.Command.html#delay/2"},{"type":"function","doc":"Executes a command within the given context. This is used by the runtime\nsystem and should not be called directly by applications.","title":"Raxol.Core.Runtime.Command.execute/2","ref":"Raxol.Core.Runtime.Command.html#execute/2"},{"type":"function","doc":"Maps a function over a command's result message. This is useful for\nnamespacing messages or transforming them before they reach the update\nfunction.","title":"Raxol.Core.Runtime.Command.map/2","ref":"Raxol.Core.Runtime.Command.html#map/2"},{"type":"function","doc":"# Transform the task's result message\n    Command.task(fn -> {:data, fetch_data()} end)\n    |> Command.map(fn {:data, result} -> {:processed_data, process(result)} end)","title":"Example - Raxol.Core.Runtime.Command.map/2","ref":"Raxol.Core.Runtime.Command.html#map/2-example"},{"type":"function","doc":"Creates a new command. This is the low-level constructor, prefer using\nthe specific command constructors unless you need custom behavior.","title":"Raxol.Core.Runtime.Command.new/2","ref":"Raxol.Core.Runtime.Command.html#new/2"},{"type":"function","doc":"Returns a command that does nothing.","title":"Raxol.Core.Runtime.Command.none/0","ref":"Raxol.Core.Runtime.Command.html#none/0"},{"type":"function","doc":"Creates a command to send a system notification.","title":"Raxol.Core.Runtime.Command.notify/2","ref":"Raxol.Core.Runtime.Command.html#notify/2"},{"type":"function","doc":"Returns a command that signals the runtime to quit.","title":"Raxol.Core.Runtime.Command.quit/0","ref":"Raxol.Core.Runtime.Command.html#quit/0"},{"type":"function","doc":"Creates a command for system-level operations like file I/O or network\nrequests. The operation type and options specify what should be done.","title":"Raxol.Core.Runtime.Command.system/2","ref":"Raxol.Core.Runtime.Command.html#system/2"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Command.t/0","ref":"Raxol.Core.Runtime.Command.html#t:t/0"},{"type":"function","doc":"Creates a command that will execute the given function asynchronously.\nThe function should return a message that will be sent back to the update\nfunction when the task completes.","title":"Raxol.Core.Runtime.Command.task/1","ref":"Raxol.Core.Runtime.Command.html#task/1"},{"type":"module","doc":"Manages component lifecycle and state in the Raxol runtime system.\n\nThis module is responsible for:\n* Mounting and unmounting components\n* Managing component state\n* Handling event dispatch to components\n* Managing component subscriptions\n* Coordinating updates and renders","title":"Raxol.Core.Runtime.ComponentManager","ref":"Raxol.Core.Runtime.ComponentManager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Runtime.ComponentManager.child_spec/1","ref":"Raxol.Core.Runtime.ComponentManager.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.ComponentManager.dispatch_event/1","ref":"Raxol.Core.Runtime.ComponentManager.html#dispatch_event/1"},{"type":"function","doc":"Retrieves a specific component's data by its ID.","title":"Raxol.Core.Runtime.ComponentManager.get_component/1","ref":"Raxol.Core.Runtime.ComponentManager.html#get_component/1"},{"type":"function","doc":"Retrieves the current render queue and clears it.","title":"Raxol.Core.Runtime.ComponentManager.get_render_queue/0","ref":"Raxol.Core.Runtime.ComponentManager.html#get_render_queue/0"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.ComponentManager.mount/2","ref":"Raxol.Core.Runtime.ComponentManager.html#mount/2"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.ComponentManager.set_runtime_pid/1","ref":"Raxol.Core.Runtime.ComponentManager.html#set_runtime_pid/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.ComponentManager.start_link/1","ref":"Raxol.Core.Runtime.ComponentManager.html#start_link/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.ComponentManager.unmount/1","ref":"Raxol.Core.Runtime.ComponentManager.html#unmount/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.ComponentManager.update/2","ref":"Raxol.Core.Runtime.ComponentManager.html#update/2"},{"type":"module","doc":"Simple logging wrapper for the runtime.","title":"Raxol.Core.Runtime.Debug","ref":"Raxol.Core.Runtime.Debug.html"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Debug.debug/1","ref":"Raxol.Core.Runtime.Debug.html#debug/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Debug.error/1","ref":"Raxol.Core.Runtime.Debug.html#error/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Debug.info/1","ref":"Raxol.Core.Runtime.Debug.html#info/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Debug.warn/1","ref":"Raxol.Core.Runtime.Debug.html#warn/1"},{"type":"behaviour","doc":"Behaviour for implementing custom event sources for subscriptions.\n\nEvent sources are processes that can generate events over time and send them\nto subscribers. This behaviour defines the contract that custom event sources\nmust implement.","title":"Raxol.Core.Runtime.EventSource","ref":"Raxol.Core.Runtime.EventSource.html"},{"type":"behaviour","doc":"defmodule MyEventSource do\n      use Raxol.Core.Runtime.EventSource\n\n      @impl true\n      def init(args, context) do\n        # Set up initial state\n        {:ok, %{args: args, context: context}}\n      end\n\n      @impl true\n      def handle_info(:tick, state) do\n        # Send an event to the subscriber\n        send_event(state.context, {:my_event, :data})\n        {:noreply, state}\n      end\n    end","title":"Example - Raxol.Core.Runtime.EventSource","ref":"Raxol.Core.Runtime.EventSource.html#module-example"},{"type":"callback","doc":"Called when the event source receives a message. Should handle the message\nand optionally send events to the subscriber.","title":"Raxol.Core.Runtime.EventSource.handle_info/2","ref":"Raxol.Core.Runtime.EventSource.html#c:handle_info/2"},{"type":"callback","doc":"* `msg` - The received message\n  * `state` - The current state","title":"Parameters - Raxol.Core.Runtime.EventSource.handle_info/2","ref":"Raxol.Core.Runtime.EventSource.html#c:handle_info/2-parameters"},{"type":"callback","doc":"* `{:noreply, new_state}` - Continue with new state\n  * `{:stop, reason, new_state}` - Stop the event source","title":"Returns - Raxol.Core.Runtime.EventSource.handle_info/2","ref":"Raxol.Core.Runtime.EventSource.html#c:handle_info/2-returns"},{"type":"callback","doc":"Called when the event source is started. Should return the initial state.","title":"Raxol.Core.Runtime.EventSource.init/2","ref":"Raxol.Core.Runtime.EventSource.html#c:init/2"},{"type":"callback","doc":"* `args` - The arguments passed to `Subscription.custom/2`\n  * `context` - The runtime context containing the subscriber pid","title":"Parameters - Raxol.Core.Runtime.EventSource.init/2","ref":"Raxol.Core.Runtime.EventSource.html#c:init/2-parameters"},{"type":"callback","doc":"* `{:ok, state}` - Successfully initialized with state\n  * `{:error, reason}` - Failed to initialize","title":"Returns - Raxol.Core.Runtime.EventSource.init/2","ref":"Raxol.Core.Runtime.EventSource.html#c:init/2-returns"},{"type":"callback","doc":"Called when the event source is stopping. Can be used to clean up resources.","title":"Raxol.Core.Runtime.EventSource.terminate/2","ref":"Raxol.Core.Runtime.EventSource.html#c:terminate/2"},{"type":"callback","doc":"* `reason` - The reason for stopping\n  * `state` - The current state","title":"Parameters - Raxol.Core.Runtime.EventSource.terminate/2","ref":"Raxol.Core.Runtime.EventSource.html#c:terminate/2-parameters"},{"type":"callback","doc":"* `:ok`","title":"Returns - Raxol.Core.Runtime.EventSource.terminate/2","ref":"Raxol.Core.Runtime.EventSource.html#c:terminate/2-returns"},{"type":"module","doc":"Handles conversion between different event formats in the Raxol system.\n\nThis module is responsible for:\n* Converting Termbox events to the Raxol event format\n* Converting VS Code events to the Raxol event format\n* Normalizing events into a consistent format","title":"Raxol.Core.Runtime.Events.Converter","ref":"Raxol.Core.Runtime.Events.Converter.html"},{"type":"function","doc":"Converts a Termbox event to the standardized Raxol event format.","title":"Raxol.Core.Runtime.Events.Converter.convert_termbox_event/6","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_termbox_event/6"},{"type":"function","doc":"- `type`: The Termbox event type (e.g., :key, :resize)\n- `mod`: Key modifiers (if applicable)\n- `key`: The key code (for key events)\n- `ch`: The character (for character events)\n- `w`, `h`: Width and height (for resize events)","title":"Parameters - Raxol.Core.Runtime.Events.Converter.convert_termbox_event/6","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_termbox_event/6-parameters"},{"type":"function","doc":"A structured `%Event{}` struct.","title":"Returns - Raxol.Core.Runtime.Events.Converter.convert_termbox_event/6","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_termbox_event/6-returns"},{"type":"function","doc":"Converts a VS Code extension event to the standardized Raxol event format.","title":"Raxol.Core.Runtime.Events.Converter.convert_vscode_event/1","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_vscode_event/1"},{"type":"function","doc":"- `event`: The VS Code event map","title":"Parameters - Raxol.Core.Runtime.Events.Converter.convert_vscode_event/1","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_vscode_event/1-parameters"},{"type":"function","doc":"A structured `%Event{}` struct.","title":"Returns - Raxol.Core.Runtime.Events.Converter.convert_vscode_event/1","ref":"Raxol.Core.Runtime.Events.Converter.html#convert_vscode_event/1-returns"},{"type":"function","doc":"Normalizes events from various sources into a consistent format.\n\nThis is useful when handling events from multiple backends to ensure\nthey all follow the same structure before processing.","title":"Raxol.Core.Runtime.Events.Converter.normalize_event/1","ref":"Raxol.Core.Runtime.Events.Converter.html#normalize_event/1"},{"type":"function","doc":"- `event`: The event to normalize","title":"Parameters - Raxol.Core.Runtime.Events.Converter.normalize_event/1","ref":"Raxol.Core.Runtime.Events.Converter.html#normalize_event/1-parameters"},{"type":"function","doc":"A normalized `%Event{}` struct.","title":"Returns - Raxol.Core.Runtime.Events.Converter.normalize_event/1","ref":"Raxol.Core.Runtime.Events.Converter.html#normalize_event/1-returns"},{"type":"module","doc":"Manages the application state (model) and dispatches events to the application's\n`update/2` function. It also handles commands returned by `update/2`.","title":"Raxol.Core.Runtime.Events.Dispatcher","ref":"Raxol.Core.Runtime.Events.Dispatcher.html"},{"type":"function","doc":"Broadcasts an event payload to all subscribers of a topic.","title":"Raxol.Core.Runtime.Events.Dispatcher.broadcast/2","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#broadcast/2"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Runtime.Events.Dispatcher.child_spec/1","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#child_spec/1"},{"type":"function","doc":"Dispatches an event to the appropriate handler based on event type and target.\n\nReturns `{:ok, updated_state}` if the event was successfully handled,\nor `{:error, reason, state}` if something went wrong.","title":"Raxol.Core.Runtime.Events.Dispatcher.dispatch_event/2","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#dispatch_event/2"},{"type":"function","doc":"Handles an application-level event and updates the application state.\n\nThis is typically used for user interaction events like keyboard or mouse input.","title":"Raxol.Core.Runtime.Events.Dispatcher.handle_event/2","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#handle_event/2"},{"type":"function","doc":"Processes a system-level event that affects the runtime itself rather than\nthe application logic.\n\nExamples include terminal resize events, focus events, or quit requests.","title":"Raxol.Core.Runtime.Events.Dispatcher.process_system_event/2","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#process_system_event/2"},{"type":"function","doc":"Subscribes the calling process to a specific event topic.","title":"Raxol.Core.Runtime.Events.Dispatcher.subscribe/1","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#subscribe/1"},{"type":"function","doc":"Unsubscribes the calling process from a specific event topic.","title":"Raxol.Core.Runtime.Events.Dispatcher.unsubscribe/1","ref":"Raxol.Core.Runtime.Events.Dispatcher.html#unsubscribe/1"},{"type":"behaviour","doc":"Defines the behaviour for the Event Dispatcher GenServer.\n\nPrimarily used for mocking with Mox.","title":"Raxol.Core.Runtime.Events.Dispatcher.Behaviour","ref":"Raxol.Core.Runtime.Events.Dispatcher.Behaviour.html"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Events.Dispatcher.Behaviour.start_link/2","ref":"Raxol.Core.Runtime.Events.Dispatcher.Behaviour.html#c:start_link/2"},{"type":"module","doc":"Manages event handlers registration and execution in the Raxol system.\n\nThis module is responsible for:\n* Registering event handlers for specific event types\n* Executing handlers when events occur\n* Managing the priority and order of handlers","title":"Raxol.Core.Runtime.Events.Handlers","ref":"Raxol.Core.Runtime.Events.Handlers.html"},{"type":"function","doc":"Executes all registered handlers for the given event.\n\nHandlers are executed in priority order (lowest to highest).\nEach handler can transform the event for the next handler.","title":"Raxol.Core.Runtime.Events.Handlers.execute_handlers/2","ref":"Raxol.Core.Runtime.Events.Handlers.html#execute_handlers/2"},{"type":"function","doc":"- `event`: The event to handle\n- `state`: The current application state","title":"Parameters - Raxol.Core.Runtime.Events.Handlers.execute_handlers/2","ref":"Raxol.Core.Runtime.Events.Handlers.html#execute_handlers/2-parameters"},{"type":"function","doc":"`{:ok, updated_event, updated_state}` if all handlers executed successfully,\n`{:error, reason, state}` if a handler failed.","title":"Returns - Raxol.Core.Runtime.Events.Handlers.execute_handlers/2","ref":"Raxol.Core.Runtime.Events.Handlers.html#execute_handlers/2-returns"},{"type":"function","doc":"Registers a new event handler for the specified event types.","title":"Raxol.Core.Runtime.Events.Handlers.register_handler/4","ref":"Raxol.Core.Runtime.Events.Handlers.html#register_handler/4"},{"type":"function","doc":"- `handler_id`: Unique identifier for the handler\n- `event_types`: List of event types the handler should receive\n- `handler_fun`: Function to call when an event occurs\n- `options`: Additional options for handler registration\n  - `:priority` - Handler priority (default: 100, lower numbers run first)\n  - `:filter` - Optional filter function to determine if events should be handled","title":"Parameters - Raxol.Core.Runtime.Events.Handlers.register_handler/4","ref":"Raxol.Core.Runtime.Events.Handlers.html#register_handler/4-parameters"},{"type":"function","doc":"`{:ok, handler_id}` if registration succeeded,\n`{:error, reason}` otherwise.","title":"Returns - Raxol.Core.Runtime.Events.Handlers.register_handler/4","ref":"Raxol.Core.Runtime.Events.Handlers.html#register_handler/4-returns"},{"type":"function","doc":"Unregisters an event handler.","title":"Raxol.Core.Runtime.Events.Handlers.unregister_handler/1","ref":"Raxol.Core.Runtime.Events.Handlers.html#unregister_handler/1"},{"type":"function","doc":"- `handler_id`: ID of the handler to remove","title":"Parameters - Raxol.Core.Runtime.Events.Handlers.unregister_handler/1","ref":"Raxol.Core.Runtime.Events.Handlers.html#unregister_handler/1-parameters"},{"type":"function","doc":"`:ok` if the handler was removed,\n`{:error, :not_found}` if the handler wasn't registered.","title":"Returns - Raxol.Core.Runtime.Events.Handlers.unregister_handler/1","ref":"Raxol.Core.Runtime.Events.Handlers.html#unregister_handler/1-returns"},{"type":"module","doc":"Handles keyboard event processing in the Raxol system.\n\nThis module is responsible for:\n* Processing keyboard events\n* Handling special key combinations\n* Converting keyboard events to application messages","title":"Raxol.Core.Runtime.Events.Keyboard","ref":"Raxol.Core.Runtime.Events.Keyboard.html"},{"type":"function","doc":"Checks if a key combination matches any of the application's registered shortcuts.","title":"Raxol.Core.Runtime.Events.Keyboard.check_shortcuts/2","ref":"Raxol.Core.Runtime.Events.Keyboard.html#check_shortcuts/2"},{"type":"function","doc":"- `event`: The keyboard event to check\n- `shortcuts`: Map of registered shortcuts","title":"Parameters - Raxol.Core.Runtime.Events.Keyboard.check_shortcuts/2","ref":"Raxol.Core.Runtime.Events.Keyboard.html#check_shortcuts/2-parameters"},{"type":"function","doc":"`{:ok, action}` if a match is found, `:none` otherwise.","title":"Returns - Raxol.Core.Runtime.Events.Keyboard.check_shortcuts/2","ref":"Raxol.Core.Runtime.Events.Keyboard.html#check_shortcuts/2-returns"},{"type":"function","doc":"Converts a keyboard event to an application message.","title":"Raxol.Core.Runtime.Events.Keyboard.convert_to_message/1","ref":"Raxol.Core.Runtime.Events.Keyboard.html#convert_to_message/1"},{"type":"function","doc":"- `event`: The keyboard event to convert","title":"Parameters - Raxol.Core.Runtime.Events.Keyboard.convert_to_message/1","ref":"Raxol.Core.Runtime.Events.Keyboard.html#convert_to_message/1-parameters"},{"type":"function","doc":"A message that can be understood by the application's update function.","title":"Returns - Raxol.Core.Runtime.Events.Keyboard.convert_to_message/1","ref":"Raxol.Core.Runtime.Events.Keyboard.html#convert_to_message/1-returns"},{"type":"function","doc":"Processes a keyboard event and determines if it should be handled by the application\nor if it's a system-level command.","title":"Raxol.Core.Runtime.Events.Keyboard.process_keyboard_event/2","ref":"Raxol.Core.Runtime.Events.Keyboard.html#process_keyboard_event/2"},{"type":"function","doc":"- `event`: The keyboard event to process\n- `state`: The current application state","title":"Parameters - Raxol.Core.Runtime.Events.Keyboard.process_keyboard_event/2","ref":"Raxol.Core.Runtime.Events.Keyboard.html#process_keyboard_event/2-parameters"},{"type":"function","doc":"`{:system, command, state}` if it's a system command,\n`{:application, event, state}` if it should be handled by the application,\n`{:ignore, state}` if the event should be ignored.","title":"Returns - Raxol.Core.Runtime.Events.Keyboard.process_keyboard_event/2","ref":"Raxol.Core.Runtime.Events.Keyboard.html#process_keyboard_event/2-returns"},{"type":"module","doc":"Manages the application lifecycle, including startup, shutdown, and terminal interaction.","title":"Raxol.Core.Runtime.Lifecycle","ref":"Raxol.Core.Runtime.Lifecycle.html"},{"type":"function","doc":"Cleans up resources when an application is shutting down.","title":"Raxol.Core.Runtime.Lifecycle.handle_cleanup/1","ref":"Raxol.Core.Runtime.Lifecycle.html#handle_cleanup/1"},{"type":"function","doc":"Handles errors during application execution.\n\nLogs the error and attempts to recover if possible.","title":"Raxol.Core.Runtime.Lifecycle.handle_error/2","ref":"Raxol.Core.Runtime.Lifecycle.html#handle_error/2"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Lifecycle.init/1","ref":"Raxol.Core.Runtime.Lifecycle.html#init/1"},{"type":"function","doc":"Initializes the appropriate environment (TTY or VS Code) based on the runtime options.","title":"Raxol.Core.Runtime.Lifecycle.initialize_environment/1","ref":"Raxol.Core.Runtime.Lifecycle.html#initialize_environment/1"},{"type":"function","doc":"Looks up an application by name.\n\nReturns `{:ok, pid}` if the application is found, `:error` otherwise.","title":"Raxol.Core.Runtime.Lifecycle.lookup_app/1","ref":"Raxol.Core.Runtime.Lifecycle.html#lookup_app/1"},{"type":"function","doc":"Registers an application with the registry.","title":"Raxol.Core.Runtime.Lifecycle.register_application/2","ref":"Raxol.Core.Runtime.Lifecycle.html#register_application/2"},{"type":"function","doc":"Starts a Raxol application with the given module and options.","title":"Raxol.Core.Runtime.Lifecycle.start_application/2","ref":"Raxol.Core.Runtime.Lifecycle.html#start_application/2"},{"type":"function","doc":"* `:title` - The window title (default: \"Raxol Application\")\n  * `:fps` - Frames per second (default: 60)\n  * `:quit_keys` - List of keys that will quit the application (default: [:ctrl_c])\n  * `:debug` - Enable debug mode (default: false)\n  * `:width` - Terminal width (default: 80)\n  * `:height` - Terminal height (default: 24)","title":"Options - Raxol.Core.Runtime.Lifecycle.start_application/2","ref":"Raxol.Core.Runtime.Lifecycle.html#start_application/2-options"},{"type":"function","doc":"Stops a running application.\n\nReturns `:ok` if the application was stopped successfully,\n`{:error, :app_not_running}` if the application is not running.","title":"Raxol.Core.Runtime.Lifecycle.stop_application/1","ref":"Raxol.Core.Runtime.Lifecycle.html#stop_application/1"},{"type":"module","doc":"Public API for Raxol plugins to interact with the core system.\n\nThis module provides standardized interfaces for plugins to:\n- Register event handlers\n- Access runtime services\n- Register commands\n- Access rendering capabilities\n- Modify application state in approved ways\n\nPlugin developers should only use these API functions for interacting with\nthe Raxol system to ensure forward compatibility when the internal system changes.","title":"Raxol.Core.Runtime.Plugins.API","ref":"Raxol.Core.Runtime.Plugins.API.html"},{"type":"function","doc":"Broadcast an event to all subscribers.","title":"Raxol.Core.Runtime.Plugins.API.broadcast/2","ref":"Raxol.Core.Runtime.Plugins.API.html#broadcast/2"},{"type":"function","doc":"- `event_type` - The type of event to broadcast\n- `payload` - Data to include with the event","title":"Parameters - Raxol.Core.Runtime.Plugins.API.broadcast/2","ref":"Raxol.Core.Runtime.Plugins.API.html#broadcast/2-parameters"},{"type":"function","doc":"- `:ok` if broadcast was successful","title":"Returns - Raxol.Core.Runtime.Plugins.API.broadcast/2","ref":"Raxol.Core.Runtime.Plugins.API.html#broadcast/2-returns"},{"type":"function","doc":"Get the current application configuration.","title":"Raxol.Core.Runtime.Plugins.API.get_config/2","ref":"Raxol.Core.Runtime.Plugins.API.html#get_config/2"},{"type":"function","doc":"- `key` - The configuration key to retrieve\n- `default` - Default value if the key is not found","title":"Parameters - Raxol.Core.Runtime.Plugins.API.get_config/2","ref":"Raxol.Core.Runtime.Plugins.API.html#get_config/2-parameters"},{"type":"function","doc":"The configuration value or default","title":"Returns - Raxol.Core.Runtime.Plugins.API.get_config/2","ref":"Raxol.Core.Runtime.Plugins.API.html#get_config/2-returns"},{"type":"function","doc":"Log a message from a plugin.","title":"Raxol.Core.Runtime.Plugins.API.log/3","ref":"Raxol.Core.Runtime.Plugins.API.html#log/3"},{"type":"function","doc":"- `plugin_id` - The ID of the plugin\n- `level` - Log level (:debug, :info, :warn, :error)\n- `message` - The message to log","title":"Parameters - Raxol.Core.Runtime.Plugins.API.log/3","ref":"Raxol.Core.Runtime.Plugins.API.html#log/3-parameters"},{"type":"function","doc":"`:ok`","title":"Returns - Raxol.Core.Runtime.Plugins.API.log/3","ref":"Raxol.Core.Runtime.Plugins.API.html#log/3-returns"},{"type":"function","doc":"Get the path to the plugin data directory.","title":"Raxol.Core.Runtime.Plugins.API.plugin_data_dir/1","ref":"Raxol.Core.Runtime.Plugins.API.html#plugin_data_dir/1"},{"type":"function","doc":"- `plugin_id` - The ID of the plugin","title":"Parameters - Raxol.Core.Runtime.Plugins.API.plugin_data_dir/1","ref":"Raxol.Core.Runtime.Plugins.API.html#plugin_data_dir/1-parameters"},{"type":"function","doc":"String path to the plugin's data directory","title":"Returns - Raxol.Core.Runtime.Plugins.API.plugin_data_dir/1","ref":"Raxol.Core.Runtime.Plugins.API.html#plugin_data_dir/1-returns"},{"type":"function","doc":"Subscribe to runtime events.","title":"Raxol.Core.Runtime.Plugins.API.subscribe/3","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3"},{"type":"function","doc":"- `event_type` - The type of event to subscribe to\n- `handler` - Module that will handle the event\n- `function` - Function in the handler module that will be called (default: :handle_event)","title":"Parameters - Raxol.Core.Runtime.Plugins.API.subscribe/3","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3-parameters"},{"type":"function","doc":"- `:ok` if successful\n- `{:error, reason}` if subscription failed","title":"Returns - Raxol.Core.Runtime.Plugins.API.subscribe/3","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3-returns"},{"type":"function","doc":"```elixir\nAPI.subscribe(:key_press, MyPluginHandlers)\n```","title":"Example - Raxol.Core.Runtime.Plugins.API.subscribe/3","ref":"Raxol.Core.Runtime.Plugins.API.html#subscribe/3-example"},{"type":"function","doc":"Unsubscribe from runtime events.","title":"Raxol.Core.Runtime.Plugins.API.unsubscribe/2","ref":"Raxol.Core.Runtime.Plugins.API.html#unsubscribe/2"},{"type":"function","doc":"- `event_type` - The type of event to unsubscribe from\n- `handler` - Module to unsubscribe","title":"Parameters - Raxol.Core.Runtime.Plugins.API.unsubscribe/2","ref":"Raxol.Core.Runtime.Plugins.API.html#unsubscribe/2-parameters"},{"type":"function","doc":"- `:ok` if successful\n- `{:error, reason}` if unsubscription failed","title":"Returns - Raxol.Core.Runtime.Plugins.API.unsubscribe/2","ref":"Raxol.Core.Runtime.Plugins.API.html#unsubscribe/2-returns"},{"type":"module","doc":"Handles command execution and management for plugins.\nThis module is responsible for:\n- Processing command requests\n- Executing commands through plugins\n- Managing command results and error handling\n- Handling clipboard-related commands","title":"Raxol.Core.Runtime.Plugins.CommandHandler","ref":"Raxol.Core.Runtime.Plugins.CommandHandler.html"},{"type":"function","doc":"Handles clipboard result messages.","title":"Raxol.Core.Runtime.Plugins.CommandHandler.handle_clipboard_result/2","ref":"Raxol.Core.Runtime.Plugins.CommandHandler.html#handle_clipboard_result/2"},{"type":"function","doc":"Handles a command request by delegating to the appropriate plugin.\nReturns an updated state and any necessary side effects.","title":"Raxol.Core.Runtime.Plugins.CommandHandler.handle_command/5","ref":"Raxol.Core.Runtime.Plugins.CommandHandler.html#handle_command/5"},{"type":"module","doc":"Handles plugin command registration and dispatch for the Plugin Manager.","title":"Raxol.Core.Runtime.Plugins.CommandHelper","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html"},{"type":"function","doc":"Finds the plugin responsible for handling a command.\n\nUses the CommandRegistry to look up the command by name and optional namespace.\nReturns `{:ok, module, function, arity} | :not_found`.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.find_plugin_for_command/4","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#find_plugin_for_command/4"},{"type":"function","doc":"Finds the plugin ID for a given module.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.find_plugin_id_by_module/2","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#find_plugin_id_by_module/2"},{"type":"function","doc":"Handles the dispatching of a command to the appropriate plugin.\n\nThis function is called by the Manager's `handle_cast`.\nIt finds the plugin, calls its command handler, and returns an updated\nplugin state map or an error indicator.\n\nReturns `{:ok, updated_plugin_states_map} | :not_found | {:error, reason}`.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.handle_command/5","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#handle_command/5"},{"type":"function","doc":"Registers the commands exposed by a plugin.\n\nCalls the plugin's `get_commands/1` or `get_commands/0` callback\nand registers them in the command table.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.register_plugin_commands/3","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#register_plugin_commands/3"},{"type":"function","doc":"Unregisters all commands associated with a specific plugin module.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.unregister_plugin_commands/2","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#unregister_plugin_commands/2"},{"type":"function","doc":"Validates command arguments.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.validate_command_args/1","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.html#validate_command_args/1"},{"type":"behaviour","doc":"Defines the behaviour for plugin command management.\n\nThis behaviour is responsible for:\n- Registering plugin commands\n- Managing command handlers\n- Validating command specifications\n- Handling command execution","title":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.html"},{"type":"callback","doc":"Executes a command for a plugin.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.execute_command/4","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.html#c:execute_command/4"},{"type":"callback","doc":"Gets all registered commands for a plugin.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.get_plugin_commands/2","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.html#c:get_plugin_commands/2"},{"type":"callback","doc":"Registers commands for a plugin.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.register_plugin_commands/3","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.html#c:register_plugin_commands/3"},{"type":"callback","doc":"Unregisters commands for a plugin.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.unregister_plugin_commands/2","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.html#c:unregister_plugin_commands/2"},{"type":"callback","doc":"Validates a plugin's command specifications.","title":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.validate_commands/1","ref":"Raxol.Core.Runtime.Plugins.CommandHelper.Behaviour.html#c:validate_commands/1"},{"type":"module","doc":"Manages command registration and execution for plugins.","title":"Raxol.Core.Runtime.Plugins.CommandRegistry","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command/0","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command_handler/0","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command_handler/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command_metadata/0","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command_metadata/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.command_name/0","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#t:command_name/0"},{"type":"function","doc":"Executes a command with proper error handling and timeout.","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.execute_command/3","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#execute_command/3"},{"type":"function","doc":"Looks up the handler for a command name and namespace (plugin module).\nReturns {:ok, {module, function, arity}} or {:error, :not_found}.","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.lookup_command/3","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#lookup_command/3"},{"type":"function","doc":"Creates a new command registry table (as a map).\nReturns the new, empty command table.","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.new/0","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#new/0"},{"type":"function","doc":"Registers commands for a plugin.","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.register_plugin_commands/3","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#register_plugin_commands/3"},{"type":"function","doc":"Unregisters all commands for a plugin.","title":"Raxol.Core.Runtime.Plugins.CommandRegistry.unregister_plugin_commands/2","ref":"Raxol.Core.Runtime.Plugins.CommandRegistry.html#unregister_plugin_commands/2"},{"type":"module","doc":"Manages plugin dependencies and dependency resolution.\nProvides sophisticated version constraint handling, efficient cycle detection,\nand detailed dependency chain reporting.\n\nThis module serves as the main entry point for dependency management functionality,\ndelegating to specialized submodules for different aspects of the functionality:\n\n- `DependencyManager.Core`: Core dependency checking and load order resolution\n- `DependencyManager.Version`: Version parsing and constraint checking\n- `DependencyManager.Graph`: Dependency graph building and analysis\n- `DependencyManager.Resolver`: Load order resolution using Tarjan's algorithm\n\nFor more detailed documentation about the module's architecture and internals,\nsee `docs/dependency_manager.md`.","title":"Raxol.Core.Runtime.Plugins.DependencyManager","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html"},{"type":"function","doc":"Checks if a plugin's dependencies are satisfied.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#check_dependencies/4"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin to check\n* `plugin_metadata` - The plugin's metadata containing its dependencies\n* `loaded_plugins` - Map of currently loaded plugins\n* `dependency_chain` - List of plugin IDs in the current dependency chain (for error reporting)","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#check_dependencies/4-parameters"},{"type":"function","doc":"* `:ok` - If all dependencies are satisfied\n* `{:error, :missing_dependencies, missing, chain}` - If any dependencies are missing\n* `{:error, :version_mismatch, mismatches, chain}` - If any dependencies have incompatible versions\n* `{:error, :circular_dependency, cycle, chain}` - If a circular dependency is detected","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#check_dependencies/4-returns"},{"type":"function","doc":"iex> DependencyManager.check_dependencies(\"my_plugin\", %{dependencies: [{\"other_plugin\", \">= 1.0.0\"}]}, %{\"other_plugin\" => %{version: \"1.1.0\"}}, [])\n    :ok\n\n    iex> DependencyManager.check_dependencies(\"my_plugin\", %{dependencies: [{\"missing_plugin\", \">= 1.0.0\"}]}, %{}, [])\n    {:error, :missing_dependencies, [\"missing_plugin\"], [\"my_plugin\"]}\n\n    iex> DependencyManager.check_dependencies(\"my_plugin\", %{dependencies: [{\"other_plugin\", \">= 2.0.0\"}]}, %{\"other_plugin\" => %{version: \"1.0.0\"}}, [])\n    {:error, :version_mismatch, [{\"other_plugin\", \"1.0.0\", \">= 2.0.0\"}], [\"my_plugin\"]}","title":"Examples - Raxol.Core.Runtime.Plugins.DependencyManager.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#check_dependencies/4-examples"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.dependency/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#t:dependency/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.dependency_chain/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#t:dependency_chain/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.dependency_error/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#t:dependency_error/0"},{"type":"function","doc":"Resolves the load order for a set of plugins based on their dependencies.\nUses Tarjan's algorithm for efficient cycle detection and component identification.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#resolve_load_order/1"},{"type":"function","doc":"* `plugins` - Map of plugin metadata, keyed by plugin ID","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#resolve_load_order/1-parameters"},{"type":"function","doc":"* `{:ok, load_order}` - List of plugin IDs in the correct load order\n* `{:error, :circular_dependency, cycle, chain}` - If a circular dependency is detected","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#resolve_load_order/1-returns"},{"type":"function","doc":"iex> DependencyManager.resolve_load_order(%{\n      \"plugin_a\" => %{dependencies: [{\"plugin_b\", \">= 1.0.0\"}]},\n      \"plugin_b\" => %{dependencies: []}\n    })\n    {:ok, [\"plugin_b\", \"plugin_a\"]}","title":"Examples - Raxol.Core.Runtime.Plugins.DependencyManager.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#resolve_load_order/1-examples"},{"type":"function","doc":"Checks if a version meets a version requirement.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.satisfies_version?/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#satisfies_version?/2"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.version_constraint/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.html#t:version_constraint/0"},{"type":"behaviour","doc":"Defines the behaviour for plugin dependency management.\n\nThis behaviour is responsible for:\n- Checking plugin dependencies\n- Resolving dependency conflicts\n- Managing dependency versions\n- Handling circular dependencies","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.html"},{"type":"callback","doc":"Checks for circular dependencies in the plugin graph.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.check_circular_dependencies/3","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.html#c:check_circular_dependencies/3"},{"type":"callback","doc":"Checks if a plugin's dependencies are satisfied.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.check_dependencies/3","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.html#c:check_dependencies/3"},{"type":"callback","doc":"Resolves dependencies between plugins.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.resolve_dependencies/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.html#c:resolve_dependencies/2"},{"type":"callback","doc":"Validates a plugin's dependency specifications.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.validate_dependencies/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Behaviour.html#c:validate_dependencies/1"},{"type":"module","doc":"Core module for managing plugin dependencies and dependency resolution.\nProvides the main public API for dependency checking and load order resolution.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html"},{"type":"function","doc":"Checks if a plugin's dependencies are satisfied.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#check_dependencies/4"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin to check\n* `plugin_metadata` - The plugin's metadata containing its dependencies\n* `loaded_plugins` - Map of currently loaded plugins\n* `dependency_chain` - List of plugin IDs in the current dependency chain (for error reporting)","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Core.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#check_dependencies/4-parameters"},{"type":"function","doc":"* `:ok` - If all dependencies are satisfied\n* `{:error, :missing_dependencies, missing, chain}` - If any dependencies are missing\n* `{:error, :version_mismatch, mismatches, chain}` - If any dependencies have incompatible versions\n* `{:error, :circular_dependency, cycle, chain}` - If a circular dependency is detected","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Core.check_dependencies/4","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#check_dependencies/4-returns"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.dependency/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#t:dependency/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.dependency_chain/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#t:dependency_chain/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.dependency_error/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#t:dependency_error/0"},{"type":"function","doc":"Resolves the load order for a set of plugins based on their dependencies.\nUses Tarjan's algorithm for efficient cycle detection and component identification.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#resolve_load_order/1"},{"type":"function","doc":"* `plugins` - Map of plugin metadata, keyed by plugin ID","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Core.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#resolve_load_order/1-parameters"},{"type":"function","doc":"* `{:ok, load_order}` - List of plugin IDs in the correct load order\n* `{:error, :circular_dependency, cycle, chain}` - If a circular dependency is detected","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Core.resolve_load_order/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#resolve_load_order/1-returns"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.version_constraint/0","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Core.html#t:version_constraint/0"},{"type":"module","doc":"Handles dependency graph building and cycle detection for plugin dependencies.\nProvides functionality for building dependency graphs and analyzing dependency chains.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html"},{"type":"function","doc":"Builds a dependency chain for error reporting.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_chain/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_chain/2"},{"type":"function","doc":"* `cycle` - List of plugin IDs forming a cycle\n* `graph` - The dependency graph","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_chain/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_chain/2-parameters"},{"type":"function","doc":"* A list of plugin IDs representing the dependency chain","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_chain/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_chain/2-returns"},{"type":"function","doc":"iex> Graph.build_dependency_chain([\"plugin_a\", \"plugin_b\"], %{\n      \"plugin_a\" => [{\"plugin_b\", \">= 1.0.0\", %{optional: false}}],\n      \"plugin_b\" => [{\"plugin_a\", \">= 1.0.0\", %{optional: false}}]\n    })\n    [\"plugin_a\", \"plugin_b\", \"plugin_a\"]","title":"Example - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_chain/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_chain/2-example"},{"type":"function","doc":"Builds a dependency graph from plugin metadata.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_graph/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_graph/1"},{"type":"function","doc":"* `plugins` - Map of plugin metadata, keyed by plugin ID","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_graph/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_graph/1-parameters"},{"type":"function","doc":"* A map representing the dependency graph, where each key is a plugin ID and the value\n  is a list of tuples containing dependency information: `{dep_id, version_req, opts}`","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_graph/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_graph/1-returns"},{"type":"function","doc":"iex> Graph.build_dependency_graph(%{\n      \"plugin_a\" => %{dependencies: [{\"plugin_b\", \">= 1.0.0\"}]},\n      \"plugin_b\" => %{dependencies: []}\n    })\n    %{\n      \"plugin_a\" => [{\"plugin_b\", \">= 1.0.0\", %{optional: false}}],\n      \"plugin_b\" => []\n    }","title":"Example - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.build_dependency_graph/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#build_dependency_graph/1-example"},{"type":"function","doc":"Gets all dependencies for a plugin, including transitive dependencies.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.get_all_dependencies/3","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#get_all_dependencies/3"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `graph` - The dependency graph\n* `visited` - Set of already visited plugin IDs (for cycle detection)","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.get_all_dependencies/3","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#get_all_dependencies/3-parameters"},{"type":"function","doc":"* `{:ok, deps}` - List of all dependencies\n* `{:error, :circular_dependency, cycle}` - If a circular dependency is detected","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Graph.get_all_dependencies/3","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Graph.html#get_all_dependencies/3-returns"},{"type":"module","doc":"Handles load order resolution for plugin dependencies using Tarjan's algorithm.\nProvides efficient cycle detection and topological sorting of dependencies.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.html"},{"type":"function","doc":"Performs a topological sort of the dependency graph using Tarjan's algorithm.\nThis algorithm efficiently detects cycles and produces a valid load order.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.tarjan_sort/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.html#tarjan_sort/1"},{"type":"function","doc":"* `graph` - The dependency graph","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.tarjan_sort/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.html#tarjan_sort/1-parameters"},{"type":"function","doc":"* `{:ok, order}` - List of plugin IDs in the correct load order\n* `{:error, cycle}` - If a circular dependency is detected","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.tarjan_sort/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.html#tarjan_sort/1-returns"},{"type":"function","doc":"iex> Resolver.tarjan_sort(%{\n      \"plugin_a\" => [{\"plugin_b\", \">= 1.0.0\", %{optional: false}}],\n      \"plugin_b\" => []\n    })\n    {:ok, [\"plugin_b\", \"plugin_a\"]}","title":"Example - Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.tarjan_sort/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Resolver.html#tarjan_sort/1-example"},{"type":"module","doc":"Handles version parsing and constraint checking for plugin dependencies.\nProvides sophisticated version constraint handling with support for complex requirements.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Version","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html"},{"type":"function","doc":"Checks if a version satisfies a version requirement.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.check_version/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#check_version/2"},{"type":"function","doc":"* `version` - The version string to check\n* `requirement` - The version requirement string","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Version.check_version/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#check_version/2-parameters"},{"type":"function","doc":"* `:ok` - If the version satisfies the requirement\n* `{:error, reason}` - If there's an error or the version doesn't satisfy the requirement","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Version.check_version/2","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#check_version/2-returns"},{"type":"function","doc":"Parses a single version requirement.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_single_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_single_requirement/1"},{"type":"function","doc":"* `req` - The version requirement string","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_single_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_single_requirement/1-parameters"},{"type":"function","doc":"* `{:ok, parsed}` - The parsed requirement\n* `{:error, :invalid_requirement}` - If the requirement is invalid","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_single_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_single_requirement/1-returns"},{"type":"function","doc":"Parses a version requirement string into a format suitable for version matching.","title":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_version_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_version_requirement/1"},{"type":"function","doc":"* `requirement` - The version requirement string","title":"Parameters - Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_version_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_version_requirement/1-parameters"},{"type":"function","doc":"* `{:ok, parsed_requirement}` - The parsed requirement\n* `{:error, :invalid_requirement}` - If the requirement is invalid","title":"Returns - Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_version_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_version_requirement/1-returns"},{"type":"function","doc":"iex> Version.parse_version_requirement(\">= 1.0.0\")\n    {:ok, \">= 1.0.0\"}\n\n    iex> Version.parse_version_requirement(\">= 1.0.0 || >= 2.0.0\")\n    {:ok, {:or, [\">= 1.0.0\", \">= 2.0.0\"]}}","title":"Examples - Raxol.Core.Runtime.Plugins.DependencyManager.Version.parse_version_requirement/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManager.Version.html#parse_version_requirement/1-examples"},{"type":"module","doc":"Test helper functions for DependencyManager tests.","title":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper","ref":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.html"},{"type":"function","doc":"Creates a complex version requirements structure for testing.","title":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.create_complex_version_requirements/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.html#create_complex_version_requirements/1"},{"type":"function","doc":"Creates a dependency chain for testing.","title":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.create_dependency_chain/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.html#create_dependency_chain/1"},{"type":"function","doc":"Creates a plugin set for dependency tests.","title":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.create_plugin_set/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.html#create_plugin_set/1"},{"type":"function","doc":"Measures the memory usage of a function or operation.","title":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.measure_memory_usage/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.html#measure_memory_usage/1"},{"type":"function","doc":"Measures the execution time of a function or operation.","title":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.measure_time/1","ref":"Raxol.Core.Runtime.Plugins.DependencyManagerTestHelper.html#measure_time/1"},{"type":"module","doc":"Handles plugin discovery and initialization.\nThis module is responsible for:\n- Discovering available plugins in configured directories\n- Initializing the plugin system\n- Managing plugin metadata and paths\n- Handling plugin dependencies","title":"Raxol.Core.Runtime.Plugins.Discovery","ref":"Raxol.Core.Runtime.Plugins.Discovery.html"},{"type":"function","doc":"Discovers plugins in the given directories.","title":"Raxol.Core.Runtime.Plugins.Discovery.discover_plugins/1","ref":"Raxol.Core.Runtime.Plugins.Discovery.html#discover_plugins/1"},{"type":"function","doc":"Discovers plugins in a specific directory.","title":"Raxol.Core.Runtime.Plugins.Discovery.discover_plugins_in_dir/2","ref":"Raxol.Core.Runtime.Plugins.Discovery.html#discover_plugins_in_dir/2"},{"type":"function","doc":"Gets a specific plugin by ID.","title":"Raxol.Core.Runtime.Plugins.Discovery.get_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Discovery.html#get_plugin/2"},{"type":"function","doc":"Initializes the plugin discovery system.","title":"Raxol.Core.Runtime.Plugins.Discovery.initialize/1","ref":"Raxol.Core.Runtime.Plugins.Discovery.html#initialize/1"},{"type":"function","doc":"Lists all discovered plugins in load order.","title":"Raxol.Core.Runtime.Plugins.Discovery.list_plugins/1","ref":"Raxol.Core.Runtime.Plugins.Discovery.html#list_plugins/1"},{"type":"module","doc":"Handles event filtering for plugins.\nThis module is responsible for:\n- Filtering events through registered plugin filters\n- Managing event modifications\n- Handling event halting","title":"Raxol.Core.Runtime.Plugins.EventFilter","ref":"Raxol.Core.Runtime.Plugins.EventFilter.html"},{"type":"function","doc":"Filters an event through registered plugin filters.\nReturns the filtered event or :halt if the event should be stopped.","title":"Raxol.Core.Runtime.Plugins.EventFilter.filter_event/2","ref":"Raxol.Core.Runtime.Plugins.EventFilter.html#filter_event/2"},{"type":"module","doc":"Handles file watching functionality for plugins.\n\nThis module provides a public API for monitoring plugin source files and triggering\nreloads when changes are detected. It delegates to specialized submodules for\ndifferent aspects of the functionality:\n\n- `FileWatcher.Core`: Core setup and state management\n- `FileWatcher.Events`: Event handling and debouncing\n- `FileWatcher.Reload`: Plugin reloading logic\n- `FileWatcher.Cleanup`: Resource cleanup","title":"Raxol.Core.Runtime.Plugins.FileWatcher","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html"},{"type":"module","doc":"The module maintains state in the following structure:\n\n```elixir\n%{\n  plugin_dirs: [String.t()],           # List of directories to watch\n  plugin_paths: %{String.t() => String.t()},  # Plugin ID to path mapping\n  reverse_plugin_paths: %{String.t() => String.t()},  # Path to plugin ID mapping\n  file_watcher_pid: pid() | nil,       # File system watcher process\n  file_event_timer: reference() | nil,  # Debounce timer reference\n  file_watching_enabled?: boolean()    # File watching status\n}\n```","title":"State - Raxol.Core.Runtime.Plugins.FileWatcher","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#module-state"},{"type":"module","doc":"```elixir\n# Initialize file watching\nstate = %{\n  plugin_dirs: [\"plugins\"],\n  plugin_paths: %{\"my_plugin\" => \"plugins/my_plugin.ex\"},\n  file_watching_enabled?: false\n}\n\n# Setup file watching\n{pid, enabled?} = FileWatcher.setup_file_watching(state)\nstate = %{state | file_watcher_pid: pid, file_watching_enabled?: enabled?}\n\n# Update file watcher with new paths\nstate = FileWatcher.update_file_watcher(state)\n\n# Cleanup on shutdown\nstate = FileWatcher.cleanup_file_watching(state)\n```\n\nFor more detailed documentation about the module's architecture and internals,\nsee `docs/file_watcher.md`.","title":"Usage - Raxol.Core.Runtime.Plugins.FileWatcher","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#module-usage"},{"type":"function","doc":"Cleans up file watching resources.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.cleanup_file_watching/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#cleanup_file_watching/1"},{"type":"function","doc":"Handles debounced file events.\nReturns updated state after processing events.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.handle_debounced_events/3","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#handle_debounced_events/3"},{"type":"function","doc":"Handles file system events.\nReturns updated state with debounced reload timer if needed.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.handle_file_event/2","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#handle_file_event/2"},{"type":"function","doc":"Creates a new file watcher state.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.new/0","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#new/0"},{"type":"function","doc":"Reloads a plugin after file changes.\nReturns :ok on success or {:error, reason} on failure.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.reload_plugin/2","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#reload_plugin/2"},{"type":"function","doc":"Sets up file watching for plugin source files.\nReturns the updated state with the file watcher PID.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.setup_file_watching/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#setup_file_watching/1"},{"type":"function","doc":"Updates the reverse path mapping for file watching.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.update_file_watcher/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.html#update_file_watcher/1"},{"type":"behaviour","doc":"Defines the behaviour for file watching functionality in the plugin system.\n\nThis behaviour is responsible for:\n- Setting up file system watchers\n- Handling file change events\n- Managing file paths and reverse mappings\n- Debouncing file events\n- Triggering plugin reloads","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.html"},{"type":"callback","doc":"Cleans up file watching resources.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.cleanup_file_watching/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.html#c:cleanup_file_watching/1"},{"type":"callback","doc":"Handles debounced file events.\nReturns updated state after processing events.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.handle_debounced_events/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.html#c:handle_debounced_events/1"},{"type":"callback","doc":"Handles file system events.\nReturns updated state with debounced reload timer if needed.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.handle_file_event/2","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.html#c:handle_file_event/2"},{"type":"callback","doc":"Sets up file watching for plugin source files.\nReturns the updated state with the file watcher PID.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.setup_file_watching/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.html#c:setup_file_watching/1"},{"type":"callback","doc":"Updates the reverse path mapping for file watching.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.update_file_watcher/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Behaviour.html#c:update_file_watcher/1"},{"type":"module","doc":"Handles cleanup of file watching resources.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Cleanup","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Cleanup.html"},{"type":"function","doc":"Cleans up file watching resources.\nReturns the updated state.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Cleanup.cleanup_file_watching/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Cleanup.html#cleanup_file_watching/1"},{"type":"module","doc":"Core functionality for file watching in plugins.\nHandles basic setup and state management.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Core","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Core.html"},{"type":"function","doc":"Sets up file watching for plugin source files.\nReturns the updated state with the file watcher PID.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Core.setup_file_watching/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Core.html#setup_file_watching/1"},{"type":"function","doc":"Updates the reverse path mapping for file watching.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Core.update_file_watcher/1","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Core.html#update_file_watcher/1"},{"type":"module","doc":"Handles file system events and debouncing for plugin reloading.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Events","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Events.html"},{"type":"function","doc":"Handles debounced file events.\nReturns updated state after processing events.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Events.handle_debounced_events/3","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Events.html#handle_debounced_events/3"},{"type":"function","doc":"Handles file system events.\nReturns updated state with debounced reload timer if needed.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Events.handle_file_event/2","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Events.html#handle_file_event/2"},{"type":"module","doc":"Handles plugin reloading functionality.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Reload","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Reload.html"},{"type":"function","doc":"Reloads a plugin after file changes.\nReturns :ok on success or {:error, reason} on failure.","title":"Raxol.Core.Runtime.Plugins.FileWatcher.Reload.reload_plugin/2","ref":"Raxol.Core.Runtime.Plugins.FileWatcher.Reload.html#reload_plugin/2"},{"type":"module","doc":"Helper functions for plugin lifecycle management.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html"},{"type":"function","doc":"Initializes plugins in the correct order with improved error handling.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.initialize_plugins/7","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#initialize_plugins/7"},{"type":"function","doc":"Loads a plugin by ID or module with improved error handling and state persistence.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.load_plugin/8","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#load_plugin/8"},{"type":"function","doc":"Reloads a plugin from disk with improved state persistence and error handling.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.reload_plugin_from_disk/8","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#reload_plugin_from_disk/8"},{"type":"function","doc":"Unloads a plugin with improved cleanup and error handling.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.unload_plugin/6","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.html#unload_plugin/6"},{"type":"behaviour","doc":"Defines the behaviour for plugin lifecycle management.\n\nThis behaviour is responsible for:\n- Loading and unloading plugins\n- Managing plugin dependencies\n- Handling plugin state transitions\n- Coordinating plugin lifecycle events","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html"},{"type":"callback","doc":"Initializes plugins based on discovery and dependencies.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.initialize_plugins/7","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html#c:initialize_plugins/7"},{"type":"callback","doc":"Loads a plugin by its ID or module.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.load_plugin/8","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html#c:load_plugin/8"},{"type":"callback","doc":"Loads a plugin by its module name when the module is already known.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.load_plugin_by_module/8","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html#c:load_plugin_by_module/8"},{"type":"callback","doc":"Reloads a plugin by its ID.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.reload_plugin/7","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html#c:reload_plugin/7"},{"type":"callback","doc":"Reloads a specific plugin from disk.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.reload_plugin_from_disk/8","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html#c:reload_plugin_from_disk/8"},{"type":"callback","doc":"Unloads a plugin by its ID.","title":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.unload_plugin/6","ref":"Raxol.Core.Runtime.Plugins.LifecycleHelper.Behaviour.html#c:unload_plugin/6"},{"type":"module","doc":"Handles plugin lifecycle operations including enabling, disabling, and reloading plugins.\nThis module is responsible for:\n- Enabling plugins\n- Disabling plugins\n- Reloading plugins\n- Managing plugin states during lifecycle changes","title":"Raxol.Core.Runtime.Plugins.LifecycleManager","ref":"Raxol.Core.Runtime.Plugins.LifecycleManager.html"},{"type":"function","doc":"Disables a plugin temporarily without unloading it.","title":"Raxol.Core.Runtime.Plugins.LifecycleManager.disable_plugin/2","ref":"Raxol.Core.Runtime.Plugins.LifecycleManager.html#disable_plugin/2"},{"type":"function","doc":"Enables a previously disabled plugin.","title":"Raxol.Core.Runtime.Plugins.LifecycleManager.enable_plugin/2","ref":"Raxol.Core.Runtime.Plugins.LifecycleManager.html#enable_plugin/2"},{"type":"function","doc":"Loads a plugin with the given configuration.","title":"Raxol.Core.Runtime.Plugins.LifecycleManager.load_plugin/3","ref":"Raxol.Core.Runtime.Plugins.LifecycleManager.html#load_plugin/3"},{"type":"function","doc":"Reloads a plugin by unloading and then loading it again.","title":"Raxol.Core.Runtime.Plugins.LifecycleManager.reload_plugin/2","ref":"Raxol.Core.Runtime.Plugins.LifecycleManager.html#reload_plugin/2"},{"type":"module","doc":"Handles loading plugin code, metadata, and discovery.\nImplements the `Raxol.Core.Runtime.Plugins.LoaderBehaviour`.","title":"Raxol.Core.Runtime.Plugins.Loader","ref":"Raxol.Core.Runtime.Plugins.Loader.html"},{"type":"function","doc":"Checks if a module implements a specific behaviour.","title":"Raxol.Core.Runtime.Plugins.Loader.behaviour_implemented?/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#behaviour_implemented?/2"},{"type":"function","doc":"* `module` - The module to check\n* `behaviour` - The behaviour to check for","title":"Parameters - Raxol.Core.Runtime.Plugins.Loader.behaviour_implemented?/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#behaviour_implemented?/2-parameters"},{"type":"function","doc":"* `true` if the module implements the behaviour, `false` otherwise","title":"Returns - Raxol.Core.Runtime.Plugins.Loader.behaviour_implemented?/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#behaviour_implemented?/2-returns"},{"type":"function","doc":"iex> Loader.behaviour_implemented?(MyPlugin, Plugin)\n    true","title":"Examples - Raxol.Core.Runtime.Plugins.Loader.behaviour_implemented?/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#behaviour_implemented?/2-examples"},{"type":"function","doc":"Extracts metadata from a plugin module.","title":"Raxol.Core.Runtime.Plugins.Loader.extract_metadata/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#extract_metadata/1"},{"type":"function","doc":"* `module` - The module to extract metadata from","title":"Parameters - Raxol.Core.Runtime.Plugins.Loader.extract_metadata/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#extract_metadata/1-parameters"},{"type":"function","doc":"* A map containing the plugin's metadata","title":"Returns - Raxol.Core.Runtime.Plugins.Loader.extract_metadata/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#extract_metadata/1-returns"},{"type":"function","doc":"iex> Loader.extract_metadata(MyPlugin)\n    %{id: \"my_plugin\", version: \"1.0.0\", dependencies: []}","title":"Examples - Raxol.Core.Runtime.Plugins.Loader.extract_metadata/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#extract_metadata/1-examples"},{"type":"function","doc":"Initializes a plugin with the given configuration.","title":"Raxol.Core.Runtime.Plugins.Loader.initialize_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#initialize_plugin/2"},{"type":"function","doc":"* `module` - The plugin module to initialize\n* `config` - The configuration to pass to the plugin's init/1 callback","title":"Parameters - Raxol.Core.Runtime.Plugins.Loader.initialize_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#initialize_plugin/2-parameters"},{"type":"function","doc":"* `{:ok, state}` - If initialization was successful\n* `{:error, reason}` - If initialization failed","title":"Returns - Raxol.Core.Runtime.Plugins.Loader.initialize_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#initialize_plugin/2-returns"},{"type":"function","doc":"iex> Loader.initialize_plugin(MyPlugin, %{setting: \"value\"})\n    {:ok, %{initialized: true}}","title":"Examples - Raxol.Core.Runtime.Plugins.Loader.initialize_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#initialize_plugin/2-examples"},{"type":"function","doc":"Loads a plugin module's code.","title":"Raxol.Core.Runtime.Plugins.Loader.load_code/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_code/1"},{"type":"function","doc":"* `module` - The module to load","title":"Parameters - Raxol.Core.Runtime.Plugins.Loader.load_code/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_code/1-parameters"},{"type":"function","doc":"* `:ok` - If the module was loaded successfully\n* `{:error, :module_not_found}` - If the module could not be found","title":"Returns - Raxol.Core.Runtime.Plugins.Loader.load_code/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_code/1-returns"},{"type":"function","doc":"iex> Loader.load_code(MyPlugin)\n    :ok","title":"Examples - Raxol.Core.Runtime.Plugins.Loader.load_code/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_code/1-examples"},{"type":"function","doc":"Loads a plugin module based on its ID (Original function - consider for removal or refactor).\n\nAssumes the plugin ID corresponds to an existing module atom.\nReturns the module atom, placeholder metadata, and config.","title":"Raxol.Core.Runtime.Plugins.Loader.load_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Loader.html#load_plugin/2"},{"type":"function","doc":"Helper to derive a default plugin ID from the module name.\nExample: `MyOrg.MyPlugin` becomes `:my_plugin`.","title":"Raxol.Core.Runtime.Plugins.Loader.module_to_default_id/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#module_to_default_id/1"},{"type":"function","doc":"Sorts plugins based on dependencies (Placeholder - consider for removal or refactor).\n\nCurrently returns the input list unsorted.\nRequires metadata extraction to be implemented first for actual sorting.\nReturns `{:ok, sorted_plugin_ids}` or `{:error, reason}`.","title":"Raxol.Core.Runtime.Plugins.Loader.sort_plugins/1","ref":"Raxol.Core.Runtime.Plugins.Loader.html#sort_plugins/1"},{"type":"behaviour","doc":"Defines the behaviour for plugin loading functionality.\n\nThis behaviour is responsible for:\n- Loading plugin modules\n- Initializing plugins with configuration\n- Verifying plugin implementations\n- Managing plugin metadata","title":"Raxol.Core.Runtime.Plugins.Loader.Behaviour","ref":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.html"},{"type":"callback","doc":"Verifies if a module implements a specific behaviour.","title":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.behaviour_implemented?/2","ref":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.html#c:behaviour_implemented?/2"},{"type":"callback","doc":"Initializes a plugin with the given configuration.","title":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.initialize_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.html#c:initialize_plugin/2"},{"type":"callback","doc":"Loads plugin metadata from a module.","title":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.load_plugin_metadata/1","ref":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.html#c:load_plugin_metadata/1"},{"type":"callback","doc":"Loads a plugin module and verifies it implements the required behaviour.","title":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.load_plugin_module/1","ref":"Raxol.Core.Runtime.Plugins.Loader.Behaviour.html#c:load_plugin_module/1"},{"type":"module","doc":"Manages the loading, initialization, and lifecycle of plugins in the Raxol runtime.\n\nThis module is responsible for:\n- Discovering available plugins\n- Loading and initializing plugins\n- Managing plugin lifecycle events\n- Providing access to loaded plugins\n- Handling plugin dependencies and conflicts\n- Optionally watching plugin source files for changes and reloading them (dev only).","title":"Raxol.Core.Runtime.Plugins.Manager","ref":"Raxol.Core.Runtime.Plugins.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Runtime.Plugins.Manager.child_spec/1","ref":"Raxol.Core.Runtime.Plugins.Manager.html#child_spec/1"},{"type":"function","doc":"Disable a plugin temporarily without unloading it.","title":"Raxol.Core.Runtime.Plugins.Manager.disable_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.html#disable_plugin/1"},{"type":"function","doc":"Enable a plugin that was previously disabled.","title":"Raxol.Core.Runtime.Plugins.Manager.enable_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.html#enable_plugin/1"},{"type":"function","doc":"Stub: execute_command/4 not yet implemented.","title":"Raxol.Core.Runtime.Plugins.Manager.execute_command/4","ref":"Raxol.Core.Runtime.Plugins.Manager.html#execute_command/4"},{"type":"function","doc":"Placeholder for allowing plugins to filter events.","title":"Raxol.Core.Runtime.Plugins.Manager.filter_event/2","ref":"Raxol.Core.Runtime.Plugins.Manager.html#filter_event/2"},{"type":"function","doc":"Get a specific plugin by its ID.","title":"Raxol.Core.Runtime.Plugins.Manager.get_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.html#get_plugin/1"},{"type":"function","doc":"Initialize the plugin system and load all available plugins.","title":"Raxol.Core.Runtime.Plugins.Manager.initialize/0","ref":"Raxol.Core.Runtime.Plugins.Manager.html#initialize/0"},{"type":"function","doc":"Get a list of all loaded plugins with their metadata.","title":"Raxol.Core.Runtime.Plugins.Manager.list_plugins/0","ref":"Raxol.Core.Runtime.Plugins.Manager.html#list_plugins/0"},{"type":"function","doc":"Load a plugin with a given configuration.","title":"Raxol.Core.Runtime.Plugins.Manager.load_plugin/2","ref":"Raxol.Core.Runtime.Plugins.Manager.html#load_plugin/2"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Manager.plugin_id/0","ref":"Raxol.Core.Runtime.Plugins.Manager.html#t:plugin_id/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Manager.plugin_metadata/0","ref":"Raxol.Core.Runtime.Plugins.Manager.html#t:plugin_metadata/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Manager.plugin_state/0","ref":"Raxol.Core.Runtime.Plugins.Manager.html#t:plugin_state/0"},{"type":"function","doc":"Stub: process_input/2 not yet implemented.","title":"Raxol.Core.Runtime.Plugins.Manager.process_input/2","ref":"Raxol.Core.Runtime.Plugins.Manager.html#process_input/2"},{"type":"function","doc":"Stub: process_mouse/3 not yet implemented.","title":"Raxol.Core.Runtime.Plugins.Manager.process_mouse/3","ref":"Raxol.Core.Runtime.Plugins.Manager.html#process_mouse/3"},{"type":"function","doc":"Stub: process_output/2 not yet implemented.","title":"Raxol.Core.Runtime.Plugins.Manager.process_output/2","ref":"Raxol.Core.Runtime.Plugins.Manager.html#process_output/2"},{"type":"function","doc":"Stub: process_placeholder/4 not yet implemented.","title":"Raxol.Core.Runtime.Plugins.Manager.process_placeholder/4","ref":"Raxol.Core.Runtime.Plugins.Manager.html#process_placeholder/4"},{"type":"function","doc":"Reload a plugin by unloading and then loading it again.","title":"Raxol.Core.Runtime.Plugins.Manager.reload_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.html#reload_plugin/1"},{"type":"function","doc":"Starts the Plugin Manager GenServer.","title":"Raxol.Core.Runtime.Plugins.Manager.start_link/1","ref":"Raxol.Core.Runtime.Plugins.Manager.html#start_link/1"},{"type":"behaviour","doc":"Defines the behaviour for plugin management functionality.\nThis is used for mocking in tests.","title":"Raxol.Core.Runtime.Plugins.Manager.Behaviour","ref":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.html"},{"type":"callback","doc":"Gets a plugin by its ID.","title":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.get_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.html#c:get_plugin/1"},{"type":"callback","doc":"Loads a plugin from a file path.","title":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.load_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.html#c:load_plugin/1"},{"type":"callback","doc":"Starts the plugin manager with the given options.","title":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.start_link/1","ref":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.html#c:start_link/1"},{"type":"callback","doc":"Unloads a plugin by its ID.","title":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.unload_plugin/1","ref":"Raxol.Core.Runtime.Plugins.Manager.Behaviour.html#c:unload_plugin/1"},{"type":"behaviour","doc":"Defines the behaviour for Raxol plugins.\n\nPlugins must implement this behaviour to be loaded and managed by the PluginManager.","title":"Raxol.Core.Runtime.Plugins.Plugin","ref":"Raxol.Core.Runtime.Plugins.Plugin.html"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Plugin.command/0","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:command/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Plugin.config/0","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:config/0"},{"type":"callback","doc":"Called when the plugin is disabled.\n\nShould return `{:ok, new_state}` or `{:error, reason}`.","title":"Raxol.Core.Runtime.Plugins.Plugin.disable/1","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:disable/1"},{"type":"callback","doc":"Called when the plugin is enabled after being disabled.\n\nShould return `{:ok, new_state}` or `{:error, reason}`.","title":"Raxol.Core.Runtime.Plugins.Plugin.enable/1","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:enable/1"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Plugin.event/0","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:event/0"},{"type":"callback","doc":"Optional callback to filter or react to system events before they reach the application.\n\nReturn `{:ok, event}` to pass the event through (potentially modified).\nReturn `:halt` to stop the event from propagating further.\nReturn any other value to indicate an error.","title":"Raxol.Core.Runtime.Plugins.Plugin.filter_event/2","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:filter_event/2"},{"type":"callback","doc":"Optional callback to declare commands provided by the plugin.\n\nShould return a list of `{name_atom, function_atom, arity_integer}` tuples.\nExample: `[{:do_something, :handle_do_something_command, 2}]`\nThe `name_atom` will be converted to a string command name.\nThe plugin module itself will be used as the namespace.\nThese will be registered in the CommandRegistry via CommandHelper.","title":"Raxol.Core.Runtime.Plugins.Plugin.get_commands/0","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:get_commands/0"},{"type":"callback","doc":"Optional callback to handle commands delegated by the PluginManager.\n\nShould return `{:ok, new_state, result}` or `{:error, reason, new_state}`.\nThe `result` can be sent back to the original command requester if needed.","title":"Raxol.Core.Runtime.Plugins.Plugin.handle_command/3","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:handle_command/3"},{"type":"callback","doc":"Called when the plugin is first initialized.\n\nShould return `{:ok, initial_state}` or `{:error, reason}`.\nThe `initial_state` will be managed by the PluginManager.","title":"Raxol.Core.Runtime.Plugins.Plugin.init/1","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:init/1"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.Plugin.state/0","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#t:state/0"},{"type":"callback","doc":"Called when the plugin is terminated (e.g., during shutdown or unload).\n\nAllows the plugin to perform cleanup. The return value is ignored.","title":"Raxol.Core.Runtime.Plugins.Plugin.terminate/2","ref":"Raxol.Core.Runtime.Plugins.Plugin.html#c:terminate/2"},{"type":"behaviour","doc":"Defines the behaviour for plugin command dispatching.\n\nThis behaviour is responsible for:\n- Dispatching commands to appropriate plugins\n- Managing command execution flow\n- Handling command results and errors\n- Coordinating command responses","title":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.html"},{"type":"callback","doc":"Dispatches a command to the appropriate plugin.\nReturns an updated state and any necessary side effects.","title":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.dispatch_command/5","ref":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.html#c:dispatch_command/5"},{"type":"callback","doc":"Handles command errors from plugins.","title":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.handle_command_error/4","ref":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.html#c:handle_command_error/4"},{"type":"callback","doc":"Handles command results from plugins.","title":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.handle_command_result/4","ref":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.html#c:handle_command_result/4"},{"type":"callback","doc":"Handles command timeouts.","title":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.handle_command_timeout/3","ref":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.html#c:handle_command_timeout/3"},{"type":"callback","doc":"Updates the command dispatcher state.","title":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.update_dispatcher_state/2","ref":"Raxol.Core.Runtime.Plugins.PluginCommandDispatcher.Behaviour.html#c:update_dispatcher_state/2"},{"type":"behaviour","doc":"Defines the behaviour for plugin command handling.\n\nThis behaviour is responsible for:\n- Processing command requests\n- Executing commands through plugins\n- Managing command results and error handling\n- Handling command timeouts and errors","title":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.html"},{"type":"callback","doc":"Handles a command request by delegating to the appropriate plugin.\nReturns an updated state and any necessary side effects.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.handle_command/5","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.html#c:handle_command/5"},{"type":"callback","doc":"Handles command errors.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.handle_command_error/4","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.html#c:handle_command_error/4"},{"type":"callback","doc":"Handles command results.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.handle_command_result/4","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.html#c:handle_command_result/4"},{"type":"callback","doc":"Handles command timeouts.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.handle_command_timeout/3","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.html#c:handle_command_timeout/3"},{"type":"callback","doc":"Updates the command handler state.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.update_command_state/2","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHandler.Behaviour.html#c:update_command_state/2"},{"type":"behaviour","doc":"Defines the behaviour for plugin command registration and dispatch.\n\nThis behaviour is responsible for:\n- Finding plugins for command handling\n- Registering plugin commands\n- Handling command dispatch\n- Managing command unregistration","title":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.html"},{"type":"callback","doc":"Finds the plugin responsible for handling a command.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.find_plugin_for_command/4","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.html#c:find_plugin_for_command/4"},{"type":"callback","doc":"Handles the dispatching of a command to the appropriate plugin.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.handle_command/5","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.html#c:handle_command/5"},{"type":"callback","doc":"Registers the commands exposed by a plugin.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.register_plugin_commands/3","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.html#c:register_plugin_commands/3"},{"type":"callback","doc":"Unregisters all commands associated with a specific plugin module.","title":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.unregister_plugin_commands/2","ref":"Raxol.Core.Runtime.Plugins.PluginCommandHelper.Behaviour.html#c:unregister_plugin_commands/2"},{"type":"behaviour","doc":"Defines the behaviour for plugin command registration.\n\nThis behaviour is responsible for:\n- Registering plugin commands\n- Managing command lookups\n- Handling command unregistration\n- Maintaining command metadata","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.command_entry/0","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#t:command_entry/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.command_key/0","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#t:command_key/0"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.command_name/0","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#t:command_name/0"},{"type":"callback","doc":"Looks up the handler for a command name and namespace.","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.lookup_command/3","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#c:lookup_command/3"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.namespace/0","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#t:namespace/0"},{"type":"callback","doc":"Creates a new command registry table.\nReturns the name of the created table.","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.new/0","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#c:new/0"},{"type":"callback","doc":"Registers a command provided by a plugin.","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.register_command/6","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#c:register_command/6"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.table_name/0","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#t:table_name/0"},{"type":"callback","doc":"Unregisters a command.","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.unregister_command/3","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#c:unregister_command/3"},{"type":"callback","doc":"Unregisters all commands associated with a specific module.","title":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.unregister_commands_by_module/2","ref":"Raxol.Core.Runtime.Plugins.PluginCommandRegistry.Behaviour.html#c:unregister_commands_by_module/2"},{"type":"behaviour","doc":"Defines the behaviour for plugin event filtering.\n\nThis behaviour is responsible for:\n- Filtering events through registered plugin filters\n- Managing event modifications\n- Handling event halting\n- Coordinating event propagation","title":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.html"},{"type":"callback","doc":"Applies a single plugin's filter to the event.","title":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.apply_plugin_filter/3","ref":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.html#c:apply_plugin_filter/3"},{"type":"callback","doc":"Filters an event through registered plugin filters.\nReturns the filtered event or :halt if the event should be stopped.","title":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.filter_event/2","ref":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.html#c:filter_event/2"},{"type":"callback","doc":"Gets a list of enabled plugins in load order.","title":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.get_enabled_plugins/1","ref":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.html#c:get_enabled_plugins/1"},{"type":"callback","doc":"Handles event filtering errors.","title":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.handle_filter_error/3","ref":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.html#c:handle_filter_error/3"},{"type":"callback","doc":"Updates the event filter state.","title":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.update_filter_state/2","ref":"Raxol.Core.Runtime.Plugins.PluginEventFilter.Behaviour.html#c:update_filter_state/2"},{"type":"behaviour","doc":"Defines the behaviour for plugins that provide metadata like ID, version, and dependencies.\n\nPlugins can optionally implement this behaviour to declare their metadata,\nwhich the `PluginManager` uses for dependency resolution and management.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.html"},{"type":"callback","doc":"Callback invoked by the `PluginManager` to retrieve the plugin's metadata.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.get_metadata/0","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.html#c:get_metadata/0"},{"type":"type","doc":"Represents the metadata for a plugin.\n- `id`: A unique atom identifying the plugin (e.g., `:my_plugin`).\n- `version`: A string representing the plugin version (e.g., \"0.1.0\").\n- `dependencies`: A list of tuples {plugin_id, version_requirement} that this plugin depends on.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.metadata/0","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.html#t:metadata/0"},{"type":"behaviour","doc":"Defines the behaviour for plugin metadata providers.\n\nThis behaviour is responsible for:\n- Providing plugin metadata (ID, version, dependencies)\n- Validating plugin metadata\n- Managing plugin metadata lifecycle","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.dependency/0","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#t:dependency/0"},{"type":"callback","doc":"Gets the metadata for a plugin.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_metadata/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_metadata/1"},{"type":"callback","doc":"Gets the plugin behaviours from metadata.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_plugin_behaviours/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_plugin_behaviours/1"},{"type":"callback","doc":"Gets the plugin config schema from metadata.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_plugin_config_schema/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_plugin_config_schema/1"},{"type":"callback","doc":"Gets the plugin dependencies from metadata.\nReturns a list of dependencies, each being either:\n- A tuple {plugin_id, version_constraint} for versioned dependencies\n- A simple plugin_id string for unversioned dependencies","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_plugin_dependencies/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_plugin_dependencies/1"},{"type":"callback","doc":"Gets the plugin ID from metadata.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_plugin_id/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_plugin_id/1"},{"type":"callback","doc":"Gets the plugin optional dependencies from metadata.\nReturns a list of dependencies, each being either:\n- A tuple {plugin_id, version_constraint} for versioned dependencies\n- A simple plugin_id string for unversioned dependencies","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_plugin_optional_dependencies/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_plugin_optional_dependencies/1"},{"type":"callback","doc":"Gets the plugin version from metadata.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.get_plugin_version/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:get_plugin_version/1"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.metadata/0","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#t:metadata/0"},{"type":"callback","doc":"Validates plugin metadata.","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.validate_metadata/1","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#c:validate_metadata/1"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.version_constraint/0","ref":"Raxol.Core.Runtime.Plugins.PluginMetadataProvider.Behaviour.html#t:version_constraint/0"},{"type":"module","doc":"Handles plugin reloading operations.\nThis module is responsible for:\n- Reloading plugins from disk\n- Managing plugin state during reloads\n- Handling reload failures and recovery","title":"Raxol.Core.Runtime.Plugins.PluginReloader","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.html"},{"type":"function","doc":"Reloads a plugin from disk.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.reload_plugin/2","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.html#reload_plugin/2"},{"type":"function","doc":"Reloads a plugin by its string ID.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.reload_plugin_by_id/2","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.html#reload_plugin_by_id/2"},{"type":"behaviour","doc":"Defines the behaviour for plugin reloading functionality.\n\nThis behaviour is responsible for:\n- Reloading plugins from disk\n- Managing plugin reload state\n- Handling plugin reload errors\n- Coordinating plugin reload lifecycle","title":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.html"},{"type":"callback","doc":"Checks if a plugin can be reloaded.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.can_reload?/3","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.html#c:can_reload?/3"},{"type":"callback","doc":"Coordinates the plugin reload lifecycle.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.coordinate_reload/6","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.html#c:coordinate_reload/6"},{"type":"callback","doc":"Gets the reload state of a plugin.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.get_reload_state/3","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.html#c:get_reload_state/3"},{"type":"callback","doc":"Handles plugin reload errors.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.handle_reload_error/5","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.html#c:handle_reload_error/5"},{"type":"callback","doc":"Reloads a plugin from disk.","title":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.reload_plugin_from_disk/8","ref":"Raxol.Core.Runtime.Plugins.PluginReloader.Behaviour.html#c:reload_plugin_from_disk/8"},{"type":"module","doc":"Placeholder for the plugin registry.\nManages information about loaded plugins.","title":"Raxol.Core.Runtime.Plugins.Registry","ref":"Raxol.Core.Runtime.Plugins.Registry.html"},{"type":"function","doc":"Placeholder for listing plugins.","title":"Raxol.Core.Runtime.Plugins.Registry.list_plugins/1","ref":"Raxol.Core.Runtime.Plugins.Registry.html#list_plugins/1"},{"type":"function","doc":"Creates a new, empty registry state.","title":"Raxol.Core.Runtime.Plugins.Registry.new/0","ref":"Raxol.Core.Runtime.Plugins.Registry.html#new/0"},{"type":"module","doc":"Manages plugin state and state transitions.","title":"Raxol.Core.Runtime.Plugins.StateManager","ref":"Raxol.Core.Runtime.Plugins.StateManager.html"},{"type":"function","doc":"Gets a plugin's configuration.","title":"Raxol.Core.Runtime.Plugins.StateManager.get_plugin_config/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_config/2"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `state_maps` - Map containing all state maps","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_config/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_config/2-parameters"},{"type":"function","doc":"* The plugin's configuration, or nil if not found","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_config/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_config/2-returns"},{"type":"function","doc":"iex> StateManager.get_plugin_config(\"my_plugin\", %{\n      plugin_config: %{\"my_plugin\" => %{setting: \"value\"}}\n    })\n    %{setting: \"value\"}","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_config/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_config/2-examples"},{"type":"function","doc":"Gets a plugin's metadata.","title":"Raxol.Core.Runtime.Plugins.StateManager.get_plugin_metadata/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_metadata/2"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `state_maps` - Map containing all state maps","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_metadata/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_metadata/2-parameters"},{"type":"function","doc":"* The plugin's metadata, or nil if not found","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_metadata/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_metadata/2-returns"},{"type":"function","doc":"iex> StateManager.get_plugin_metadata(\"my_plugin\", %{\n      metadata: %{\"my_plugin\" => %{version: \"1.0.0\"}}\n    })\n    %{version: \"1.0.0\"}","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_metadata/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_metadata/2-examples"},{"type":"function","doc":"Gets a plugin's module.","title":"Raxol.Core.Runtime.Plugins.StateManager.get_plugin_module/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_module/2"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `state_maps` - Map containing all state maps","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_module/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_module/2-parameters"},{"type":"function","doc":"* The plugin's module, or nil if not found","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_module/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_module/2-returns"},{"type":"function","doc":"iex> StateManager.get_plugin_module(\"my_plugin\", %{\n      plugins: %{\"my_plugin\" => MyPlugin}\n    })\n    MyPlugin","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_module/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_module/2-examples"},{"type":"function","doc":"Gets a plugin's state.","title":"Raxol.Core.Runtime.Plugins.StateManager.get_plugin_state/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_state/2"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `state_maps` - Map containing all state maps","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_state/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_state/2-parameters"},{"type":"function","doc":"* The plugin's state, or nil if not found","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_state/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_state/2-returns"},{"type":"function","doc":"iex> StateManager.get_plugin_state(\"my_plugin\", %{\n      plugin_states: %{\"my_plugin\" => %{initialized: true}}\n    })\n    %{initialized: true}","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.get_plugin_state/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#get_plugin_state/2-examples"},{"type":"function","doc":"Returns a new default plugin manager state struct.","title":"Raxol.Core.Runtime.Plugins.StateManager.new/0","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#new/0"},{"type":"function","doc":"Removes a plugin from the state maps.","title":"Raxol.Core.Runtime.Plugins.StateManager.remove_plugin/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#remove_plugin/2"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin to remove\n* `state_maps` - Map containing all state maps","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.remove_plugin/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#remove_plugin/2-parameters"},{"type":"function","doc":"* Updated state maps","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.remove_plugin/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#remove_plugin/2-returns"},{"type":"function","doc":"iex> StateManager.remove_plugin(\"my_plugin\", %{\n      plugins: %{\"my_plugin\" => MyPlugin},\n      metadata: %{\"my_plugin\" => %{version: \"1.0.0\"}},\n      plugin_states: %{\"my_plugin\" => %{initialized: true}},\n      load_order: [\"my_plugin\"],\n      plugin_config: %{\"my_plugin\" => %{setting: \"value\"}}\n    })\n    %{\n      plugins: %{},\n      metadata: %{},\n      plugin_states: %{},\n      load_order: [],\n      plugin_config: %{}\n    }","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.remove_plugin/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#remove_plugin/2-examples"},{"type":"function","doc":"Sets the state for a given plugin.\nAlias for update_plugin_state/3.","title":"Raxol.Core.Runtime.Plugins.StateManager.set_plugin_state/3","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#set_plugin_state/3"},{"type":"function","doc":"Updates a plugin's state.","title":"Raxol.Core.Runtime.Plugins.StateManager.update_plugin_state/3","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_plugin_state/3"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `new_state` - The new state to set\n* `state_maps` - Map containing all state maps","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.update_plugin_state/3","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_plugin_state/3-parameters"},{"type":"function","doc":"* Updated state maps","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.update_plugin_state/3","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_plugin_state/3-returns"},{"type":"function","doc":"iex> StateManager.update_plugin_state(\"my_plugin\", %{updated: true}, %{\n      plugins: %{\"my_plugin\" => MyPlugin},\n      metadata: %{\"my_plugin\" => %{version: \"1.0.0\"}},\n      plugin_states: %{\"my_plugin\" => %{initialized: true}},\n      load_order: [\"my_plugin\"],\n      plugin_config: %{\"my_plugin\" => %{setting: \"value\"}}\n    })\n    %{\n      plugins: %{\"my_plugin\" => MyPlugin},\n      metadata: %{\"my_plugin\" => %{version: \"1.0.0\"}},\n      plugin_states: %{\"my_plugin\" => %{updated: true}},\n      load_order: [\"my_plugin\"],\n      plugin_config: %{\"my_plugin\" => %{setting: \"value\"}}\n    }","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.update_plugin_state/3","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_plugin_state/3-examples"},{"type":"function","doc":"Updates the plugin state maps with a new plugin.","title":"Raxol.Core.Runtime.Plugins.StateManager.update_state_maps/6","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_state_maps/6"},{"type":"function","doc":"* `plugin_id` - The ID of the plugin\n* `plugin_module` - The plugin's module\n* `plugin_metadata` - The plugin's metadata\n* `plugin_state` - The plugin's initial state\n* `config` - The plugin's configuration\n* `state_maps` - Map containing all state maps (plugins, metadata, states, load_order, config)","title":"Parameters - Raxol.Core.Runtime.Plugins.StateManager.update_state_maps/6","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_state_maps/6-parameters"},{"type":"function","doc":"* Updated state maps","title":"Returns - Raxol.Core.Runtime.Plugins.StateManager.update_state_maps/6","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_state_maps/6-returns"},{"type":"function","doc":"iex> StateManager.update_state_maps(\"my_plugin\", MyPlugin, %{version: \"1.0.0\"}, %{initialized: true}, %{setting: \"value\"}, %{\n      plugins: %{},\n      metadata: %{},\n      plugin_states: %{},\n      load_order: [],\n      plugin_config: %{}\n    })\n    %{\n      plugins: %{\"my_plugin\" => MyPlugin},\n      metadata: %{\"my_plugin\" => %{version: \"1.0.0\"}},\n      plugin_states: %{\"my_plugin\" => %{initialized: true}},\n      load_order: [\"my_plugin\"],\n      plugin_config: %{\"my_plugin\" => %{setting: \"value\"}}\n    }","title":"Examples - Raxol.Core.Runtime.Plugins.StateManager.update_state_maps/6","ref":"Raxol.Core.Runtime.Plugins.StateManager.html#update_state_maps/6-examples"},{"type":"behaviour","doc":"Defines the behaviour for plugin state management.\n\nThis behaviour is responsible for:\n- Managing plugin state transitions\n- Updating plugin state maps\n- Retrieving plugin state information\n- Handling plugin state lifecycle","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html"},{"type":"callback","doc":"Gets a plugin's configuration.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.get_plugin_config/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:get_plugin_config/2"},{"type":"callback","doc":"Gets a plugin's metadata.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.get_plugin_metadata/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:get_plugin_metadata/2"},{"type":"callback","doc":"Gets a plugin's module.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.get_plugin_module/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:get_plugin_module/2"},{"type":"callback","doc":"Gets a plugin's state.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.get_plugin_state/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:get_plugin_state/2"},{"type":"callback","doc":"Removes a plugin from the state maps.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.remove_plugin/2","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:remove_plugin/2"},{"type":"callback","doc":"Updates a plugin's state.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.update_plugin_state/3","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:update_plugin_state/3"},{"type":"callback","doc":"Updates the plugin state maps with a new plugin.","title":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.update_state_maps/6","ref":"Raxol.Core.Runtime.Plugins.StateManager.Behaviour.html#c:update_state_maps/6"},{"type":"module","doc":"Implements timer management functionality for plugins.\n\nThis module is responsible for:\n- Managing plugin timers\n- Handling timer scheduling and cancellation\n- Coordinating timer events\n- Managing timer state","title":"Raxol.Core.Runtime.Plugins.TimerManager","ref":"Raxol.Core.Runtime.Plugins.TimerManager.html"},{"type":"behaviour","doc":"Defines the behaviour for plugin timer management.\n\nThis behaviour is responsible for:\n- Managing plugin timers\n- Handling timer scheduling and cancellation\n- Coordinating timer events\n- Managing timer state","title":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour","ref":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.html"},{"type":"callback","doc":"Cancels an existing timer and returns updated state.","title":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.cancel_existing_timer/1","ref":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.html#c:cancel_existing_timer/1"},{"type":"callback","doc":"Gets the current timer state.","title":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.get_timer_state/1","ref":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.html#c:get_timer_state/1"},{"type":"callback","doc":"Handles timer message delivery.","title":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.handle_timer_message/2","ref":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.html#c:handle_timer_message/2"},{"type":"callback","doc":"Schedules a new timer and returns updated state.","title":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.schedule_timer/3","ref":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.html#c:schedule_timer/3"},{"type":"callback","doc":"Updates the timer state.","title":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.update_timer_state/2","ref":"Raxol.Core.Runtime.Plugins.TimerManager.Behaviour.html#c:update_timer_state/2"},{"type":"module","doc":"Provides a screen buffer implementation for efficient rendering in Raxol applications.\n\nThis module is responsible for:\n* Maintaining the screen buffer state\n* Calculating diffs between buffer states\n* Optimizing rendering by only updating changed cells","title":"Raxol.Core.Runtime.Rendering.Buffer","ref":"Raxol.Core.Runtime.Rendering.Buffer.html"},{"type":"type","doc":"A cell represents a single character position on the screen.\n\nIt is represented as a tuple with the following elements:\n- `x`: X coordinate (column)\n- `y`: Y coordinate (row)\n- `ch`: Character to display\n- `fg`: Foreground color\n- `bg`: Background color\n- `attrs`: List of attributes (e.g., :bold, :underline)","title":"Raxol.Core.Runtime.Rendering.Buffer.cell/0","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#t:cell/0"},{"type":"function","doc":"Clears the buffer by removing all cells.","title":"Raxol.Core.Runtime.Rendering.Buffer.clear/1","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#clear/1"},{"type":"function","doc":"- `buffer`: The buffer to clear","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.clear/1","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#clear/1-parameters"},{"type":"function","doc":"Cleared buffer.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.clear/1","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#clear/1-returns"},{"type":"function","doc":"Computes the diff between two buffers.\n\nThe diff contains only the cells that need to be updated.","title":"Raxol.Core.Runtime.Rendering.Buffer.diff/2","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#diff/2"},{"type":"function","doc":"- `old_buffer`: Previous buffer state\n- `new_buffer`: Current buffer state","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.diff/2","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#diff/2-parameters"},{"type":"function","doc":"List of changed cells.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.diff/2","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#diff/2-returns"},{"type":"function","doc":"Builds a buffer from a list of cells.","title":"Raxol.Core.Runtime.Rendering.Buffer.from_cells/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#from_cells/3"},{"type":"function","doc":"- `cells`: List of cells\n- `width`: Width of the buffer in columns\n- `height`: Height of the buffer in rows","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.from_cells/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#from_cells/3-parameters"},{"type":"function","doc":"A new buffer containing the cells.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.from_cells/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#from_cells/3-returns"},{"type":"function","doc":"Gets the cell at the specified position.","title":"Raxol.Core.Runtime.Rendering.Buffer.get_cell/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#get_cell/3"},{"type":"function","doc":"- `buffer`: The buffer to query\n- `x`: X coordinate\n- `y`: Y coordinate","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.get_cell/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#get_cell/3-parameters"},{"type":"function","doc":"The cell tuple if found, nil otherwise.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.get_cell/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#get_cell/3-returns"},{"type":"function","doc":"Merges another buffer's cells into this buffer.\n\nCells from the other buffer overwrite cells in this buffer.","title":"Raxol.Core.Runtime.Rendering.Buffer.merge/4","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#merge/4"},{"type":"function","doc":"- `buffer`: The destination buffer\n- `other`: The source buffer\n- `offset_x`: X offset to apply when merging\n- `offset_y`: Y offset to apply when merging","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.merge/4","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#merge/4-parameters"},{"type":"function","doc":"Updated buffer.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.merge/4","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#merge/4-returns"},{"type":"function","doc":"Creates a new empty buffer with the given dimensions.","title":"Raxol.Core.Runtime.Rendering.Buffer.new/2","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#new/2"},{"type":"function","doc":"- `width`: Width of the buffer in columns\n- `height`: Height of the buffer in rows","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.new/2","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#new/2-parameters"},{"type":"function","doc":"A new buffer struct.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.new/2","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#new/2-returns"},{"type":"function","doc":"Resizes the buffer to new dimensions.\n\nCells outside the new dimensions are discarded.","title":"Raxol.Core.Runtime.Rendering.Buffer.resize/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#resize/3"},{"type":"function","doc":"- `buffer`: The buffer to resize\n- `width`: New width\n- `height`: New height","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.resize/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#resize/3-parameters"},{"type":"function","doc":"Resized buffer.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.resize/3","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#resize/3-returns"},{"type":"function","doc":"Sets a cell in the buffer.","title":"Raxol.Core.Runtime.Rendering.Buffer.set_cell/7","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#set_cell/7"},{"type":"function","doc":"- `buffer`: The buffer to modify\n- `x`: X coordinate\n- `y`: Y coordinate\n- `ch`: Character\n- `fg`: Foreground color\n- `bg`: Background color\n- `attrs`: Attributes list","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.set_cell/7","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#set_cell/7-parameters"},{"type":"function","doc":"Updated buffer.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.set_cell/7","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#set_cell/7-returns"},{"type":"type","doc":"A buffer is a map containing cells indexed by their position.\n\nThe buffer also contains metadata about its dimensions.","title":"Raxol.Core.Runtime.Rendering.Buffer.t/0","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#t:t/0"},{"type":"function","doc":"Converts the buffer to a flat list of cells.","title":"Raxol.Core.Runtime.Rendering.Buffer.to_cells/1","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#to_cells/1"},{"type":"function","doc":"- `buffer`: The buffer to convert","title":"Parameters - Raxol.Core.Runtime.Rendering.Buffer.to_cells/1","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#to_cells/1-parameters"},{"type":"function","doc":"List of cells.","title":"Returns - Raxol.Core.Runtime.Rendering.Buffer.to_cells/1","ref":"Raxol.Core.Runtime.Rendering.Buffer.html#to_cells/1-returns"},{"type":"module","doc":"Provides the core rendering functionality for Raxol applications.\n\nThis module is responsible for:\n* Rendering application views into screen buffers\n* Managing the rendering lifecycle\n* Coordinating with the output backends","title":"Raxol.Core.Runtime.Rendering.Engine","ref":"Raxol.Core.Runtime.Rendering.Engine.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Runtime.Rendering.Engine.child_spec/1","ref":"Raxol.Core.Runtime.Rendering.Engine.html#child_spec/1"},{"type":"function","doc":"Starts the Rendering Engine process.","title":"Raxol.Core.Runtime.Rendering.Engine.start_link/1","ref":"Raxol.Core.Runtime.Rendering.Engine.html#start_link/1"},{"type":"behaviour","doc":"Behaviour for Rendering.Engine, used for mocking.","title":"Raxol.Core.Runtime.Rendering.Engine.Behaviour","ref":"Raxol.Core.Runtime.Rendering.Engine.Behaviour.html"},{"type":"callback","doc":"","title":"Raxol.Core.Runtime.Rendering.Engine.Behaviour.start_link/1","ref":"Raxol.Core.Runtime.Rendering.Engine.Behaviour.html#c:start_link/1"},{"type":"module","doc":"Manages the rendering schedule based on frame rate.","title":"Raxol.Core.Runtime.Rendering.Scheduler","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Runtime.Rendering.Scheduler.child_spec/1","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Rendering.Scheduler.disable/0","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#disable/0"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Rendering.Scheduler.enable/0","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#enable/0"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Rendering.Scheduler.set_interval/1","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#set_interval/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Rendering.Scheduler.start_link/1","ref":"Raxol.Core.Runtime.Rendering.Scheduler.html#start_link/1"},{"type":"module","doc":"Provides a way to subscribe to recurring updates and external events.\n\nSubscriptions allow applications to receive messages over time without\nexplicitly requesting them. This is useful for:\n* Timer-based updates (animation, polling)\n* System events (window resize, focus change)\n* External data streams (file changes, network events)","title":"Raxol.Core.Runtime.Subscription","ref":"Raxol.Core.Runtime.Subscription.html"},{"type":"module","doc":"* `:interval` - Regular time-based updates\n* `:events` - System or component events\n* `:file_watch` - File system changes\n* `:custom` - Custom event sources","title":"Types of Subscriptions - Raxol.Core.Runtime.Subscription","ref":"Raxol.Core.Runtime.Subscription.html#module-types-of-subscriptions"},{"type":"module","doc":"# Update every second\n    Subscription.interval(1000, :tick)\n\n    # Listen for specific events\n    Subscription.events([:key_press, :mouse_click])\n\n    # Watch a file for changes\n    Subscription.file_watch(\"config.json\", [:modify, :delete])\n\n    # Custom subscription\n    Subscription.custom(MyEventSource, :start_listening)","title":"Examples - Raxol.Core.Runtime.Subscription","ref":"Raxol.Core.Runtime.Subscription.html#module-examples"},{"type":"function","doc":"Creates a custom subscription using a provided event source.\nThe event source should implement the `Raxol.Core.Runtime.EventSource`\nbehaviour.","title":"Raxol.Core.Runtime.Subscription.custom/2","ref":"Raxol.Core.Runtime.Subscription.html#custom/2"},{"type":"function","doc":"Creates a subscription for system or component events.","title":"Raxol.Core.Runtime.Subscription.events/1","ref":"Raxol.Core.Runtime.Subscription.html#events/1"},{"type":"function","doc":"* `:key_press` - Keyboard events\n  * `:mouse_click` - Mouse click events\n  * `:mouse_move` - Mouse movement events\n  * `:window_resize` - Terminal window resize\n  * `:focus_change` - Terminal focus change\n  * `:component` - Component-specific events","title":"Event Types - Raxol.Core.Runtime.Subscription.events/1","ref":"Raxol.Core.Runtime.Subscription.html#events/1-event-types"},{"type":"function","doc":"Creates a subscription that watches for file system changes.","title":"Raxol.Core.Runtime.Subscription.file_watch/2","ref":"Raxol.Core.Runtime.Subscription.html#file_watch/2"},{"type":"function","doc":"* `:modify` - File content changes\n  * `:delete` - File deletion\n  * `:create` - File creation\n  * `:rename` - File rename\n  * `:attrib` - Attribute changes","title":"Event Types - Raxol.Core.Runtime.Subscription.file_watch/2","ref":"Raxol.Core.Runtime.Subscription.html#file_watch/2-event-types"},{"type":"function","doc":"Creates a subscription that will send a message at regular intervals.","title":"Raxol.Core.Runtime.Subscription.interval/3","ref":"Raxol.Core.Runtime.Subscription.html#interval/3"},{"type":"function","doc":"* `:start_immediately` - Send first message immediately (default: false)\n  * `:jitter` - Add random jitter to interval (default: 0)","title":"Options - Raxol.Core.Runtime.Subscription.interval/3","ref":"Raxol.Core.Runtime.Subscription.html#interval/3-options"},{"type":"function","doc":"Creates a new subscription. This is the low-level constructor, prefer using\nthe specific subscription constructors unless you need custom behavior.","title":"Raxol.Core.Runtime.Subscription.new/2","ref":"Raxol.Core.Runtime.Subscription.html#new/2"},{"type":"function","doc":"Starts a subscription within the given context. This is used by the runtime\nsystem and should not be called directly by applications.\n\nReturns `{:ok, subscription_id}` or `{:error, reason}`.","title":"Raxol.Core.Runtime.Subscription.start/2","ref":"Raxol.Core.Runtime.Subscription.html#start/2"},{"type":"function","doc":"Stops a subscription. This is used by the runtime system and should not\nbe called directly by applications.","title":"Raxol.Core.Runtime.Subscription.stop/1","ref":"Raxol.Core.Runtime.Subscription.html#stop/1"},{"type":"type","doc":"","title":"Raxol.Core.Runtime.Subscription.t/0","ref":"Raxol.Core.Runtime.Subscription.html#t:t/0"},{"type":"module","doc":"Supervises the core runtime processes of a Raxol application.\n\nThis supervisor manages:\n* Application runtime\n* Event handlers\n* Render processes\n* State management\n* Plugin system","title":"Raxol.Core.Runtime.Supervisor","ref":"Raxol.Core.Runtime.Supervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.Runtime.Supervisor.child_spec/1","ref":"Raxol.Core.Runtime.Supervisor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Core.Runtime.Supervisor.start_link/1","ref":"Raxol.Core.Runtime.Supervisor.html#start_link/1"},{"type":"behaviour","doc":"Defines a behaviour for interacting with the operating system, allowing for mocking.","title":"Raxol.Core.SystemInteraction","ref":"Raxol.Core.SystemInteraction.html"},{"type":"callback","doc":"Finds an executable like System.find_executable/1","title":"Raxol.Core.SystemInteraction.find_executable/1","ref":"Raxol.Core.SystemInteraction.html#c:find_executable/1"},{"type":"callback","doc":"Returns the OS type like :os.type()","title":"Raxol.Core.SystemInteraction.get_os_type/0","ref":"Raxol.Core.SystemInteraction.html#c:get_os_type/0"},{"type":"callback","doc":"Executes a system command like System.cmd/3","title":"Raxol.Core.SystemInteraction.system_cmd/3","ref":"Raxol.Core.SystemInteraction.html#c:system_cmd/3"},{"type":"module","doc":"Handles OSC 4 (Color Palette Set/Query) commands.\n\nThis handler manages the terminal's color palette, allowing dynamic\nmodification of colors during runtime.","title":"Raxol.Core.Terminal.OSC.Handlers.ColorPalette","ref":"Raxol.Core.Terminal.OSC.Handlers.ColorPalette.html"},{"type":"module","doc":"- rgb:RRRR/GGGG/BBBB (hex, 1-4 digits per component)\n- #RRGGBB (hex, 2 digits per component)\n- #RGB (hex, 1 digit per component)\n- rgb(r,g,b) (decimal, 0-255)\n- rgb(r%,g%,b%) (percentage, 0-100%)","title":"Color Formats Supported - Raxol.Core.Terminal.OSC.Handlers.ColorPalette","ref":"Raxol.Core.Terminal.OSC.Handlers.ColorPalette.html#module-color-formats-supported"},{"type":"function","doc":"Handles OSC 4 commands for color palette management.","title":"Raxol.Core.Terminal.OSC.Handlers.ColorPalette.handle/2","ref":"Raxol.Core.Terminal.OSC.Handlers.ColorPalette.html#handle/2"},{"type":"function","doc":"- `4;c;spec` - Set color c to spec\n- `4;c;?` - Query color c\n\nWhere:\n- c is the color index (0-255)\n- spec is the color specification","title":"Commands - Raxol.Core.Terminal.OSC.Handlers.ColorPalette.handle/2","ref":"Raxol.Core.Terminal.OSC.Handlers.ColorPalette.html#handle/2-commands"},{"type":"module","doc":"Minimal state struct for color palette OSC handler tests.","title":"Raxol.Core.Terminal.State","ref":"Raxol.Core.Terminal.State.html"},{"type":"module","doc":"User experience refinement module for the Raxol terminal UI.\n\nThis module provides comprehensive UX features to enhance the terminal UI experience:\n\n* Focus Management - Track and manage focus across UI components\n* Keyboard Navigation - Enable intuitive keyboard navigation\n* Contextual Hints - Display helpful hints based on current context\n* Focus Indicators - Visual indicators for focused elements\n* Multi-level Hints - Basic, detailed, and examples for different help levels\n* Keyboard Shortcuts - Global and context-specific keyboard shortcuts\n* Accessibility Features - Screen reader support, high contrast, reduced motion, etc.\n\nAll features can be enabled or disabled individually to customize the UX to your needs.","title":"Raxol.Core.UXRefinement","ref":"Raxol.Core.UXRefinement.html"},{"type":"function","doc":"Make an announcement for screen readers.","title":"Raxol.Core.UXRefinement.announce/2","ref":"Raxol.Core.UXRefinement.html#announce/2"},{"type":"function","doc":"Disable a previously enabled UX refinement feature.","title":"Raxol.Core.UXRefinement.disable_feature/1","ref":"Raxol.Core.UXRefinement.html#disable_feature/1"},{"type":"function","doc":"* `feature` - The feature to disable","title":"Parameters - Raxol.Core.UXRefinement.disable_feature/1","ref":"Raxol.Core.UXRefinement.html#disable_feature/1-parameters"},{"type":"function","doc":"iex> UXRefinement.disable_feature(:hints)\n    :ok","title":"Examples - Raxol.Core.UXRefinement.disable_feature/1","ref":"Raxol.Core.UXRefinement.html#disable_feature/1-examples"},{"type":"function","doc":"Enable a UX refinement feature.\n\nAvailable features:\n\n* `:focus_management` - Enable focus tracking and management\n* `:keyboard_navigation` - Enable keyboard navigation\n* `:hints` - Enable contextual hints\n* `:focus_ring` - Enable visual focus indicators\n* `:accessibility` - Enable accessibility features\n* `:keyboard_shortcuts` - Enable keyboard shortcuts\n* `:events` - Enable event management system","title":"Raxol.Core.UXRefinement.enable_feature/2","ref":"Raxol.Core.UXRefinement.html#enable_feature/2"},{"type":"function","doc":"* `feature` - The feature to enable\n* `opts` - Options for the feature","title":"Parameters - Raxol.Core.UXRefinement.enable_feature/2","ref":"Raxol.Core.UXRefinement.html#enable_feature/2-parameters"},{"type":"function","doc":"iex> UXRefinement.enable_feature(:focus_management)\n    :ok\n\n    iex> UXRefinement.enable_feature(:accessibility, high_contrast: true)\n    :ok","title":"Examples - Raxol.Core.UXRefinement.enable_feature/2","ref":"Raxol.Core.UXRefinement.html#enable_feature/2-examples"},{"type":"function","doc":"Check if a UX refinement feature is enabled.","title":"Raxol.Core.UXRefinement.feature_enabled?/1","ref":"Raxol.Core.UXRefinement.html#feature_enabled?/1"},{"type":"function","doc":"* `feature` - The feature to check","title":"Parameters - Raxol.Core.UXRefinement.feature_enabled?/1","ref":"Raxol.Core.UXRefinement.html#feature_enabled?/1-parameters"},{"type":"function","doc":"iex> UXRefinement.feature_enabled?(:focus_management)\n    true","title":"Examples - Raxol.Core.UXRefinement.feature_enabled?/1","ref":"Raxol.Core.UXRefinement.html#feature_enabled?/1-examples"},{"type":"function","doc":"Get accessibility metadata for a component.","title":"Raxol.Core.UXRefinement.get_accessibility_metadata/1","ref":"Raxol.Core.UXRefinement.html#get_accessibility_metadata/1"},{"type":"function","doc":"Get all available shortcuts for a given context.\nIf no context is provided, returns shortcuts for the current active context.","title":"Raxol.Core.UXRefinement.get_available_shortcuts/1","ref":"Raxol.Core.UXRefinement.html#get_available_shortcuts/1"},{"type":"function","doc":"Get a specific hint level for a component.","title":"Raxol.Core.UXRefinement.get_component_hint/2","ref":"Raxol.Core.UXRefinement.html#get_component_hint/2"},{"type":"function","doc":"* `component_id` - The ID of the component\n* `level` - The hint level to retrieve (`:basic`, `:detailed`, `:examples`)","title":"Parameters - Raxol.Core.UXRefinement.get_component_hint/2","ref":"Raxol.Core.UXRefinement.html#get_component_hint/2-parameters"},{"type":"function","doc":"iex> UXRefinement.get_component_hint(\"search_button\", :detailed)\n    \"Search for content in the application using keywords\"","title":"Examples - Raxol.Core.UXRefinement.get_component_hint/2","ref":"Raxol.Core.UXRefinement.html#get_component_hint/2-examples"},{"type":"function","doc":"Get shortcuts for a component.","title":"Raxol.Core.UXRefinement.get_component_shortcuts/1","ref":"Raxol.Core.UXRefinement.html#get_component_shortcuts/1"},{"type":"function","doc":"* `component_id` - The ID of the component","title":"Parameters - Raxol.Core.UXRefinement.get_component_shortcuts/1","ref":"Raxol.Core.UXRefinement.html#get_component_shortcuts/1-parameters"},{"type":"function","doc":"iex> UXRefinement.get_component_shortcuts(\"search_button\")\n    [{\"Enter\", \"Execute search\"}, {\"Alt+S\", \"Focus search\"}]","title":"Examples - Raxol.Core.UXRefinement.get_component_shortcuts/1","ref":"Raxol.Core.UXRefinement.html#get_component_shortcuts/1-examples"},{"type":"function","doc":"Get the hint for a component.\n\nThis returns the basic hint by default. Use `get_component_hint/2` for\nmore detailed hints.","title":"Raxol.Core.UXRefinement.get_hint/1","ref":"Raxol.Core.UXRefinement.html#get_hint/1"},{"type":"function","doc":"* `component_id` - The ID of the component","title":"Parameters - Raxol.Core.UXRefinement.get_hint/1","ref":"Raxol.Core.UXRefinement.html#get_hint/1-parameters"},{"type":"function","doc":"iex> UXRefinement.get_hint(\"search_button\")\n    \"Search for content\"","title":"Examples - Raxol.Core.UXRefinement.get_hint/1","ref":"Raxol.Core.UXRefinement.html#get_hint/1-examples"},{"type":"function","doc":"Initialize the UX refinement system.\n\nThis function sets up the basic infrastructure for UX refinement features.\nIt should be called before enabling any specific features.","title":"Raxol.Core.UXRefinement.init/0","ref":"Raxol.Core.UXRefinement.html#init/0"},{"type":"function","doc":"iex> UXRefinement.init()\n    :ok","title":"Examples - Raxol.Core.UXRefinement.init/0","ref":"Raxol.Core.UXRefinement.html#init/0-examples"},{"type":"function","doc":"Register accessibility metadata for a component.","title":"Raxol.Core.UXRefinement.register_accessibility_metadata/2","ref":"Raxol.Core.UXRefinement.html#register_accessibility_metadata/2"},{"type":"function","doc":"* `component_id` - The ID of the component\n* `metadata` - The metadata to register","title":"Parameters - Raxol.Core.UXRefinement.register_accessibility_metadata/2","ref":"Raxol.Core.UXRefinement.html#register_accessibility_metadata/2-parameters"},{"type":"function","doc":"iex> UXRefinement.register_accessibility_metadata(\"search_button\", %{label: \"Search\"})\n    :ok","title":"Examples - Raxol.Core.UXRefinement.register_accessibility_metadata/2","ref":"Raxol.Core.UXRefinement.html#register_accessibility_metadata/2-examples"},{"type":"function","doc":"Register comprehensive hints for a component with multiple detail levels.","title":"Raxol.Core.UXRefinement.register_component_hint/2","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2"},{"type":"function","doc":"* `component_id` - The ID of the component\n* `hint_info` - Map containing different levels of hints and shortcuts","title":"Parameters - Raxol.Core.UXRefinement.register_component_hint/2","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2-parameters"},{"type":"function","doc":"* `:basic` - Basic hint (shown by default)\n* `:detailed` - More detailed explanation\n* `:examples` - Examples of usage\n* `:shortcuts` - List of keyboard shortcuts for the component: `[{\"Ctrl+S\", \"Save\"}, ...]`","title":"Hint Info Structure - Raxol.Core.UXRefinement.register_component_hint/2","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2-hint-info-structure"},{"type":"function","doc":"iex> UXRefinement.register_component_hint(\"search_button\", %{\n    ...>   basic: \"Search for content\",\n    ...>   detailed: \"Search for content in the application using keywords\",\n    ...>   examples: \"Type keywords like 'settings' or 'help'\",\n    ...>   shortcuts: [\n    ...>     {\"Enter\", \"Execute search\"},\n    ...>     {\"Alt+S\", \"Focus search\"}\n    ...>   ]\n    ...> })\n    :ok\n\n    iex> UXRefinement.register_component_hint(\"simple_button\", \"Click me\")\n    :ok","title":"Examples - Raxol.Core.UXRefinement.register_component_hint/2","ref":"Raxol.Core.UXRefinement.html#register_component_hint/2-examples"},{"type":"function","doc":"Register a hint for a component.","title":"Raxol.Core.UXRefinement.register_hint/2","ref":"Raxol.Core.UXRefinement.html#register_hint/2"},{"type":"function","doc":"* `component_id` - The ID of the component\n* `hint` - The hint text","title":"Parameters - Raxol.Core.UXRefinement.register_hint/2","ref":"Raxol.Core.UXRefinement.html#register_hint/2-parameters"},{"type":"function","doc":"iex> UXRefinement.register_hint(\"search_button\", \"Search for content\")\n    :ok","title":"Examples - Raxol.Core.UXRefinement.register_hint/2","ref":"Raxol.Core.UXRefinement.html#register_hint/2-examples"},{"type":"function","doc":"Set the active context for keyboard shortcuts.","title":"Raxol.Core.UXRefinement.set_shortcuts_context/1","ref":"Raxol.Core.UXRefinement.html#set_shortcuts_context/1"},{"type":"function","doc":"Display help for available keyboard shortcuts.","title":"Raxol.Core.UXRefinement.show_shortcuts_help/0","ref":"Raxol.Core.UXRefinement.html#show_shortcuts_help/0"},{"type":"module","doc":"Manages user preferences for the Raxol application.\n\nActs as a GenServer holding the preferences state and handles persistence.","title":"Raxol.Core.UserPreferences","ref":"Raxol.Core.UserPreferences.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Core.UserPreferences.child_spec/1","ref":"Raxol.Core.UserPreferences.html#child_spec/1"},{"type":"function","doc":"Gets a user preference value by key path.\n\nAccepts a single key or a list of keys for nested access.","title":"Raxol.Core.UserPreferences.get/2","ref":"Raxol.Core.UserPreferences.html#get/2"},{"type":"function","doc":"UserPreferences.get(:theme) #=> \"dark\"\n    UserPreferences.get([:accessibility, :high_contrast]) #=> true\n    UserPreferences.get(:theme, my_prefs_pid) #=> \"dark\"","title":"Examples - Raxol.Core.UserPreferences.get/2","ref":"Raxol.Core.UserPreferences.html#get/2-examples"},{"type":"function","doc":"Retrieves the entire preferences map.\nAccepts an optional PID or registered name","title":"Raxol.Core.UserPreferences.get_all/1","ref":"Raxol.Core.UserPreferences.html#get_all/1"},{"type":"function","doc":"UserPreferences.get_all()\n    UserPreferences.get_all(my_prefs_pid)","title":"Examples - Raxol.Core.UserPreferences.get_all/1","ref":"Raxol.Core.UserPreferences.html#get_all/1-examples"},{"type":"function","doc":"Forces an immediate save of the current preferences.","title":"Raxol.Core.UserPreferences.save!/1","ref":"Raxol.Core.UserPreferences.html#save!/1"},{"type":"function","doc":"Sets a user preference value by key path.\n\nAccepts a single key or a list of keys for nested access.\nTriggers an automatic save after a short delay.","title":"Raxol.Core.UserPreferences.set/3","ref":"Raxol.Core.UserPreferences.html#set/3"},{"type":"function","doc":"UserPreferences.set(:theme, \"light\")\n    UserPreferences.set([:accessibility, :high_contrast], false)\n    UserPreferences.set(:theme, \"light\", my_prefs_pid)","title":"Examples - Raxol.Core.UserPreferences.set/3","ref":"Raxol.Core.UserPreferences.html#set/3-examples"},{"type":"behaviour","doc":"Defines the behaviour for UserPreferences services.","title":"Raxol.Core.UserPreferences.Behaviour","ref":"Raxol.Core.UserPreferences.Behaviour.html"},{"type":"callback","doc":"","title":"Raxol.Core.UserPreferences.Behaviour.get/1","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:get/1"},{"type":"callback","doc":"Gets a user preference value by key path.","title":"Raxol.Core.UserPreferences.Behaviour.get/2","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:get/2"},{"type":"callback","doc":"","title":"Raxol.Core.UserPreferences.Behaviour.get_all/0","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:get_all/0"},{"type":"callback","doc":"Retrieves the entire preferences map.","title":"Raxol.Core.UserPreferences.Behaviour.get_all/1","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:get_all/1"},{"type":"callback","doc":"","title":"Raxol.Core.UserPreferences.Behaviour.save!/0","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:save!/0"},{"type":"callback","doc":"Forces an immediate save of the current preferences.","title":"Raxol.Core.UserPreferences.Behaviour.save!/1","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:save!/1"},{"type":"callback","doc":"","title":"Raxol.Core.UserPreferences.Behaviour.set/2","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:set/2"},{"type":"callback","doc":"Sets a user preference value by key path.","title":"Raxol.Core.UserPreferences.Behaviour.set/3","ref":"Raxol.Core.UserPreferences.Behaviour.html#c:set/3"},{"type":"module","doc":"Internal state for the UserPreferences GenServer.","title":"Raxol.Core.UserPreferences.State","ref":"Raxol.Core.UserPreferences.State.html"},{"type":"module","doc":"Provides a safe interface for database operations.\n\nThis module:\n- Wraps all database operations with retry logic\n- Provides convenience functions for common database operations\n- Handles database errors gracefully","title":"Raxol.Database","ref":"Raxol.Database.html"},{"type":"function","doc":"Gets all records of a schema with retry logic.","title":"Raxol.Database.all/2","ref":"Raxol.Database.html#all/2"},{"type":"function","doc":"- `schema` - The schema module\n- `clauses` - Optional where clauses","title":"Parameters - Raxol.Database.all/2","ref":"Raxol.Database.html#all/2-parameters"},{"type":"function","doc":"- `{:ok, records}` - Records found\n- `{:error, reason}` - Query failed","title":"Returns - Raxol.Database.all/2","ref":"Raxol.Database.html#all/2-returns"},{"type":"function","doc":"Creates a record with retry logic.","title":"Raxol.Database.create/2","ref":"Raxol.Database.html#create/2"},{"type":"function","doc":"- `schema` - The schema module\n- `attrs` - The attributes for the new record","title":"Parameters - Raxol.Database.create/2","ref":"Raxol.Database.html#create/2-parameters"},{"type":"function","doc":"- `{:ok, record}` - Record created\n- `{:error, changeset}` - Validation failed\n- `{:error, reason}` - Query failed","title":"Returns - Raxol.Database.create/2","ref":"Raxol.Database.html#create/2-returns"},{"type":"function","doc":"Deletes a record with retry logic.","title":"Raxol.Database.delete/1","ref":"Raxol.Database.html#delete/1"},{"type":"function","doc":"- `record` - The record to delete","title":"Parameters - Raxol.Database.delete/1","ref":"Raxol.Database.html#delete/1-parameters"},{"type":"function","doc":"- `{:ok, record}` - Record deleted\n- `{:error, changeset}` - Deletion validation failed\n- `{:error, reason}` - Query failed","title":"Returns - Raxol.Database.delete/1","ref":"Raxol.Database.html#delete/1-returns"},{"type":"function","doc":"Gets a record by ID with retry logic.","title":"Raxol.Database.get/2","ref":"Raxol.Database.html#get/2"},{"type":"function","doc":"- `schema` - The schema module\n- `id` - The record ID","title":"Parameters - Raxol.Database.get/2","ref":"Raxol.Database.html#get/2-parameters"},{"type":"function","doc":"- `{:ok, record}` - Record found\n- `{:error, :not_found}` - Record not found\n- `{:error, reason}` - Query failed","title":"Returns - Raxol.Database.get/2","ref":"Raxol.Database.html#get/2-returns"},{"type":"function","doc":"Checks if the database connection is healthy.","title":"Raxol.Database.healthy?/0","ref":"Raxol.Database.html#healthy?/0"},{"type":"function","doc":"- `true` - Connection is healthy\n- `false` - Connection is unhealthy","title":"Returns - Raxol.Database.healthy?/0","ref":"Raxol.Database.html#healthy?/0-returns"},{"type":"function","doc":"Restarts the database connection if it becomes unhealthy.","title":"Raxol.Database.restart_connection/0","ref":"Raxol.Database.html#restart_connection/0"},{"type":"function","doc":"- `:ok` - Connection restart attempted","title":"Returns - Raxol.Database.restart_connection/0","ref":"Raxol.Database.html#restart_connection/0-returns"},{"type":"function","doc":"Safely executes a database query with retry logic.","title":"Raxol.Database.safe_query/1","ref":"Raxol.Database.html#safe_query/1"},{"type":"function","doc":"- `fun` - Function containing database operations","title":"Parameters - Raxol.Database.safe_query/1","ref":"Raxol.Database.html#safe_query/1-parameters"},{"type":"function","doc":"- `{:ok, result}` - Operation succeeded\n- `{:error, reason}` - Operation failed after retries","title":"Returns - Raxol.Database.safe_query/1","ref":"Raxol.Database.html#safe_query/1-returns"},{"type":"function","doc":"Executes a transaction with retry logic.","title":"Raxol.Database.transaction/1","ref":"Raxol.Database.html#transaction/1"},{"type":"function","doc":"- `fun` - Function containing transaction operations","title":"Parameters - Raxol.Database.transaction/1","ref":"Raxol.Database.html#transaction/1-parameters"},{"type":"function","doc":"- `{:ok, result}` - Transaction succeeded\n- `{:error, reason}` - Transaction failed","title":"Returns - Raxol.Database.transaction/1","ref":"Raxol.Database.html#transaction/1-returns"},{"type":"function","doc":"Updates a record with retry logic.","title":"Raxol.Database.update/3","ref":"Raxol.Database.html#update/3"},{"type":"function","doc":"- `schema` - The schema module\n- `record` - The record to update\n- `attrs` - The new attributes","title":"Parameters - Raxol.Database.update/3","ref":"Raxol.Database.html#update/3-parameters"},{"type":"function","doc":"- `{:ok, record}` - Record updated\n- `{:error, changeset}` - Validation failed\n- `{:error, reason}` - Query failed","title":"Returns - Raxol.Database.update/3","ref":"Raxol.Database.html#update/3-returns"},{"type":"module","doc":"Manages database connections and provides retry logic for Postgres errors.\n\nThis module:\n- Handles graceful connection retries\n- Monitors database connection health\n- Provides tools for debugging connection issues","title":"Raxol.Database.ConnectionManager","ref":"Raxol.Database.ConnectionManager.html"},{"type":"function","doc":"Ensures the database connection is reset after application crash.\n\nThis function should be called during application startup.","title":"Raxol.Database.ConnectionManager.ensure_connection/0","ref":"Raxol.Database.ConnectionManager.html#ensure_connection/0"},{"type":"function","doc":"Checks if the database connection is healthy.","title":"Raxol.Database.ConnectionManager.healthy?/0","ref":"Raxol.Database.ConnectionManager.html#healthy?/0"},{"type":"function","doc":"- `true` - Connection is healthy\n- `false` - Connection is unhealthy","title":"Returns - Raxol.Database.ConnectionManager.healthy?/0","ref":"Raxol.Database.ConnectionManager.html#healthy?/0-returns"},{"type":"function","doc":"Forcibly restarts the database connection.","title":"Raxol.Database.ConnectionManager.restart_connection/0","ref":"Raxol.Database.ConnectionManager.html#restart_connection/0"},{"type":"function","doc":"Attempts a database operation with retry logic.","title":"Raxol.Database.ConnectionManager.with_retries/3","ref":"Raxol.Database.ConnectionManager.html#with_retries/3"},{"type":"function","doc":"- `operation` - A function that performs a database operation\n- `max_retries` - Maximum number of retry attempts (default: 5)\n- `retry_delay_ms` - Delay between retries in milliseconds (default: 1000)","title":"Parameters - Raxol.Database.ConnectionManager.with_retries/3","ref":"Raxol.Database.ConnectionManager.html#with_retries/3-parameters"},{"type":"function","doc":"- `{:ok, result}` - Operation succeeded\n- `{:error, error}` - Operation failed after retries","title":"Returns - Raxol.Database.ConnectionManager.with_retries/3","ref":"Raxol.Database.ConnectionManager.html#with_retries/3-returns"},{"type":"module","doc":"Visual component catalog for Raxol documentation.\n\nThis module provides a comprehensive catalog of all UI components\navailable in Raxol, with visual examples, code snippets, and interactive\ncustomization capabilities.\n\nFeatures:\n* Categorized components listing\n* Live examples with code snippets\n* Interactive property customization\n* Accessibility information\n* Related components suggestions\n* Search functionality","title":"Raxol.Docs.ComponentCatalog","ref":"Raxol.Docs.ComponentCatalog.html"},{"type":"function","doc":"Generates code snippets for a component with the given properties.","title":"Raxol.Docs.ComponentCatalog.generate_code_snippet/2","ref":"Raxol.Docs.ComponentCatalog.html#generate_code_snippet/2"},{"type":"function","doc":"Gets accessibility information for a component.","title":"Raxol.Docs.ComponentCatalog.get_accessibility_info/1","ref":"Raxol.Docs.ComponentCatalog.html#get_accessibility_info/1"},{"type":"function","doc":"Gets a specific category by ID.","title":"Raxol.Docs.ComponentCatalog.get_category/1","ref":"Raxol.Docs.ComponentCatalog.html#get_category/1"},{"type":"function","doc":"Gets a specific component by ID.","title":"Raxol.Docs.ComponentCatalog.get_component/1","ref":"Raxol.Docs.ComponentCatalog.html#get_component/1"},{"type":"function","doc":"Gets usage statistics for components.","title":"Raxol.Docs.ComponentCatalog.get_usage_stats/0","ref":"Raxol.Docs.ComponentCatalog.html#get_usage_stats/0"},{"type":"function","doc":"Initializes the component catalog.","title":"Raxol.Docs.ComponentCatalog.init/0","ref":"Raxol.Docs.ComponentCatalog.html#init/0"},{"type":"function","doc":"Lists all component categories.","title":"Raxol.Docs.ComponentCatalog.list_categories/0","ref":"Raxol.Docs.ComponentCatalog.html#list_categories/0"},{"type":"function","doc":"Lists all components in a specific category.","title":"Raxol.Docs.ComponentCatalog.list_components/1","ref":"Raxol.Docs.ComponentCatalog.html#list_components/1"},{"type":"function","doc":"Renders a component example.","title":"Raxol.Docs.ComponentCatalog.render_example/3","ref":"Raxol.Docs.ComponentCatalog.html#render_example/3"},{"type":"function","doc":"Searches for components based on a query.","title":"Raxol.Docs.ComponentCatalog.search/1","ref":"Raxol.Docs.ComponentCatalog.html#search/1"},{"type":"function","doc":"Suggests related components.","title":"Raxol.Docs.ComponentCatalog.suggest_related_components/1","ref":"Raxol.Docs.ComponentCatalog.html#suggest_related_components/1"},{"type":"module","doc":"Interactive tutorial system for Raxol documentation.\n\nThis module provides a framework for creating and displaying interactive\ntutorials that guide users through Raxol features with hands-on examples\nand step-by-step instructions.\n\nFeatures:\n* Step-by-step guides with interactive examples\n* Progress tracking and bookmarking\n* Exercise validation\n* Contextual hints and help\n* Integration with documentation","title":"Raxol.Docs.InteractiveTutorial","ref":"Raxol.Docs.InteractiveTutorial.html"},{"type":"function","doc":"Gets the progress for a tutorial.","title":"Raxol.Docs.InteractiveTutorial.get_progress/1","ref":"Raxol.Docs.InteractiveTutorial.html#get_progress/1"},{"type":"function","doc":"Initializes the tutorial system.","title":"Raxol.Docs.InteractiveTutorial.init/0","ref":"Raxol.Docs.InteractiveTutorial.html#init/0"},{"type":"function","doc":"Jumps to a specific step in the current tutorial.","title":"Raxol.Docs.InteractiveTutorial.jump_to_step/1","ref":"Raxol.Docs.InteractiveTutorial.html#jump_to_step/1"},{"type":"function","doc":"Returns a list of all available tutorials.","title":"Raxol.Docs.InteractiveTutorial.list_tutorials/0","ref":"Raxol.Docs.InteractiveTutorial.html#list_tutorials/0"},{"type":"function","doc":"Goes to the next step in the current tutorial.","title":"Raxol.Docs.InteractiveTutorial.next_step/0","ref":"Raxol.Docs.InteractiveTutorial.html#next_step/0"},{"type":"function","doc":"Goes to the previous step in the current tutorial.","title":"Raxol.Docs.InteractiveTutorial.previous_step/0","ref":"Raxol.Docs.InteractiveTutorial.html#previous_step/0"},{"type":"function","doc":"Registers a new tutorial.","title":"Raxol.Docs.InteractiveTutorial.register_tutorial/2","ref":"Raxol.Docs.InteractiveTutorial.html#register_tutorial/2"},{"type":"function","doc":"Renders the current step's content.","title":"Raxol.Docs.InteractiveTutorial.render_current_step/0","ref":"Raxol.Docs.InteractiveTutorial.html#render_current_step/0"},{"type":"function","doc":"Renders interactive elements for the current step.","title":"Raxol.Docs.InteractiveTutorial.render_interactive_elements/0","ref":"Raxol.Docs.InteractiveTutorial.html#render_interactive_elements/0"},{"type":"function","doc":"Starts a tutorial by ID.","title":"Raxol.Docs.InteractiveTutorial.start_tutorial/1","ref":"Raxol.Docs.InteractiveTutorial.html#start_tutorial/1"},{"type":"function","doc":"Validates a solution for the current step.","title":"Raxol.Docs.InteractiveTutorial.validate_solution/1","ref":"Raxol.Docs.InteractiveTutorial.html#validate_solution/1"},{"type":"module","doc":"Handles loading and parsing of tutorials from markdown files.","title":"Raxol.Docs.InteractiveTutorial.Loader","ref":"Raxol.Docs.InteractiveTutorial.Loader.html"},{"type":"function","doc":"Extracts YAML front matter from markdown content.","title":"Raxol.Docs.InteractiveTutorial.Loader.extract_front_matter/1","ref":"Raxol.Docs.InteractiveTutorial.Loader.html#extract_front_matter/1"},{"type":"function","doc":"Loads a single tutorial from a markdown file.","title":"Raxol.Docs.InteractiveTutorial.Loader.load_tutorial/1","ref":"Raxol.Docs.InteractiveTutorial.Loader.html#load_tutorial/1"},{"type":"function","doc":"Loads all tutorials from the specified directory.","title":"Raxol.Docs.InteractiveTutorial.Loader.load_tutorials_from_markdown/1","ref":"Raxol.Docs.InteractiveTutorial.Loader.html#load_tutorials_from_markdown/1"},{"type":"function","doc":"Parses YAML front matter into a Tutorial struct.","title":"Raxol.Docs.InteractiveTutorial.Loader.parse_front_matter/1","ref":"Raxol.Docs.InteractiveTutorial.Loader.html#parse_front_matter/1"},{"type":"function","doc":"Parses a single step from markdown content.","title":"Raxol.Docs.InteractiveTutorial.Loader.parse_step/1","ref":"Raxol.Docs.InteractiveTutorial.Loader.html#parse_step/1"},{"type":"function","doc":"Parses markdown content into a list of Step structs.","title":"Raxol.Docs.InteractiveTutorial.Loader.parse_steps/1","ref":"Raxol.Docs.InteractiveTutorial.Loader.html#parse_steps/1"},{"type":"module","doc":"Defines the core data structures for the interactive tutorial system.","title":"Raxol.Docs.InteractiveTutorial.Models","ref":"Raxol.Docs.InteractiveTutorial.Models.html"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.Models.step_id/0","ref":"Raxol.Docs.InteractiveTutorial.Models.html#t:step_id/0"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.Models.tutorial_id/0","ref":"Raxol.Docs.InteractiveTutorial.Models.html#t:tutorial_id/0"},{"type":"module","doc":"Represents a single step in a tutorial.","title":"Raxol.Docs.InteractiveTutorial.Models.Step","ref":"Raxol.Docs.InteractiveTutorial.Models.Step.html"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.Models.Step.t/0","ref":"Raxol.Docs.InteractiveTutorial.Models.Step.html#t:t/0"},{"type":"module","doc":"Represents a complete tutorial with multiple steps.","title":"Raxol.Docs.InteractiveTutorial.Models.Tutorial","ref":"Raxol.Docs.InteractiveTutorial.Models.Tutorial.html"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.Models.Tutorial.t/0","ref":"Raxol.Docs.InteractiveTutorial.Models.Tutorial.html#t:t/0"},{"type":"module","doc":"Handles navigation and progress tracking for tutorials.","title":"Raxol.Docs.InteractiveTutorial.Navigation","ref":"Raxol.Docs.InteractiveTutorial.Navigation.html"},{"type":"function","doc":"Gets the progress for a tutorial.","title":"Raxol.Docs.InteractiveTutorial.Navigation.get_progress/2","ref":"Raxol.Docs.InteractiveTutorial.Navigation.html#get_progress/2"},{"type":"function","doc":"Jumps to a specific step in the current tutorial.","title":"Raxol.Docs.InteractiveTutorial.Navigation.jump_to_step/2","ref":"Raxol.Docs.InteractiveTutorial.Navigation.html#jump_to_step/2"},{"type":"function","doc":"Goes to the next step in the current tutorial.","title":"Raxol.Docs.InteractiveTutorial.Navigation.next_step/1","ref":"Raxol.Docs.InteractiveTutorial.Navigation.html#next_step/1"},{"type":"function","doc":"Goes to the previous step in the current tutorial.","title":"Raxol.Docs.InteractiveTutorial.Navigation.previous_step/1","ref":"Raxol.Docs.InteractiveTutorial.Navigation.html#previous_step/1"},{"type":"function","doc":"Starts a tutorial by ID.","title":"Raxol.Docs.InteractiveTutorial.Navigation.start_tutorial/2","ref":"Raxol.Docs.InteractiveTutorial.Navigation.html#start_tutorial/2"},{"type":"module","doc":"Handles rendering of tutorial content and interactive elements.","title":"Raxol.Docs.InteractiveTutorial.Renderer","ref":"Raxol.Docs.InteractiveTutorial.Renderer.html"},{"type":"function","doc":"Renders interactive elements for a step.","title":"Raxol.Docs.InteractiveTutorial.Renderer.render_interactive_elements/1","ref":"Raxol.Docs.InteractiveTutorial.Renderer.html#render_interactive_elements/1"},{"type":"function","doc":"Renders a single step's content.","title":"Raxol.Docs.InteractiveTutorial.Renderer.render_step/1","ref":"Raxol.Docs.InteractiveTutorial.Renderer.html#render_step/1"},{"type":"function","doc":"Renders a tutorial's content.","title":"Raxol.Docs.InteractiveTutorial.Renderer.render_tutorial/1","ref":"Raxol.Docs.InteractiveTutorial.Renderer.html#render_tutorial/1"},{"type":"module","doc":"Manages the state of the interactive tutorial system.","title":"Raxol.Docs.InteractiveTutorial.State","ref":"Raxol.Docs.InteractiveTutorial.State.html"},{"type":"function","doc":"Gets the current step from the state.","title":"Raxol.Docs.InteractiveTutorial.State.get_current_step/1","ref":"Raxol.Docs.InteractiveTutorial.State.html#get_current_step/1"},{"type":"function","doc":"Marks a tutorial as completed.","title":"Raxol.Docs.InteractiveTutorial.State.mark_completed/2","ref":"Raxol.Docs.InteractiveTutorial.State.html#mark_completed/2"},{"type":"function","doc":"Creates a new empty state.","title":"Raxol.Docs.InteractiveTutorial.State.new/0","ref":"Raxol.Docs.InteractiveTutorial.State.html#new/0"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.State.progress/0","ref":"Raxol.Docs.InteractiveTutorial.State.html#t:progress/0"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.State.step_id/0","ref":"Raxol.Docs.InteractiveTutorial.State.html#t:step_id/0"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.State.t/0","ref":"Raxol.Docs.InteractiveTutorial.State.html#t:t/0"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.State.tutorial_id/0","ref":"Raxol.Docs.InteractiveTutorial.State.html#t:tutorial_id/0"},{"type":"function","doc":"Updates the progress for a tutorial.","title":"Raxol.Docs.InteractiveTutorial.State.update_progress/3","ref":"Raxol.Docs.InteractiveTutorial.State.html#update_progress/3"},{"type":"module","doc":"Handles validation of tutorial exercises and user input.","title":"Raxol.Docs.InteractiveTutorial.Validation","ref":"Raxol.Docs.InteractiveTutorial.Validation.html"},{"type":"function","doc":"Validates code execution.","title":"Raxol.Docs.InteractiveTutorial.Validation.validate_execution/1","ref":"Raxol.Docs.InteractiveTutorial.Validation.html#validate_execution/1"},{"type":"function","doc":"Checks if a solution matches the expected output.","title":"Raxol.Docs.InteractiveTutorial.Validation.validate_output/2","ref":"Raxol.Docs.InteractiveTutorial.Validation.html#validate_output/2"},{"type":"function","doc":"Validates a user's solution for an exercise.","title":"Raxol.Docs.InteractiveTutorial.Validation.validate_solution/2","ref":"Raxol.Docs.InteractiveTutorial.Validation.html#validate_solution/2"},{"type":"function","doc":"Validates a user's solution for an exercise with custom validation function.","title":"Raxol.Docs.InteractiveTutorial.Validation.validate_solution/3","ref":"Raxol.Docs.InteractiveTutorial.Validation.html#validate_solution/3"},{"type":"function","doc":"Validates code syntax.","title":"Raxol.Docs.InteractiveTutorial.Validation.validate_syntax/1","ref":"Raxol.Docs.InteractiveTutorial.Validation.html#validate_syntax/1"},{"type":"type","doc":"","title":"Raxol.Docs.InteractiveTutorial.Validation.validation_result/0","ref":"Raxol.Docs.InteractiveTutorial.Validation.html#t:validation_result/0"},{"type":"module","doc":"UI Component for displaying interactive tutorials.\n\nUses Raxol.Docs.InteractiveTutorial to manage state and content.","title":"Raxol.Docs.TutorialViewer","ref":"Raxol.Docs.TutorialViewer.html"},{"type":"function","doc":"","title":"Raxol.Docs.TutorialViewer.batch/1","ref":"Raxol.Docs.TutorialViewer.html#batch/1"},{"type":"function","doc":"","title":"Raxol.Docs.TutorialViewer.command/1","ref":"Raxol.Docs.TutorialViewer.html#command/1"},{"type":"function","doc":"","title":"Raxol.Docs.TutorialViewer.subscribe/1","ref":"Raxol.Docs.TutorialViewer.html#subscribe/1"},{"type":"function","doc":"","title":"Raxol.Docs.TutorialViewer.subscribe_interval/2","ref":"Raxol.Docs.TutorialViewer.html#subscribe_interval/2"},{"type":"function","doc":"","title":"Raxol.Docs.TutorialViewer.subscribe_to_events/1","ref":"Raxol.Docs.TutorialViewer.html#subscribe_to_events/1"},{"type":"module","doc":"A dynamic supervisor for dynamically starting Raxol application processes.","title":"Raxol.DynamicSupervisor","ref":"Raxol.DynamicSupervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.DynamicSupervisor.child_spec/1","ref":"Raxol.DynamicSupervisor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.DynamicSupervisor.start_link/1","ref":"Raxol.DynamicSupervisor.html#start_link/1"},{"type":"module","doc":"","title":"Raxol.Examples.ComponentShowcase","ref":"Raxol.Examples.ComponentShowcase.html"},{"type":"function","doc":"","title":"Raxol.Examples.ComponentShowcase.broadcast/1","ref":"Raxol.Examples.ComponentShowcase.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Examples.ComponentShowcase.command/1","ref":"Raxol.Examples.ComponentShowcase.html#command/1"},{"type":"function","doc":"","title":"Raxol.Examples.ComponentShowcase.mount/1","ref":"Raxol.Examples.ComponentShowcase.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Examples.ComponentShowcase.schedule/2","ref":"Raxol.Examples.ComponentShowcase.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Examples.ComponentShowcase.unmount/1","ref":"Raxol.Examples.ComponentShowcase.html#unmount/1"},{"type":"module","doc":"Showcase for the enhanced FocusRing component with various styling options.\n\nThis example demonstrates:\n- Different animation types (pulse, blink, fade, glow, bounce)\n- Component-specific styling (button, text_input, checkbox)\n- State-based styling (normal, active, disabled)\n- Accessibility integration (high contrast mode, reduced motion)","title":"Raxol.Examples.FocusRingShowcase","ref":"Raxol.Examples.FocusRingShowcase.html"},{"type":"function","doc":"","title":"Raxol.Examples.FocusRingShowcase.broadcast/1","ref":"Raxol.Examples.FocusRingShowcase.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Examples.FocusRingShowcase.command/1","ref":"Raxol.Examples.FocusRingShowcase.html#command/1"},{"type":"function","doc":"","title":"Raxol.Examples.FocusRingShowcase.mount/1","ref":"Raxol.Examples.FocusRingShowcase.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Examples.FocusRingShowcase.schedule/2","ref":"Raxol.Examples.FocusRingShowcase.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Examples.FocusRingShowcase.unmount/1","ref":"Raxol.Examples.FocusRingShowcase.html#unmount/1"},{"type":"module","doc":"Showcase for the enhanced SelectList component with its various features.\n\nThis example demonstrates:\n- Basic selection (single and multiple)\n- Searching and filtering\n- Pagination\n- Keyboard navigation\n- Styling options","title":"Raxol.Examples.SelectListShowcase","ref":"Raxol.Examples.SelectListShowcase.html"},{"type":"function","doc":"","title":"Raxol.Examples.SelectListShowcase.broadcast/1","ref":"Raxol.Examples.SelectListShowcase.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.Examples.SelectListShowcase.command/1","ref":"Raxol.Examples.SelectListShowcase.html#command/1"},{"type":"function","doc":"","title":"Raxol.Examples.SelectListShowcase.mount/1","ref":"Raxol.Examples.SelectListShowcase.html#mount/1"},{"type":"function","doc":"","title":"Raxol.Examples.SelectListShowcase.schedule/2","ref":"Raxol.Examples.SelectListShowcase.html#schedule/2"},{"type":"function","doc":"","title":"Raxol.Examples.SelectListShowcase.unmount/1","ref":"Raxol.Examples.SelectListShowcase.html#unmount/1"},{"type":"module","doc":"Handles collection and management of system metrics.\n\nThis module is responsible for collecting and managing various system metrics\nincluding:\n- CPU usage\n- Memory usage\n- Active sessions\n- Database connections\n- Response times\n- Error rates","title":"Raxol.Metrics","ref":"Raxol.Metrics.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Metrics.child_spec/1","ref":"Raxol.Metrics.html#child_spec/1"},{"type":"function","doc":"Records a gauge metric value.","title":"Raxol.Metrics.gauge/2","ref":"Raxol.Metrics.html#gauge/2"},{"type":"function","doc":"- name: The name of the metric\n- value: The value to record for the metric","title":"Parameters - Raxol.Metrics.gauge/2","ref":"Raxol.Metrics.html#gauge/2-parameters"},{"type":"function","doc":"Raxol.Metrics.gauge(\"raxol.chart_render_time\", 42.5)","title":"Examples - Raxol.Metrics.gauge/2","ref":"Raxol.Metrics.html#gauge/2-examples"},{"type":"function","doc":"","title":"Raxol.Metrics.get_active_sessions/0","ref":"Raxol.Metrics.html#get_active_sessions/0"},{"type":"function","doc":"","title":"Raxol.Metrics.get_cpu_usage/0","ref":"Raxol.Metrics.html#get_cpu_usage/0"},{"type":"function","doc":"Returns the current metrics.\n\nReturns a map containing the current system metrics.","title":"Raxol.Metrics.get_current_metrics/0","ref":"Raxol.Metrics.html#get_current_metrics/0"},{"type":"function","doc":"","title":"Raxol.Metrics.get_memory_usage/0","ref":"Raxol.Metrics.html#get_memory_usage/0"},{"type":"function","doc":"Increments a counter metric.","title":"Raxol.Metrics.increment/1","ref":"Raxol.Metrics.html#increment/1"},{"type":"function","doc":"- name: The name of the metric to increment","title":"Parameters - Raxol.Metrics.increment/1","ref":"Raxol.Metrics.html#increment/1-parameters"},{"type":"function","doc":"Raxol.Metrics.increment(\"raxol.chart_cache_hits\")","title":"Examples - Raxol.Metrics.increment/1","ref":"Raxol.Metrics.html#increment/1-examples"},{"type":"function","doc":"","title":"Raxol.Metrics.init/1","ref":"Raxol.Metrics.html#init/1"},{"type":"function","doc":"","title":"Raxol.Metrics.start_link/1","ref":"Raxol.Metrics.html#start_link/1"},{"type":"module","doc":"Collects and stores performance metrics for the Raxol event system.\nWorks in conjunction with the Visualizer module to provide insights into system performance.","title":"Raxol.Metrics.Collector","ref":"Raxol.Metrics.Collector.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Metrics.Collector.child_spec/1","ref":"Raxol.Metrics.Collector.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Metrics.Collector.get_metrics/0","ref":"Raxol.Metrics.Collector.html#get_metrics/0"},{"type":"function","doc":"","title":"Raxol.Metrics.Collector.record_event_timing/2","ref":"Raxol.Metrics.Collector.html#record_event_timing/2"},{"type":"function","doc":"","title":"Raxol.Metrics.Collector.record_memory_usage/0","ref":"Raxol.Metrics.Collector.html#record_memory_usage/0"},{"type":"function","doc":"","title":"Raxol.Metrics.Collector.record_throughput/1","ref":"Raxol.Metrics.Collector.html#record_throughput/1"},{"type":"function","doc":"","title":"Raxol.Metrics.Collector.start_link/1","ref":"Raxol.Metrics.Collector.html#start_link/1"},{"type":"module","doc":"Provides visualization capabilities for Raxol performance metrics.\nUses Contex to generate charts and graphs for various performance indicators.","title":"Raxol.Metrics.Visualizer","ref":"Raxol.Metrics.Visualizer.html"},{"type":"function","doc":"Creates a bar chart visualization for event processing times.","title":"Raxol.Metrics.Visualizer.create_event_timing_chart/2","ref":"Raxol.Metrics.Visualizer.html#create_event_timing_chart/2"},{"type":"function","doc":"* data - List of {event_type, processing_time} tuples\n  * options - Optional configuration for the chart","title":"Parameters - Raxol.Metrics.Visualizer.create_event_timing_chart/2","ref":"Raxol.Metrics.Visualizer.html#create_event_timing_chart/2-parameters"},{"type":"function","doc":"Creates a line chart for memory usage trends.","title":"Raxol.Metrics.Visualizer.create_memory_usage_chart/2","ref":"Raxol.Metrics.Visualizer.html#create_memory_usage_chart/2"},{"type":"function","doc":"* data - List of {timestamp, memory_usage} tuples\n  * options - Optional configuration for the chart","title":"Parameters - Raxol.Metrics.Visualizer.create_memory_usage_chart/2","ref":"Raxol.Metrics.Visualizer.html#create_memory_usage_chart/2-parameters"},{"type":"function","doc":"Creates a scatter plot for event throughput over time.","title":"Raxol.Metrics.Visualizer.create_throughput_plot/2","ref":"Raxol.Metrics.Visualizer.html#create_throughput_plot/2"},{"type":"function","doc":"* data - List of {timestamp, events_per_second} tuples\n  * options - Optional configuration for the chart","title":"Parameters - Raxol.Metrics.Visualizer.create_throughput_plot/2","ref":"Raxol.Metrics.Visualizer.html#create_throughput_plot/2-parameters"},{"type":"behaviour","doc":"Defines the behavior for Raxol plugins.\nPlugins can extend the terminal's functionality by implementing this behavior.","title":"Raxol.Plugin","ref":"Raxol.Plugin.html"},{"type":"callback","doc":"","title":"Raxol.Plugin.cleanup/1","ref":"Raxol.Plugin.html#c:cleanup/1"},{"type":"callback","doc":"","title":"Raxol.Plugin.commands/0","ref":"Raxol.Plugin.html#c:commands/0"},{"type":"callback","doc":"","title":"Raxol.Plugin.handle_event/2","ref":"Raxol.Plugin.html#c:handle_event/2"},{"type":"callback","doc":"","title":"Raxol.Plugin.init/1","ref":"Raxol.Plugin.html#c:init/1"},{"type":"module","doc":"Handles the processing of rendered cells, allowing plugins to modify or replace them.\nEspecially targets placeholder cells generated by the rendering pipeline.","title":"Raxol.Plugins.CellProcessor","ref":"Raxol.Plugins.CellProcessor.html"},{"type":"function","doc":"Processes a list of cells, allowing relevant plugins to handle placeholders.\n\nIterates through the list of cells. If a cell is a placeholder (e.g.,\n`%{type: :placeholder, value: :image, ...}`), it identifies the responsible\nplugin (based on `placeholder_value`) and calls that plugin's `handle_cells/3`\ncallback.\n\nThe plugin's callback receives the placeholder cell map, the current emulator state,\nand its own current plugin state. It should return:\n- `{:ok, updated_plugin_state, list_of_replacement_cells, list_of_commands}`:\n  The placeholder is replaced by `list_of_replacement_cells`, and the plugin's\n  state is updated. `list_of_commands` are collected.\n- `{:cont, updated_plugin_state}`: The plugin declines to handle the placeholder.\n  Its state is updated, but the placeholder is effectively removed (replaced by []).\n- `{:error, reason}`: An error occurred.\n\nRegular cells (non-placeholders) are passed through unchanged.\n\nReturns `{:ok, updated_manager_state, final_cell_list, collected_commands}` where\n`updated_manager_state` reflects any changes to plugin states.","title":"Raxol.Plugins.CellProcessor.process/3","ref":"Raxol.Plugins.CellProcessor.html#process/3"},{"type":"module","doc":"Plugin for clipboard operations in Raxol.","title":"Raxol.Plugins.ClipboardPlugin","ref":"Raxol.Plugins.ClipboardPlugin.html"},{"type":"type","doc":"","title":"Raxol.Plugins.ClipboardPlugin.t/0","ref":"Raxol.Plugins.ClipboardPlugin.html#t:t/0"},{"type":"module","doc":"Handles dispatching various events (input, resize, mouse, etc.) to plugins.\n\nProvides a generic mechanism to iterate through enabled plugins and invoke\nspecific callback functions defined by the `Raxol.Plugins.Plugin` behaviour.\nUpdates the plugin manager state based on the results returned by the plugins.","title":"Raxol.Plugins.EventHandler","ref":"Raxol.Plugins.EventHandler.html"},{"type":"type","doc":"","title":"Raxol.Plugins.EventHandler.accumulator/0","ref":"Raxol.Plugins.EventHandler.html#t:accumulator/0"},{"type":"type","doc":"","title":"Raxol.Plugins.EventHandler.callback_name/0","ref":"Raxol.Plugins.EventHandler.html#t:callback_name/0"},{"type":"type","doc":"","title":"Raxol.Plugins.EventHandler.event_args/0","ref":"Raxol.Plugins.EventHandler.html#t:event_args/0"},{"type":"function","doc":"Dispatches an 'input' event to all enabled plugins implementing `handle_input/2`.","title":"Raxol.Plugins.EventHandler.handle_input/2","ref":"Raxol.Plugins.EventHandler.html#handle_input/2"},{"type":"function","doc":"Dispatches a key event (map) to enabled plugins implementing `handle_input/2`.\nNOTE: Uses `handle_input/2` as per the original PluginManager logic. Consider adding\n      a dedicated `handle_key_event` callback to the Plugin behaviour later.\nAccumulates commands and handles propagation control.","title":"Raxol.Plugins.EventHandler.handle_key_event/3","ref":"Raxol.Plugins.EventHandler.html#handle_key_event/3"},{"type":"function","doc":"Dispatches a mouse event (new format with propagation control) to enabled plugins implementing `handle_mouse/3`.","title":"Raxol.Plugins.EventHandler.handle_mouse_event/3","ref":"Raxol.Plugins.EventHandler.html#handle_mouse_event/3"},{"type":"function","doc":"Dispatches a 'mouse' event (older format) to all enabled plugins implementing `handle_mouse/3`.\nThis corresponds to the `PluginManager.process_mouse/3` function.","title":"Raxol.Plugins.EventHandler.handle_mouse_legacy/3","ref":"Raxol.Plugins.EventHandler.html#handle_mouse_legacy/3"},{"type":"function","doc":"Dispatches an 'output' event to all enabled plugins implementing `handle_output/2`.\nAccumulates transformed output.","title":"Raxol.Plugins.EventHandler.handle_output/2","ref":"Raxol.Plugins.EventHandler.html#handle_output/2"},{"type":"function","doc":"Dispatches a 'resize' event to all enabled plugins implementing `handle_resize/3`.","title":"Raxol.Plugins.EventHandler.handle_resize/3","ref":"Raxol.Plugins.EventHandler.html#handle_resize/3"},{"type":"type","doc":"","title":"Raxol.Plugins.EventHandler.handler_payload/0","ref":"Raxol.Plugins.EventHandler.html#t:handler_payload/0"},{"type":"type","doc":"","title":"Raxol.Plugins.EventHandler.handler_result/0","ref":"Raxol.Plugins.EventHandler.html#t:handler_result/0"},{"type":"module","doc":"Plugin that detects URLs in terminal output and makes them clickable.","title":"Raxol.Plugins.HyperlinkPlugin","ref":"Raxol.Plugins.HyperlinkPlugin.html"},{"type":"type","doc":"","title":"Raxol.Plugins.HyperlinkPlugin.t/0","ref":"Raxol.Plugins.HyperlinkPlugin.html#t:t/0"},{"type":"module","doc":"Plugin that enables displaying images in the terminal using the iTerm2 image protocol.\nSupports various image formats and provides options for image display.","title":"Raxol.Plugins.ImagePlugin","ref":"Raxol.Plugins.ImagePlugin.html"},{"type":"type","doc":"","title":"Raxol.Plugins.ImagePlugin.t/0","ref":"Raxol.Plugins.ImagePlugin.html#t:t/0"},{"type":"module","doc":"Handles the lifecycle management of Raxol plugins.\n\nThis includes loading, unloading, enabling, disabling, and managing\ndependencies and configuration persistence.","title":"Raxol.Plugins.Lifecycle","ref":"Raxol.Plugins.Lifecycle.html"},{"type":"function","doc":"Disables a plugin by name.\n\nUpdates the configuration to disable the plugin, saves the configuration,\nand updates the plugin state in the manager.\nReturns `{:ok, updated_manager}` or `{:error, reason}`.","title":"Raxol.Plugins.Lifecycle.disable_plugin/2","ref":"Raxol.Plugins.Lifecycle.html#disable_plugin/2"},{"type":"function","doc":"Enables a plugin by name.\n\nChecks dependencies, updates the configuration to enable the plugin,\nsaves the configuration, and updates the plugin state in the manager.\nReturns `{:ok, updated_manager}` or `{:error, reason}`.","title":"Raxol.Plugins.Lifecycle.enable_plugin/2","ref":"Raxol.Plugins.Lifecycle.html#enable_plugin/2"},{"type":"function","doc":"Loads a single plugin module and initializes it.\n\nHandles configuration merging, API compatibility checks, dependency checks,\nand saving the updated configuration.\nReturns `{:ok, updated_manager}` or `{:error, reason}`.","title":"Raxol.Plugins.Lifecycle.load_plugin/3","ref":"Raxol.Plugins.Lifecycle.html#load_plugin/3"},{"type":"function","doc":"Loads multiple plugins in the correct dependency order.\n\nInitializes all plugins first, resolves dependencies, then loads them\none by one using `load_plugin/3`.\nReturns `{:ok, updated_manager}` or `{:error, reason}`.","title":"Raxol.Plugins.Lifecycle.load_plugins/2","ref":"Raxol.Plugins.Lifecycle.html#load_plugins/2"},{"type":"function","doc":"Unloads a plugin by name.\n\nCalls the plugin's `cleanup/1` callback, updates the configuration to disable\nthe plugin, saves the configuration, and removes the plugin from the manager state.\nReturns `{:ok, updated_manager}` or `{:error, reason}`.","title":"Raxol.Plugins.Lifecycle.unload_plugin/2","ref":"Raxol.Plugins.Lifecycle.html#unload_plugin/2"},{"type":"module","doc":"Handles cell processing functionality.\nProvides functions for processing and transforming cells through plugins.","title":"Raxol.Plugins.Manager.Cells","ref":"Raxol.Plugins.Manager.Cells.html"},{"type":"function","doc":"Collects cell-related commands from all enabled plugins.\nReturns {:ok, updated_manager, commands}.","title":"Raxol.Plugins.Manager.Cells.collect_cell_commands/1","ref":"Raxol.Plugins.Manager.Cells.html#collect_cell_commands/1"},{"type":"function","doc":"Allows plugins to process or replace cells generated by the renderer.\nDelegates processing to `Raxol.Plugins.CellProcessor`.\n\nReturns `{:ok, updated_manager, processed_cells, collected_commands}`.","title":"Raxol.Plugins.Manager.Cells.handle_cells/3","ref":"Raxol.Plugins.Manager.Cells.html#handle_cells/3"},{"type":"function","doc":"Processes a single cell through all enabled plugins.\nReturns {:ok, updated_manager, processed_cell} or {:error, reason}.","title":"Raxol.Plugins.Manager.Cells.process_cell/3","ref":"Raxol.Plugins.Manager.Cells.html#process_cell/3"},{"type":"module","doc":"Core functionality for the plugin manager.\nHandles basic plugin management operations and state.","title":"Raxol.Plugins.Manager.Core","ref":"Raxol.Plugins.Manager.Core.html"},{"type":"function","doc":"Gets the current API version of the plugin manager.","title":"Raxol.Plugins.Manager.Core.get_api_version/1","ref":"Raxol.Plugins.Manager.Core.html#get_api_version/1"},{"type":"function","doc":"Gets a plugin by name.","title":"Raxol.Plugins.Manager.Core.get_plugin/2","ref":"Raxol.Plugins.Manager.Core.html#get_plugin/2"},{"type":"function","doc":"Gets a list of all loaded plugins.","title":"Raxol.Plugins.Manager.Core.list_plugins/1","ref":"Raxol.Plugins.Manager.Core.html#list_plugins/1"},{"type":"function","doc":"Creates a new plugin manager with default configuration.","title":"Raxol.Plugins.Manager.Core.new/1","ref":"Raxol.Plugins.Manager.Core.html#new/1"},{"type":"type","doc":"","title":"Raxol.Plugins.Manager.Core.t/0","ref":"Raxol.Plugins.Manager.Core.html#t:t/0"},{"type":"function","doc":"Updates the configuration in the manager.","title":"Raxol.Plugins.Manager.Core.update_config/2","ref":"Raxol.Plugins.Manager.Core.html#update_config/2"},{"type":"function","doc":"Updates the plugins map in the manager.","title":"Raxol.Plugins.Manager.Core.update_plugins/2","ref":"Raxol.Plugins.Manager.Core.html#update_plugins/2"},{"type":"module","doc":"Handles plugin event processing.\nProvides functions for processing various types of events through plugins.","title":"Raxol.Plugins.Manager.Events","ref":"Raxol.Plugins.Manager.Events.html"},{"type":"function","doc":"Broadcasts an event to all enabled plugins.\nReturns {:ok, updated_manager} or {:error, reason}.","title":"Raxol.Plugins.Manager.Events.broadcast_event/2","ref":"Raxol.Plugins.Manager.Events.html#broadcast_event/2"},{"type":"function","doc":"Processes a mouse event through all enabled plugins, providing cell context.\nPlugins can choose to halt propagation if they handle the event.\nReturns {:ok, updated_manager, :propagate | :halt} or {:error, reason}.\nDelegates to `Raxol.Plugins.EventHandler.handle_mouse_event/3`.","title":"Raxol.Plugins.Manager.Events.handle_mouse_event/3","ref":"Raxol.Plugins.Manager.Events.html#handle_mouse_event/3"},{"type":"function","doc":"Notifies all enabled plugins of a terminal resize event.\nDelegates to `Raxol.Plugins.EventHandler.handle_resize/3`.","title":"Raxol.Plugins.Manager.Events.handle_resize/3","ref":"Raxol.Plugins.Manager.Events.html#handle_resize/3"},{"type":"function","doc":"Processes input through all enabled plugins.\nDelegates to `Raxol.Plugins.EventHandler.handle_input/2`.","title":"Raxol.Plugins.Manager.Events.process_input/2","ref":"Raxol.Plugins.Manager.Events.html#process_input/2"},{"type":"function","doc":"Processes mouse events through all enabled plugins.\nDelegates to `Raxol.Plugins.EventHandler.handle_mouse_legacy/3`.","title":"Raxol.Plugins.Manager.Events.process_mouse/3","ref":"Raxol.Plugins.Manager.Events.html#process_mouse/3"},{"type":"function","doc":"Processes output through all enabled plugins.\nReturns {:ok, manager, transformed_output} if a plugin transforms the output,\nor {:ok, manager} if no transformation is needed.\nDelegates to `Raxol.Plugins.EventHandler.handle_output/2`.","title":"Raxol.Plugins.Manager.Events.process_output/2","ref":"Raxol.Plugins.Manager.Events.html#process_output/2"},{"type":"module","doc":"Handles plugin hook execution.\nProvides functions for running various plugin hooks and collecting their results.","title":"Raxol.Plugins.Manager.Hooks","ref":"Raxol.Plugins.Manager.Hooks.html"},{"type":"function","doc":"Runs a specific hook on all enabled plugins.\nReturns {:ok, updated_manager, results} where results is a list of hook results.","title":"Raxol.Plugins.Manager.Hooks.run_hook/3","ref":"Raxol.Plugins.Manager.Hooks.html#run_hook/3"},{"type":"function","doc":"Runs render-related hooks for all enabled plugins.\nCollects any direct output commands (e.g., escape sequences) returned by plugins.\nReturns {:ok, updated_manager, list_of_output_commands}","title":"Raxol.Plugins.Manager.Hooks.run_render_hooks/1","ref":"Raxol.Plugins.Manager.Hooks.html#run_render_hooks/1"},{"type":"module","doc":"Handles plugin state management and updates.\nProvides functions for updating plugin state and managing plugin lifecycle states.","title":"Raxol.Plugins.Manager.State","ref":"Raxol.Plugins.Manager.State.html"},{"type":"function","doc":"Disables a plugin by name.\nDelegates to `Raxol.Plugins.Lifecycle.disable_plugin/2`.","title":"Raxol.Plugins.Manager.State.disable_plugin/2","ref":"Raxol.Plugins.Manager.State.html#disable_plugin/2"},{"type":"function","doc":"Enables a plugin by name.\nDelegates to `Raxol.Plugins.Lifecycle.enable_plugin/2`.","title":"Raxol.Plugins.Manager.State.enable_plugin/2","ref":"Raxol.Plugins.Manager.State.html#enable_plugin/2"},{"type":"function","doc":"Loads a plugin module and initializes it with the given configuration.\nDelegates to `Raxol.Plugins.Lifecycle.load_plugin/3`.","title":"Raxol.Plugins.Manager.State.load_plugin/3","ref":"Raxol.Plugins.Manager.State.html#load_plugin/3"},{"type":"function","doc":"Loads multiple plugins in the correct dependency order.\nDelegates to `Raxol.Plugins.Lifecycle.load_plugins/2`.","title":"Raxol.Plugins.Manager.State.load_plugins/2","ref":"Raxol.Plugins.Manager.State.html#load_plugins/2"},{"type":"function","doc":"Unloads a plugin by name.\nDelegates to `Raxol.Plugins.Lifecycle.unload_plugin/2`.","title":"Raxol.Plugins.Manager.State.unload_plugin/2","ref":"Raxol.Plugins.Manager.State.html#unload_plugin/2"},{"type":"function","doc":"Updates the state of a specific plugin within the manager.\nThe `update_fun` receives the current plugin state and should return the new state.","title":"Raxol.Plugins.Manager.State.update_plugin/3","ref":"Raxol.Plugins.Manager.State.html#update_plugin/3"},{"type":"behaviour","doc":"Defines the behavior for Raxol terminal emulator plugins.\nPlugins can extend the terminal's functionality by implementing this behavior.","title":"Raxol.Plugins.Plugin","ref":"Raxol.Plugins.Plugin.html"},{"type":"callback","doc":"","title":"Raxol.Plugins.Plugin.cleanup/1","ref":"Raxol.Plugins.Plugin.html#c:cleanup/1"},{"type":"callback","doc":"Returns the plugin's API version.\nThis is used to check compatibility with the plugin manager.","title":"Raxol.Plugins.Plugin.get_api_version/0","ref":"Raxol.Plugins.Plugin.html#c:get_api_version/0"},{"type":"callback","doc":"Returns the plugin's dependencies.\nEach dependency is a map with the following keys:\n- name: The name of the plugin\n- version: The version constraint (e.g., \">= 1.0.0\")\n- optional: Whether the dependency is optional (default: false)","title":"Raxol.Plugins.Plugin.get_dependencies/0","ref":"Raxol.Plugins.Plugin.html#c:get_dependencies/0"},{"type":"callback","doc":"(Optional) Processes a cell, potentially a placeholder, before drawing.\n\nAllows plugins to identify specific cells (like placeholders) and replace them\nwith actual content (a list of cells) or generate commands (like escape sequences).","title":"Raxol.Plugins.Plugin.handle_cells/3","ref":"Raxol.Plugins.Plugin.html#c:handle_cells/3"},{"type":"callback","doc":"- `cell` - The specific cell being processed. Can be a regular cell map\n           `%{x: _, y: _, char: _, ...}` or a special map like\n           `%{type: :placeholder, value: :image, bounds: ...}`.\n- `emulator_state` - The current state map of the `Runtime` GenServer.\n- `plugin_state` - The current internal state of the plugin itself.","title":"Parameters - Raxol.Plugins.Plugin.handle_cells/3","ref":"Raxol.Plugins.Plugin.html#c:handle_cells/3-parameters"},{"type":"callback","doc":"- `{:ok, updated_plugin_state, replacement_cells, commands}`:\n  The plugin handled the cell. `replacement_cells` (a list of `{x,y,map}` tuples)\n  will replace the original `cell` in the render list. `commands` are executed.\n  `updated_plugin_state` is stored.\n- `{:cont, updated_plugin_state}`:\n  The plugin declined to handle this cell or handled it internally without replacing it.\n  The original cell is kept. `updated_plugin_state` is stored.\n  Allows other plugins to potentially process the same cell.","title":"Returns - Raxol.Plugins.Plugin.handle_cells/3","ref":"Raxol.Plugins.Plugin.html#c:handle_cells/3-returns"},{"type":"callback","doc":"","title":"Raxol.Plugins.Plugin.handle_input/2","ref":"Raxol.Plugins.Plugin.html#c:handle_input/2"},{"type":"callback","doc":"","title":"Raxol.Plugins.Plugin.handle_mouse/3","ref":"Raxol.Plugins.Plugin.html#c:handle_mouse/3"},{"type":"callback","doc":"","title":"Raxol.Plugins.Plugin.handle_output/2","ref":"Raxol.Plugins.Plugin.html#c:handle_output/2"},{"type":"callback","doc":"Optional callback executed just before the terminal buffer is presented.\nAllows plugins to inject direct output commands (e.g., escape sequences).\n\nShould return:\n- `{:ok, updated_plugin_state, command_to_write}` - If state changes and command is output.\n- `{:ok, updated_plugin_state}` - If state changes but no command is output.\n- `command_to_write` - If only a command is output (state unchanged).\n- `:ok` - If nothing needs to be done.","title":"Raxol.Plugins.Plugin.handle_render/1","ref":"Raxol.Plugins.Plugin.html#c:handle_render/1"},{"type":"callback","doc":"","title":"Raxol.Plugins.Plugin.handle_resize/3","ref":"Raxol.Plugins.Plugin.html#c:handle_resize/3"},{"type":"callback","doc":"","title":"Raxol.Plugins.Plugin.init/1","ref":"Raxol.Plugins.Plugin.html#c:init/1"},{"type":"type","doc":"","title":"Raxol.Plugins.Plugin.t/0","ref":"Raxol.Plugins.Plugin.html#t:t/0"},{"type":"module","doc":"Handles persistence of plugin configurations.\nStores and loads plugin configurations from disk.","title":"Raxol.Plugins.PluginConfig","ref":"Raxol.Plugins.PluginConfig.html"},{"type":"function","doc":"Disables a plugin.","title":"Raxol.Plugins.PluginConfig.disable_plugin/2","ref":"Raxol.Plugins.PluginConfig.html#disable_plugin/2"},{"type":"function","doc":"Enables a plugin.","title":"Raxol.Plugins.PluginConfig.enable_plugin/2","ref":"Raxol.Plugins.PluginConfig.html#enable_plugin/2"},{"type":"function","doc":"Gets the configuration for a specific plugin.","title":"Raxol.Plugins.PluginConfig.get_plugin_config/2","ref":"Raxol.Plugins.PluginConfig.html#get_plugin_config/2"},{"type":"function","doc":"Checks if a plugin is enabled.","title":"Raxol.Plugins.PluginConfig.is_plugin_enabled?/2","ref":"Raxol.Plugins.PluginConfig.html#is_plugin_enabled?/2"},{"type":"function","doc":"Loads plugin configurations from disk.","title":"Raxol.Plugins.PluginConfig.load/0","ref":"Raxol.Plugins.PluginConfig.html#load/0"},{"type":"function","doc":"Creates a new plugin configuration manager.","title":"Raxol.Plugins.PluginConfig.new/0","ref":"Raxol.Plugins.PluginConfig.html#new/0"},{"type":"function","doc":"Saves plugin configurations to disk.","title":"Raxol.Plugins.PluginConfig.save/1","ref":"Raxol.Plugins.PluginConfig.html#save/1"},{"type":"type","doc":"","title":"Raxol.Plugins.PluginConfig.t/0","ref":"Raxol.Plugins.PluginConfig.html#t:t/0"},{"type":"function","doc":"Updates the configuration for a specific plugin.","title":"Raxol.Plugins.PluginConfig.update_plugin_config/3","ref":"Raxol.Plugins.PluginConfig.html#update_plugin_config/3"},{"type":"module","doc":"Manages plugins for the Raxol terminal emulator.\nHandles plugin loading, lifecycle management, and event dispatching.","title":"Raxol.Plugins.PluginManager","ref":"Raxol.Plugins.PluginManager.html"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.broadcast_event/2","ref":"Raxol.Plugins.PluginManager.html#broadcast_event/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.collect_cell_commands/1","ref":"Raxol.Plugins.PluginManager.html#collect_cell_commands/1"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.disable_plugin/2","ref":"Raxol.Plugins.PluginManager.html#disable_plugin/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.enable_plugin/2","ref":"Raxol.Plugins.PluginManager.html#enable_plugin/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.get_api_version/1","ref":"Raxol.Plugins.PluginManager.html#get_api_version/1"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.get_plugin/2","ref":"Raxol.Plugins.PluginManager.html#get_plugin/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.handle_cells/3","ref":"Raxol.Plugins.PluginManager.html#handle_cells/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.handle_mouse_event/3","ref":"Raxol.Plugins.PluginManager.html#handle_mouse_event/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.handle_resize/3","ref":"Raxol.Plugins.PluginManager.html#handle_resize/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.list_plugins/1","ref":"Raxol.Plugins.PluginManager.html#list_plugins/1"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.load_plugin/3","ref":"Raxol.Plugins.PluginManager.html#load_plugin/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.load_plugins/2","ref":"Raxol.Plugins.PluginManager.html#load_plugins/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.new/1","ref":"Raxol.Plugins.PluginManager.html#new/1"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.process_cell/3","ref":"Raxol.Plugins.PluginManager.html#process_cell/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.process_input/2","ref":"Raxol.Plugins.PluginManager.html#process_input/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.process_mouse/3","ref":"Raxol.Plugins.PluginManager.html#process_mouse/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.process_output/2","ref":"Raxol.Plugins.PluginManager.html#process_output/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.run_hook/3","ref":"Raxol.Plugins.PluginManager.html#run_hook/3"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.run_render_hooks/1","ref":"Raxol.Plugins.PluginManager.html#run_render_hooks/1"},{"type":"type","doc":"","title":"Raxol.Plugins.PluginManager.t/0","ref":"Raxol.Plugins.PluginManager.html#t:t/0"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.unload_plugin/2","ref":"Raxol.Plugins.PluginManager.html#unload_plugin/2"},{"type":"function","doc":"","title":"Raxol.Plugins.PluginManager.update_plugin/3","ref":"Raxol.Plugins.PluginManager.html#update_plugin/3"},{"type":"module","doc":"Plugin for text search functionality.","title":"Raxol.Plugins.SearchPlugin","ref":"Raxol.Plugins.SearchPlugin.html"},{"type":"function","doc":"Gets the current search result.","title":"Raxol.Plugins.SearchPlugin.get_current_result/1","ref":"Raxol.Plugins.SearchPlugin.html#get_current_result/1"},{"type":"function","doc":"Gets the current result index.","title":"Raxol.Plugins.SearchPlugin.get_current_result_index/1","ref":"Raxol.Plugins.SearchPlugin.html#get_current_result_index/1"},{"type":"function","doc":"Gets the current search results.","title":"Raxol.Plugins.SearchPlugin.get_search_results/1","ref":"Raxol.Plugins.SearchPlugin.html#get_search_results/1"},{"type":"function","doc":"Gets the current search term.","title":"Raxol.Plugins.SearchPlugin.get_search_term/1","ref":"Raxol.Plugins.SearchPlugin.html#get_search_term/1"},{"type":"function","doc":"Highlights the search term in the given text.","title":"Raxol.Plugins.SearchPlugin.highlight_search_term/2","ref":"Raxol.Plugins.SearchPlugin.html#highlight_search_term/2"},{"type":"type","doc":"","title":"Raxol.Plugins.SearchPlugin.t/0","ref":"Raxol.Plugins.SearchPlugin.html#t:t/0"},{"type":"module","doc":"Plugin that manages terminal themes and color schemes.\nAllows users to apply predefined themes or create custom color schemes.","title":"Raxol.Plugins.ThemePlugin","ref":"Raxol.Plugins.ThemePlugin.html"},{"type":"function","doc":"Changes the current theme to the specified theme name.","title":"Raxol.Plugins.ThemePlugin.change_theme/2","ref":"Raxol.Plugins.ThemePlugin.html#change_theme/2"},{"type":"function","doc":"","title":"Raxol.Plugins.ThemePlugin.disable/1","ref":"Raxol.Plugins.ThemePlugin.html#disable/1"},{"type":"function","doc":"","title":"Raxol.Plugins.ThemePlugin.enable/1","ref":"Raxol.Plugins.ThemePlugin.html#enable/1"},{"type":"function","doc":"","title":"Raxol.Plugins.ThemePlugin.get_name/1","ref":"Raxol.Plugins.ThemePlugin.html#get_name/1"},{"type":"function","doc":"Gets the current theme.","title":"Raxol.Plugins.ThemePlugin.get_theme/1","ref":"Raxol.Plugins.ThemePlugin.html#get_theme/1"},{"type":"function","doc":"","title":"Raxol.Plugins.ThemePlugin.is_enabled?/1","ref":"Raxol.Plugins.ThemePlugin.html#is_enabled?/1"},{"type":"function","doc":"Gets a list of available themes.","title":"Raxol.Plugins.ThemePlugin.list_themes/0","ref":"Raxol.Plugins.ThemePlugin.html#list_themes/0"},{"type":"function","doc":"Registers a new theme.","title":"Raxol.Plugins.ThemePlugin.register_theme/1","ref":"Raxol.Plugins.ThemePlugin.html#register_theme/1"},{"type":"module","doc":"Handles rendering logic for chart visualizations within the VisualizationPlugin.","title":"Raxol.Plugins.Visualization.ChartRenderer","ref":"Raxol.Plugins.Visualization.ChartRenderer.html"},{"type":"function","doc":"Public entry point for rendering chart content.\nHandles bounds checking, error handling, and calls the internal drawing logic.\nExpects bounds to be a map like %{width: w, height: h}.","title":"Raxol.Plugins.Visualization.ChartRenderer.render_chart_content/4","ref":"Raxol.Plugins.Visualization.ChartRenderer.html#render_chart_content/4"},{"type":"module","doc":"Utility functions for drawing basic shapes and text onto a cell grid.\nUsed by visualization renderers.","title":"Raxol.Plugins.Visualization.DrawingUtils","ref":"Raxol.Plugins.Visualization.DrawingUtils.html"},{"type":"function","doc":"Draws box borders onto an existing grid.","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_box_borders/6","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_box_borders/6"},{"type":"function","doc":"Draws a simple box with optional text centered inside.\nReturns a grid of cells.\nExpects bounds map: %{width: w, height: h}.","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_box_with_text/2","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_box_with_text/2"},{"type":"function","doc":"Draws text onto a grid at a specific coordinate.\nTruncates if text exceeds grid width.\nUses optional style.","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_text/5","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_text/5"},{"type":"function","doc":"Draws text centered horizontally on a specific row in the grid.\nTruncates text if it exceeds grid width.","title":"Raxol.Plugins.Visualization.DrawingUtils.draw_text_centered/3","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#draw_text_centered/3"},{"type":"function","doc":"Safely gets a cell from the grid.\nReturns nil if coordinates are out of bounds.","title":"Raxol.Plugins.Visualization.DrawingUtils.get_cell/3","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#get_cell/3"},{"type":"function","doc":"Safely puts a cell into the grid (list of lists).\nHandles out-of-bounds coordinates gracefully (no-op).","title":"Raxol.Plugins.Visualization.DrawingUtils.put_cell/4","ref":"Raxol.Plugins.Visualization.DrawingUtils.html#put_cell/4"},{"type":"module","doc":"Handles rendering logic for image placeholders within the VisualizationPlugin.\nCurrently provides a text placeholder, but intended for protocols like sixel or kitty.","title":"Raxol.Plugins.Visualization.ImageRenderer","ref":"Raxol.Plugins.Visualization.ImageRenderer.html"},{"type":"function","doc":"Public entry point for rendering image content.\nHandles bounds checking and calls the internal drawing logic.\nExpects bounds map: %{width: w, height: h}.","title":"Raxol.Plugins.Visualization.ImageRenderer.render_image_content/4","ref":"Raxol.Plugins.Visualization.ImageRenderer.html#render_image_content/4"},{"type":"module","doc":"Handles rendering logic for treemap visualizations within the VisualizationPlugin.\nUses a squarified layout algorithm.","title":"Raxol.Plugins.Visualization.TreemapRenderer","ref":"Raxol.Plugins.Visualization.TreemapRenderer.html"},{"type":"function","doc":"Public entry point for rendering treemap content.\nHandles bounds checking, error handling, and calls the internal layout/drawing logic.\nExpects bounds map: %{width: w, height: h}.","title":"Raxol.Plugins.Visualization.TreemapRenderer.render_treemap_content/4","ref":"Raxol.Plugins.Visualization.TreemapRenderer.html#render_treemap_content/4"},{"type":"module","doc":"Plugin responsible for rendering visualization components like charts and treemaps.\nIt receives data structures from the view rendering pipeline and outputs\nactual terminal cells.","title":"Raxol.Plugins.VisualizationPlugin","ref":"Raxol.Plugins.VisualizationPlugin.html"},{"type":"function","doc":"","title":"Raxol.Plugins.VisualizationPlugin.get_commands/0","ref":"Raxol.Plugins.VisualizationPlugin.html#get_commands/0"},{"type":"function","doc":"","title":"Raxol.Plugins.VisualizationPlugin.handle_command/4","ref":"Raxol.Plugins.VisualizationPlugin.html#handle_command/4"},{"type":"function","doc":"","title":"Raxol.Plugins.VisualizationPlugin.handle_event/3","ref":"Raxol.Plugins.VisualizationPlugin.html#handle_event/3"},{"type":"function","doc":"","title":"Raxol.Plugins.VisualizationPlugin.handle_placeholder/3","ref":"Raxol.Plugins.VisualizationPlugin.html#handle_placeholder/3"},{"type":"function","doc":"","title":"Raxol.Plugins.VisualizationPlugin.terminate/3","ref":"Raxol.Plugins.VisualizationPlugin.html#terminate/3"},{"type":"module","doc":"Handles layout calculations for UI elements.\n\nThis module translates the logical layout (panels, rows, columns)\ninto absolute positions for rendering.","title":"Raxol.Renderer.Layout","ref":"Raxol.Renderer.Layout.html"},{"type":"function","doc":"Applies layout to a view, calculating absolute positions for all elements.","title":"Raxol.Renderer.Layout.apply_layout/2","ref":"Raxol.Renderer.Layout.html#apply_layout/2"},{"type":"function","doc":"* `view` - The view to calculate layout for\n* `dimensions` - Terminal dimensions `%{width: w, height: h}`","title":"Parameters - Raxol.Renderer.Layout.apply_layout/2","ref":"Raxol.Renderer.Layout.html#apply_layout/2-parameters"},{"type":"function","doc":"A list of positioned elements with absolute coordinates.","title":"Returns - Raxol.Renderer.Layout.apply_layout/2","ref":"Raxol.Renderer.Layout.html#apply_layout/2-returns"},{"type":"module","doc":"","title":"Raxol.Repo","ref":"Raxol.Repo.html"},{"type":"function","doc":"","title":"Raxol.Repo.aggregate/3","ref":"Raxol.Repo.html#aggregate/3"},{"type":"function","doc":"","title":"Raxol.Repo.aggregate/4","ref":"Raxol.Repo.html#aggregate/4"},{"type":"function","doc":"","title":"Raxol.Repo.all/2","ref":"Raxol.Repo.html#all/2"},{"type":"function","doc":"","title":"Raxol.Repo.checked_out?/0","ref":"Raxol.Repo.html#checked_out?/0"},{"type":"function","doc":"","title":"Raxol.Repo.checkout/2","ref":"Raxol.Repo.html#checkout/2"},{"type":"function","doc":"","title":"Raxol.Repo.child_spec/1","ref":"Raxol.Repo.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Repo.config/0","ref":"Raxol.Repo.html#config/0"},{"type":"function","doc":"Executes raw SQL query with logging.\n\nThis adds better error handling and logging around raw SQL queries.","title":"Raxol.Repo.custom_query/3","ref":"Raxol.Repo.html#custom_query/3"},{"type":"function","doc":"* `{:ok, result}` - on success\n* `{:error, exception}` - on failure","title":"Returns - Raxol.Repo.custom_query/3","ref":"Raxol.Repo.html#custom_query/3-returns"},{"type":"function","doc":"Executes raw SQL query with logging, raising on errors.\n\nThis adds better error handling and logging around raw SQL queries.","title":"Raxol.Repo.custom_query!/3","ref":"Raxol.Repo.html#custom_query!/3"},{"type":"function","doc":"","title":"Raxol.Repo.default_options/1","ref":"Raxol.Repo.html#default_options/1"},{"type":"function","doc":"","title":"Raxol.Repo.delete/2","ref":"Raxol.Repo.html#delete/2"},{"type":"function","doc":"","title":"Raxol.Repo.delete!/2","ref":"Raxol.Repo.html#delete!/2"},{"type":"function","doc":"","title":"Raxol.Repo.delete_all/2","ref":"Raxol.Repo.html#delete_all/2"},{"type":"function","doc":"A convenience function for SQL-based repositories that forces all connections in the\npool to disconnect within the given interval.\n\nSee `Ecto.Adapters.SQL.disconnect_all/3` for more information.","title":"Raxol.Repo.disconnect_all/2","ref":"Raxol.Repo.html#disconnect_all/2"},{"type":"function","doc":"","title":"Raxol.Repo.exists?/2","ref":"Raxol.Repo.html#exists?/2"},{"type":"function","doc":"A convenience function for SQL-based repositories that executes an EXPLAIN statement or similar\ndepending on the adapter to obtain statistics for the given query.\n\nSee `Ecto.Adapters.SQL.explain/4` for more information.","title":"Raxol.Repo.explain/3","ref":"Raxol.Repo.html#explain/3"},{"type":"function","doc":"","title":"Raxol.Repo.get/3","ref":"Raxol.Repo.html#get/3"},{"type":"function","doc":"","title":"Raxol.Repo.get!/3","ref":"Raxol.Repo.html#get!/3"},{"type":"function","doc":"","title":"Raxol.Repo.get_by/3","ref":"Raxol.Repo.html#get_by/3"},{"type":"function","doc":"","title":"Raxol.Repo.get_by!/3","ref":"Raxol.Repo.html#get_by!/3"},{"type":"function","doc":"","title":"Raxol.Repo.get_dynamic_repo/0","ref":"Raxol.Repo.html#get_dynamic_repo/0"},{"type":"function","doc":"","title":"Raxol.Repo.in_transaction?/0","ref":"Raxol.Repo.html#in_transaction?/0"},{"type":"function","doc":"Initializes the repository.","title":"Raxol.Repo.init/2","ref":"Raxol.Repo.html#init/2"},{"type":"function","doc":"This function is called when the repo is started. It adds improved logging\naround database connection events.","title":"Overrides - Raxol.Repo.init/2","ref":"Raxol.Repo.html#init/2-overrides"},{"type":"function","doc":"","title":"Raxol.Repo.insert/2","ref":"Raxol.Repo.html#insert/2"},{"type":"function","doc":"","title":"Raxol.Repo.insert!/2","ref":"Raxol.Repo.html#insert!/2"},{"type":"function","doc":"","title":"Raxol.Repo.insert_all/3","ref":"Raxol.Repo.html#insert_all/3"},{"type":"function","doc":"","title":"Raxol.Repo.insert_or_update/2","ref":"Raxol.Repo.html#insert_or_update/2"},{"type":"function","doc":"","title":"Raxol.Repo.insert_or_update!/2","ref":"Raxol.Repo.html#insert_or_update!/2"},{"type":"function","doc":"","title":"Raxol.Repo.load/2","ref":"Raxol.Repo.html#load/2"},{"type":"function","doc":"","title":"Raxol.Repo.one/2","ref":"Raxol.Repo.html#one/2"},{"type":"function","doc":"","title":"Raxol.Repo.one!/2","ref":"Raxol.Repo.html#one!/2"},{"type":"function","doc":"","title":"Raxol.Repo.preload/3","ref":"Raxol.Repo.html#preload/3"},{"type":"function","doc":"","title":"Raxol.Repo.prepare_query/3","ref":"Raxol.Repo.html#prepare_query/3"},{"type":"function","doc":"","title":"Raxol.Repo.put_dynamic_repo/1","ref":"Raxol.Repo.html#put_dynamic_repo/1"},{"type":"function","doc":"A convenience function for SQL-based repositories that executes the given query.\n\nSee `Ecto.Adapters.SQL.query/4` for more information.","title":"Raxol.Repo.query/3","ref":"Raxol.Repo.html#query/3"},{"type":"function","doc":"A convenience function for SQL-based repositories that executes the given query.\n\nSee `Ecto.Adapters.SQL.query!/4` for more information.","title":"Raxol.Repo.query!/3","ref":"Raxol.Repo.html#query!/3"},{"type":"function","doc":"A convenience function for SQL-based repositories that executes the given multi-result query.\n\nSee `Ecto.Adapters.SQL.query_many/4` for more information.","title":"Raxol.Repo.query_many/3","ref":"Raxol.Repo.html#query_many/3"},{"type":"function","doc":"A convenience function for SQL-based repositories that executes the given multi-result query.\n\nSee `Ecto.Adapters.SQL.query_many!/4` for more information.","title":"Raxol.Repo.query_many!/3","ref":"Raxol.Repo.html#query_many!/3"},{"type":"function","doc":"","title":"Raxol.Repo.reload/2","ref":"Raxol.Repo.html#reload/2"},{"type":"function","doc":"","title":"Raxol.Repo.reload!/2","ref":"Raxol.Repo.html#reload!/2"},{"type":"function","doc":"","title":"Raxol.Repo.rollback/1","ref":"Raxol.Repo.html#rollback/1"},{"type":"function","doc":"","title":"Raxol.Repo.start_link/1","ref":"Raxol.Repo.html#start_link/1"},{"type":"function","doc":"","title":"Raxol.Repo.stop/1","ref":"Raxol.Repo.html#stop/1"},{"type":"function","doc":"","title":"Raxol.Repo.stream/2","ref":"Raxol.Repo.html#stream/2"},{"type":"function","doc":"A convenience function for SQL-based repositories that translates the given query to SQL.\n\nSee `Ecto.Adapters.SQL.to_sql/3` for more information.","title":"Raxol.Repo.to_sql/2","ref":"Raxol.Repo.html#to_sql/2"},{"type":"function","doc":"","title":"Raxol.Repo.transaction/2","ref":"Raxol.Repo.html#transaction/2"},{"type":"function","doc":"","title":"Raxol.Repo.update/2","ref":"Raxol.Repo.html#update/2"},{"type":"function","doc":"","title":"Raxol.Repo.update!/2","ref":"Raxol.Repo.html#update!/2"},{"type":"function","doc":"","title":"Raxol.Repo.update_all/3","ref":"Raxol.Repo.html#update_all/3"},{"type":"module","doc":"The main supervisor for the Raxol application runtime.\nManages core processes like Dispatcher, PluginManager, etc.","title":"Raxol.Runtime.Supervisor","ref":"Raxol.Runtime.Supervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Runtime.Supervisor.child_spec/1","ref":"Raxol.Runtime.Supervisor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Runtime.Supervisor.start_link/1","ref":"Raxol.Runtime.Supervisor.html#start_link/1"},{"type":"module","doc":"Session management module for handling terminal sessions.\n\nThis module provides functionality for:\n- Session creation and management\n- Session authentication\n- Session state tracking\n- Session cleanup","title":"Raxol.Session","ref":"Raxol.Session.html"},{"type":"function","doc":"","title":"Raxol.Session.authenticate_session/2","ref":"Raxol.Session.html#authenticate_session/2"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Session.child_spec/1","ref":"Raxol.Session.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Session.cleanup_session/1","ref":"Raxol.Session.html#cleanup_session/1"},{"type":"function","doc":"","title":"Raxol.Session.create_session/1","ref":"Raxol.Session.html#create_session/1"},{"type":"function","doc":"","title":"Raxol.Session.get_session/1","ref":"Raxol.Session.html#get_session/1"},{"type":"function","doc":"","title":"Raxol.Session.start_link/1","ref":"Raxol.Session.html#start_link/1"},{"type":"module","doc":"Defines style properties for terminal UI elements.","title":"Raxol.Style","ref":"Raxol.Style.html"},{"type":"function","doc":"Apply component-specific styling.","title":"Raxol.Style.apply_component_specific/2","ref":"Raxol.Style.html#apply_component_specific/2"},{"type":"function","doc":"Apply responsive styling based on terminal dimensions.","title":"Raxol.Style.apply_responsive/3","ref":"Raxol.Style.html#apply_responsive/3"},{"type":"function","doc":"Merges two styles, with the second overriding the first.","title":"Raxol.Style.merge/2","ref":"Raxol.Style.html#merge/2"},{"type":"function","doc":"Creates a new style with default values.","title":"Raxol.Style.new/0","ref":"Raxol.Style.html#new/0"},{"type":"function","doc":"Creates a new style from a keyword list or map of attributes.","title":"Raxol.Style.new/1","ref":"Raxol.Style.html#new/1"},{"type":"function","doc":"Resolves a style definition against the current theme.","title":"Raxol.Style.resolve/2","ref":"Raxol.Style.html#resolve/2"},{"type":"type","doc":"","title":"Raxol.Style.t/0","ref":"Raxol.Style.html#t:t/0"},{"type":"function","doc":"Converts style properties to ANSI escape sequences (currently just numeric codes).","title":"Raxol.Style.to_ansi/1","ref":"Raxol.Style.html#to_ansi/1"},{"type":"module","doc":"Defines border properties for terminal UI elements.","title":"Raxol.Style.Borders","ref":"Raxol.Style.Borders.html"},{"type":"function","doc":"Merges two border structs, with the second overriding the first.","title":"Raxol.Style.Borders.merge/2","ref":"Raxol.Style.Borders.html#merge/2"},{"type":"function","doc":"Creates a new border with default values.","title":"Raxol.Style.Borders.new/0","ref":"Raxol.Style.Borders.html#new/0"},{"type":"function","doc":"Creates a new border with the specified values.","title":"Raxol.Style.Borders.new/1","ref":"Raxol.Style.Borders.html#new/1"},{"type":"type","doc":"","title":"Raxol.Style.Borders.t/0","ref":"Raxol.Style.Borders.html#t:t/0"},{"type":"module","doc":"Provides utilities for color accessibility, focusing on WCAG contrast.","title":"Raxol.Style.Colors.Accessibility","ref":"Raxol.Style.Colors.Accessibility.html"},{"type":"function","doc":"Finds an accessible color pair (foreground/background) based on a base color and WCAG level.\n\nTries to find a contrasting color (black or white first) that meets the desired level.\n\nParameters:\n  - `base_color`: The Color struct or hex string to find a contrasting pair for.\n  - `level`: The minimum WCAG contrast ratio level (:aa or :aaa, defaults to :aa).\n\nReturns:\n  A tuple `{foreground_color, background_color}` where one is the `base_color`\n  and the other is a contrasting color (typically black or white) that meets the\n  specified `level`. Returns `nil` if no suitable pair is found immediately\n  (further logic might be needed for complex cases).","title":"Raxol.Style.Colors.Accessibility.accessible_color_pair/2","ref":"Raxol.Style.Colors.Accessibility.html#accessible_color_pair/2"},{"type":"function","doc":"Calculates the contrast ratio between two colors according to WCAG guidelines.","title":"Raxol.Style.Colors.Accessibility.contrast_ratio/2","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2"},{"type":"function","doc":"- `color1` - The first color (hex string or Color struct)\n- `color2` - The second color (hex string or Color struct)","title":"Parameters - Raxol.Style.Colors.Accessibility.contrast_ratio/2","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2-parameters"},{"type":"function","doc":"- A float representing the contrast ratio (1:1 to 21:1)","title":"Returns - Raxol.Style.Colors.Accessibility.contrast_ratio/2","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2-returns"},{"type":"function","doc":"iex> Raxol.Style.Colors.Accessibility.contrast_ratio(\"#000000\", \"#FFFFFF\")\n    21.0\n\n    iex> Raxol.Style.Colors.Accessibility.contrast_ratio(\"#777777\", \"#999999\")\n    1.3","title":"Examples - Raxol.Style.Colors.Accessibility.contrast_ratio/2","ref":"Raxol.Style.Colors.Accessibility.html#contrast_ratio/2-examples"},{"type":"function","doc":"Darkens a color until it meets the specified contrast ratio with a background color.\n\nRequires HSL module for `darken` function.","title":"Raxol.Style.Colors.Accessibility.darken_until_contrast/3","ref":"Raxol.Style.Colors.Accessibility.html#darken_until_contrast/3"},{"type":"function","doc":"- `color` - The color to darken (Color struct)\n- `background` - The background color (Color struct)\n- `target_ratio` - The target contrast ratio to achieve","title":"Parameters - Raxol.Style.Colors.Accessibility.darken_until_contrast/3","ref":"Raxol.Style.Colors.Accessibility.html#darken_until_contrast/3-parameters"},{"type":"function","doc":"- A Color struct representing the darkened color","title":"Returns - Raxol.Style.Colors.Accessibility.darken_until_contrast/3","ref":"Raxol.Style.Colors.Accessibility.html#darken_until_contrast/3-returns"},{"type":"function","doc":"","title":"Raxol.Style.Colors.Accessibility.lighten_until_contrast/3","ref":"Raxol.Style.Colors.Accessibility.html#lighten_until_contrast/3"},{"type":"function","doc":"Checks if a foreground color is readable on a background color.","title":"Raxol.Style.Colors.Accessibility.readable?/3","ref":"Raxol.Style.Colors.Accessibility.html#readable?/3"},{"type":"function","doc":"- `background` - Background color\n- `foreground` - Text color\n- `level` - Accessibility level (`:aa`, `:aaa`, `:aa_large`, `:aaa_large`)","title":"Parameters - Raxol.Style.Colors.Accessibility.readable?/3","ref":"Raxol.Style.Colors.Accessibility.html#readable?/3-parameters"},{"type":"function","doc":"iex> bg = Raxol.Style.Colors.Color.from_hex(\"#333333\")\n    iex> fg = Raxol.Style.Colors.Color.from_hex(\"#FFFFFF\")\n    iex> Raxol.Style.Colors.Accessibility.readable?(bg, fg)\n    true\n\n    iex> bg = Raxol.Style.Colors.Color.from_hex(\"#CCCCCC\")\n    iex> fg = Raxol.Style.Colors.Color.from_hex(\"#999999\")\n    iex> Raxol.Style.Colors.Accessibility.readable?(bg, fg, :aaa)\n    false","title":"Examples - Raxol.Style.Colors.Accessibility.readable?/3","ref":"Raxol.Style.Colors.Accessibility.html#readable?/3-examples"},{"type":"function","doc":"Calculates the relative luminance of a color according to WCAG guidelines.","title":"Raxol.Style.Colors.Accessibility.relative_luminance/1","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1"},{"type":"function","doc":"- `color` - The color to calculate luminance for (hex string or Color struct)","title":"Parameters - Raxol.Style.Colors.Accessibility.relative_luminance/1","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1-parameters"},{"type":"function","doc":"- A float between 0 and 1 representing the relative luminance","title":"Returns - Raxol.Style.Colors.Accessibility.relative_luminance/1","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1-returns"},{"type":"function","doc":"iex> Raxol.Style.Colors.Accessibility.relative_luminance(\"#000000\")\n    0.0\n\n    iex> Raxol.Style.Colors.Accessibility.relative_luminance(\"#FFFFFF\")\n    1.0","title":"Examples - Raxol.Style.Colors.Accessibility.relative_luminance/1","ref":"Raxol.Style.Colors.Accessibility.html#relative_luminance/1-examples"},{"type":"function","doc":"Suggests a color with good contrast (at least AA) to the base color.\n\nPrioritizes complementary color, then black/white.","title":"Raxol.Style.Colors.Accessibility.suggest_contrast_color/1","ref":"Raxol.Style.Colors.Accessibility.html#suggest_contrast_color/1"},{"type":"function","doc":"- `color` - The base color (hex string or Color struct)","title":"Parameters - Raxol.Style.Colors.Accessibility.suggest_contrast_color/1","ref":"Raxol.Style.Colors.Accessibility.html#suggest_contrast_color/1-parameters"},{"type":"function","doc":"iex> color = Raxol.Style.Colors.Color.from_hex(\"#3366CC\")\n    iex> contrast_color = Raxol.Style.Colors.Accessibility.suggest_contrast_color(color)\n    iex> Raxol.Style.Colors.Accessibility.readable?(color, contrast_color)\n    true","title":"Examples - Raxol.Style.Colors.Accessibility.suggest_contrast_color/1","ref":"Raxol.Style.Colors.Accessibility.html#suggest_contrast_color/1-examples"},{"type":"function","doc":"Suggests an appropriate text color (black or white) for a given background.\n\nEnsures minimum AA contrast.","title":"Raxol.Style.Colors.Accessibility.suggest_text_color/1","ref":"Raxol.Style.Colors.Accessibility.html#suggest_text_color/1"},{"type":"function","doc":"- `background` - The background color (hex string or Color struct)","title":"Parameters - Raxol.Style.Colors.Accessibility.suggest_text_color/1","ref":"Raxol.Style.Colors.Accessibility.html#suggest_text_color/1-parameters"},{"type":"function","doc":"iex> Raxol.Style.Colors.Accessibility.suggest_text_color(\"#333333\").hex\n    \"#FFFFFF\"\n\n    iex> Raxol.Style.Colors.Accessibility.suggest_text_color(\"#EEEEEE\").hex\n    \"#000000\"","title":"Examples - Raxol.Style.Colors.Accessibility.suggest_text_color/1","ref":"Raxol.Style.Colors.Accessibility.html#suggest_text_color/1-examples"},{"type":"module","doc":"Detects terminal capabilities and adapts color schemes accordingly.\n\nThis module provides functionality to detect what color capabilities are\nsupported by the current terminal and adapt colors and themes to work\noptimally with the detected capabilities.","title":"Raxol.Style.Colors.Adaptive","ref":"Raxol.Style.Colors.Adaptive.html"},{"type":"module","doc":"```elixir\n# Check if the terminal supports true color\nif Raxol.Style.Colors.Adaptive.supports_true_color?() do\n  # Use true color features\nelse\n  # Fall back to 256 colors or 16 colors\nend\n\n# Adapt a color to the current terminal capabilities\ncolor = Raxol.Style.Colors.Color.from_hex(\"#FF5500\")\nadapted_color = Raxol.Style.Colors.Adaptive.adapt_color(color)\n\n# Check if we're in a dark terminal\nif Raxol.Style.Colors.Adaptive.is_dark_terminal?() do\n  # Use light text on dark background\nelse\n  # Use dark text on light background\nend\n```","title":"Examples - Raxol.Style.Colors.Adaptive","ref":"Raxol.Style.Colors.Adaptive.html#module-examples"},{"type":"function","doc":"Adapts a color to the current terminal capabilities.\n\nIf the terminal does not support the full color range, this will\nconvert the color to the best available representation.","title":"Raxol.Style.Colors.Adaptive.adapt_color/1","ref":"Raxol.Style.Colors.Adaptive.html#adapt_color/1"},{"type":"function","doc":"- `color` - The color to adapt","title":"Parameters - Raxol.Style.Colors.Adaptive.adapt_color/1","ref":"Raxol.Style.Colors.Adaptive.html#adapt_color/1-parameters"},{"type":"function","doc":"iex> color = Raxol.Style.Colors.Color.from_hex(\"#FF5500\")\n    iex> adapted = Raxol.Style.Colors.Adaptive.adapt_color(color)\n    iex> adapted.hex\n    \"#FF5500\"  # If terminal supports true color, otherwise closest supported color","title":"Examples - Raxol.Style.Colors.Adaptive.adapt_color/1","ref":"Raxol.Style.Colors.Adaptive.html#adapt_color/1-examples"},{"type":"function","doc":"Adapts a theme (canonical structure) to the current terminal capabilities and background.","title":"Raxol.Style.Colors.Adaptive.adapt_theme/1","ref":"Raxol.Style.Colors.Adaptive.html#adapt_theme/1"},{"type":"function","doc":"- `theme` - The canonical theme map to adapt","title":"Parameters - Raxol.Style.Colors.Adaptive.adapt_theme/1","ref":"Raxol.Style.Colors.Adaptive.html#adapt_theme/1-parameters"},{"type":"function","doc":"iex> theme = Raxol.UI.Theming.Theme.default_theme()\n    iex> adapted = Raxol.Style.Colors.Adaptive.adapt_theme(theme)\n    iex> adapted.name\n    \"default (Adapted)\"  # Adapted to terminal capabilities","title":"Examples - Raxol.Style.Colors.Adaptive.adapt_theme/1","ref":"Raxol.Style.Colors.Adaptive.html#adapt_theme/1-examples"},{"type":"function","doc":"Detects the color support level of the current terminal.\n\nReturns one of:\n- `:true_color` - 24-bit color (16 million colors)\n- `:ansi_256` - 256 colors\n- `:ansi_16` - 16 colors\n- `:no_color` - No color support","title":"Raxol.Style.Colors.Adaptive.detect_color_support/0","ref":"Raxol.Style.Colors.Adaptive.html#detect_color_support/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.detect_color_support()\n    :true_color  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.detect_color_support/0","ref":"Raxol.Style.Colors.Adaptive.html#detect_color_support/0-examples"},{"type":"function","doc":"Gets the optimal color format for the current terminal.\n\nReturns one of:\n- `:true_color` - 24-bit color (16 million colors)\n- `:ansi_256` - 256 colors\n- `:ansi_16`","title":"Raxol.Style.Colors.Adaptive.get_optimal_format/0","ref":"Raxol.Style.Colors.Adaptive.html#get_optimal_format/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.get_optimal_format()\n    :true_color  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.get_optimal_format/0","ref":"Raxol.Style.Colors.Adaptive.html#get_optimal_format/0-examples"},{"type":"function","doc":"Initializes the terminal capabilities cache.\n\nThis should be called once, usually during application startup.\nIt creates the ETS table used for caching detected capabilities.","title":"Raxol.Style.Colors.Adaptive.init/0","ref":"Raxol.Style.Colors.Adaptive.html#init/0"},{"type":"function","doc":"Checks if the terminal has a dark background.","title":"Raxol.Style.Colors.Adaptive.is_dark_terminal?/0","ref":"Raxol.Style.Colors.Adaptive.html#is_dark_terminal?/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.is_dark_terminal?()\n    true  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.is_dark_terminal?/0","ref":"Raxol.Style.Colors.Adaptive.html#is_dark_terminal?/0-examples"},{"type":"function","doc":"Gets the optimal color format for the current terminal.\n\nReturns one of:\n- `:true_color` - 24-bit color (16 million colors)\n- `:ansi_256` - 256 colors\n- `:ansi_16` - 16 colors\n- `:no_color` - No color support","title":"Raxol.Style.Colors.Adaptive.optimal_format/0","ref":"Raxol.Style.Colors.Adaptive.html#optimal_format/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.optimal_format()\n    :true_color  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.optimal_format/0","ref":"Raxol.Style.Colors.Adaptive.html#optimal_format/0-examples"},{"type":"function","doc":"Resets the cached terminal capabilities.\n\nThis forces the next call to detection functions to re-evaluate\nthe terminal environment.","title":"Raxol.Style.Colors.Adaptive.reset_detection/0","ref":"Raxol.Style.Colors.Adaptive.html#reset_detection/0"},{"type":"function","doc":"Checks if the terminal supports 256 colors.","title":"Raxol.Style.Colors.Adaptive.supports_256_colors?/0","ref":"Raxol.Style.Colors.Adaptive.html#supports_256_colors?/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.supports_256_colors?()\n    true  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.supports_256_colors?/0","ref":"Raxol.Style.Colors.Adaptive.html#supports_256_colors?/0-examples"},{"type":"function","doc":"Checks if the terminal supports true color (24-bit color).","title":"Raxol.Style.Colors.Adaptive.supports_true_color?/0","ref":"Raxol.Style.Colors.Adaptive.html#supports_true_color?/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.supports_true_color?()\n    true  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.supports_true_color?/0","ref":"Raxol.Style.Colors.Adaptive.html#supports_true_color?/0-examples"},{"type":"function","doc":"Detects the terminal background color (light or dark).\n\nReturns one of:\n- `:dark` - Dark background\n- `:light` - Light background\n- `:unknown` - Unable to determine","title":"Raxol.Style.Colors.Adaptive.terminal_background/0","ref":"Raxol.Style.Colors.Adaptive.html#terminal_background/0"},{"type":"function","doc":"iex> Raxol.Style.Colors.Adaptive.terminal_background()\n    :dark  # Depends on your terminal","title":"Examples - Raxol.Style.Colors.Adaptive.terminal_background/0","ref":"Raxol.Style.Colors.Adaptive.html#terminal_background/0-examples"},{"type":"module","doc":"Provides advanced color handling capabilities for the terminal.\n\nFeatures:\n- Color blending and mixing\n- Custom color palettes\n- Enhanced color adaptation\n- Color space conversions\n- Color harmony generation","title":"Raxol.Style.Colors.Advanced","ref":"Raxol.Style.Colors.Advanced.html"},{"type":"function","doc":"Adapts a color to the current terminal capabilities with advanced options.","title":"Raxol.Style.Colors.Advanced.adapt_color_advanced/2","ref":"Raxol.Style.Colors.Advanced.html#adapt_color_advanced/2"},{"type":"function","doc":"- `color` - The color to adapt\n- `options` - Adaptation options\n  - `:preserve_brightness` - Try to maintain perceived brightness\n  - `:enhance_contrast` - Increase contrast when possible\n  - `:color_blind_safe` - Ensure color blind friendly colors","title":"Parameters - Raxol.Style.Colors.Advanced.adapt_color_advanced/2","ref":"Raxol.Style.Colors.Advanced.html#adapt_color_advanced/2-parameters"},{"type":"function","doc":"iex> color = Color.from_hex(\"#FF0000\")\n    iex> adapted = Advanced.adapt_color_advanced(color, preserve_brightness: true)\n    iex> adapted.hex\n    \"#FF0000\"  # If terminal supports true color","title":"Examples - Raxol.Style.Colors.Advanced.adapt_color_advanced/2","ref":"Raxol.Style.Colors.Advanced.html#adapt_color_advanced/2-examples"},{"type":"function","doc":"Blends two colors together with the given ratio.","title":"Raxol.Style.Colors.Advanced.blend_colors/3","ref":"Raxol.Style.Colors.Advanced.html#blend_colors/3"},{"type":"function","doc":"- `color1` - First color\n- `color2` - Second color\n- `ratio` - Blend ratio (0.0 to 1.0, where 0.0 is color1 and 1.0 is color2)","title":"Parameters - Raxol.Style.Colors.Advanced.blend_colors/3","ref":"Raxol.Style.Colors.Advanced.html#blend_colors/3-parameters"},{"type":"function","doc":"iex> color1 = Color.from_hex(\"#FF0000\")\n    iex> color2 = Color.from_hex(\"#0000FF\")\n    iex> blended = Advanced.blend_colors(color1, color2, 0.5)\n    iex> blended.hex\n    \"#800080\"  # Purple","title":"Examples - Raxol.Style.Colors.Advanced.blend_colors/3","ref":"Raxol.Style.Colors.Advanced.html#blend_colors/3-examples"},{"type":"type","doc":"","title":"Raxol.Style.Colors.Advanced.color/0","ref":"Raxol.Style.Colors.Advanced.html#t:color/0"},{"type":"function","doc":"Converts a color to a different color space.","title":"Raxol.Style.Colors.Advanced.convert_color_space/2","ref":"Raxol.Style.Colors.Advanced.html#convert_color_space/2"},{"type":"function","doc":"- `color` - The color to convert\n- `target_space` - The target color space (:rgb, :hsl, :lab, or :xyz)","title":"Parameters - Raxol.Style.Colors.Advanced.convert_color_space/2","ref":"Raxol.Style.Colors.Advanced.html#convert_color_space/2-parameters"},{"type":"function","doc":"iex> color = Color.from_hex(\"#FF0000\")\n    iex> hsl = Advanced.convert_color_space(color, :hsl)\n    iex> hsl\n    %{h: 0, s: 100, l: 50}","title":"Examples - Raxol.Style.Colors.Advanced.convert_color_space/2","ref":"Raxol.Style.Colors.Advanced.html#convert_color_space/2-examples"},{"type":"function","doc":"Creates a gradient between two colors with the specified number of steps.","title":"Raxol.Style.Colors.Advanced.create_gradient/3","ref":"Raxol.Style.Colors.Advanced.html#create_gradient/3"},{"type":"function","doc":"- `color1` - Start color\n- `color2` - End color\n- `steps` - Number of steps in the gradient","title":"Parameters - Raxol.Style.Colors.Advanced.create_gradient/3","ref":"Raxol.Style.Colors.Advanced.html#create_gradient/3-parameters"},{"type":"function","doc":"iex> color1 = Color.from_hex(\"#FF0000\")\n    iex> color2 = Color.from_hex(\"#0000FF\")\n    iex> gradient = Advanced.create_gradient(color1, color2, 3)\n    iex> Enum.map(gradient, & &1.hex)\n    [\"#FF0000\", \"#800080\", \"#0000FF\"]","title":"Examples - Raxol.Style.Colors.Advanced.create_gradient/3","ref":"Raxol.Style.Colors.Advanced.html#create_gradient/3-examples"},{"type":"function","doc":"Creates a color harmony based on the input color.","title":"Raxol.Style.Colors.Advanced.create_harmony/3","ref":"Raxol.Style.Colors.Advanced.html#create_harmony/3"},{"type":"function","doc":"- `color` - The base color\n- `harmony_type` - Type of harmony (:complementary, :analogous, :triadic, :tetradic)","title":"Parameters - Raxol.Style.Colors.Advanced.create_harmony/3","ref":"Raxol.Style.Colors.Advanced.html#create_harmony/3-parameters"},{"type":"function","doc":"iex> color = Color.from_hex(\"#FF0000\")\n    iex> harmony = Advanced.create_harmony(color, :complementary)\n    iex> Enum.map(harmony, & &1.hex)\n    [\"#FF0000\", \"#00FFFF\"]","title":"Examples - Raxol.Style.Colors.Advanced.create_harmony/3","ref":"Raxol.Style.Colors.Advanced.html#create_harmony/3-examples"},{"type":"module","doc":"Core color representation and manipulation module.\n\nThis module provides a unified interface for working with colors in Raxol,\nsupporting various color formats and operations.","title":"Raxol.Style.Colors.Color","ref":"Raxol.Style.Colors.Color.html"},{"type":"module","doc":"- RGB: `{r, g, b}` where each component is 0-255\n- RGBA: `{r, g, b, a}` where alpha is 0-255\n- Hex: `\"#RRGGBB\"` or `\"#RRGGBBAA\"`\n- ANSI: 0-255 for 256-color mode, 0-15 for basic colors\n- Named: `:red`, `:blue`, etc.","title":"Color Formats - Raxol.Style.Colors.Color","ref":"Raxol.Style.Colors.Color.html#module-color-formats"},{"type":"module","doc":"iex> Color.from_hex(\"#FF0000\")\n    %Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}\n\n    iex> Color.from_rgb(255, 0, 0)\n    %Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}\n\n    iex> Color.from_ansi(1)\n    %Color{r: 205, g: 0, b: 0, hex: \"#CD0000\", ansi_code: 1}","title":"Examples - Raxol.Style.Colors.Color","ref":"Raxol.Style.Colors.Color.html#module-examples"},{"type":"function","doc":"Blends two colors with the specified alpha value.","title":"Raxol.Style.Colors.Color.alpha_blend/3","ref":"Raxol.Style.Colors.Color.html#alpha_blend/3"},{"type":"function","doc":"iex> Color.from_hex(\"#FF0000\") |> Color.alpha_blend(Color.from_hex(\"#0000FF\"), 0.5)\n    %Color{r: 128, g: 0, b: 128, hex: \"#800080\"}","title":"Examples - Raxol.Style.Colors.Color.alpha_blend/3","ref":"Raxol.Style.Colors.Color.html#alpha_blend/3-examples"},{"type":"function","doc":"Returns the complementary color.","title":"Raxol.Style.Colors.Color.complement/1","ref":"Raxol.Style.Colors.Color.html#complement/1"},{"type":"function","doc":"iex> Color.from_hex(\"#FF0000\") |> Color.complement()\n    %Color{r: 0, g: 255, b: 255, hex: \"#00FFFF\"}","title":"Examples - Raxol.Style.Colors.Color.complement/1","ref":"Raxol.Style.Colors.Color.html#complement/1-examples"},{"type":"function","doc":"Darkens a color by the specified amount.","title":"Raxol.Style.Colors.Color.darken/2","ref":"Raxol.Style.Colors.Color.html#darken/2"},{"type":"function","doc":"iex> Color.from_hex(\"#FFFFFF\") |> Color.darken(0.5)\n    %Color{r: 128, g: 128, b: 128, hex: \"#808080\"}","title":"Examples - Raxol.Style.Colors.Color.darken/2","ref":"Raxol.Style.Colors.Color.html#darken/2-examples"},{"type":"function","doc":"Creates a color from an ANSI color code.","title":"Raxol.Style.Colors.Color.from_ansi/1","ref":"Raxol.Style.Colors.Color.html#from_ansi/1"},{"type":"function","doc":"iex> Color.from_ansi(1)\n    %Color{r: 205, g: 0, b: 0, hex: \"#CD0000\", ansi_code: 1}","title":"Examples - Raxol.Style.Colors.Color.from_ansi/1","ref":"Raxol.Style.Colors.Color.html#from_ansi/1-examples"},{"type":"function","doc":"Creates a color from a hex string.","title":"Raxol.Style.Colors.Color.from_hex/1","ref":"Raxol.Style.Colors.Color.html#from_hex/1"},{"type":"function","doc":"iex> Color.from_hex(\"#FF0000\")\n    %Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}\n\n    iex> Color.from_hex(\"#FF000080\")\n    %Color{r: 255, g: 0, b: 0, a: 128, hex: \"#FF000080\"}","title":"Examples - Raxol.Style.Colors.Color.from_hex/1","ref":"Raxol.Style.Colors.Color.html#from_hex/1-examples"},{"type":"function","doc":"Creates a color from RGB values.","title":"Raxol.Style.Colors.Color.from_rgb/3","ref":"Raxol.Style.Colors.Color.html#from_rgb/3"},{"type":"function","doc":"iex> Color.from_rgb(255, 0, 0)\n    %Color{r: 255, g: 0, b: 0, hex: \"#FF0000\"}","title":"Examples - Raxol.Style.Colors.Color.from_rgb/3","ref":"Raxol.Style.Colors.Color.html#from_rgb/3-examples"},{"type":"function","doc":"Creates a color from RGBA values.","title":"Raxol.Style.Colors.Color.from_rgba/4","ref":"Raxol.Style.Colors.Color.html#from_rgba/4"},{"type":"function","doc":"iex> Color.from_rgba(255, 0, 0, 128)\n    %Color{r: 255, g: 0, b: 0, a: 128, hex: \"#FF000080\"}","title":"Examples - Raxol.Style.Colors.Color.from_rgba/4","ref":"Raxol.Style.Colors.Color.html#from_rgba/4-examples"},{"type":"function","doc":"Lightens a color by the specified amount.","title":"Raxol.Style.Colors.Color.lighten/2","ref":"Raxol.Style.Colors.Color.html#lighten/2"},{"type":"function","doc":"iex> Color.from_hex(\"#000000\") |> Color.lighten(0.5)\n    %Color{r: 128, g: 128, b: 128, hex: \"#808080\"}","title":"Examples - Raxol.Style.Colors.Color.lighten/2","ref":"Raxol.Style.Colors.Color.html#lighten/2-examples"},{"type":"function","doc":"Mixes two colors with the specified weight (0.0 to 1.0).","title":"Raxol.Style.Colors.Color.mix/3","ref":"Raxol.Style.Colors.Color.html#mix/3"},{"type":"function","doc":"iex> color1 = Color.from_rgb(255, 0, 0)\n    iex> color2 = Color.from_rgb(0, 0, 255)\n    iex> mixed = Color.mix(color1, color2, 0.5)\n    iex> {mixed.r, mixed.g, mixed.b}\n    {127, 0, 127}","title":"Examples - Raxol.Style.Colors.Color.mix/3","ref":"Raxol.Style.Colors.Color.html#mix/3-examples"},{"type":"type","doc":"","title":"Raxol.Style.Colors.Color.t/0","ref":"Raxol.Style.Colors.Color.html#t:t/0"},{"type":"function","doc":"Converts a color to an ANSI code (currently defaults to 256-color code).\nThe `type` parameter (:foreground or :background) is currently ignored.\n\nNOTE: This is a placeholder. Implement proper ANSI sequence generation based on type and terminal capabilities in the future.","title":"Raxol.Style.Colors.Color.to_ansi/2","ref":"Raxol.Style.Colors.Color.html#to_ansi/2"},{"type":"function","doc":"Converts a color to the closest ANSI 16-color code.","title":"Raxol.Style.Colors.Color.to_ansi_16/1","ref":"Raxol.Style.Colors.Color.html#to_ansi_16/1"},{"type":"function","doc":"iex> color = Color.from_rgb(255, 0, 0)\n    iex> Color.to_ansi_16(color)\n    9","title":"Examples - Raxol.Style.Colors.Color.to_ansi_16/1","ref":"Raxol.Style.Colors.Color.html#to_ansi_16/1-examples"},{"type":"function","doc":"Converts a color to the closest ANSI 256-color code.","title":"Raxol.Style.Colors.Color.to_ansi_256/1","ref":"Raxol.Style.Colors.Color.html#to_ansi_256/1"},{"type":"function","doc":"iex> color = Color.from_rgb(255, 0, 0)\n    iex> Color.to_ansi_256(color)\n    196","title":"Examples - Raxol.Style.Colors.Color.to_ansi_256/1","ref":"Raxol.Style.Colors.Color.html#to_ansi_256/1-examples"},{"type":"function","doc":"Converts a color to its hex representation.","title":"Raxol.Style.Colors.Color.to_hex/1","ref":"Raxol.Style.Colors.Color.html#to_hex/1"},{"type":"function","doc":"iex> color = Color.from_rgb(255, 0, 0)\n    iex> Color.to_hex(color)\n    \"#FF0000\"","title":"Examples - Raxol.Style.Colors.Color.to_hex/1","ref":"Raxol.Style.Colors.Color.html#to_hex/1-examples"},{"type":"module","doc":"Color format conversion utilities.\n\nThis module provides functions for converting between different color formats:\n- RGB/RGBA tuples\n- Hex strings\n- ANSI color codes\n- Named colors","title":"Raxol.Style.Colors.Formats","ref":"Raxol.Style.Colors.Formats.html"},{"type":"function","doc":"Converts an ANSI color code to RGB values.","title":"Raxol.Style.Colors.Formats.ansi_to_rgb/1","ref":"Raxol.Style.Colors.Formats.html#ansi_to_rgb/1"},{"type":"function","doc":"iex> Formats.ansi_to_rgb(1)\n    {205, 0, 0}","title":"Examples - Raxol.Style.Colors.Formats.ansi_to_rgb/1","ref":"Raxol.Style.Colors.Formats.html#ansi_to_rgb/1-examples"},{"type":"function","doc":"Parses a hex string into RGB/RGBA values.","title":"Raxol.Style.Colors.Formats.from_hex/1","ref":"Raxol.Style.Colors.Formats.html#from_hex/1"},{"type":"function","doc":"iex> Formats.from_hex(\"#FF0000\")\n    {255, 0, 0}\n\n    iex> Formats.from_hex(\"#FF000080\")\n    {255, 0, 0, 128}","title":"Examples - Raxol.Style.Colors.Formats.from_hex/1","ref":"Raxol.Style.Colors.Formats.html#from_hex/1-examples"},{"type":"function","doc":"Converts RGB values to an ANSI color code.","title":"Raxol.Style.Colors.Formats.rgb_to_ansi/1","ref":"Raxol.Style.Colors.Formats.html#rgb_to_ansi/1"},{"type":"function","doc":"iex> Formats.rgb_to_ansi({255, 0, 0})\n    196","title":"Examples - Raxol.Style.Colors.Formats.rgb_to_ansi/1","ref":"Raxol.Style.Colors.Formats.html#rgb_to_ansi/1-examples"},{"type":"function","doc":"Converts a color to its hex representation.","title":"Raxol.Style.Colors.Formats.to_hex/1","ref":"Raxol.Style.Colors.Formats.html#to_hex/1"},{"type":"function","doc":"iex> Formats.to_hex({255, 0, 0})\n    \"#FF0000\"\n\n    iex> Formats.to_hex({255, 0, 0, 128})\n    \"#FF000080\"","title":"Examples - Raxol.Style.Colors.Formats.to_hex/1","ref":"Raxol.Style.Colors.Formats.html#to_hex/1-examples"},{"type":"module","doc":"Creates and manages color gradients for terminal applications.\n\nThis module provides functionality for creating gradients between colors and\napplying them to text, creating visually striking terminal effects.","title":"Raxol.Style.Colors.Gradient","ref":"Raxol.Style.Colors.Gradient.html"},{"type":"module","doc":"```elixir\n# Create a simple linear gradient between red and blue\nalias Raxol.Style.Colors.{Color, Gradient}\n\nred = Color.from_hex(\"#FF0000\")\nblue = Color.from_hex(\"#0000FF\")\ngradient = Gradient.linear(red, blue, 10)\n\n# Apply the gradient to text\ncolored_text = Gradient.apply_to_text(gradient, \"Hello, World!\")\n\n# Create a rainbow gradient\nrainbow = Gradient.rainbow(20)\nrainbow_text = Gradient.apply_to_text(rainbow, \"Rainbow Text\")\n\n# Create a multi-stop gradient\ncolors = [\n  Color.from_hex(\"#FF0000\"),  # Red\n  Color.from_hex(\"#FFFF00\"),  # Yellow\n  Color.from_hex(\"#00FF00\")   # Green\n]\nmulti = Gradient.multi_stop(colors, 15)\n```","title":"Examples - Raxol.Style.Colors.Gradient","ref":"Raxol.Style.Colors.Gradient.html#module-examples"},{"type":"function","doc":"Applies a gradient to text, returning an ANSI-formatted string.","title":"Raxol.Style.Colors.Gradient.apply_to_text/2","ref":"Raxol.Style.Colors.Gradient.html#apply_to_text/2"},{"type":"function","doc":"- `gradient` - The gradient to apply\n- `text` - The text to colorize","title":"Parameters - Raxol.Style.Colors.Gradient.apply_to_text/2","ref":"Raxol.Style.Colors.Gradient.html#apply_to_text/2-parameters"},{"type":"function","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 5)\n    iex> Raxol.Style.Colors.Gradient.apply_to_text(gradient, \"Hello\")\n    \"\u001B[38;2;255;0;0mH\u001B[0m\u001B[38;2;191;0;64me\u001B[0m\u001B[38;2;128;0;128ml\u001B[0m\u001B[38;2;64;0;191ml\u001B[0m\u001B[38;2;0;0;255mo\u001B[0m\"","title":"Examples - Raxol.Style.Colors.Gradient.apply_to_text/2","ref":"Raxol.Style.Colors.Gradient.html#apply_to_text/2-examples"},{"type":"function","doc":"Gets the color at a specific position in the gradient.","title":"Raxol.Style.Colors.Gradient.at_position/2","ref":"Raxol.Style.Colors.Gradient.html#at_position/2"},{"type":"function","doc":"- `gradient` - The gradient to sample from\n- `position` - A value between 0.0 and 1.0 representing the position in the gradient","title":"Parameters - Raxol.Style.Colors.Gradient.at_position/2","ref":"Raxol.Style.Colors.Gradient.html#at_position/2-parameters"},{"type":"function","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 5)\n    iex> color = Raxol.Style.Colors.Gradient.at_position(gradient, 0.5)\n    iex> color.hex\n    \"#800080\"  # Purple (mix of red and blue)","title":"Examples - Raxol.Style.Colors.Gradient.at_position/2","ref":"Raxol.Style.Colors.Gradient.html#at_position/2-examples"},{"type":"type","doc":"","title":"Raxol.Style.Colors.Gradient.gradient_type/0","ref":"Raxol.Style.Colors.Gradient.html#t:gradient_type/0"},{"type":"function","doc":"Creates a heat map gradient from cool to hot colors.","title":"Raxol.Style.Colors.Gradient.heat_map/1","ref":"Raxol.Style.Colors.Gradient.html#heat_map/1"},{"type":"function","doc":"- `steps` - The number of color steps in the heat map","title":"Parameters - Raxol.Style.Colors.Gradient.heat_map/1","ref":"Raxol.Style.Colors.Gradient.html#heat_map/1-parameters"},{"type":"function","doc":"iex> gradient = Raxol.Style.Colors.Gradient.heat_map(5)\n    iex> length(gradient.colors)\n    5","title":"Examples - Raxol.Style.Colors.Gradient.heat_map/1","ref":"Raxol.Style.Colors.Gradient.html#heat_map/1-examples"},{"type":"function","doc":"Creates a linear gradient between two colors.","title":"Raxol.Style.Colors.Gradient.linear/3","ref":"Raxol.Style.Colors.Gradient.html#linear/3"},{"type":"function","doc":"- `start_color` - The starting color\n- `end_color` - The ending color\n- `steps` - The number of color steps in the gradient (including start and end)","title":"Parameters - Raxol.Style.Colors.Gradient.linear/3","ref":"Raxol.Style.Colors.Gradient.html#linear/3-parameters"},{"type":"function","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 5)\n    iex> length(gradient.colors)\n    5","title":"Examples - Raxol.Style.Colors.Gradient.linear/3","ref":"Raxol.Style.Colors.Gradient.html#linear/3-examples"},{"type":"function","doc":"Creates a multi-stop gradient with multiple color stops.","title":"Raxol.Style.Colors.Gradient.multi_stop/2","ref":"Raxol.Style.Colors.Gradient.html#multi_stop/2"},{"type":"function","doc":"- `color_stops` - A list of colors to transition between\n- `steps` - The total number of color steps in the gradient","title":"Parameters - Raxol.Style.Colors.Gradient.multi_stop/2","ref":"Raxol.Style.Colors.Gradient.html#multi_stop/2-parameters"},{"type":"function","doc":"iex> colors = [\n    ...>   Raxol.Style.Colors.Color.from_hex(\"#FF0000\"),\n    ...>   Raxol.Style.Colors.Color.from_hex(\"#00FF00\"),\n    ...>   Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    ...> ]\n    iex> gradient = Raxol.Style.Colors.Gradient.multi_stop(colors, 10)\n    iex> length(gradient.colors)\n    10","title":"Examples - Raxol.Style.Colors.Gradient.multi_stop/2","ref":"Raxol.Style.Colors.Gradient.html#multi_stop/2-examples"},{"type":"function","doc":"Creates a rainbow gradient with the given number of steps.","title":"Raxol.Style.Colors.Gradient.rainbow/1","ref":"Raxol.Style.Colors.Gradient.html#rainbow/1"},{"type":"function","doc":"- `steps` - The number of color steps in the rainbow","title":"Parameters - Raxol.Style.Colors.Gradient.rainbow/1","ref":"Raxol.Style.Colors.Gradient.html#rainbow/1-parameters"},{"type":"function","doc":"iex> gradient = Raxol.Style.Colors.Gradient.rainbow(6)\n    iex> length(gradient.colors)\n    6","title":"Examples - Raxol.Style.Colors.Gradient.rainbow/1","ref":"Raxol.Style.Colors.Gradient.html#rainbow/1-examples"},{"type":"function","doc":"Reverses the direction of a gradient.","title":"Raxol.Style.Colors.Gradient.reverse/1","ref":"Raxol.Style.Colors.Gradient.html#reverse/1"},{"type":"function","doc":"- `gradient` - The gradient to reverse","title":"Parameters - Raxol.Style.Colors.Gradient.reverse/1","ref":"Raxol.Style.Colors.Gradient.html#reverse/1-parameters"},{"type":"function","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> blue = Raxol.Style.Colors.Color.from_hex(\"#0000FF\")\n    iex> gradient = Raxol.Style.Colors.Gradient.linear(red, blue, 3)\n    iex> reversed = Raxol.Style.Colors.Gradient.reverse(gradient)\n    iex> hd(reversed.colors).hex\n    \"#0000FF\"","title":"Examples - Raxol.Style.Colors.Gradient.reverse/1","ref":"Raxol.Style.Colors.Gradient.html#reverse/1-examples"},{"type":"type","doc":"","title":"Raxol.Style.Colors.Gradient.t/0","ref":"Raxol.Style.Colors.Gradient.html#t:t/0"},{"type":"function","doc":"Alias for apply_to_text/2.","title":"Raxol.Style.Colors.Gradient.to_ansi_sequence/2","ref":"Raxol.Style.Colors.Gradient.html#to_ansi_sequence/2"},{"type":"module","doc":"Provides functions for HSL color space conversions and adjustments.","title":"Raxol.Style.Colors.HSL","ref":"Raxol.Style.Colors.HSL.html"},{"type":"function","doc":"Darkens a color by a specified amount (adjusting Lightness).","title":"Raxol.Style.Colors.HSL.darken/2","ref":"Raxol.Style.Colors.HSL.html#darken/2"},{"type":"function","doc":"- `color` - The color to darken (Color struct)\n- `amount` - The amount to darken by (0.0 to 1.0)","title":"Parameters - Raxol.Style.Colors.HSL.darken/2","ref":"Raxol.Style.Colors.HSL.html#darken/2-parameters"},{"type":"function","doc":"- A Color struct representing the darkened color","title":"Returns - Raxol.Style.Colors.HSL.darken/2","ref":"Raxol.Style.Colors.HSL.html#darken/2-returns"},{"type":"function","doc":"Desaturates a color by a specified amount (adjusting Saturation).","title":"Raxol.Style.Colors.HSL.desaturate/2","ref":"Raxol.Style.Colors.HSL.html#desaturate/2"},{"type":"function","doc":"- `color` - The color to desaturate (Color struct)\n- `amount` - The amount to desaturate by (0.0 to 1.0)","title":"Parameters - Raxol.Style.Colors.HSL.desaturate/2","ref":"Raxol.Style.Colors.HSL.html#desaturate/2-parameters"},{"type":"function","doc":"- A Color struct representing the desaturated color","title":"Returns - Raxol.Style.Colors.HSL.desaturate/2","ref":"Raxol.Style.Colors.HSL.html#desaturate/2-returns"},{"type":"function","doc":"Converts HSL values to RGB.","title":"Raxol.Style.Colors.HSL.hsl_to_rgb/3","ref":"Raxol.Style.Colors.HSL.html#hsl_to_rgb/3"},{"type":"function","doc":"- `h`, `s`, `l` - Hue (0-360), Saturation (0.0-1.0), Lightness (0.0-1.0)","title":"Parameters - Raxol.Style.Colors.HSL.hsl_to_rgb/3","ref":"Raxol.Style.Colors.HSL.html#hsl_to_rgb/3-parameters"},{"type":"function","doc":"- `{r, g, b}` tuple: Red, Green, Blue values (0-255)","title":"Returns - Raxol.Style.Colors.HSL.hsl_to_rgb/3","ref":"Raxol.Style.Colors.HSL.html#hsl_to_rgb/3-returns"},{"type":"function","doc":"Lightens a color by a specified amount (adjusting Lightness).","title":"Raxol.Style.Colors.HSL.lighten/2","ref":"Raxol.Style.Colors.HSL.html#lighten/2"},{"type":"function","doc":"- `color` - The color to lighten (Color struct)\n- `amount` - The amount to lighten by (0.0 to 1.0)","title":"Parameters - Raxol.Style.Colors.HSL.lighten/2","ref":"Raxol.Style.Colors.HSL.html#lighten/2-parameters"},{"type":"function","doc":"- A Color struct representing the lightened color","title":"Returns - Raxol.Style.Colors.HSL.lighten/2","ref":"Raxol.Style.Colors.HSL.html#lighten/2-returns"},{"type":"function","doc":"Converts RGB values to HSL.","title":"Raxol.Style.Colors.HSL.rgb_to_hsl/3","ref":"Raxol.Style.Colors.HSL.html#rgb_to_hsl/3"},{"type":"function","doc":"- `r`, `g`, `b` - Red, Green, Blue values (0-255)","title":"Parameters - Raxol.Style.Colors.HSL.rgb_to_hsl/3","ref":"Raxol.Style.Colors.HSL.html#rgb_to_hsl/3-parameters"},{"type":"function","doc":"- `{h, s, l}` tuple: Hue (0-360), Saturation (0.0-1.0), Lightness (0.0-1.0)","title":"Returns - Raxol.Style.Colors.HSL.rgb_to_hsl/3","ref":"Raxol.Style.Colors.HSL.html#rgb_to_hsl/3-returns"},{"type":"function","doc":"Rotates the hue of a color by a specified number of degrees.","title":"Raxol.Style.Colors.HSL.rotate_hue/2","ref":"Raxol.Style.Colors.HSL.html#rotate_hue/2"},{"type":"function","doc":"- `color` - The color to rotate (Color struct)\n- `degrees` - The number of degrees to rotate (positive or negative)","title":"Parameters - Raxol.Style.Colors.HSL.rotate_hue/2","ref":"Raxol.Style.Colors.HSL.html#rotate_hue/2-parameters"},{"type":"function","doc":"- A Color struct representing the rotated color","title":"Returns - Raxol.Style.Colors.HSL.rotate_hue/2","ref":"Raxol.Style.Colors.HSL.html#rotate_hue/2-returns"},{"type":"function","doc":"Saturates a color by a specified amount (adjusting Saturation).","title":"Raxol.Style.Colors.HSL.saturate/2","ref":"Raxol.Style.Colors.HSL.html#saturate/2"},{"type":"function","doc":"- `color` - The color to saturate (Color struct)\n- `amount` - The amount to saturate by (0.0 to 1.0)","title":"Parameters - Raxol.Style.Colors.HSL.saturate/2","ref":"Raxol.Style.Colors.HSL.html#saturate/2-parameters"},{"type":"function","doc":"- A Color struct representing the saturated color","title":"Returns - Raxol.Style.Colors.HSL.saturate/2","ref":"Raxol.Style.Colors.HSL.html#saturate/2-returns"},{"type":"module","doc":"Provides functions for generating color harmonies based on a base color.","title":"Raxol.Style.Colors.Harmony","ref":"Raxol.Style.Colors.Harmony.html"},{"type":"function","doc":"Generates analogous colors based on the HSL color wheel.\nAnalogous colors are groups of colors that are adjacent to each other on the color wheel.","title":"Raxol.Style.Colors.Harmony.analogous_colors/3","ref":"Raxol.Style.Colors.Harmony.html#analogous_colors/3"},{"type":"function","doc":"- `color`: The base `Color{}` struct.\n- `count`: The number of analogous colors to generate (defaults to 3).\n- `angle`: The angle separation between analogous colors (defaults to 30 degrees).","title":"Parameters - Raxol.Style.Colors.Harmony.analogous_colors/3","ref":"Raxol.Style.Colors.Harmony.html#analogous_colors/3-parameters"},{"type":"function","doc":"A list of `Color{}` structs representing the analogous colors.","title":"Returns - Raxol.Style.Colors.Harmony.analogous_colors/3","ref":"Raxol.Style.Colors.Harmony.html#analogous_colors/3-returns"},{"type":"function","doc":"Generates complementary colors (opposite on the color wheel).\n\nReturns a list containing the base color and its complement.","title":"Raxol.Style.Colors.Harmony.complementary_colors/1","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1"},{"type":"function","doc":"- `color` - The base color (Color struct or hex string)","title":"Parameters - Raxol.Style.Colors.Harmony.complementary_colors/1","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1-parameters"},{"type":"function","doc":"- A list of two Color structs: `[base_color, complement]`","title":"Returns - Raxol.Style.Colors.Harmony.complementary_colors/1","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1-returns"},{"type":"function","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> [red_struct, cyan_struct] = Raxol.Style.Colors.Harmony.complementary_colors(red)\n    iex> cyan_struct.hex\n    \"#00FFFF\"","title":"Examples - Raxol.Style.Colors.Harmony.complementary_colors/1","ref":"Raxol.Style.Colors.Harmony.html#complementary_colors/1-examples"},{"type":"function","doc":"Generates triadic colors (three colors evenly spaced on the color wheel).","title":"Raxol.Style.Colors.Harmony.triadic_colors/1","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1"},{"type":"function","doc":"- `color` - The base color (Color struct or hex string)","title":"Parameters - Raxol.Style.Colors.Harmony.triadic_colors/1","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1-parameters"},{"type":"function","doc":"- A list of three Color structs","title":"Returns - Raxol.Style.Colors.Harmony.triadic_colors/1","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1-returns"},{"type":"function","doc":"iex> red = Raxol.Style.Colors.Color.from_hex(\"#FF0000\")\n    iex> colors = Raxol.Style.Colors.Harmony.triadic_colors(red)\n    iex> length(colors)\n    3\n    # Colors will be red, green, blue (approximately)","title":"Examples - Raxol.Style.Colors.Harmony.triadic_colors/1","ref":"Raxol.Style.Colors.Harmony.html#triadic_colors/1-examples"},{"type":"module","doc":"Provides hot-reloading capabilities for color themes.\n\nThis module watches for changes to theme files and automatically\nreloads them when they change. It also provides a way to subscribe\nto theme change events.","title":"Raxol.Style.Colors.HotReload","ref":"Raxol.Style.Colors.HotReload.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Style.Colors.HotReload.child_spec/1","ref":"Raxol.Style.Colors.HotReload.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Style.Colors.HotReload.start_link/1","ref":"Raxol.Style.Colors.HotReload.html#start_link/1"},{"type":"function","doc":"Subscribe to theme change events.","title":"Raxol.Style.Colors.HotReload.subscribe/0","ref":"Raxol.Style.Colors.HotReload.html#subscribe/0"},{"type":"function","doc":"iex> HotReload.subscribe()\n    :ok","title":"Examples - Raxol.Style.Colors.HotReload.subscribe/0","ref":"Raxol.Style.Colors.HotReload.html#subscribe/0-examples"},{"type":"function","doc":"Unsubscribe from theme change events.","title":"Raxol.Style.Colors.HotReload.unsubscribe/0","ref":"Raxol.Style.Colors.HotReload.html#unsubscribe/0"},{"type":"function","doc":"iex> HotReload.unsubscribe()\n    :ok","title":"Examples - Raxol.Style.Colors.HotReload.unsubscribe/0","ref":"Raxol.Style.Colors.HotReload.html#unsubscribe/0-examples"},{"type":"function","doc":"Add a path to watch for theme changes.","title":"Raxol.Style.Colors.HotReload.watch_path/1","ref":"Raxol.Style.Colors.HotReload.html#watch_path/1"},{"type":"function","doc":"- `path` - The path to watch","title":"Parameters - Raxol.Style.Colors.HotReload.watch_path/1","ref":"Raxol.Style.Colors.HotReload.html#watch_path/1-parameters"},{"type":"function","doc":"iex> HotReload.watch_path(\"/path/to/themes\")\n    :ok","title":"Examples - Raxol.Style.Colors.HotReload.watch_path/1","ref":"Raxol.Style.Colors.HotReload.html#watch_path/1-examples"},{"type":"module","doc":"Handles persistence of color themes and user preferences.\n\nThis module provides functionality for:\n- Saving and loading themes\n- Managing user preferences\n- Handling theme file storage","title":"Raxol.Style.Colors.Persistence","ref":"Raxol.Style.Colors.Persistence.html"},{"type":"function","doc":"Deletes a theme.","title":"Raxol.Style.Colors.Persistence.delete_theme/1","ref":"Raxol.Style.Colors.Persistence.html#delete_theme/1"},{"type":"function","doc":"- `theme_name` - The name of the theme to delete","title":"Parameters - Raxol.Style.Colors.Persistence.delete_theme/1","ref":"Raxol.Style.Colors.Persistence.html#delete_theme/1-parameters"},{"type":"function","doc":"- `:ok` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.Persistence.delete_theme/1","ref":"Raxol.Style.Colors.Persistence.html#delete_theme/1-returns"},{"type":"function","doc":"Lists all available themes.","title":"Raxol.Style.Colors.Persistence.list_themes/0","ref":"Raxol.Style.Colors.Persistence.html#list_themes/0"},{"type":"function","doc":"- A list of theme names","title":"Returns - Raxol.Style.Colors.Persistence.list_themes/0","ref":"Raxol.Style.Colors.Persistence.html#list_themes/0-returns"},{"type":"function","doc":"Loads the current theme from user preferences.","title":"Raxol.Style.Colors.Persistence.load_current_theme/0","ref":"Raxol.Style.Colors.Persistence.html#load_current_theme/0"},{"type":"function","doc":"- `{:ok, theme}` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.Persistence.load_current_theme/0","ref":"Raxol.Style.Colors.Persistence.html#load_current_theme/0-returns"},{"type":"function","doc":"Loads a theme from a file.","title":"Raxol.Style.Colors.Persistence.load_theme/1","ref":"Raxol.Style.Colors.Persistence.html#load_theme/1"},{"type":"function","doc":"- `theme_name` - The name of the theme to load","title":"Parameters - Raxol.Style.Colors.Persistence.load_theme/1","ref":"Raxol.Style.Colors.Persistence.html#load_theme/1-parameters"},{"type":"function","doc":"- `{:ok, theme}` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.Persistence.load_theme/1","ref":"Raxol.Style.Colors.Persistence.html#load_theme/1-returns"},{"type":"function","doc":"Loads user preferences from file.","title":"Raxol.Style.Colors.Persistence.load_user_preferences/0","ref":"Raxol.Style.Colors.Persistence.html#load_user_preferences/0"},{"type":"function","doc":"- `{:ok, preferences}` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.Persistence.load_user_preferences/0","ref":"Raxol.Style.Colors.Persistence.html#load_user_preferences/0-returns"},{"type":"function","doc":"Saves a theme to a file.","title":"Raxol.Style.Colors.Persistence.save_theme/1","ref":"Raxol.Style.Colors.Persistence.html#save_theme/1"},{"type":"function","doc":"- `theme` - The theme to save","title":"Parameters - Raxol.Style.Colors.Persistence.save_theme/1","ref":"Raxol.Style.Colors.Persistence.html#save_theme/1-parameters"},{"type":"function","doc":"- `:ok` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.Persistence.save_theme/1","ref":"Raxol.Style.Colors.Persistence.html#save_theme/1-returns"},{"type":"function","doc":"Saves user preferences to file.","title":"Raxol.Style.Colors.Persistence.save_user_preferences/1","ref":"Raxol.Style.Colors.Persistence.html#save_user_preferences/1"},{"type":"function","doc":"- `preferences` - The preferences to save","title":"Parameters - Raxol.Style.Colors.Persistence.save_user_preferences/1","ref":"Raxol.Style.Colors.Persistence.html#save_user_preferences/1-parameters"},{"type":"function","doc":"- `:ok` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.Persistence.save_user_preferences/1","ref":"Raxol.Style.Colors.Persistence.html#save_user_preferences/1-returns"},{"type":"module","doc":"Core color system for the Raxol terminal emulator.\n\nThis module provides a robust color system that:\n- Manages color palettes with semantic naming\n- Provides accessible color alternatives for high contrast mode\n- Supports theme customization\n- Calculates contrast ratios for text/background combinations\n- Automatically adjusts colors for optimal readability\n- Integrates with the accessibility module","title":"Raxol.Style.Colors.System","ref":"Raxol.Style.Colors.System.html"},{"type":"module","doc":"```elixir\n# Initialize the color system\nColorSystem.init()\n\n# Get a semantic color (will respect accessibility settings)\ncolor = ColorSystem.get_color(:primary)\n\n# Get a specific color variation\nhover_color = ColorSystem.get_color(:primary, :hover)\n\n# Register a custom theme\nColorSystem.register_theme(:ocean, %{\n  primary: \"#0077CC\",\n  secondary: \"#00AAFF\",\n  background: \"#001133\",\n  foreground: \"#FFFFFF\",\n  accent: \"#FF9900\"\n})\n\n# Apply a theme\nColorSystem.apply_theme(:ocean)\n```","title":"Usage - Raxol.Style.Colors.System","ref":"Raxol.Style.Colors.System.html#module-usage"},{"type":"function","doc":"Applies a theme to the color system.","title":"Raxol.Style.Colors.System.apply_theme/2","ref":"Raxol.Style.Colors.System.html#apply_theme/2"},{"type":"function","doc":"- `theme_id` - The ID of the theme to apply\n- `opts` - Additional options\n  - `:high_contrast` - Whether to apply high contrast mode (default: current setting)","title":"Parameters - Raxol.Style.Colors.System.apply_theme/2","ref":"Raxol.Style.Colors.System.html#apply_theme/2-parameters"},{"type":"function","doc":"- `:ok` on success\n- `{:error, reason}` on failure","title":"Returns - Raxol.Style.Colors.System.apply_theme/2","ref":"Raxol.Style.Colors.System.html#apply_theme/2-returns"},{"type":"function","doc":"Get a color from the current theme.\n\nThis function respects the current accessibility settings, automatically\nreturning high-contrast alternatives when needed.","title":"Raxol.Style.Colors.System.get_color/2","ref":"Raxol.Style.Colors.System.html#get_color/2"},{"type":"function","doc":"* `color_name` - The semantic name of the color (e.g., `:primary`, `:error`)\n* `variant` - The variant of the color (e.g., `:base`, `:hover`, `:active`) (default: `:base`)","title":"Parameters - Raxol.Style.Colors.System.get_color/2","ref":"Raxol.Style.Colors.System.html#get_color/2-parameters"},{"type":"function","doc":"iex> ColorSystem.get_color(:primary)\n    \"#0077CC\"\n\n    iex> ColorSystem.get_color(:primary, :hover)\n    \"#0088DD\"","title":"Examples - Raxol.Style.Colors.System.get_color/2","ref":"Raxol.Style.Colors.System.html#get_color/2-examples"},{"type":"function","doc":"","title":"Raxol.Style.Colors.System.get_current_theme_name/0","ref":"Raxol.Style.Colors.System.html#get_current_theme_name/0"},{"type":"function","doc":"Handle high contrast mode changes from the accessibility module.","title":"Raxol.Style.Colors.System.handle_high_contrast/1","ref":"Raxol.Style.Colors.System.html#handle_high_contrast/1"},{"type":"function","doc":"Initialize the color system.\n\nThis sets up the default themes, registers event handlers for accessibility changes,\nand establishes the default color palette.","title":"Raxol.Style.Colors.System.init/1","ref":"Raxol.Style.Colors.System.html#init/1"},{"type":"function","doc":"* `:theme` - The initial theme to use (default: `:default`)\n* `:high_contrast` - Whether to start in high contrast mode (default: from accessibility settings)","title":"Options - Raxol.Style.Colors.System.init/1","ref":"Raxol.Style.Colors.System.html#init/1-options"},{"type":"function","doc":"iex> ColorSystem.init()\n    :ok\n\n    iex> ColorSystem.init(theme: :dark)\n    :ok","title":"Examples - Raxol.Style.Colors.System.init/1","ref":"Raxol.Style.Colors.System.html#init/1-examples"},{"type":"function","doc":"Register a custom theme.","title":"Raxol.Style.Colors.System.register_theme/1","ref":"Raxol.Style.Colors.System.html#register_theme/1"},{"type":"function","doc":"* `theme_attrs` - Map of theme attributes","title":"Parameters - Raxol.Style.Colors.System.register_theme/1","ref":"Raxol.Style.Colors.System.html#register_theme/1-parameters"},{"type":"function","doc":"iex> ColorSystem.register_theme(%{\n    ...>   primary: \"#0077CC\",\n    ...>   secondary: \"#00AAFF\",\n    ...>   background: \"#001133\",\n    ...>   foreground: \"#FFFFFF\",\n    ...>   accent: \"#FF9900\"\n    ...> })\n    :ok","title":"Examples - Raxol.Style.Colors.System.register_theme/1","ref":"Raxol.Style.Colors.System.html#register_theme/1-examples"},{"type":"module","doc":"Shared color utilities for the Raxol color system.\n\nThis module provides common color manipulation and analysis functions,\nincluding contrast calculations, accessibility checks, and color format\nconversions.","title":"Raxol.Style.Colors.Utilities","ref":"Raxol.Style.Colors.Utilities.html"},{"type":"function","doc":"Adjusts a color to meet contrast requirements with another color.","title":"Raxol.Style.Colors.Utilities.adjust_for_contrast/4","ref":"Raxol.Style.Colors.Utilities.html#adjust_for_contrast/4"},{"type":"function","doc":"* `color` - The color to adjust (Color struct or RGB tuple)\n* `background` - The background color (Color struct or RGB tuple)\n* `level` - WCAG level (:A, :AA, or :AAA)\n* `size` - Text size (:normal or :large)","title":"Parameters - Raxol.Style.Colors.Utilities.adjust_for_contrast/4","ref":"Raxol.Style.Colors.Utilities.html#adjust_for_contrast/4-parameters"},{"type":"function","doc":"An adjusted Color struct that meets contrast requirements","title":"Returns - Raxol.Style.Colors.Utilities.adjust_for_contrast/4","ref":"Raxol.Style.Colors.Utilities.html#adjust_for_contrast/4-returns"},{"type":"function","doc":"Calculates the contrast ratio between two colors according to WCAG 2.0.","title":"Raxol.Style.Colors.Utilities.contrast_ratio/2","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2"},{"type":"function","doc":"* `color1` - First color (Color struct or RGB tuple)\n* `color2` - Second color (Color struct or RGB tuple)","title":"Parameters - Raxol.Style.Colors.Utilities.contrast_ratio/2","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2-parameters"},{"type":"function","doc":"A float representing the contrast ratio (1:1 to 21:1)","title":"Returns - Raxol.Style.Colors.Utilities.contrast_ratio/2","ref":"Raxol.Style.Colors.Utilities.html#contrast_ratio/2-returns"},{"type":"function","doc":"Increases the contrast of a color by making it more extreme.","title":"Raxol.Style.Colors.Utilities.increase_contrast/1","ref":"Raxol.Style.Colors.Utilities.html#increase_contrast/1"},{"type":"function","doc":"* `color` - The color to increase contrast for (Color struct or RGB tuple)","title":"Parameters - Raxol.Style.Colors.Utilities.increase_contrast/1","ref":"Raxol.Style.Colors.Utilities.html#increase_contrast/1-parameters"},{"type":"function","doc":"A new Color struct with increased contrast","title":"Returns - Raxol.Style.Colors.Utilities.increase_contrast/1","ref":"Raxol.Style.Colors.Utilities.html#increase_contrast/1-returns"},{"type":"function","doc":"Checks if two colors meet WCAG contrast requirements.","title":"Raxol.Style.Colors.Utilities.meets_contrast_requirements?/4","ref":"Raxol.Style.Colors.Utilities.html#meets_contrast_requirements?/4"},{"type":"function","doc":"* `color1` - First color (Color struct or RGB tuple)\n* `color2` - Second color (Color struct or RGB tuple)\n* `level` - WCAG level (:A, :AA, or :AAA)\n* `size` - Text size (:normal or :large)","title":"Parameters - Raxol.Style.Colors.Utilities.meets_contrast_requirements?/4","ref":"Raxol.Style.Colors.Utilities.html#meets_contrast_requirements?/4-parameters"},{"type":"function","doc":"`true` if the contrast meets requirements, `false` otherwise","title":"Returns - Raxol.Style.Colors.Utilities.meets_contrast_requirements?/4","ref":"Raxol.Style.Colors.Utilities.html#meets_contrast_requirements?/4-returns"},{"type":"function","doc":"Calculates the relative luminance of a color according to WCAG 2.0.","title":"Raxol.Style.Colors.Utilities.relative_luminance/1","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1"},{"type":"function","doc":"* `color` - A Color struct or RGB tuple","title":"Parameters - Raxol.Style.Colors.Utilities.relative_luminance/1","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1-parameters"},{"type":"function","doc":"A float between 0 and 1 representing the relative luminance","title":"Returns - Raxol.Style.Colors.Utilities.relative_luminance/1","ref":"Raxol.Style.Colors.Utilities.html#relative_luminance/1-returns"},{"type":"module","doc":"Defines layout properties for terminal UI elements.","title":"Raxol.Style.Layout","ref":"Raxol.Style.Layout.html"},{"type":"function","doc":"Merges two layout structs, with the second overriding the first.","title":"Raxol.Style.Layout.merge/2","ref":"Raxol.Style.Layout.html#merge/2"},{"type":"function","doc":"Creates a new layout with default values.","title":"Raxol.Style.Layout.new/0","ref":"Raxol.Style.Layout.html#new/0"},{"type":"function","doc":"Creates a new layout with the specified values.","title":"Raxol.Style.Layout.new/1","ref":"Raxol.Style.Layout.html#new/1"},{"type":"type","doc":"","title":"Raxol.Style.Layout.t/0","ref":"Raxol.Style.Layout.html#t:t/0"},{"type":"module","doc":"Provides consolidated access to the system clipboard across different operating systems.\n\nHandles interactions with platform-specific clipboard utilities like `pbcopy`/`pbpaste` (macOS),\n`xclip` (Linux/X11), and `clip`/`powershell Get-Clipboard` (Windows).\n\nRequires `xclip` to be installed on Linux systems using X11.\nWayland clipboard access might require different utilities not currently handled.","title":"Raxol.System.Clipboard","ref":"Raxol.System.Clipboard.html"},{"type":"function","doc":"Copies the given text to the system clipboard.","title":"Raxol.System.Clipboard.copy/1","ref":"Raxol.System.Clipboard.html#copy/1"},{"type":"function","doc":"Retrieves text from the system clipboard.\n\nReturns `{:ok, text}` on success, or `{:error, reason}` on failure.\nAn empty clipboard is considered success and returns `{:ok, \"\"}`.","title":"Raxol.System.Clipboard.paste/0","ref":"Raxol.System.Clipboard.html#paste/0"},{"type":"behaviour","doc":"Behaviour for clipboard operations.\nAllows mocking in tests.","title":"Raxol.System.Clipboard.Behaviour","ref":"Raxol.System.Clipboard.Behaviour.html"},{"type":"callback","doc":"","title":"Raxol.System.Clipboard.Behaviour.copy/1","ref":"Raxol.System.Clipboard.Behaviour.html#c:copy/1"},{"type":"callback","doc":"","title":"Raxol.System.Clipboard.Behaviour.paste/0","ref":"Raxol.System.Clipboard.Behaviour.html#c:paste/0"},{"type":"module","doc":"Handles delta updates for the Raxol terminal emulator.","title":"Raxol.System.DeltaUpdater","ref":"Raxol.System.DeltaUpdater.html"},{"type":"function","doc":"","title":"Raxol.System.DeltaUpdater.apply_delta_update/2","ref":"Raxol.System.DeltaUpdater.html#apply_delta_update/2"},{"type":"function","doc":"","title":"Raxol.System.DeltaUpdater.check_delta_availability/1","ref":"Raxol.System.DeltaUpdater.html#check_delta_availability/1"},{"type":"behaviour","doc":"Behaviour for a system adapter used by DeltaUpdater.\n\nThis module defines the contract for functions that interact with the system,\nallowing for different implementations (e.g., a real one and a mock for tests).","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html"},{"type":"callback","doc":"Changes the mode of a file.\nMirrors `File.chmod!/2` or `File.chmod/2`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.file_chmod/2","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:file_chmod/2"},{"type":"callback","doc":"Creates a directory, including any necessary parent directories.\nMirrors `File.mkdir_p!/1` or `File.mkdir_p/1`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.file_mkdir_p/1","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:file_mkdir_p/1"},{"type":"callback","doc":"Removes a file or directory recursively.\nMirrors `File.rm_rf!/1` or `File.rm_rf/1`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.file_rm_rf/1","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:file_rm_rf/1"},{"type":"callback","doc":"Performs an HTTP request.\nMirrors `:httpc.request/4` or similar functionality.\n`method` is an atom e.g. `:get`, `:post`.\n`url_with_headers` is typically `{charlist_url, list_of_headers}`.\n`http_options` and `stream_options` are keyword lists or lists of tuples.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.httpc_request/4","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:httpc_request/4"},{"type":"callback","doc":"Gets the operating system type.\nMirrors `:os.type/0`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.os_type/0","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:os_type/0"},{"type":"callback","doc":"Gets the command-line arguments passed to the program.\nMirrors `System.argv/0`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.system_argv/0","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:system_argv/0"},{"type":"callback","doc":"Executes a system command.\nMirrors `System.cmd/3`.\nOptions can include e.g. `:stderr_to_stdout`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.system_cmd/3","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:system_cmd/3"},{"type":"callback","doc":"Gets the value of an environment variable.\nMirrors `System.get_env/1`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.system_get_env/1","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:system_get_env/1"},{"type":"callback","doc":"Gets the path to the system's temporary directory.\nMirrors `System.tmp_dir!/0` or `System.tmp_dir/0`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.system_tmp_dir/0","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:system_tmp_dir/0"},{"type":"callback","doc":"Replaces the current executable with a new one.\nThis abstracts the call to `Raxol.System.Updater.do_replace_executable/3`.","title":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.updater_do_replace_executable/3","ref":"Raxol.System.DeltaUpdaterSystemAdapterBehaviour.html#c:updater_do_replace_executable/3"},{"type":"module","doc":"","title":"Raxol.System.DeltaUpdaterSystemAdapterImpl","ref":"Raxol.System.DeltaUpdaterSystemAdapterImpl.html"},{"type":"behaviour","doc":"A behaviour for abstracting system environment interactions.","title":"Raxol.System.EnvironmentAdapterBehaviour","ref":"Raxol.System.EnvironmentAdapterBehaviour.html"},{"type":"callback","doc":"","title":"Raxol.System.EnvironmentAdapterBehaviour.cmd/3","ref":"Raxol.System.EnvironmentAdapterBehaviour.html#c:cmd/3"},{"type":"callback","doc":"","title":"Raxol.System.EnvironmentAdapterBehaviour.get_env/1","ref":"Raxol.System.EnvironmentAdapterBehaviour.html#c:get_env/1"},{"type":"module","doc":"Concrete implementation of EnvironmentAdapterBehaviour using Elixir's System module.","title":"Raxol.System.EnvironmentAdapterImpl","ref":"Raxol.System.EnvironmentAdapterImpl.html"},{"type":"behaviour","doc":"Behaviour for abstracting system interactions like running commands,\nfinding executables, and getting OS type. Allows for easier testing.","title":"Raxol.System.Interaction","ref":"Raxol.System.Interaction.html"},{"type":"callback","doc":"Finds the full path to an executable. Returns `nil` if not found.","title":"Raxol.System.Interaction.find_executable/1","ref":"Raxol.System.Interaction.html#c:find_executable/1"},{"type":"callback","doc":"Returns the OS type.","title":"Raxol.System.Interaction.get_os_type/0","ref":"Raxol.System.Interaction.html#c:get_os_type/0"},{"type":"type","doc":"","title":"Raxol.System.Interaction.os_type/0","ref":"Raxol.System.Interaction.html#t:os_type/0"},{"type":"callback","doc":"Executes a system command.\nReturns `{output, exit_status}` on success.\nCan raise exceptions on errors depending on the implementation.\nOptions can be passed to control execution (e.g., `stderr_to_stdout`).","title":"Raxol.System.Interaction.system_cmd/3","ref":"Raxol.System.Interaction.html#c:system_cmd/3"},{"type":"module","doc":"Concrete implementation of the System.Interaction behaviour using standard Elixir/Erlang functions.","title":"Raxol.System.InteractionImpl","ref":"Raxol.System.InteractionImpl.html"},{"type":"module","doc":"Platform-specific functionality and detection for Raxol.\n\nThis module handles detection of the current platform, providing platform-specific\ninformation, and managing platform-dependent operations.","title":"Raxol.System.Platform","ref":"Raxol.System.Platform.html"},{"type":"function","doc":"Returns the current platform as an atom.","title":"Raxol.System.Platform.get_current_platform/0","ref":"Raxol.System.Platform.html#get_current_platform/0"},{"type":"function","doc":"* `:macos` - macOS (Darwin)\n* `:linux` - Linux variants\n* `:windows` - Windows","title":"Returns - Raxol.System.Platform.get_current_platform/0","ref":"Raxol.System.Platform.html#get_current_platform/0-returns"},{"type":"function","doc":"iex> Platform.get_current_platform()\n    :macos","title":"Examples - Raxol.System.Platform.get_current_platform/0","ref":"Raxol.System.Platform.html#get_current_platform/0-examples"},{"type":"function","doc":"Returns the executable name for the current platform.","title":"Raxol.System.Platform.get_executable_name/0","ref":"Raxol.System.Platform.html#get_executable_name/0"},{"type":"function","doc":"* `\"raxol.exe\"` - Windows platforms\n* `\"raxol\"` - Unix platforms (macOS, Linux)","title":"Returns - Raxol.System.Platform.get_executable_name/0","ref":"Raxol.System.Platform.html#get_executable_name/0-returns"},{"type":"function","doc":"iex> Platform.get_executable_name()\n    \"raxol\"","title":"Examples - Raxol.System.Platform.get_executable_name/0","ref":"Raxol.System.Platform.html#get_executable_name/0-examples"},{"type":"function","doc":"Returns the file extension for the current platform.","title":"Raxol.System.Platform.get_platform_extension/0","ref":"Raxol.System.Platform.html#get_platform_extension/0"},{"type":"function","doc":"* `\"zip\"` - Windows platforms\n* `\"tar.gz\"` - Unix platforms (macOS, Linux)","title":"Returns - Raxol.System.Platform.get_platform_extension/0","ref":"Raxol.System.Platform.html#get_platform_extension/0-returns"},{"type":"function","doc":"iex> Platform.get_platform_extension()\n    \"tar.gz\"","title":"Examples - Raxol.System.Platform.get_platform_extension/0","ref":"Raxol.System.Platform.html#get_platform_extension/0-examples"},{"type":"function","doc":"Gathers detailed information about the current platform.","title":"Raxol.System.Platform.get_platform_info/0","ref":"Raxol.System.Platform.html#get_platform_info/0"},{"type":"function","doc":"A map containing platform details including:\n\n* `:name` - Platform name (e.g., \"macOS\", \"Linux\", \"Windows\")\n* `:version` - OS version if available\n* `:architecture` - CPU architecture (e.g., \"x86_64\", \"arm64\")\n* `:terminal` - Current terminal information if available","title":"Returns - Raxol.System.Platform.get_platform_info/0","ref":"Raxol.System.Platform.html#get_platform_info/0-returns"},{"type":"function","doc":"iex> Platform.get_platform_info()\n    %{\n      name: \"macOS\",\n      version: \"12.6\",\n      architecture: \"arm64\",\n      terminal: \"iTerm.app\"\n    }","title":"Examples - Raxol.System.Platform.get_platform_info/0","ref":"Raxol.System.Platform.html#get_platform_info/0-examples"},{"type":"function","doc":"Returns the platform name as a string.","title":"Raxol.System.Platform.get_platform_name/0","ref":"Raxol.System.Platform.html#get_platform_name/0"},{"type":"function","doc":"* `\"macos\"` - macOS (Darwin)\n* `\"linux\"` - Linux variants\n* `\"windows\"` - Windows","title":"Returns - Raxol.System.Platform.get_platform_name/0","ref":"Raxol.System.Platform.html#get_platform_name/0-returns"},{"type":"function","doc":"iex> Platform.get_platform_name()\n    \"macos\"","title":"Examples - Raxol.System.Platform.get_platform_name/0","ref":"Raxol.System.Platform.html#get_platform_name/0-examples"},{"type":"function","doc":"Detects if the feature is supported on the current platform.","title":"Raxol.System.Platform.supports_feature?/1","ref":"Raxol.System.Platform.html#supports_feature?/1"},{"type":"function","doc":"* `feature` - Feature name as an atom (e.g., `:true_color`, `:unicode`, `:mouse`)","title":"Parameters - Raxol.System.Platform.supports_feature?/1","ref":"Raxol.System.Platform.html#supports_feature?/1-parameters"},{"type":"function","doc":"* `true` - Feature is supported on the current platform\n* `false` - Feature is not supported or support is uncertain","title":"Returns - Raxol.System.Platform.supports_feature?/1","ref":"Raxol.System.Platform.html#supports_feature?/1-returns"},{"type":"function","doc":"iex> Platform.supports_feature?(:true_color)\n    true","title":"Examples - Raxol.System.Platform.supports_feature?/1","ref":"Raxol.System.Platform.html#supports_feature?/1-examples"},{"type":"module","doc":"Terminal-specific platform features and compatibility checks.\n\nThis module provides detailed information about terminal capabilities,\nfeature support, and compatibility across different platforms and terminal emulators.","title":"Raxol.System.TerminalPlatform","ref":"Raxol.System.TerminalPlatform.html"},{"type":"function","doc":"Returns the list of all supported terminal features.","title":"Raxol.System.TerminalPlatform.get_supported_features/0","ref":"Raxol.System.TerminalPlatform.html#get_supported_features/0"},{"type":"function","doc":"List of supported feature atoms.","title":"Returns - Raxol.System.TerminalPlatform.get_supported_features/0","ref":"Raxol.System.TerminalPlatform.html#get_supported_features/0-returns"},{"type":"function","doc":"iex> TerminalPlatform.get_supported_features()\n    [:true_color, :unicode, :mouse, :clipboard]","title":"Examples - Raxol.System.TerminalPlatform.get_supported_features/0","ref":"Raxol.System.TerminalPlatform.html#get_supported_features/0-examples"},{"type":"function","doc":"Returns detailed information about the current terminal's capabilities.","title":"Raxol.System.TerminalPlatform.get_terminal_capabilities/0","ref":"Raxol.System.TerminalPlatform.html#get_terminal_capabilities/0"},{"type":"function","doc":"A map containing terminal capabilities including:\n\n* `:name` - Terminal name/type\n* `:version` - Terminal version if available\n* `:features` - List of supported features\n* `:colors` - Color support information\n* `:unicode` - Unicode support details\n* `:input` - Input capabilities\n* `:output` - Output capabilities","title":"Returns - Raxol.System.TerminalPlatform.get_terminal_capabilities/0","ref":"Raxol.System.TerminalPlatform.html#get_terminal_capabilities/0-returns"},{"type":"function","doc":"iex> TerminalPlatform.get_terminal_capabilities()\n    %{\n      name: \"iTerm2\",\n      version: \"3.5.0\",\n      features: [:true_color, :unicode, :mouse, :clipboard],\n      colors: %{\n        basic: true,\n        true_color: true,\n        palette: \"default\"\n      },\n      unicode: %{\n        support: true,\n        width: :ambiguous,\n        emoji: true\n      },\n      input: %{\n        mouse: true,\n        bracketed_paste: true,\n        focus: true\n      },\n      output: %{\n        title: true,\n        bell: true,\n        alternate_screen: true\n      }\n    }","title":"Examples - Raxol.System.TerminalPlatform.get_terminal_capabilities/0","ref":"Raxol.System.TerminalPlatform.html#get_terminal_capabilities/0-examples"},{"type":"function","doc":"Checks if a specific terminal feature is supported.","title":"Raxol.System.TerminalPlatform.supports_feature?/1","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1"},{"type":"function","doc":"* `feature` - Feature to check for support","title":"Parameters - Raxol.System.TerminalPlatform.supports_feature?/1","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1-parameters"},{"type":"function","doc":"* `true` - Feature is supported\n* `false` - Feature is not supported","title":"Returns - Raxol.System.TerminalPlatform.supports_feature?/1","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1-returns"},{"type":"function","doc":"iex> TerminalPlatform.supports_feature?(:true_color)\n    true","title":"Examples - Raxol.System.TerminalPlatform.supports_feature?/1","ref":"Raxol.System.TerminalPlatform.html#supports_feature?/1-examples"},{"type":"type","doc":"","title":"Raxol.System.TerminalPlatform.terminal_feature/0","ref":"Raxol.System.TerminalPlatform.html#t:terminal_feature/0"},{"type":"module","doc":"Provides version management and self-update functionality for Raxol.\n\nThis module handles:\n- Checking for updates from GitHub releases\n- Comparing versions to determine if updates are available\n- Self-updating the application when running as a compiled binary\n- Managing update settings and configurations","title":"Raxol.System.Updater","ref":"Raxol.System.Updater.html"},{"type":"function","doc":"Checks if a newer version of Raxol is available.\n\nReturns a tuple with the check result and the latest version if available:\n- `{:no_update, current_version}` - No update available\n- `{:update_available, latest_version}` - Update available\n- `{:error, reason}` - Error occurred during check","title":"Raxol.System.Updater.check_for_updates/1","ref":"Raxol.System.Updater.html#check_for_updates/1"},{"type":"function","doc":"- `force`: When set to `true`, bypasses the update check interval. Defaults to `false`.","title":"Parameters - Raxol.System.Updater.check_for_updates/1","ref":"Raxol.System.Updater.html#check_for_updates/1-parameters"},{"type":"function","doc":"iex> Raxol.System.Updater.check_for_updates()\n    {:no_update, \"0.1.0\"}\n\n    iex> Raxol.System.Updater.check_for_updates(force: true)\n    {:update_available, \"0.2.0\"}","title":"Examples - Raxol.System.Updater.check_for_updates/1","ref":"Raxol.System.Updater.html#check_for_updates/1-examples"},{"type":"function","doc":"","title":"Raxol.System.Updater.do_replace_executable/3","ref":"Raxol.System.Updater.html#do_replace_executable/3"},{"type":"function","doc":"Displays update information to the user, if an update is available.\n\nThis function checks for updates (respecting the check interval) and\noutputs a message to the user if an update is available.","title":"Raxol.System.Updater.notify_if_update_available/0","ref":"Raxol.System.Updater.html#notify_if_update_available/0"},{"type":"function","doc":"iex> Raxol.System.Updater.notify_if_update_available()\n    :ok","title":"Examples - Raxol.System.Updater.notify_if_update_available/0","ref":"Raxol.System.Updater.html#notify_if_update_available/0-examples"},{"type":"function","doc":"Performs a self-update of the application if running as a compiled binary.\n\nReturns:\n- `:ok` - Update successfully completed\n- `{:error, reason}` - Error occurred during update\n- `{:no_update, current_version}` - No update needed","title":"Raxol.System.Updater.self_update/2","ref":"Raxol.System.Updater.html#self_update/2"},{"type":"function","doc":"- `version`: The version to update to. If not provided, updates to the latest version.\n- `opts`: Options for the update process:\n  - `:use_delta`: Whether to try using delta updates (default: true)","title":"Parameters - Raxol.System.Updater.self_update/2","ref":"Raxol.System.Updater.html#self_update/2-parameters"},{"type":"function","doc":"iex> Raxol.System.Updater.self_update()\n    :ok\n\n    iex> Raxol.System.Updater.self_update(\"0.2.0\")\n    {:error, \"Not running as a compiled binary\"}","title":"Examples - Raxol.System.Updater.self_update/2","ref":"Raxol.System.Updater.html#self_update/2-examples"},{"type":"function","doc":"Enables or disables automatic update checks.","title":"Raxol.System.Updater.set_auto_check/1","ref":"Raxol.System.Updater.html#set_auto_check/1"},{"type":"function","doc":"- `enabled`: Whether to enable or disable automatic update checks","title":"Parameters - Raxol.System.Updater.set_auto_check/1","ref":"Raxol.System.Updater.html#set_auto_check/1-parameters"},{"type":"function","doc":"iex> Raxol.System.Updater.set_auto_check(true)\n    :ok\n\n    iex> Raxol.System.Updater.set_auto_check(false)\n    :ok","title":"Examples - Raxol.System.Updater.set_auto_check/1","ref":"Raxol.System.Updater.html#set_auto_check/1-examples"},{"type":"module","doc":"ANSI escape sequence handling.\n\nDEPRECATED: This module is being refactored into smaller, more focused modules.\nUse the modules in the Raxol.Terminal.ANSI namespace instead:\n\n- Raxol.Terminal.ANSI.Parser - For parsing ANSI sequences\n- Raxol.Terminal.ANSI.Emitter - For generating ANSI sequences\n- Raxol.Terminal.ANSI.Processor - For processing ANSI sequences\n- Raxol.Terminal.ANSI.Sequences.{Cursor, Colors, Modes} - For specific sequence types\n\nThis module is maintained for backward compatibility and will be removed in a future release.","title":"Raxol.Terminal.ANSI","ref":"Raxol.Terminal.ANSI.html"},{"type":"function","doc":"Returns a map of ANSI color codes.\n\nDEPRECATED: Use Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0 instead.","title":"Raxol.Terminal.ANSI.colors/0","ref":"Raxol.Terminal.ANSI.html#colors/0"},{"type":"function","doc":"A map of color names to ANSI codes.","title":"Returns - Raxol.Terminal.ANSI.colors/0","ref":"Raxol.Terminal.ANSI.html#colors/0-returns"},{"type":"function","doc":"```elixir\n# Before\ncolors = Raxol.Terminal.ANSI.colors()\n\n# After\ncolors = Raxol.Terminal.ANSI.Sequences.Colors.color_codes()\n```","title":"Migration Path - Raxol.Terminal.ANSI.colors/0","ref":"Raxol.Terminal.ANSI.html#colors/0-migration-path"},{"type":"function","doc":"Parses ANSI escape sequences from a string.\n\nDEPRECATED: Use Raxol.Terminal.ANSI.Parser.parse/1 instead.","title":"Raxol.Terminal.ANSI.parse/1","ref":"Raxol.Terminal.ANSI.html#parse/1"},{"type":"function","doc":"* `input` - The string containing ANSI escape sequences","title":"Parameters - Raxol.Terminal.ANSI.parse/1","ref":"Raxol.Terminal.ANSI.html#parse/1-parameters"},{"type":"function","doc":"A list of parsed tokens.","title":"Returns - Raxol.Terminal.ANSI.parse/1","ref":"Raxol.Terminal.ANSI.html#parse/1-returns"},{"type":"function","doc":"```elixir\n# Before\ntokens = Raxol.Terminal.ANSI.parse(input)\n\n# After\ntokens = Raxol.Terminal.ANSI.Parser.parse(input)\n```","title":"Migration Path - Raxol.Terminal.ANSI.parse/1","ref":"Raxol.Terminal.ANSI.html#parse/1-migration-path"},{"type":"function","doc":"Processes an ANSI escape sequence.\n\nDEPRECATED: Use the Processor and specific sequence handler modules instead.","title":"Raxol.Terminal.ANSI.process_escape/2","ref":"Raxol.Terminal.ANSI.html#process_escape/2"},{"type":"function","doc":"* `sequence` - The ANSI escape sequence to process\n* `state` - The current state","title":"Parameters - Raxol.Terminal.ANSI.process_escape/2","ref":"Raxol.Terminal.ANSI.html#process_escape/2-parameters"},{"type":"function","doc":"Updated state after processing the sequence.","title":"Returns - Raxol.Terminal.ANSI.process_escape/2","ref":"Raxol.Terminal.ANSI.html#process_escape/2-returns"},{"type":"function","doc":"```elixir\n# Before\nnew_state = Raxol.Terminal.ANSI.process_escape(sequence, state)\n\n# After\nparsed = Raxol.Terminal.ANSI.Parser.parse_sequence(sequence)\nnew_state = Raxol.Terminal.ANSI.Processor.process(parsed, state)\n```","title":"Migration Path - Raxol.Terminal.ANSI.process_escape/2","ref":"Raxol.Terminal.ANSI.html#process_escape/2-migration-path"},{"type":"module","doc":"Manages character set switching and translation for the terminal emulator.\nSupports G0, G1, G2, G3 character sets and their switching operations.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.charset/0","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#t:charset/0"},{"type":"function","doc":"Map character code byte to charset atom (Based on escape_sequence.ex).\nPublic for use in tests and other modules.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.charset_code_to_atom/1","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#charset_code_to_atom/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.charset_state/0","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#t:charset_state/0"},{"type":"function","doc":"Clears any active single shift. This should be called after processing\na character that was interpreted using a single-shifted charset.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.clear_single_shift/1","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#clear_single_shift/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.codepoint/0","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#t:codepoint/0"},{"type":"function","doc":"Delegates to Handler.designate_charset/3 for designating a character set for a specific G-set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.designate_charset/3","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#designate_charset/3"},{"type":"function","doc":"Gets the active character set based on the current state.\nNote: This function does not consume an active single shift.\nThe caller is responsible for calling clear_single_shift after processing\nthe character if a single shift was active.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.get_active_charset/1","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#get_active_charset/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.gl_gr_target/0","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#t:gl_gr_target/0"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.gset_name/0","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#t:gset_name/0"},{"type":"function","doc":"Map G-set index (0-3) to map key (:g0-:g3).\nPublic for use in tests and other modules.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.index_to_gset/1","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#index_to_gset/1"},{"type":"function","doc":"Invokes a character set designator into GL or GR.\nBy default, invokes into GL (left). If the second argument is :gr, invokes into GR (right).","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.invoke_designator/3","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#invoke_designator/3"},{"type":"function","doc":"Creates a new character set state with default values.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.new/0","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#new/0"},{"type":"function","doc":"Sets the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.set_active/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#set_active/2"},{"type":"function","doc":"Sets the character set designator.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.set_designator/3","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#set_designator/3"},{"type":"function","doc":"Sets the GL (left) character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.set_gl/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#set_gl/2"},{"type":"function","doc":"Sets the GR (right) character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.set_gr/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#set_gr/2"},{"type":"function","doc":"Sets the locking shift character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.set_locking_shift/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#set_locking_shift/2"},{"type":"function","doc":"Activates a single shift for the next character.\nSS2 invokes the G2 character set.\nSS3 invokes the G3 character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.set_single_shift/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#set_single_shift/2"},{"type":"function","doc":"Switches the specified character set to the given charset.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.switch_charset/3","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#switch_charset/3"},{"type":"function","doc":"Translates a character using the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.translate_char/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#translate_char/2"},{"type":"function","doc":"Translates a string using the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.translate_string/2","ref":"Raxol.Terminal.ANSI.CharacterSets.CharacterSets.html#translate_string/2"},{"type":"module","doc":"Handles character set control sequences and state changes.","title":"Raxol.Terminal.ANSI.CharacterSets.Handler","ref":"Raxol.Terminal.ANSI.CharacterSets.Handler.html"},{"type":"function","doc":"Designates a character set for a specific G-set.","title":"Raxol.Terminal.ANSI.CharacterSets.Handler.designate_charset/3","ref":"Raxol.Terminal.ANSI.CharacterSets.Handler.html#designate_charset/3"},{"type":"function","doc":"Handles a character set control sequence.","title":"Raxol.Terminal.ANSI.CharacterSets.Handler.handle_sequence/2","ref":"Raxol.Terminal.ANSI.CharacterSets.Handler.html#handle_sequence/2"},{"type":"function","doc":"Invokes a character set.","title":"Raxol.Terminal.ANSI.CharacterSets.Handler.invoke_charset/2","ref":"Raxol.Terminal.ANSI.CharacterSets.Handler.html#invoke_charset/2"},{"type":"function","doc":"Sets a locking shift character set.","title":"Raxol.Terminal.ANSI.CharacterSets.Handler.set_locking_shift/2","ref":"Raxol.Terminal.ANSI.CharacterSets.Handler.html#set_locking_shift/2"},{"type":"function","doc":"Sets a single shift character set.","title":"Raxol.Terminal.ANSI.CharacterSets.Handler.set_single_shift/2","ref":"Raxol.Terminal.ANSI.CharacterSets.Handler.html#set_single_shift/2"},{"type":"module","doc":"Manages character set state and operations.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.charset/0","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#t:charset/0"},{"type":"function","doc":"Converts a character set code to an atom.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.charset_code_to_atom/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#charset_code_to_atom/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.charset_state/0","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#t:charset_state/0"},{"type":"function","doc":"Clears the single shift character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.clear_single_shift/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#clear_single_shift/1"},{"type":"function","doc":"Gets the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_active/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_active/1"},{"type":"function","doc":"Gets the active GR character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_active_gr/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_active_gr/1"},{"type":"function","doc":"Gets the active G-set character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_active_gset/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_active_gset/1"},{"type":"function","doc":"Gets the GL (left) character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_gl/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_gl/1"},{"type":"function","doc":"Gets the GR (right) character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_gr/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_gr/1"},{"type":"function","doc":"Gets a G-set character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_gset/2","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_gset/2"},{"type":"function","doc":"Gets the single shift character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.get_single_shift/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#get_single_shift/1"},{"type":"function","doc":"Converts a G-set index to an atom.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.index_to_gset/1","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#index_to_gset/1"},{"type":"function","doc":"Creates a new character set state with default values.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.new/0","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#new/0"},{"type":"function","doc":"Sets the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.set_active/2","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#set_active/2"},{"type":"function","doc":"Sets the GL (left) character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.set_gl/2","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#set_gl/2"},{"type":"function","doc":"Sets the GR (right) character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.set_gr/2","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#set_gr/2"},{"type":"function","doc":"Sets a G-set character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.set_gset/3","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#set_gset/3"},{"type":"function","doc":"Sets the single shift character set.","title":"Raxol.Terminal.ANSI.CharacterSets.StateManager.set_single_shift/2","ref":"Raxol.Terminal.ANSI.CharacterSets.StateManager.html#set_single_shift/2"},{"type":"module","doc":"Handles character set translations and mappings.","title":"Raxol.Terminal.ANSI.CharacterSets.Translator","ref":"Raxol.Terminal.ANSI.CharacterSets.Translator.html"},{"type":"function","doc":"Translates a character using the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.Translator.translate_char/3","ref":"Raxol.Terminal.ANSI.CharacterSets.Translator.html#translate_char/3"},{"type":"function","doc":"Translates a string using the active character set.","title":"Raxol.Terminal.ANSI.CharacterSets.Translator.translate_string/3","ref":"Raxol.Terminal.ANSI.CharacterSets.Translator.html#translate_string/3"},{"type":"module","doc":"Provides character translation tables for different character sets.\nMaps characters between different character sets according to ANSI standards.","title":"Raxol.Terminal.ANSI.CharacterTranslations","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html"},{"type":"function","doc":"Returns the DEC Special Graphics character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.dec_special/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#dec_special/0"},{"type":"function","doc":"Returns the DEC Supplementary character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.dec_supplementary/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#dec_supplementary/0"},{"type":"function","doc":"Returns the DEC Supplementary Graphics character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.dec_supplementary_graphics/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#dec_supplementary_graphics/0"},{"type":"function","doc":"Returns the DEC Technical character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.dec_technical/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#dec_technical/0"},{"type":"function","doc":"Returns the French character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.french/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#french/0"},{"type":"function","doc":"Returns the German character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.german/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#german/0"},{"type":"function","doc":"Returns the Latin-1 character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.latin1/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#latin1/0"},{"type":"function","doc":"Translates a character from the source character set to the target character set.\nReturns the translated character as a UTF-8 binary or the original if no translation exists.","title":"Raxol.Terminal.ANSI.CharacterTranslations.translate_char/2","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#translate_char/2"},{"type":"function","doc":"Translates a string from the source character set to the target character set.\nHandles invalid bytes gracefully by passing them through as-is.","title":"Raxol.Terminal.ANSI.CharacterTranslations.translate_string/2","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#translate_string/2"},{"type":"function","doc":"Returns the UK character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.uk/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#uk/0"},{"type":"function","doc":"Map of Unicode codepoints to their ANSI terminal equivalents.","title":"Raxol.Terminal.ANSI.CharacterTranslations.unicode_to_ansi/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#unicode_to_ansi/0"},{"type":"function","doc":"Returns the US ASCII character set translation table.","title":"Raxol.Terminal.ANSI.CharacterTranslations.us_ascii/0","ref":"Raxol.Terminal.ANSI.CharacterTranslations.html#us_ascii/0"},{"type":"module","doc":"Handles terminal state queries and device status reports.\nThis includes cursor position reports, device status reports,\nand terminal identification queries.","title":"Raxol.Terminal.ANSI.DeviceStatus","ref":"Raxol.Terminal.ANSI.DeviceStatus.html"},{"type":"function","doc":"Generates a cursor position report.","title":"Raxol.Terminal.ANSI.DeviceStatus.cursor_position_report/1","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#cursor_position_report/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.DeviceStatus.device_status/0","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#t:device_status/0"},{"type":"function","doc":"Generates a device status report.","title":"Raxol.Terminal.ANSI.DeviceStatus.device_status_report/2","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#device_status_report/2"},{"type":"function","doc":"Generates a fourth device attributes report.","title":"Raxol.Terminal.ANSI.DeviceStatus.fourth_device_attributes/1","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#fourth_device_attributes/1"},{"type":"function","doc":"Creates a new device status map with default values.","title":"Raxol.Terminal.ANSI.DeviceStatus.new/0","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#new/0"},{"type":"function","doc":"Generates a primary device attributes report.","title":"Raxol.Terminal.ANSI.DeviceStatus.primary_device_attributes/1","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#primary_device_attributes/1"},{"type":"function","doc":"Generates a secondary device attributes report.","title":"Raxol.Terminal.ANSI.DeviceStatus.secondary_device_attributes/1","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#secondary_device_attributes/1"},{"type":"function","doc":"Generates a tertiary device attributes report.","title":"Raxol.Terminal.ANSI.DeviceStatus.tertiary_device_attributes/1","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#tertiary_device_attributes/1"},{"type":"function","doc":"Updates the cursor position in the device status.","title":"Raxol.Terminal.ANSI.DeviceStatus.update_cursor_position/2","ref":"Raxol.Terminal.ANSI.DeviceStatus.html#update_cursor_position/2"},{"type":"module","doc":"ANSI escape sequence generation module.\n\nProvides functions for generating ANSI escape sequences for terminal control:\n- Cursor movements\n- Colors and text attributes\n- Screen manipulation\n- Various terminal modes","title":"Raxol.Terminal.ANSI.Emitter","ref":"Raxol.Terminal.ANSI.Emitter.html"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.alternate_buffer_off/0","ref":"Raxol.Terminal.ANSI.Emitter.html#alternate_buffer_off/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.alternate_buffer_on/0","ref":"Raxol.Terminal.ANSI.Emitter.html#alternate_buffer_on/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.auto_wrap_off/0","ref":"Raxol.Terminal.ANSI.Emitter.html#auto_wrap_off/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.auto_wrap_on/0","ref":"Raxol.Terminal.ANSI.Emitter.html#auto_wrap_on/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.background/1","ref":"Raxol.Terminal.ANSI.Emitter.html#background/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.background_256/1","ref":"Raxol.Terminal.ANSI.Emitter.html#background_256/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.background_rgb/3","ref":"Raxol.Terminal.ANSI.Emitter.html#background_rgb/3"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.blink/0","ref":"Raxol.Terminal.ANSI.Emitter.html#blink/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.bold/0","ref":"Raxol.Terminal.ANSI.Emitter.html#bold/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.bracketed_paste_off/0","ref":"Raxol.Terminal.ANSI.Emitter.html#bracketed_paste_off/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.bracketed_paste_on/0","ref":"Raxol.Terminal.ANSI.Emitter.html#bracketed_paste_on/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.clear_line/0","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_line/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.clear_line_from_cursor/0","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_line_from_cursor/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.clear_line_to_cursor/0","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_line_to_cursor/0"},{"type":"function","doc":"Generates an ANSI sequence for screen manipulation.","title":"Raxol.Terminal.ANSI.Emitter.clear_screen/0","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_screen/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.clear_screen_from_cursor/0","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_screen_from_cursor/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.clear_screen_to_cursor/0","ref":"Raxol.Terminal.ANSI.Emitter.html#clear_screen_to_cursor/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.conceal/0","ref":"Raxol.Terminal.ANSI.Emitter.html#conceal/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_backward/1","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_backward/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_down/1","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_down/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_forward/1","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_forward/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_hide/0","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_hide/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_position/2","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_position/2"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_restore_position/0","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_restore_position/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_save_position/0","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_save_position/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.cursor_show/0","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_show/0"},{"type":"function","doc":"Generates an ANSI sequence for cursor movement.","title":"Raxol.Terminal.ANSI.Emitter.cursor_up/1","ref":"Raxol.Terminal.ANSI.Emitter.html#cursor_up/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.faint/0","ref":"Raxol.Terminal.ANSI.Emitter.html#faint/0"},{"type":"function","doc":"Generates ANSI sequences for colors.","title":"Raxol.Terminal.ANSI.Emitter.foreground/1","ref":"Raxol.Terminal.ANSI.Emitter.html#foreground/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.foreground_256/1","ref":"Raxol.Terminal.ANSI.Emitter.html#foreground_256/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.foreground_rgb/3","ref":"Raxol.Terminal.ANSI.Emitter.html#foreground_rgb/3"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.inverse/0","ref":"Raxol.Terminal.ANSI.Emitter.html#inverse/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.italic/0","ref":"Raxol.Terminal.ANSI.Emitter.html#italic/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.no_blink/0","ref":"Raxol.Terminal.ANSI.Emitter.html#no_blink/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.no_conceal/0","ref":"Raxol.Terminal.ANSI.Emitter.html#no_conceal/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.no_inverse/0","ref":"Raxol.Terminal.ANSI.Emitter.html#no_inverse/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.no_italic/0","ref":"Raxol.Terminal.ANSI.Emitter.html#no_italic/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.no_strikethrough/0","ref":"Raxol.Terminal.ANSI.Emitter.html#no_strikethrough/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.no_underline/0","ref":"Raxol.Terminal.ANSI.Emitter.html#no_underline/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.normal_intensity/0","ref":"Raxol.Terminal.ANSI.Emitter.html#normal_intensity/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.rapid_blink/0","ref":"Raxol.Terminal.ANSI.Emitter.html#rapid_blink/0"},{"type":"function","doc":"Generates ANSI sequences for text attributes.","title":"Raxol.Terminal.ANSI.Emitter.reset_attributes/0","ref":"Raxol.Terminal.ANSI.Emitter.html#reset_attributes/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.reset_mode/1","ref":"Raxol.Terminal.ANSI.Emitter.html#reset_mode/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.scroll_down/1","ref":"Raxol.Terminal.ANSI.Emitter.html#scroll_down/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.scroll_up/1","ref":"Raxol.Terminal.ANSI.Emitter.html#scroll_up/1"},{"type":"function","doc":"Generates ANSI sequences for terminal modes.","title":"Raxol.Terminal.ANSI.Emitter.set_mode/1","ref":"Raxol.Terminal.ANSI.Emitter.html#set_mode/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.strikethrough/0","ref":"Raxol.Terminal.ANSI.Emitter.html#strikethrough/0"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Emitter.underline/0","ref":"Raxol.Terminal.ANSI.Emitter.html#underline/0"},{"type":"module","doc":"Handles mouse event reporting for the terminal emulator.\nSupports various mouse reporting modes including:\n- Basic mouse tracking (mode 1000)\n- Highlight mouse tracking (mode 1001)\n- Cell mouse tracking (mode 1002)\n- All mouse tracking (mode 1003)\n- Focus events (mode 1004)\n- UTF-8 mouse reporting (mode 1005)\n- SGR mouse reporting (mode 1006)\n- URXVT mouse reporting (mode 1015)\n- SGR pixels mouse reporting (mode 1016)","title":"Raxol.Terminal.ANSI.MouseEvents","ref":"Raxol.Terminal.ANSI.MouseEvents.html"},{"type":"function","doc":"Calculates the drag state based on the current and previous mouse states.","title":"Raxol.Terminal.ANSI.MouseEvents.calculate_drag_state/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#calculate_drag_state/2"},{"type":"function","doc":"Decodes button state and modifiers from a mouse event byte.","title":"Raxol.Terminal.ANSI.MouseEvents.decode_button/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#decode_button/1"},{"type":"function","doc":"Decodes modifier keys from a mouse event byte.","title":"Raxol.Terminal.ANSI.MouseEvents.decode_modifiers/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#decode_modifiers/1"},{"type":"function","doc":"Decodes button state for URXVT mouse events.","title":"Raxol.Terminal.ANSI.MouseEvents.decode_urxvt_button/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#decode_urxvt_button/1"},{"type":"function","doc":"Disables mouse tracking.","title":"Raxol.Terminal.ANSI.MouseEvents.disable/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#disable/1"},{"type":"function","doc":"Enables mouse tracking with the specified mode.","title":"Raxol.Terminal.ANSI.MouseEvents.enable/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#enable/2"},{"type":"function","doc":"Generates a mouse event report based on the current state.","title":"Raxol.Terminal.ANSI.MouseEvents.generate_report/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#generate_report/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.MouseEvents.modifier/0","ref":"Raxol.Terminal.ANSI.MouseEvents.html#t:modifier/0"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.MouseEvents.mouse_mode/0","ref":"Raxol.Terminal.ANSI.MouseEvents.html#t:mouse_mode/0"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.MouseEvents.mouse_state/0","ref":"Raxol.Terminal.ANSI.MouseEvents.html#t:mouse_state/0"},{"type":"function","doc":"Creates a new mouse state with default values.","title":"Raxol.Terminal.ANSI.MouseEvents.new/0","ref":"Raxol.Terminal.ANSI.MouseEvents.html#new/0"},{"type":"function","doc":"Parses coordinates from a mouse event string.","title":"Raxol.Terminal.ANSI.MouseEvents.parse_coordinates/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_coordinates/1"},{"type":"function","doc":"Parses an SGR mouse event in the format:  ; ; M","title":"Raxol.Terminal.ANSI.MouseEvents.parse_sgr_event/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_sgr_event/1"},{"type":"function","doc":"Parses an SGR pixels mouse event in the format:  ; ; M","title":"Raxol.Terminal.ANSI.MouseEvents.parse_sgr_pixels_event/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_sgr_pixels_event/1"},{"type":"function","doc":"Parses a URXVT mouse event in the format:  ; ; M","title":"Raxol.Terminal.ANSI.MouseEvents.parse_urxvt_event/1","ref":"Raxol.Terminal.ANSI.MouseEvents.html#parse_urxvt_event/1"},{"type":"function","doc":"Processes a mouse event and returns the updated state and event data.\nSupports extended mouse reporting modes including SGR pixels and URXVT.","title":"Raxol.Terminal.ANSI.MouseEvents.process_event/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#process_event/2"},{"type":"function","doc":"Updates the button state.","title":"Raxol.Terminal.ANSI.MouseEvents.update_button_state/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_button_state/2"},{"type":"function","doc":"Updates the drag state.","title":"Raxol.Terminal.ANSI.MouseEvents.update_drag_state/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_drag_state/2"},{"type":"function","doc":"Updates the modifiers state.","title":"Raxol.Terminal.ANSI.MouseEvents.update_modifiers/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_modifiers/2"},{"type":"function","doc":"Updates the mouse position.","title":"Raxol.Terminal.ANSI.MouseEvents.update_position/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_position/2"},{"type":"function","doc":"Updates the mouse state with new event data.","title":"Raxol.Terminal.ANSI.MouseEvents.update_state/2","ref":"Raxol.Terminal.ANSI.MouseEvents.html#update_state/2"},{"type":"module","doc":"ANSI escape sequence parser module.\n\nProvides comprehensive parsing for ANSI escape sequences, determining\nthe type of sequence and extracting its parameters for processing.\nThis is the main entry point for parsing all ANSI sequences.","title":"Raxol.Terminal.ANSI.Parser","ref":"Raxol.Terminal.ANSI.Parser.html"},{"type":"function","doc":"Parse a string containing ANSI escape sequences into tokens.\n\nThis function scans through the input and returns a list of tokens, where each\ntoken is either a plain string or a parsed ANSI sequence.","title":"Raxol.Terminal.ANSI.Parser.parse/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1"},{"type":"function","doc":"* `input` - The string containing ANSI escape sequences","title":"Parameters - Raxol.Terminal.ANSI.Parser.parse/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1-parameters"},{"type":"function","doc":"A list of tokens where each token is either:\n  - A binary string (plain text)\n  - A tuple representing a parsed ANSI sequence","title":"Returns - Raxol.Terminal.ANSI.Parser.parse/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1-returns"},{"type":"function","doc":"iex> Raxol.Terminal.ANSI.Parser.parse(\"Hello\u001B[31mWorld\")\n    [\"Hello\", {:text_attributes, [{:foreground_basic, 1}]}]","title":"Examples - Raxol.Terminal.ANSI.Parser.parse/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse/1-examples"},{"type":"function","doc":"Parse an ANSI escape sequence and return its type and parameters.","title":"Raxol.Terminal.ANSI.Parser.parse_sequence/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse_sequence/1"},{"type":"function","doc":"* `sequence` - The ANSI sequence to parse","title":"Parameters - Raxol.Terminal.ANSI.Parser.parse_sequence/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse_sequence/1-parameters"},{"type":"function","doc":"Parsed sequence as a tuple of type and parameters or error","title":"Returns - Raxol.Terminal.ANSI.Parser.parse_sequence/1","ref":"Raxol.Terminal.ANSI.Parser.html#parse_sequence/1-returns"},{"type":"module","doc":"ANSI sequence processor module.\n\nThis module processes ANSI escape sequences for terminal control, including:\n- Cursor movement\n- Text formatting\n- Screen manipulation\n- Terminal state changes\n- Bracketed paste mode\n- Focus reporting","title":"Raxol.Terminal.ANSI.Processor","ref":"Raxol.Terminal.ANSI.Processor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.ANSI.Processor.child_spec/1","ref":"Raxol.Terminal.ANSI.Processor.html#child_spec/1"},{"type":"function","doc":"Gets the current buffer manager.","title":"Raxol.Terminal.ANSI.Processor.get_buffer_manager/1","ref":"Raxol.Terminal.ANSI.Processor.html#get_buffer_manager/1"},{"type":"function","doc":"iex> {:ok, processor} = Processor.start_link([])\n    iex> {:ok, buffer_manager} = Manager.new(80, 24)\n    iex> :ok = Processor.set_buffer_manager(processor, buffer_manager)\n    iex> Processor.get_buffer_manager(processor)\n    {:ok, ^buffer_manager}","title":"Examples - Raxol.Terminal.ANSI.Processor.get_buffer_manager/1","ref":"Raxol.Terminal.ANSI.Processor.html#get_buffer_manager/1-examples"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Processor.init/1","ref":"Raxol.Terminal.ANSI.Processor.html#init/1"},{"type":"function","doc":"Process a parsed ANSI sequence and return the updated emulator state.\nThis is a direct interface for processing sequences without using the GenServer.","title":"Raxol.Terminal.ANSI.Processor.process/2","ref":"Raxol.Terminal.ANSI.Processor.html#process/2"},{"type":"function","doc":"* `sequence` - The parsed ANSI sequence (result from Parser.parse_sequence/1)\n* `emulator` - The current emulator state","title":"Parameters - Raxol.Terminal.ANSI.Processor.process/2","ref":"Raxol.Terminal.ANSI.Processor.html#process/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Processor.process/2","ref":"Raxol.Terminal.ANSI.Processor.html#process/2-returns"},{"type":"function","doc":"iex> sequence = Raxol.Terminal.ANSI.Parser.parse_sequence(\"\u001B[31m\")\n    iex> new_state = Raxol.Terminal.ANSI.Processor.process(sequence, emulator)","title":"Examples - Raxol.Terminal.ANSI.Processor.process/2","ref":"Raxol.Terminal.ANSI.Processor.html#process/2-examples"},{"type":"function","doc":"Processes an ANSI sequence.","title":"Raxol.Terminal.ANSI.Processor.process_sequence/2","ref":"Raxol.Terminal.ANSI.Processor.html#process_sequence/2"},{"type":"function","doc":"iex> {:ok, processor} = Processor.start_link([])\n    iex> {:ok, buffer_manager} = Manager.new(80, 24)\n    iex> :ok = Processor.set_buffer_manager(processor, buffer_manager)\n    iex> {:ok, _} = Processor.process_sequence(processor, \"\u001B[31m\")\n    :ok","title":"Examples - Raxol.Terminal.ANSI.Processor.process_sequence/2","ref":"Raxol.Terminal.ANSI.Processor.html#process_sequence/2-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.Processor.sequence/0","ref":"Raxol.Terminal.ANSI.Processor.html#t:sequence/0"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.Processor.sequence_type/0","ref":"Raxol.Terminal.ANSI.Processor.html#t:sequence_type/0"},{"type":"function","doc":"Sets the buffer manager for the processor.","title":"Raxol.Terminal.ANSI.Processor.set_buffer_manager/2","ref":"Raxol.Terminal.ANSI.Processor.html#set_buffer_manager/2"},{"type":"function","doc":"iex> {:ok, processor} = Processor.start_link([])\n    iex> {:ok, buffer_manager} = Manager.new(80, 24)\n    iex> :ok = Processor.set_buffer_manager(processor, buffer_manager)\n    :ok","title":"Examples - Raxol.Terminal.ANSI.Processor.set_buffer_manager/2","ref":"Raxol.Terminal.ANSI.Processor.html#set_buffer_manager/2-examples"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.Processor.start_link/1","ref":"Raxol.Terminal.ANSI.Processor.html#start_link/1"},{"type":"module","doc":"Handles parsing of SGR (Select Graphic Rendition) ANSI escape sequences.\nTranslates SGR codes into updates on a TextFormatting style map.","title":"Raxol.Terminal.ANSI.SGRHandler","ref":"Raxol.Terminal.ANSI.SGRHandler.html"},{"type":"function","doc":"Applies a list of SGR parameters to the current style.\nHandles multi-parameter sequences like 38/48.","title":"Raxol.Terminal.ANSI.SGRHandler.apply_sgr_params/2","ref":"Raxol.Terminal.ANSI.SGRHandler.html#apply_sgr_params/2"},{"type":"module","doc":"Helper module for parsing ANSI escape sequences.\n\nThis module provides common utilities for parsing and handling ANSI sequences,\nextracted from duplicate implementations in other ANSI-related modules.","title":"Raxol.Terminal.ANSI.SequenceParser","ref":"Raxol.Terminal.ANSI.SequenceParser.html"},{"type":"function","doc":"Parses parameters from an ANSI sequence.\n\nSplits the parameter string by semicolons and converts them to integers.","title":"Raxol.Terminal.ANSI.SequenceParser.parse_params/1","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_params/1"},{"type":"function","doc":"* `{:ok, params}` - Successfully parsed parameters\n* `:error` - Failed to parse parameters","title":"Returns - Raxol.Terminal.ANSI.SequenceParser.parse_params/1","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_params/1-returns"},{"type":"function","doc":"Generic parser for ANSI sequences that follow the pattern: params + operation code.","title":"Raxol.Terminal.ANSI.SequenceParser.parse_sequence/2","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_sequence/2"},{"type":"function","doc":"* `sequence` - The binary sequence to parse\n* `operation_decoder` - Function to decode operation from character code","title":"Parameters - Raxol.Terminal.ANSI.SequenceParser.parse_sequence/2","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_sequence/2-parameters"},{"type":"function","doc":"* `{:ok, operation, params}` - Successfully parsed sequence\n* `:error` - Failed to parse sequence","title":"Returns - Raxol.Terminal.ANSI.SequenceParser.parse_sequence/2","ref":"Raxol.Terminal.ANSI.SequenceParser.html#parse_sequence/2-returns"},{"type":"module","doc":"ANSI Color Sequence Handler.\n\nHandles parsing and application of ANSI color control sequences,\nincluding 16-color mode, 256-color mode, and true color (24-bit) mode.","title":"Raxol.Terminal.ANSI.Sequences.Colors","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html"},{"type":"function","doc":"Generate ANSI color code for a given color.","title":"Raxol.Terminal.ANSI.Sequences.Colors.color_code/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_code/2"},{"type":"function","doc":"* `color` - The color struct\n* `type` - Either :foreground or :background","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.color_code/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_code/2-parameters"},{"type":"function","doc":"ANSI escape sequence as string","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.color_code/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_code/2-returns"},{"type":"function","doc":"Returns a map of ANSI color codes.","title":"Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_codes/0"},{"type":"function","doc":"A map of color names to ANSI codes.","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_codes/0-returns"},{"type":"function","doc":"iex> Raxol.Terminal.ANSI.Sequences.Colors.color_codes()\n    %{\n      black: \"\u001B[30m\",\n      red: \"\u001B[31m\",\n      # ... other colors ...\n      reset: \"\u001B[0m\"\n    }","title":"Examples - Raxol.Terminal.ANSI.Sequences.Colors.color_codes/0","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#color_codes/0-examples"},{"type":"function","doc":"Set background color using 256-color mode.","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_background_256/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_256/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `index` - Color index (0-255)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_background_256/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_256/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_background_256/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_256/2-returns"},{"type":"function","doc":"Set background color using basic 16-color mode.","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_background_basic/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_basic/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `color_code` - Color code (0-15)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_background_basic/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_basic/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_background_basic/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_basic/2-returns"},{"type":"function","doc":"Set background color using true (24-bit) RGB color.","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_background_true/4","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_true/4"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `r` - Red component (0-255)\n* `g` - Green component (0-255)\n* `b` - Blue component (0-255)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_background_true/4","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_true/4-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_background_true/4","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_background_true/4-returns"},{"type":"function","doc":"Set foreground color using 256-color mode.","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_256/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_256/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `index` - Color index (0-255)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_256/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_256/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_256/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_256/2-returns"},{"type":"function","doc":"Set foreground color using basic 16-color mode.","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_basic/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_basic/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `color_code` - Color code (0-15)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_basic/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_basic/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_basic/2","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_basic/2-returns"},{"type":"function","doc":"Set foreground color using true (24-bit) RGB color.","title":"Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_true/4","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_true/4"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `r` - Red component (0-255)\n* `g` - Green component (0-255)\n* `b` - Blue component (0-255)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_true/4","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_true/4-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Colors.set_foreground_true/4","ref":"Raxol.Terminal.ANSI.Sequences.Colors.html#set_foreground_true/4-returns"},{"type":"module","doc":"ANSI Cursor Sequence Handler.\n\nHandles parsing and application of ANSI cursor control sequences,\nincluding movement, position saving/restoring, and visibility.","title":"Raxol.Terminal.ANSI.Sequences.Cursor","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html"},{"type":"function","doc":"Move cursor to absolute position.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor/3","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor/3"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `row` - Row to move to (1-indexed)\n* `col` - Column to move to (1-indexed)","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor/3","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor/3-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor/3","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor/3-returns"},{"type":"function","doc":"Move cursor backward by specified number of columns.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_backward/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_backward/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of columns to move backward","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_backward/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_backward/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_backward/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_backward/2-returns"},{"type":"function","doc":"Move cursor down by specified number of rows.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_down/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_down/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of rows to move down","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_down/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_down/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_down/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_down/2-returns"},{"type":"function","doc":"Move cursor forward by specified number of columns.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_forward/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_forward/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of columns to move forward","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_forward/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_forward/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_forward/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_forward/2-returns"},{"type":"function","doc":"Move cursor up by specified number of rows.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_up/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_up/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `n` - Number of rows to move up","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_up/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_up/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.move_cursor_up/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#move_cursor_up/2-returns"},{"type":"function","doc":"Restore previously saved cursor position.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.restore_cursor_position/1","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#restore_cursor_position/1"},{"type":"function","doc":"* `emulator` - The terminal emulator state","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.restore_cursor_position/1","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#restore_cursor_position/1-parameters"},{"type":"function","doc":"Updated emulator state with restored cursor position","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.restore_cursor_position/1","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#restore_cursor_position/1-returns"},{"type":"function","doc":"Save current cursor position.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.save_cursor_position/1","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#save_cursor_position/1"},{"type":"function","doc":"* `emulator` - The terminal emulator state","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.save_cursor_position/1","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#save_cursor_position/1-parameters"},{"type":"function","doc":"Updated emulator state with saved cursor position","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.save_cursor_position/1","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#save_cursor_position/1-returns"},{"type":"function","doc":"Set cursor visibility.","title":"Raxol.Terminal.ANSI.Sequences.Cursor.set_cursor_visibility/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#set_cursor_visibility/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `visible` - Boolean indicating visibility","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Cursor.set_cursor_visibility/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#set_cursor_visibility/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Cursor.set_cursor_visibility/2","ref":"Raxol.Terminal.ANSI.Sequences.Cursor.html#set_cursor_visibility/2-returns"},{"type":"module","doc":"ANSI Terminal Modes Sequence Handler.\n\nHandles parsing and application of ANSI terminal mode sequences,\nincluding screen modes, input modes, and rendering modes.","title":"Raxol.Terminal.ANSI.Sequences.Modes","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html"},{"type":"function","doc":"Switch to alternate buffer mode.","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_alternate_buffer/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_alternate_buffer/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `use_alternate` - Boolean indicating if alternate buffer should be used","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_alternate_buffer/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_alternate_buffer/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_alternate_buffer/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_alternate_buffer/2-returns"},{"type":"function","doc":"Enable or disable bracketed paste mode.","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_bracketed_paste_mode/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_bracketed_paste_mode/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `enabled` - Boolean indicating if mode should be enabled or disabled","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_bracketed_paste_mode/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_bracketed_paste_mode/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_bracketed_paste_mode/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_bracketed_paste_mode/2-returns"},{"type":"function","doc":"Enable or disable focus reporting.","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_focus_reporting/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_focus_reporting/2"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `enabled` - Boolean indicating if mode should be enabled or disabled","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_focus_reporting/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_focus_reporting/2-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_focus_reporting/2","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_focus_reporting/2-returns"},{"type":"function","doc":"Set or reset a screen mode.","title":"Raxol.Terminal.ANSI.Sequences.Modes.set_screen_mode/3","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_screen_mode/3"},{"type":"function","doc":"* `emulator` - The terminal emulator state\n* `mode` - Mode identifier\n* `enabled` - Boolean indicating if mode should be enabled or disabled","title":"Parameters - Raxol.Terminal.ANSI.Sequences.Modes.set_screen_mode/3","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_screen_mode/3-parameters"},{"type":"function","doc":"Updated emulator state","title":"Returns - Raxol.Terminal.ANSI.Sequences.Modes.set_screen_mode/3","ref":"Raxol.Terminal.ANSI.Sequences.Modes.html#set_screen_mode/3-returns"},{"type":"module","doc":"Handles Sixel graphics for the terminal emulator.\nSupports:\n- Sixel color palette management\n- Sixel image rendering\n- Sixel image scaling\n- Sixel image positioning\n- Sixel image attributes","title":"Raxol.Terminal.ANSI.SixelGraphics","ref":"Raxol.Terminal.ANSI.SixelGraphics.html"},{"type":"function","doc":"Creates a new Sixel state with default values.","title":"Raxol.Terminal.ANSI.SixelGraphics.new/0","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#new/0"},{"type":"function","doc":"Processes a Sixel sequence (DCS P...q DATA ST) and returns the updated state.\n\nThe pixel data is stored in `state.pixel_buffer`.","title":"Raxol.Terminal.ANSI.SixelGraphics.process_sequence/2","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#process_sequence/2"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.SixelGraphics.sixel_attribute/0","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#t:sixel_attribute/0"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.SixelGraphics.sixel_state/0","ref":"Raxol.Terminal.ANSI.SixelGraphics.html#t:sixel_state/0"},{"type":"module","doc":"Handles Sixel color palette management.\n\nProvides functions to initialize the default palette and potentially\nmanage custom color definitions in the future.","title":"Raxol.Terminal.ANSI.SixelPalette","ref":"Raxol.Terminal.ANSI.SixelPalette.html"},{"type":"function","doc":"Converts color parameters based on the specified color space.\n\nHandles clamping values and delegation to specific conversion functions.\nSupports HLS (1) and RGB (2).","title":"Raxol.Terminal.ANSI.SixelPalette.convert_color/4","ref":"Raxol.Terminal.ANSI.SixelPalette.html#convert_color/4"},{"type":"function","doc":"Defines a custom color in the palette using the Sixel '#' command format.","title":"Raxol.Terminal.ANSI.SixelPalette.define_color/6","ref":"Raxol.Terminal.ANSI.SixelPalette.html#define_color/6"},{"type":"function","doc":"* `palette` - The current color palette map\n  * `index` - The color index to define (0-255)\n  * `format` - The color space format (1 for HLS, 2 for RGB)\n  * `p1` - First parameter (H or R)\n  * `p2` - Second parameter (L or G)\n  * `p3` - Third parameter (S or B)","title":"Parameters - Raxol.Terminal.ANSI.SixelPalette.define_color/6","ref":"Raxol.Terminal.ANSI.SixelPalette.html#define_color/6-parameters"},{"type":"function","doc":"* `{:ok, updated_palette}` - The updated palette with the new color\n  * `{:error, reason}` - If the color definition fails","title":"Returns - Raxol.Terminal.ANSI.SixelPalette.define_color/6","ref":"Raxol.Terminal.ANSI.SixelPalette.html#define_color/6-returns"},{"type":"function","doc":"Simplified HLS to RGB conversion (based on standard formulas).\n\nInput: H (0-360), L (0-1), S (0-1)\nOutput: {:ok, {R, G, B}} (0-255)","title":"Raxol.Terminal.ANSI.SixelPalette.hls_to_rgb/3","ref":"Raxol.Terminal.ANSI.SixelPalette.html#hls_to_rgb/3"},{"type":"function","doc":"Initializes the default Sixel color palette (256 colors).","title":"Raxol.Terminal.ANSI.SixelPalette.initialize_palette/0","ref":"Raxol.Terminal.ANSI.SixelPalette.html#initialize_palette/0"},{"type":"function","doc":"Returns the maximum valid color index (typically 255 for a 256-color palette).","title":"Raxol.Terminal.ANSI.SixelPalette.max_colors/0","ref":"Raxol.Terminal.ANSI.SixelPalette.html#max_colors/0"},{"type":"module","doc":"Handles the parsing logic for Sixel graphics data streams within a DCS sequence.","title":"Raxol.Terminal.ANSI.SixelParser","ref":"Raxol.Terminal.ANSI.SixelParser.html"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.SixelParser.consume_integer_params/1","ref":"Raxol.Terminal.ANSI.SixelParser.html#consume_integer_params/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.SixelParser.parse/2","ref":"Raxol.Terminal.ANSI.SixelParser.html#parse/2"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.SixelParser.parse_dcs_params_list/1","ref":"Raxol.Terminal.ANSI.SixelParser.html#parse_dcs_params_list/1"},{"type":"module","doc":"","title":"Raxol.Terminal.ANSI.SixelParser.ParserState","ref":"Raxol.Terminal.ANSI.SixelParser.ParserState.html"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.SixelParser.ParserState.t/0","ref":"Raxol.Terminal.ANSI.SixelParser.ParserState.html#t:t/0"},{"type":"module","doc":"Provides a mapping from Sixel characters to their 6-bit pixel patterns.","title":"Raxol.Terminal.ANSI.SixelPatternMap","ref":"Raxol.Terminal.ANSI.SixelPatternMap.html"},{"type":"function","doc":"Gets the 6-bit integer pattern for a given Sixel character code.\n\nReturns `nil` if the character code is outside the valid Sixel range (? to ~).\nSixel characters range from ? (63) to ~ (126).","title":"Raxol.Terminal.ANSI.SixelPatternMap.get_pattern/1","ref":"Raxol.Terminal.ANSI.SixelPatternMap.html#get_pattern/1"},{"type":"function","doc":"Converts a 6-bit integer pattern into a list of 6 pixel values (0 or 1).\n\nBit 0 (LSB) corresponds to the top pixel.","title":"Raxol.Terminal.ANSI.SixelPatternMap.pattern_to_pixels/1","ref":"Raxol.Terminal.ANSI.SixelPatternMap.html#pattern_to_pixels/1"},{"type":"module","doc":"Handles rendering Sixel graphics data from a pixel buffer.","title":"Raxol.Terminal.ANSI.SixelRenderer","ref":"Raxol.Terminal.ANSI.SixelRenderer.html"},{"type":"function","doc":"Renders the image stored in the pixel_buffer as a Sixel data stream.","title":"Raxol.Terminal.ANSI.SixelRenderer.render_image/1","ref":"Raxol.Terminal.ANSI.SixelRenderer.html#render_image/1"},{"type":"module","doc":"Manages terminal state for the terminal emulator.\nHandles saving and restoring terminal state, including cursor position,\nattributes, character sets, and screen modes.","title":"Raxol.Terminal.ANSI.TerminalState","ref":"Raxol.Terminal.ANSI.TerminalState.html"},{"type":"function","doc":"Applies specified fields from restored data onto the current emulator state.","title":"Raxol.Terminal.ANSI.TerminalState.apply_restored_data/3","ref":"Raxol.Terminal.ANSI.TerminalState.html#apply_restored_data/3"},{"type":"function","doc":"Clears the terminal state stack.","title":"Raxol.Terminal.ANSI.TerminalState.clear_state/1","ref":"Raxol.Terminal.ANSI.TerminalState.html#clear_state/1"},{"type":"function","doc":"Gets the number of saved states in the stack.","title":"Raxol.Terminal.ANSI.TerminalState.count/1","ref":"Raxol.Terminal.ANSI.TerminalState.html#count/1"},{"type":"function","doc":"Checks if the terminal state stack is empty.","title":"Raxol.Terminal.ANSI.TerminalState.empty?/1","ref":"Raxol.Terminal.ANSI.TerminalState.html#empty?/1"},{"type":"function","doc":"Gets the current terminal state stack.","title":"Raxol.Terminal.ANSI.TerminalState.get_state_stack/1","ref":"Raxol.Terminal.ANSI.TerminalState.html#get_state_stack/1"},{"type":"function","doc":"Creates a new terminal state stack.","title":"Raxol.Terminal.ANSI.TerminalState.new/0","ref":"Raxol.Terminal.ANSI.TerminalState.html#new/0"},{"type":"function","doc":"Restores the most recently saved terminal state from the stack.\nReturns the updated stack and the restored state.","title":"Raxol.Terminal.ANSI.TerminalState.restore_state/1","ref":"Raxol.Terminal.ANSI.TerminalState.html#restore_state/1"},{"type":"function","doc":"Saves the current terminal state to the stack.","title":"Raxol.Terminal.ANSI.TerminalState.save_state/2","ref":"Raxol.Terminal.ANSI.TerminalState.html#save_state/2"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.TerminalState.saved_state/0","ref":"Raxol.Terminal.ANSI.TerminalState.html#t:saved_state/0"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.TerminalState.state_stack/0","ref":"Raxol.Terminal.ANSI.TerminalState.html#t:state_stack/0"},{"type":"behaviour","doc":"Behaviour for managing terminal state saving and restoring.","title":"Raxol.Terminal.ANSI.TerminalStateBehaviour","ref":"Raxol.Terminal.ANSI.TerminalStateBehaviour.html"},{"type":"callback","doc":"","title":"Raxol.Terminal.ANSI.TerminalStateBehaviour.apply_restored_data/3","ref":"Raxol.Terminal.ANSI.TerminalStateBehaviour.html#c:apply_restored_data/3"},{"type":"callback","doc":"","title":"Raxol.Terminal.ANSI.TerminalStateBehaviour.restore_state/1","ref":"Raxol.Terminal.ANSI.TerminalStateBehaviour.html#c:restore_state/1"},{"type":"callback","doc":"","title":"Raxol.Terminal.ANSI.TerminalStateBehaviour.save_state/2","ref":"Raxol.Terminal.ANSI.TerminalStateBehaviour.html#c:save_state/2"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.TerminalStateBehaviour.state_data_map/0","ref":"Raxol.Terminal.ANSI.TerminalStateBehaviour.html#t:state_data_map/0"},{"type":"module","doc":"Handles advanced text formatting features for the terminal emulator.\nThis includes double-width and double-height characters, as well as\nother advanced text attributes and colors.","title":"Raxol.Terminal.ANSI.TextFormatting","ref":"Raxol.Terminal.ANSI.TextFormatting.html"},{"type":"function","doc":"Converts a standard ANSI 3/4-bit color code to a color name atom.","title":"Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#ansi_code_to_color_name/1"},{"type":"function","doc":"iex> Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name(31)\n    :red\n\n    iex> Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name(44)\n    :blue\n\n    iex> Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name(99) # Unknown\n    nil","title":"Examples - Raxol.Terminal.ANSI.TextFormatting.ansi_code_to_color_name/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#ansi_code_to_color_name/1-examples"},{"type":"function","doc":"Applies a text attribute to the style map.","title":"Raxol.Terminal.ANSI.TextFormatting.apply_attribute/2","ref":"Raxol.Terminal.ANSI.TextFormatting.html#apply_attribute/2"},{"type":"function","doc":"Applies a color attribute to the style map.","title":"Raxol.Terminal.ANSI.TextFormatting.apply_color/3","ref":"Raxol.Terminal.ANSI.TextFormatting.html#apply_color/3"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.TextFormatting.color/0","ref":"Raxol.Terminal.ANSI.TextFormatting.html#t:color/0"},{"type":"function","doc":"Calculates the effective width of a character based on the current style.","title":"Raxol.Terminal.ANSI.TextFormatting.effective_width/2","ref":"Raxol.Terminal.ANSI.TextFormatting.html#effective_width/2"},{"type":"function","doc":"Reconstructs the SGR parameter string corresponding to the given style attributes.\nUsed primarily for DECRQSS responses.","title":"Raxol.Terminal.ANSI.TextFormatting.format_sgr_params/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#format_sgr_params/1"},{"type":"function","doc":"Gets the background color.","title":"Raxol.Terminal.ANSI.TextFormatting.get_background/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#get_background/1"},{"type":"function","doc":"Gets the foreground color.","title":"Raxol.Terminal.ANSI.TextFormatting.get_foreground/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#get_foreground/1"},{"type":"function","doc":"Gets the hyperlink URI.","title":"Raxol.Terminal.ANSI.TextFormatting.get_hyperlink/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#get_hyperlink/1"},{"type":"function","doc":"Gets the paired line type for double-height mode.","title":"Raxol.Terminal.ANSI.TextFormatting.get_paired_line_type/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#get_paired_line_type/1"},{"type":"function","doc":"Determines if the current line needs a paired line (for double-height mode).","title":"Raxol.Terminal.ANSI.TextFormatting.needs_paired_line?/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#needs_paired_line?/1"},{"type":"function","doc":"Creates a new text style map with default values.","title":"Raxol.Terminal.ANSI.TextFormatting.new/0","ref":"Raxol.Terminal.ANSI.TextFormatting.html#new/0"},{"type":"function","doc":"Resets all text formatting attributes to their default values.","title":"Raxol.Terminal.ANSI.TextFormatting.reset/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#reset/1"},{"type":"function","doc":"Resets to single-width, single-height mode.","title":"Raxol.Terminal.ANSI.TextFormatting.reset_size/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#reset_size/1"},{"type":"function","doc":"Sets the background color.","title":"Raxol.Terminal.ANSI.TextFormatting.set_background/2","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_background/2"},{"type":"function","doc":"Sets double-height bottom half mode for the current line.","title":"Raxol.Terminal.ANSI.TextFormatting.set_double_height_bottom/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_double_height_bottom/1"},{"type":"function","doc":"Sets double-height top half mode for the current line.","title":"Raxol.Terminal.ANSI.TextFormatting.set_double_height_top/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_double_height_top/1"},{"type":"function","doc":"Sets double-width mode for the current line.","title":"Raxol.Terminal.ANSI.TextFormatting.set_double_width/1","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_double_width/1"},{"type":"function","doc":"Sets the foreground color.","title":"Raxol.Terminal.ANSI.TextFormatting.set_foreground/2","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_foreground/2"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.TextFormatting.set_hyperlink/2","ref":"Raxol.Terminal.ANSI.TextFormatting.html#set_hyperlink/2"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.TextFormatting.text_style/0","ref":"Raxol.Terminal.ANSI.TextFormatting.html#t:text_style/0"},{"type":"module","doc":"Handles window manipulation sequences for the terminal emulator.\nSupports various window operations including:\n- Window size queries and reports\n- Window position queries and reports\n- Window title manipulation\n- Window icon manipulation\n- Window stacking order","title":"Raxol.Terminal.ANSI.WindowManipulation","ref":"Raxol.Terminal.ANSI.WindowManipulation.html"},{"type":"function","doc":"","title":"Raxol.Terminal.ANSI.WindowManipulation.handle_operation/3","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#handle_operation/3"},{"type":"function","doc":"Creates a new window state with default values.","title":"Raxol.Terminal.ANSI.WindowManipulation.new/0","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#new/0"},{"type":"function","doc":"Processes a window manipulation sequence and returns the updated state and response.\nHandles CSI (\u001B[...t) and OSC (\u001B]...\u0007 or \u001B]...\u001B\\) sequences.","title":"Raxol.Terminal.ANSI.WindowManipulation.process_sequence/2","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#process_sequence/2"},{"type":"type","doc":"","title":"Raxol.Terminal.ANSI.WindowManipulation.window_state/0","ref":"Raxol.Terminal.ANSI.WindowManipulation.html#t:window_state/0"},{"type":"module","doc":"Handles character insertion and deletion within the Raxol.Terminal.ScreenBuffer lines.","title":"Raxol.Terminal.Buffer.CharEditor","ref":"Raxol.Terminal.Buffer.CharEditor.html"},{"type":"function","doc":"Deletes a specified number of characters starting from the given row and column index.\nCharacters to the right of the deleted characters are shifted left. Blank characters\nare added at the end of the line to fill the space using the provided default_style.\nUses the buffer's default style for new cells.","title":"Raxol.Terminal.Buffer.CharEditor.delete_characters/5","ref":"Raxol.Terminal.Buffer.CharEditor.html#delete_characters/5"},{"type":"function","doc":"Inserts a specified number of blank characters at the given row and column index\nusing the provided default_style.\nCharacters to the right of the insertion point are shifted right. Characters shifted\noff the end of the line are discarded. Uses the buffer's default style for new cells.","title":"Raxol.Terminal.Buffer.CharEditor.insert_characters/5","ref":"Raxol.Terminal.Buffer.CharEditor.html#insert_characters/5"},{"type":"module","doc":"Manages damage tracking for terminal buffers.\n\nHandles marking regions as damaged and merging overlapping regions\nfor efficient redrawing.","title":"Raxol.Terminal.Buffer.DamageTracker","ref":"Raxol.Terminal.Buffer.DamageTracker.html"},{"type":"function","doc":"Clears all tracked damage regions.","title":"Raxol.Terminal.Buffer.DamageTracker.clear_regions/1","ref":"Raxol.Terminal.Buffer.DamageTracker.html#clear_regions/1"},{"type":"function","doc":"Gets the list of distinct damaged regions.","title":"Raxol.Terminal.Buffer.DamageTracker.get_regions/1","ref":"Raxol.Terminal.Buffer.DamageTracker.html#get_regions/1"},{"type":"function","doc":"Marks a rectangular region as damaged.\n\nMerges the new region with any existing overlapping regions.","title":"Raxol.Terminal.Buffer.DamageTracker.mark_damaged/5","ref":"Raxol.Terminal.Buffer.DamageTracker.html#mark_damaged/5"},{"type":"function","doc":"Creates a new, empty damage tracker.","title":"Raxol.Terminal.Buffer.DamageTracker.new/0","ref":"Raxol.Terminal.Buffer.DamageTracker.html#new/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Buffer.DamageTracker.region/0","ref":"Raxol.Terminal.Buffer.DamageTracker.html#t:region/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Buffer.DamageTracker.t/0","ref":"Raxol.Terminal.Buffer.DamageTracker.html#t:t/0"},{"type":"module","doc":"Handles erasing parts of the Raxol.Terminal.ScreenBuffer.\nIncludes functions for erasing lines, screen regions, and characters.","title":"Raxol.Terminal.Buffer.Eraser","ref":"Raxol.Terminal.Buffer.Eraser.html"},{"type":"function","doc":"Clears the entire line using the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_line/3","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_line/3"},{"type":"function","doc":"Clears from the given position to the end of the line using the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_line_from/4","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_line_from/4"},{"type":"function","doc":"Clears from the beginning of the line to the given position using the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_line_to/4","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_line_to/4"},{"type":"function","doc":"Clears a rectangular region of the buffer by replacing cells with blank cells\nusing the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_region/6","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_region/6"},{"type":"function","doc":"Clears the entire screen (main buffer grid) using the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_screen/2","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_screen/2"},{"type":"function","doc":"Clears the screen from the given position down using the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_screen_from/4","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_screen_from/4"},{"type":"function","doc":"Clears the screen from the beginning up to the given position using the provided default_style.\nReturns the updated buffer state.","title":"Raxol.Terminal.Buffer.Eraser.clear_screen_to/4","ref":"Raxol.Terminal.Buffer.Eraser.html#clear_screen_to/4"},{"type":"function","doc":"Erases parts of the display based on cursor position and type.\nType can be :to_end, :to_beginning, or :all.\nRequires cursor state {col, row}.\nDelegates to specific clear_screen_* functions.\nDoes not handle type 3 (scrollback) - that should be handled by the Emulator.","title":"Raxol.Terminal.Buffer.Eraser.erase_in_display/4","ref":"Raxol.Terminal.Buffer.Eraser.html#erase_in_display/4"},{"type":"function","doc":"Erases parts of the current line based on cursor position and type.\nType can be :to_end, :to_beginning, or :all.\nRequires cursor state {col, row}.\nDelegates to specific clear_line_* functions.","title":"Raxol.Terminal.Buffer.Eraser.erase_in_line/4","ref":"Raxol.Terminal.Buffer.Eraser.html#erase_in_line/4"},{"type":"module","doc":"Handles insertion and deletion of lines within the Raxol.Terminal.ScreenBuffer.","title":"Raxol.Terminal.Buffer.LineEditor","ref":"Raxol.Terminal.Buffer.LineEditor.html"},{"type":"function","doc":"Deletes a specified number of lines starting from the given row index.\nLines below the deleted lines are shifted up.\nBlank lines are added at the bottom of the buffer to fill the space using the provided default_style.\nUses the buffer's default style for new lines.","title":"Raxol.Terminal.Buffer.LineEditor.delete_lines/4","ref":"Raxol.Terminal.Buffer.LineEditor.html#delete_lines/4"},{"type":"function","doc":"Inserts a specified number of blank lines at the given row index using the provided default_style.\nExisting lines from the insertion point downwards are shifted down.\nLines shifted off the bottom of the buffer are discarded.\nUses the buffer's default style for new lines.","title":"Raxol.Terminal.Buffer.LineEditor.insert_lines/4","ref":"Raxol.Terminal.Buffer.LineEditor.html#insert_lines/4"},{"type":"module","doc":"Manages terminal buffers and their operations.\nCoordinates between different buffer-related modules.","title":"Raxol.Terminal.Buffer.Manager","ref":"Raxol.Terminal.Buffer.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.Buffer.Manager.child_spec/1","ref":"Raxol.Terminal.Buffer.Manager.html#child_spec/1"},{"type":"function","doc":"Clears all damage regions.","title":"Raxol.Terminal.Buffer.Manager.clear_damage/1","ref":"Raxol.Terminal.Buffer.Manager.html#clear_damage/1"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> :ok = Buffer.Manager.clear_damage(pid)\n    iex> Buffer.Manager.get_damage(pid)\n    []","title":"Examples - Raxol.Terminal.Buffer.Manager.clear_damage/1","ref":"Raxol.Terminal.Buffer.Manager.html#clear_damage/1-examples"},{"type":"function","doc":"Returns the default tab stop positions for a given width.","title":"Raxol.Terminal.Buffer.Manager.default_tab_stops/1","ref":"Raxol.Terminal.Buffer.Manager.html#default_tab_stops/1"},{"type":"function","doc":"iex> Manager.default_tab_stops(8)\n    [0, 8, 16, 24, 32, 40, 48, 56]","title":"Examples - Raxol.Terminal.Buffer.Manager.default_tab_stops/1","ref":"Raxol.Terminal.Buffer.Manager.html#default_tab_stops/1-examples"},{"type":"function","doc":"Gets a cell from the active buffer.","title":"Raxol.Terminal.Buffer.Manager.get_cell/3","ref":"Raxol.Terminal.Buffer.Manager.html#get_cell/3"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> Buffer.Manager.get_cell(pid, 0, 0)\n    %Cell{char: \" \", fg: :default, bg: :default}","title":"Examples - Raxol.Terminal.Buffer.Manager.get_cell/3","ref":"Raxol.Terminal.Buffer.Manager.html#get_cell/3-examples"},{"type":"function","doc":"Gets the current cursor position.","title":"Raxol.Terminal.Buffer.Manager.get_cursor/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_cursor/1"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> Buffer.Manager.get_cursor(pid)\n    {0, 0}","title":"Examples - Raxol.Terminal.Buffer.Manager.get_cursor/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_cursor/1-examples"},{"type":"function","doc":"Gets the damaged regions in the buffer.","title":"Raxol.Terminal.Buffer.Manager.get_damage/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_damage/1"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> Buffer.Manager.get_damage(pid)\n    []","title":"Examples - Raxol.Terminal.Buffer.Manager.get_damage/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_damage/1-examples"},{"type":"function","doc":"Gets the current memory usage.","title":"Raxol.Terminal.Buffer.Manager.get_memory_usage/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_memory_usage/1"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> Buffer.Manager.get_memory_usage(pid)\n    0","title":"Examples - Raxol.Terminal.Buffer.Manager.get_memory_usage/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_memory_usage/1-examples"},{"type":"function","doc":"Gets the number of lines in the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.get_scrollback_count/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_scrollback_count/1"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> Buffer.Manager.get_scrollback_count(pid)\n    0","title":"Examples - Raxol.Terminal.Buffer.Manager.get_scrollback_count/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_scrollback_count/1-examples"},{"type":"function","doc":"Gets the current state of the buffer manager.","title":"Raxol.Terminal.Buffer.Manager.get_state/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_state/1"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> state = Buffer.Manager.get_state(pid)\n    iex> state.active_buffer.width\n    80","title":"Examples - Raxol.Terminal.Buffer.Manager.get_state/1","ref":"Raxol.Terminal.Buffer.Manager.html#get_state/1-examples"},{"type":"function","doc":"Initializes main and alternate screen buffers with the specified dimensions.","title":"Raxol.Terminal.Buffer.Manager.initialize_buffers/3","ref":"Raxol.Terminal.Buffer.Manager.html#initialize_buffers/3"},{"type":"function","doc":"iex> {main_buffer, alt_buffer} = Manager.initialize_buffers(80, 24, 1000)\n    iex> main_buffer.width\n    80\n    iex> alt_buffer.height\n    24","title":"Examples - Raxol.Terminal.Buffer.Manager.initialize_buffers/3","ref":"Raxol.Terminal.Buffer.Manager.html#initialize_buffers/3-examples"},{"type":"function","doc":"Marks a region of the buffer as damaged (needs redraw).","title":"Raxol.Terminal.Buffer.Manager.mark_damaged/5","ref":"Raxol.Terminal.Buffer.Manager.html#mark_damaged/5"},{"type":"function","doc":"Creates a new buffer manager with the specified dimensions.","title":"Raxol.Terminal.Buffer.Manager.new/4","ref":"Raxol.Terminal.Buffer.Manager.html#new/4"},{"type":"function","doc":"iex> {:ok, manager} = Manager.new(80, 24)\n    iex> manager.active_buffer.width\n    80\n    iex> manager.active_buffer.height\n    24","title":"Examples - Raxol.Terminal.Buffer.Manager.new/4","ref":"Raxol.Terminal.Buffer.Manager.html#new/4-examples"},{"type":"function","doc":"Resizes the buffer.","title":"Raxol.Terminal.Buffer.Manager.resize/3","ref":"Raxol.Terminal.Buffer.Manager.html#resize/3"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> :ok = Buffer.Manager.resize(pid, 100, 30)\n    iex> state = Buffer.Manager.get_state(pid)\n    iex> state.active_buffer.width\n    100\n    iex> state.active_buffer.height\n    30","title":"Examples - Raxol.Terminal.Buffer.Manager.resize/3","ref":"Raxol.Terminal.Buffer.Manager.html#resize/3-examples"},{"type":"function","doc":"Sets a cell in the active buffer.","title":"Raxol.Terminal.Buffer.Manager.set_cell/4","ref":"Raxol.Terminal.Buffer.Manager.html#set_cell/4"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> cell = %Cell{char: \"A\", fg: :red, bg: :blue}\n    iex> :ok = Buffer.Manager.set_cell(pid, 0, 0, cell)\n    iex> state = Buffer.Manager.get_state(pid)\n    iex> Buffer.get_cell(state, 0, 0)\n    %Cell{char: \"A\", fg: :red, bg: :blue}","title":"Examples - Raxol.Terminal.Buffer.Manager.set_cell/4","ref":"Raxol.Terminal.Buffer.Manager.html#set_cell/4-examples"},{"type":"function","doc":"Sets the cursor position.","title":"Raxol.Terminal.Buffer.Manager.set_cursor/3","ref":"Raxol.Terminal.Buffer.Manager.html#set_cursor/3"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link()\n    iex> :ok = Buffer.Manager.set_cursor(pid, 10, 5)\n    iex> state = Buffer.Manager.get_state(pid)\n    iex> Cursor.get_position(state)\n    {10, 5}","title":"Examples - Raxol.Terminal.Buffer.Manager.set_cursor/3","ref":"Raxol.Terminal.Buffer.Manager.html#set_cursor/3-examples"},{"type":"function","doc":"Sets the cursor position in the buffer manager.","title":"Raxol.Terminal.Buffer.Manager.set_cursor_position/3","ref":"Raxol.Terminal.Buffer.Manager.html#set_cursor_position/3"},{"type":"function","doc":"Starts a new buffer manager process.","title":"Raxol.Terminal.Buffer.Manager.start_link/1","ref":"Raxol.Terminal.Buffer.Manager.html#start_link/1"},{"type":"function","doc":"* `:width` - The width of the buffer (default: 80)\n  * `:height` - The height of the buffer (default: 24)\n  * `:scrollback_height` - The maximum number of scrollback lines (default: 1000)\n  * `:memory_limit` - The maximum memory usage in bytes (default: 10_000_000)","title":"Options - Raxol.Terminal.Buffer.Manager.start_link/1","ref":"Raxol.Terminal.Buffer.Manager.html#start_link/1-options"},{"type":"function","doc":"iex> {:ok, pid} = Buffer.Manager.start_link(width: 100, height: 30)\n    iex> Process.alive?(pid)\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.start_link/1","ref":"Raxol.Terminal.Buffer.Manager.html#start_link/1-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Buffer.Manager.t/0","ref":"Raxol.Terminal.Buffer.Manager.html#t:t/0"},{"type":"function","doc":"Updates the memory usage for the buffer manager.","title":"Raxol.Terminal.Buffer.Manager.update_memory_usage/1","ref":"Raxol.Terminal.Buffer.Manager.html#update_memory_usage/1"},{"type":"module","doc":"Handles buffer operations and synchronization for the terminal.\nProvides functionality for buffer manipulation, double buffering, and synchronization.","title":"Raxol.Terminal.Buffer.Manager.Buffer","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html"},{"type":"function","doc":"Clears the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.clear/1","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#clear/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Buffer.clear(state)\n    iex> Buffer.get_cell(state, 0, 0)\n    %Cell{char: \" \", fg: :default, bg: :default}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.clear/1","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#clear/1-examples"},{"type":"function","doc":"Copies a region from one position to another in the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.copy_region/7","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#copy_region/7"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> cell = %Cell{char: \"A\", fg: :red, bg: :blue}\n    iex> state = Buffer.set_cell(state, 0, 0, cell)\n    iex> state = Buffer.copy_region(state, 0, 0, 10, 0, 5, 5)\n    iex> Buffer.get_cell(state, 10, 0)\n    %Cell{char: \"A\", fg: :red, bg: :blue}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.copy_region/7","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#copy_region/7-examples"},{"type":"function","doc":"Fills a region in the active buffer with a cell.","title":"Raxol.Terminal.Buffer.Manager.Buffer.fill_region/6","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#fill_region/6"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> cell = %Cell{char: \"X\", fg: :red, bg: :blue}\n    iex> state = Buffer.fill_region(state, 0, 0, 10, 5, cell)\n    iex> Buffer.get_cell(state, 5, 2)\n    %Cell{char: \"X\", fg: :red, bg: :blue}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.fill_region/6","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#fill_region/6-examples"},{"type":"function","doc":"Gets a cell from the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.get_cell/3","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#get_cell/3"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Buffer.get_cell(state, 0, 0)\n    %Cell{char: \" \", fg: :default, bg: :default}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.get_cell/3","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#get_cell/3-examples"},{"type":"function","doc":"Gets the differences between the active and back buffers.","title":"Raxol.Terminal.Buffer.Manager.Buffer.get_differences/1","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#get_differences/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> cell = %Cell{char: \"A\", fg: :red, bg: :blue}\n    iex> state = Buffer.set_cell(state, 0, 0, cell)\n    iex> Buffer.get_differences(state)\n    [{0, 0, %Cell{char: \"A\", fg: :red, bg: :blue}}]","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.get_differences/1","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#get_differences/1-examples"},{"type":"function","doc":"Creates a new buffer with the specified dimensions.","title":"Raxol.Terminal.Buffer.Manager.Buffer.new/2","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#new/2"},{"type":"function","doc":"iex> Buffer.new(80, 24)\n    %Buffer{width: 80, height: 24, cells: %{}}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.new/2","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#new/2-examples"},{"type":"function","doc":"Resizes the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.resize/3","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#resize/3"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Buffer.resize(state, 100, 30)\n    iex> state.active_buffer.width\n    100\n    iex> state.active_buffer.height\n    30","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.resize/3","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#resize/3-examples"},{"type":"function","doc":"Scrolls a region in the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.scroll_region/6","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#scroll_region/6"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Buffer.scroll_region(state, 0, 0, 10, 5, 2)\n    iex> Buffer.get_cell(state, 0, 2)\n    %Cell{char: \" \", fg: :default, bg: :default}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.scroll_region/6","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#scroll_region/6-examples"},{"type":"function","doc":"Sets a cell in the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.set_cell/4","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#set_cell/4"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> cell = %Cell{char: \"A\", fg: :red, bg: :blue}\n    iex> state = Buffer.set_cell(state, 0, 0, cell)\n    iex> Buffer.get_cell(state, 0, 0)\n    %Cell{char: \"A\", fg: :red, bg: :blue}","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.set_cell/4","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#set_cell/4-examples"},{"type":"function","doc":"Synchronizes the back buffer with the active buffer.","title":"Raxol.Terminal.Buffer.Manager.Buffer.sync_buffers/1","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#sync_buffers/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Buffer.sync_buffers(state)\n    iex> state.active_buffer == state.back_buffer\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.Buffer.sync_buffers/1","ref":"Raxol.Terminal.Buffer.Manager.Buffer.html#sync_buffers/1-examples"},{"type":"module","doc":"Handles cursor management for the terminal buffer.\nProvides functionality for cursor position tracking and movement.","title":"Raxol.Terminal.Buffer.Manager.Cursor","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html"},{"type":"function","doc":"Gets the current cursor position.","title":"Raxol.Terminal.Buffer.Manager.Cursor.get_position/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#get_position/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Cursor.get_position(state)\n    {0, 0}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.get_position/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#get_position/1-examples"},{"type":"function","doc":"Moves the cursor relative to its current position.","title":"Raxol.Terminal.Buffer.Manager.Cursor.move/3","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move/3"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Cursor.move(state, 5, 3)\n    iex> Cursor.get_position(state)\n    {5, 3}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.move/3","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move/3-examples"},{"type":"function","doc":"Moves the cursor to the bottom of the screen.","title":"Raxol.Terminal.Buffer.Manager.Cursor.move_to_bottom/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_bottom/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Cursor.set_position(state, 10, 5)\n    iex> state = Cursor.move_to_bottom(state)\n    iex> Cursor.get_position(state)\n    {10, 23}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.move_to_bottom/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_bottom/1-examples"},{"type":"function","doc":"Moves the cursor to the end of the line.","title":"Raxol.Terminal.Buffer.Manager.Cursor.move_to_line_end/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_line_end/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Cursor.set_position(state, 10, 5)\n    iex> state = Cursor.move_to_line_end(state)\n    iex> Cursor.get_position(state)\n    {79, 5}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.move_to_line_end/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_line_end/1-examples"},{"type":"function","doc":"Moves the cursor to the beginning of the line.","title":"Raxol.Terminal.Buffer.Manager.Cursor.move_to_line_start/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_line_start/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Cursor.set_position(state, 10, 5)\n    iex> state = Cursor.move_to_line_start(state)\n    iex> Cursor.get_position(state)\n    {0, 5}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.move_to_line_start/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_line_start/1-examples"},{"type":"function","doc":"Moves the cursor to the top of the screen.","title":"Raxol.Terminal.Buffer.Manager.Cursor.move_to_top/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_top/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Cursor.set_position(state, 10, 5)\n    iex> state = Cursor.move_to_top(state)\n    iex> Cursor.get_position(state)\n    {10, 0}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.move_to_top/1","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#move_to_top/1-examples"},{"type":"function","doc":"Sets the cursor position in the buffer state.","title":"Raxol.Terminal.Buffer.Manager.Cursor.set_position/3","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#set_position/3"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Cursor.set_position(state, 10, 5)\n    iex> Cursor.get_position(state)\n    {10, 5}","title":"Examples - Raxol.Terminal.Buffer.Manager.Cursor.set_position/3","ref":"Raxol.Terminal.Buffer.Manager.Cursor.html#set_position/3-examples"},{"type":"module","doc":"Handles damage tracking for the terminal buffer.\nProvides functionality for tracking and managing damaged regions.","title":"Raxol.Terminal.Buffer.Manager.Damage","ref":"Raxol.Terminal.Buffer.Manager.Damage.html"},{"type":"function","doc":"Clears all damage regions.","title":"Raxol.Terminal.Buffer.Manager.Damage.clear_regions/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#clear_regions/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_region(state, 0, 0, 10, 5)\n    iex> state = Damage.clear_regions(state)\n    iex> length(Damage.get_regions(state))\n    0","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.clear_regions/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#clear_regions/1-examples"},{"type":"function","doc":"Gets all damaged regions.","title":"Raxol.Terminal.Buffer.Manager.Damage.get_regions/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#get_regions/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_region(state, 0, 0, 10, 5)\n    iex> regions = Damage.get_regions(state)\n    iex> length(regions)\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.get_regions/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#get_regions/1-examples"},{"type":"function","doc":"Marks the entire visible region as damaged.","title":"Raxol.Terminal.Buffer.Manager.Damage.mark_all/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_all/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_all(state)\n    iex> length(Damage.get_regions(state))\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.mark_all/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_all/1-examples"},{"type":"function","doc":"Marks a column as damaged.","title":"Raxol.Terminal.Buffer.Manager.Damage.mark_column/2","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_column/2"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_column(state, 10)\n    iex> length(Damage.get_regions(state))\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.mark_column/2","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_column/2-examples"},{"type":"function","doc":"Marks a line as damaged.","title":"Raxol.Terminal.Buffer.Manager.Damage.mark_line/2","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_line/2"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_line(state, 5)\n    iex> length(Damage.get_regions(state))\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.mark_line/2","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_line/2-examples"},{"type":"function","doc":"Marks a region of the buffer as damaged.","title":"Raxol.Terminal.Buffer.Manager.Damage.mark_region/5","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_region/5"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_region(state, 0, 0, 10, 5)\n    iex> length(Damage.get_regions(state))\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.mark_region/5","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#mark_region/5-examples"},{"type":"function","doc":"Merges overlapping damage regions.","title":"Raxol.Terminal.Buffer.Manager.Damage.merge_regions/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#merge_regions/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Damage.mark_region(state, 0, 0, 10, 5)\n    iex> state = Damage.mark_region(state, 5, 0, 15, 5)\n    iex> state = Damage.merge_regions(state)\n    iex> length(Damage.get_regions(state))\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Damage.merge_regions/1","ref":"Raxol.Terminal.Buffer.Manager.Damage.html#merge_regions/1-examples"},{"type":"module","doc":"Handles memory management for the terminal buffer.\nProvides functionality for tracking memory usage and enforcing limits.","title":"Raxol.Terminal.Buffer.Manager.Memory","ref":"Raxol.Terminal.Buffer.Manager.Memory.html"},{"type":"function","doc":"Calculates memory usage for a specific buffer.","title":"Raxol.Terminal.Buffer.Manager.Memory.calculate_buffer_usage/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#calculate_buffer_usage/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Memory.calculate_buffer_usage(state.active_buffer) > 0\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.calculate_buffer_usage/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#calculate_buffer_usage/1-examples"},{"type":"function","doc":"Estimates memory usage for a given buffer size.","title":"Raxol.Terminal.Buffer.Manager.Memory.estimate_usage/3","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#estimate_usage/3"},{"type":"function","doc":"iex> Memory.estimate_usage(80, 24, 1000) > 0\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.estimate_usage/3","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#estimate_usage/3-examples"},{"type":"function","doc":"Gets the memory limit.","title":"Raxol.Terminal.Buffer.Manager.Memory.get_limit/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#get_limit/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Memory.get_limit(state)\n    10_000_000","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.get_limit/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#get_limit/1-examples"},{"type":"function","doc":"Gets the current memory usage.","title":"Raxol.Terminal.Buffer.Manager.Memory.get_usage/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#get_usage/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Memory.update_usage(state)\n    iex> Memory.get_usage(state) > 0\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.get_usage/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#get_usage/1-examples"},{"type":"function","doc":"Sets a new memory limit.","title":"Raxol.Terminal.Buffer.Manager.Memory.set_limit/2","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#set_limit/2"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Memory.set_limit(state, 5_000_000)\n    iex> Memory.get_limit(state)\n    5_000_000","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.set_limit/2","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#set_limit/2-examples"},{"type":"function","doc":"Updates memory usage tracking.","title":"Raxol.Terminal.Buffer.Manager.Memory.update_usage/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#update_usage/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Memory.update_usage(state)\n    iex> state.memory_usage > 0\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.update_usage/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#update_usage/1-examples"},{"type":"function","doc":"Checks if memory usage is within limits.","title":"Raxol.Terminal.Buffer.Manager.Memory.within_limits?/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#within_limits?/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Memory.within_limits?(state)\n    true","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.within_limits?/1","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#within_limits?/1-examples"},{"type":"function","doc":"Checks if a given buffer size would exceed memory limits.","title":"Raxol.Terminal.Buffer.Manager.Memory.would_exceed_limit?/4","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#would_exceed_limit?/4"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Memory.would_exceed_limit?(state, 100, 50, 2000)\n    false","title":"Examples - Raxol.Terminal.Buffer.Manager.Memory.would_exceed_limit?/4","ref":"Raxol.Terminal.Buffer.Manager.Memory.html#would_exceed_limit?/4-examples"},{"type":"module","doc":"Handles scrollback buffer management for the terminal.\nProvides functionality for managing scrollback history and operations.","title":"Raxol.Terminal.Buffer.Manager.Scrollback","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html"},{"type":"function","doc":"Adds a line to the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.add_line/2","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#add_line/2"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Hello, World!\")\n    iex> Scrollback.get_line(state, 0)\n    \"Hello, World!\"","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.add_line/2","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#add_line/2-examples"},{"type":"function","doc":"Clears the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.clear/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#clear/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Hello, World!\")\n    iex> state = Scrollback.clear(state)\n    iex> Scrollback.get_line_count(state)\n    0","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.clear/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#clear/1-examples"},{"type":"function","doc":"Gets the scrollback height limit.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.get_height/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_height/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Scrollback.get_height(state)\n    1000","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.get_height/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_height/1-examples"},{"type":"function","doc":"Gets a line from the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.get_line/2","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_line/2"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Hello, World!\")\n    iex> Scrollback.get_line(state, 0)\n    \"Hello, World!\"","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.get_line/2","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_line/2-examples"},{"type":"function","doc":"Gets the number of lines in the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.get_line_count/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_line_count/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Hello, World!\")\n    iex> Scrollback.get_line_count(state)\n    1","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.get_line_count/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_line_count/1-examples"},{"type":"function","doc":"Gets a range of lines from the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.get_lines/3","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_lines/3"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Line 1\")\n    iex> state = Scrollback.add_line(state, \"Line 2\")\n    iex> Scrollback.get_lines(state, 0, 2)\n    [\"Line 1\", \"Line 2\"]","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.get_lines/3","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_lines/3-examples"},{"type":"function","doc":"Gets the newest line in the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.get_newest_line/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_newest_line/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Newest line\")\n    iex> Scrollback.get_newest_line(state)\n    \"Newest line\"","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.get_newest_line/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_newest_line/1-examples"},{"type":"function","doc":"Gets the oldest line in the scrollback buffer.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.get_oldest_line/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_oldest_line/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.add_line(state, \"Oldest line\")\n    iex> Scrollback.get_oldest_line(state)\n    \"Oldest line\"","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.get_oldest_line/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#get_oldest_line/1-examples"},{"type":"function","doc":"Checks if the scrollback buffer is full.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.is_full?/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#is_full?/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> Scrollback.is_full?(state)\n    false","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.is_full?/1","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#is_full?/1-examples"},{"type":"function","doc":"Sets a new scrollback height limit.","title":"Raxol.Terminal.Buffer.Manager.Scrollback.set_height/2","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#set_height/2"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = Scrollback.set_height(state, 2000)\n    iex> Scrollback.get_height(state)\n    2000","title":"Examples - Raxol.Terminal.Buffer.Manager.Scrollback.set_height/2","ref":"Raxol.Terminal.Buffer.Manager.Scrollback.html#set_height/2-examples"},{"type":"module","doc":"Handles state management for the terminal buffer manager.\nProvides functionality for initializing and managing buffer state.","title":"Raxol.Terminal.Buffer.Manager.State","ref":"Raxol.Terminal.Buffer.Manager.State.html"},{"type":"function","doc":"Gets the current dimensions of the buffer.","title":"Raxol.Terminal.Buffer.Manager.State.get_dimensions/1","ref":"Raxol.Terminal.Buffer.Manager.State.html#get_dimensions/1"},{"type":"function","doc":"Gets the scrollback height.","title":"Raxol.Terminal.Buffer.Manager.State.get_scrollback_height/1","ref":"Raxol.Terminal.Buffer.Manager.State.html#get_scrollback_height/1"},{"type":"function","doc":"Creates a new buffer manager state with the given dimensions.","title":"Raxol.Terminal.Buffer.Manager.State.new/4","ref":"Raxol.Terminal.Buffer.Manager.State.html#new/4"},{"type":"function","doc":"iex> {:ok, state} = State.new(80, 24)\n    iex> state.active_buffer.width\n    80\n    iex> state.active_buffer.height\n    24","title":"Examples - Raxol.Terminal.Buffer.Manager.State.new/4","ref":"Raxol.Terminal.Buffer.Manager.State.html#new/4-examples"},{"type":"function","doc":"Switches the active and back buffers.","title":"Raxol.Terminal.Buffer.Manager.State.switch_buffers/1","ref":"Raxol.Terminal.Buffer.Manager.State.html#switch_buffers/1"},{"type":"function","doc":"iex> state = State.new(80, 24)\n    iex> state = State.switch_buffers(state)\n    iex> state.active_buffer == state.back_buffer\n    false","title":"Examples - Raxol.Terminal.Buffer.Manager.State.switch_buffers/1","ref":"Raxol.Terminal.Buffer.Manager.State.html#switch_buffers/1-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Buffer.Manager.State.t/0","ref":"Raxol.Terminal.Buffer.Manager.State.html#t:t/0"},{"type":"function","doc":"Updates the active buffer in the state.","title":"Raxol.Terminal.Buffer.Manager.State.update_active_buffer/2","ref":"Raxol.Terminal.Buffer.Manager.State.html#update_active_buffer/2"},{"type":"function","doc":"Updates the back buffer in the state.","title":"Raxol.Terminal.Buffer.Manager.State.update_back_buffer/2","ref":"Raxol.Terminal.Buffer.Manager.State.html#update_back_buffer/2"},{"type":"module","doc":"Handles calculation and checking of terminal buffer memory usage.","title":"Raxol.Terminal.Buffer.MemoryManager","ref":"Raxol.Terminal.Buffer.MemoryManager.html"},{"type":"function","doc":"Calculates the approximate memory usage of a single screen buffer.\n\nThis is a rough estimation based on buffer dimensions and an estimated cell size.","title":"Raxol.Terminal.Buffer.MemoryManager.calculate_buffer_usage/1","ref":"Raxol.Terminal.Buffer.MemoryManager.html#calculate_buffer_usage/1"},{"type":"function","doc":"Calculates the total approximate memory usage for two buffers (active and back).","title":"Raxol.Terminal.Buffer.MemoryManager.get_total_usage/2","ref":"Raxol.Terminal.Buffer.MemoryManager.html#get_total_usage/2"},{"type":"function","doc":"Checks if the given memory usage is within the specified limit.","title":"Raxol.Terminal.Buffer.MemoryManager.is_within_limit?/2","ref":"Raxol.Terminal.Buffer.MemoryManager.html#is_within_limit?/2"},{"type":"module","doc":"Provides functions for manipulating the Raxol.Terminal.ScreenBuffer grid and state.\nIncludes writing, clearing, deleting, inserting, resizing, and other operations.","title":"Raxol.Terminal.Buffer.Operations","ref":"Raxol.Terminal.Buffer.Operations.html"},{"type":"function","doc":"Clears the entire screen buffer (excluding scrollback) with empty cells.","title":"Raxol.Terminal.Buffer.Operations.clear/2","ref":"Raxol.Terminal.Buffer.Operations.html#clear/2"},{"type":"function","doc":"Clears a rectangular region of the buffer by replacing cells with empty cells.","title":"Raxol.Terminal.Buffer.Operations.clear_region/6","ref":"Raxol.Terminal.Buffer.Operations.html#clear_region/6"},{"type":"function","doc":"Clears the scroll region setting in the buffer.","title":"Raxol.Terminal.Buffer.Operations.clear_scroll_region/1","ref":"Raxol.Terminal.Buffer.Operations.html#clear_scroll_region/1"},{"type":"function","doc":"Deletes characters at the cursor position {x, y}, shifting remaining chars left.\nDelegates to `CharEditor.delete_characters/5`.","title":"Raxol.Terminal.Buffer.Operations.delete_characters/5","ref":"Raxol.Terminal.Buffer.Operations.html#delete_characters/5"},{"type":"function","doc":"Calculates the difference between the current buffer state and a list of desired cell changes.\nReturns a list of {x, y, cell_map} tuples representing only the cells that need to be updated.\nInput `changes` must be a list of {x, y, map} tuples.","title":"Raxol.Terminal.Buffer.Operations.diff/2","ref":"Raxol.Terminal.Buffer.Operations.html#diff/2"},{"type":"function","doc":"Erases parts of the display based on cursor position (:to_end, :to_beginning, :all).\nRequires cursor state {x, y}.","title":"Raxol.Terminal.Buffer.Operations.erase_in_display/4","ref":"Raxol.Terminal.Buffer.Operations.html#erase_in_display/4"},{"type":"function","doc":"Erases parts of the current line based on cursor position (:to_end, :to_beginning, :all).\nRequires cursor state {x, y}.","title":"Raxol.Terminal.Buffer.Operations.erase_in_line/4","ref":"Raxol.Terminal.Buffer.Operations.html#erase_in_line/4"},{"type":"function","doc":"Gets a specific Cell from the buffer at {x, y}.\nReturns nil if coordinates are out of bounds.","title":"Raxol.Terminal.Buffer.Operations.get_cell/3","ref":"Raxol.Terminal.Buffer.Operations.html#get_cell/3"},{"type":"function","doc":"Gets the cell at the specified coordinates {x, y}.\nReturns nil if coordinates are out of bounds. Alias for get_cell/3.","title":"Raxol.Terminal.Buffer.Operations.get_cell_at/3","ref":"Raxol.Terminal.Buffer.Operations.html#get_cell_at/3"},{"type":"function","doc":"Converts the screen buffer content to a plain text string.","title":"Raxol.Terminal.Buffer.Operations.get_content/1","ref":"Raxol.Terminal.Buffer.Operations.html#get_content/1"},{"type":"function","doc":"Gets the dimensions {width, height} of the screen buffer.","title":"Raxol.Terminal.Buffer.Operations.get_dimensions/1","ref":"Raxol.Terminal.Buffer.Operations.html#get_dimensions/1"},{"type":"function","doc":"Gets the current height of the screen buffer.","title":"Raxol.Terminal.Buffer.Operations.get_height/1","ref":"Raxol.Terminal.Buffer.Operations.html#get_height/1"},{"type":"function","doc":"Gets a specific line (list of Cells) from the buffer by index.\nReturns nil if index is out of bounds.","title":"Raxol.Terminal.Buffer.Operations.get_line/2","ref":"Raxol.Terminal.Buffer.Operations.html#get_line/2"},{"type":"function","doc":"Gets the current width of the screen buffer.","title":"Raxol.Terminal.Buffer.Operations.get_width/1","ref":"Raxol.Terminal.Buffer.Operations.html#get_width/1"},{"type":"function","doc":"Inserts blank characters at the cursor position {x, y}, shifting existing chars right.\nDelegates to `CharEditor.insert_characters/5`.","title":"Raxol.Terminal.Buffer.Operations.insert_characters/5","ref":"Raxol.Terminal.Buffer.Operations.html#insert_characters/5"},{"type":"function","doc":"Resizes the screen buffer to the new dimensions.\nPreserves content that fits within the new bounds. Clears selection and scroll region.","title":"Raxol.Terminal.Buffer.Operations.resize/3","ref":"Raxol.Terminal.Buffer.Operations.html#resize/3"},{"type":"function","doc":"Scrolls the buffer down by the specified number of lines, optionally within a specified scroll region.\nHandles cell manipulation using provided lines from scrollback.\nExpects `lines_to_insert` from the caller (e.g., Buffer.Manager via Buffer.Scrollback).","title":"Raxol.Terminal.Buffer.Operations.scroll_down/4","ref":"Raxol.Terminal.Buffer.Operations.html#scroll_down/4"},{"type":"function","doc":"Scrolls the buffer up by the specified number of lines, optionally within a specified scroll region.\nHandles cell manipulation.\nReturns `{updated_buffer, scrolled_off_lines}`.","title":"Raxol.Terminal.Buffer.Operations.scroll_up/3","ref":"Raxol.Terminal.Buffer.Operations.html#scroll_up/3"},{"type":"function","doc":"Sets a scroll region in the buffer.","title":"Raxol.Terminal.Buffer.Operations.set_scroll_region/3","ref":"Raxol.Terminal.Buffer.Operations.html#set_scroll_region/3"},{"type":"function","doc":"Updates the buffer state by applying a list of cell changes.\nChanges must be in the format {x, y, Cell.t() | map()}.\nReturns the updated buffer.","title":"Raxol.Terminal.Buffer.Operations.update/2","ref":"Raxol.Terminal.Buffer.Operations.html#update/2"},{"type":"function","doc":"Writes a character to the buffer at the specified position.\nHandles wide characters by taking up two cells when necessary.\nAccepts an optional style to apply to the cell.","title":"Raxol.Terminal.Buffer.Operations.write_char/5","ref":"Raxol.Terminal.Buffer.Operations.html#write_char/5"},{"type":"function","doc":"Writes a string to the buffer at the specified position.\nHandles wide characters and bidirectional text.","title":"Raxol.Terminal.Buffer.Operations.write_string/4","ref":"Raxol.Terminal.Buffer.Operations.html#write_string/4"},{"type":"module","doc":"Terminal scroll buffer module.\n\nThis module handles the management of terminal scrollback buffers, including:\n- Virtual scrolling implementation\n- Memory-efficient buffer management\n- Scroll position tracking\n- Buffer compression","title":"Raxol.Terminal.Buffer.Scroll","ref":"Raxol.Terminal.Buffer.Scroll.html"},{"type":"function","doc":"Adds a line to the scroll buffer.","title":"Raxol.Terminal.Buffer.Scroll.add_line/2","ref":"Raxol.Terminal.Buffer.Scroll.html#add_line/2"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> scroll.height\n    1","title":"Examples - Raxol.Terminal.Buffer.Scroll.add_line/2","ref":"Raxol.Terminal.Buffer.Scroll.html#add_line/2-examples"},{"type":"function","doc":"Clears the scroll buffer.","title":"Raxol.Terminal.Buffer.Scroll.clear/1","ref":"Raxol.Terminal.Buffer.Scroll.html#clear/1"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> scroll = Scroll.clear(scroll)\n    iex> scroll.height\n    0","title":"Examples - Raxol.Terminal.Buffer.Scroll.clear/1","ref":"Raxol.Terminal.Buffer.Scroll.html#clear/1-examples"},{"type":"function","doc":"Gets the total height of the scroll buffer.","title":"Raxol.Terminal.Buffer.Scroll.get_height/1","ref":"Raxol.Terminal.Buffer.Scroll.html#get_height/1"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> Scroll.get_height(scroll)\n    1","title":"Examples - Raxol.Terminal.Buffer.Scroll.get_height/1","ref":"Raxol.Terminal.Buffer.Scroll.html#get_height/1-examples"},{"type":"function","doc":"Gets the current scroll position.","title":"Raxol.Terminal.Buffer.Scroll.get_position/1","ref":"Raxol.Terminal.Buffer.Scroll.html#get_position/1"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> Scroll.get_position(scroll)\n    0","title":"Examples - Raxol.Terminal.Buffer.Scroll.get_position/1","ref":"Raxol.Terminal.Buffer.Scroll.html#get_position/1-examples"},{"type":"function","doc":"Gets a view of the scroll buffer at the current position.","title":"Raxol.Terminal.Buffer.Scroll.get_view/2","ref":"Raxol.Terminal.Buffer.Scroll.html#get_view/2"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> view = Scroll.get_view(scroll, 10)\n    iex> length(view)\n    1","title":"Examples - Raxol.Terminal.Buffer.Scroll.get_view/2","ref":"Raxol.Terminal.Buffer.Scroll.html#get_view/2-examples"},{"type":"function","doc":"Creates a new scroll buffer with the given dimensions.","title":"Raxol.Terminal.Buffer.Scroll.new/2","ref":"Raxol.Terminal.Buffer.Scroll.html#new/2"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> scroll.max_height\n    1000\n    iex> scroll.position\n    0","title":"Examples - Raxol.Terminal.Buffer.Scroll.new/2","ref":"Raxol.Terminal.Buffer.Scroll.html#new/2-examples"},{"type":"function","doc":"Scrolls the buffer by the given amount.","title":"Raxol.Terminal.Buffer.Scroll.scroll/2","ref":"Raxol.Terminal.Buffer.Scroll.html#scroll/2"},{"type":"function","doc":"iex> scroll = Scroll.new(1000)\n    iex> line = [Cell.new(\"A\"), Cell.new(\"B\")]\n    iex> scroll = Scroll.add_line(scroll, line)\n    iex> scroll = Scroll.scroll(scroll, 5)\n    iex> scroll.position\n    5","title":"Examples - Raxol.Terminal.Buffer.Scroll.scroll/2","ref":"Raxol.Terminal.Buffer.Scroll.html#scroll/2-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Buffer.Scroll.t/0","ref":"Raxol.Terminal.Buffer.Scroll.html#t:t/0"},{"type":"module","doc":"Manages the scrollback buffer lines.\n\nStores lines scrolled off the top and provides them when scrolling down.\nEnforces a configurable size limit.","title":"Raxol.Terminal.Buffer.Scrollback","ref":"Raxol.Terminal.Buffer.Scrollback.html"},{"type":"function","doc":"Adds new lines to the top of the scrollback buffer.\n\nLines are prepended. The buffer is trimmed to the limit if necessary.","title":"Raxol.Terminal.Buffer.Scrollback.add_lines/2","ref":"Raxol.Terminal.Buffer.Scrollback.html#add_lines/2"},{"type":"function","doc":"Clears all lines from the scrollback buffer.","title":"Raxol.Terminal.Buffer.Scrollback.clear/1","ref":"Raxol.Terminal.Buffer.Scrollback.html#clear/1"},{"type":"function","doc":"Creates a new scrollback buffer with a given limit.","title":"Raxol.Terminal.Buffer.Scrollback.new/1","ref":"Raxol.Terminal.Buffer.Scrollback.html#new/1"},{"type":"function","doc":"Gets the current number of lines stored in the scrollback buffer.","title":"Raxol.Terminal.Buffer.Scrollback.size/1","ref":"Raxol.Terminal.Buffer.Scrollback.html#size/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Buffer.Scrollback.t/0","ref":"Raxol.Terminal.Buffer.Scrollback.html#t:t/0"},{"type":"function","doc":"Takes a number of lines from the top of the scrollback buffer.\n\nUsed when scrolling down to restore lines.\nReturns a tuple: `{restored_lines, updated_scrollback_state}`.\nFewer lines than requested may be returned if the buffer is smaller.","title":"Raxol.Terminal.Buffer.Scrollback.take_lines/2","ref":"Raxol.Terminal.Buffer.Scrollback.html#take_lines/2"},{"type":"module","doc":"Handles scrolling operations (up and down) within the Raxol.Terminal.ScreenBuffer,\nconsidering scroll regions.","title":"Raxol.Terminal.Buffer.Scroller","ref":"Raxol.Terminal.Buffer.Scroller.html"},{"type":"function","doc":"Scrolls the buffer down by the specified number of lines, optionally within a specified scroll region.\nHandles cell manipulation using provided lines from scrollback.\nExpects `lines_to_insert` from the caller (e.g., Buffer.Manager via Buffer.Scrollback).","title":"Raxol.Terminal.Buffer.Scroller.scroll_down/4","ref":"Raxol.Terminal.Buffer.Scroller.html#scroll_down/4"},{"type":"function","doc":"Scrolls the buffer up by the specified number of lines, optionally within a specified scroll region.\nHandles cell manipulation.\nReturns `{updated_buffer, scrolled_off_lines}`.","title":"Raxol.Terminal.Buffer.Scroller.scroll_up/3","ref":"Raxol.Terminal.Buffer.Scroller.html#scroll_up/3"},{"type":"module","doc":"Handles text selection within the Raxol.Terminal.ScreenBuffer.","title":"Raxol.Terminal.Buffer.Selection","ref":"Raxol.Terminal.Buffer.Selection.html"},{"type":"function","doc":"Checks if a position (x, y) is within the current selection in the buffer.","title":"Raxol.Terminal.Buffer.Selection.contains?/3","ref":"Raxol.Terminal.Buffer.Selection.html#contains?/3"},{"type":"function","doc":"Gets the boundaries {start_x, start_y, end_x, end_y} of the current selection.\nReturns nil if there is no selection.","title":"Raxol.Terminal.Buffer.Selection.get_boundaries/1","ref":"Raxol.Terminal.Buffer.Selection.html#get_boundaries/1"},{"type":"function","doc":"Gets the text within the current selection in the buffer.","title":"Raxol.Terminal.Buffer.Selection.get_text/1","ref":"Raxol.Terminal.Buffer.Selection.html#get_text/1"},{"type":"function","doc":"Gets the text within a specified rectangular region of the buffer.\nCoordinates are inclusive.","title":"Raxol.Terminal.Buffer.Selection.get_text_in_region/5","ref":"Raxol.Terminal.Buffer.Selection.html#get_text_in_region/5"},{"type":"function","doc":"Starts a selection at the specified coordinates in the buffer.","title":"Raxol.Terminal.Buffer.Selection.start/3","ref":"Raxol.Terminal.Buffer.Selection.html#start/3"},{"type":"function","doc":"Updates the endpoint of the current selection in the buffer.","title":"Raxol.Terminal.Buffer.Selection.update/3","ref":"Raxol.Terminal.Buffer.Selection.html#update/3"},{"type":"module","doc":"Handles state management and accessors for the Raxol.Terminal.ScreenBuffer.\nIncludes resizing, getting dimensions, accessing cells/lines, managing scroll regions,\nand getting content.","title":"Raxol.Terminal.Buffer.State","ref":"Raxol.Terminal.Buffer.State.html"},{"type":"function","doc":"Clears the scroll region setting in the buffer.","title":"Raxol.Terminal.Buffer.State.clear_scroll_region/1","ref":"Raxol.Terminal.Buffer.State.html#clear_scroll_region/1"},{"type":"function","doc":"Gets a specific Cell from the buffer at {x, y}.\nReturns nil if coordinates are out of bounds.","title":"Raxol.Terminal.Buffer.State.get_cell/3","ref":"Raxol.Terminal.Buffer.State.html#get_cell/3"},{"type":"function","doc":"Gets the cell at the specified coordinates {x, y}.\nReturns nil if coordinates are out of bounds. Alias for get_cell/3.","title":"Raxol.Terminal.Buffer.State.get_cell_at/3","ref":"Raxol.Terminal.Buffer.State.html#get_cell_at/3"},{"type":"function","doc":"Converts the screen buffer content to a plain text string.","title":"Raxol.Terminal.Buffer.State.get_content/1","ref":"Raxol.Terminal.Buffer.State.html#get_content/1"},{"type":"function","doc":"Gets the dimensions {width, height} of the screen buffer.","title":"Raxol.Terminal.Buffer.State.get_dimensions/1","ref":"Raxol.Terminal.Buffer.State.html#get_dimensions/1"},{"type":"function","doc":"Gets the current height of the screen buffer.","title":"Raxol.Terminal.Buffer.State.get_height/1","ref":"Raxol.Terminal.Buffer.State.html#get_height/1"},{"type":"function","doc":"Gets a specific line (list of Cells) from the buffer by index.\nReturns nil if index is out of bounds.","title":"Raxol.Terminal.Buffer.State.get_line/2","ref":"Raxol.Terminal.Buffer.State.html#get_line/2"},{"type":"function","doc":"Gets the boundaries {top, bottom} of the current scroll region.\nReturns {0, height - 1} if no region is set.","title":"Raxol.Terminal.Buffer.State.get_scroll_region_boundaries/1","ref":"Raxol.Terminal.Buffer.State.html#get_scroll_region_boundaries/1"},{"type":"function","doc":"Gets the current width of the screen buffer.","title":"Raxol.Terminal.Buffer.State.get_width/1","ref":"Raxol.Terminal.Buffer.State.html#get_width/1"},{"type":"function","doc":"Resizes the screen buffer to the new dimensions.\nPreserves content that fits within the new bounds. Clears selection and scroll region.","title":"Raxol.Terminal.Buffer.State.resize/3","ref":"Raxol.Terminal.Buffer.State.html#resize/3"},{"type":"function","doc":"Sets a scroll region in the buffer.","title":"Raxol.Terminal.Buffer.State.set_scroll_region/3","ref":"Raxol.Terminal.Buffer.State.html#set_scroll_region/3"},{"type":"module","doc":"Handles calculating differences and applying updates to the Raxol.Terminal.ScreenBuffer.","title":"Raxol.Terminal.Buffer.Updater","ref":"Raxol.Terminal.Buffer.Updater.html"},{"type":"function","doc":"Calculates the difference between the current buffer state and a list of desired cell changes.\nReturns a list of {x, y, cell_map} tuples representing only the cells that need to be updated.\nInput `changes` must be a list of {x, y, map} tuples.","title":"Raxol.Terminal.Buffer.Updater.diff/2","ref":"Raxol.Terminal.Buffer.Updater.html#diff/2"},{"type":"function","doc":"Updates the buffer state by applying a list of cell changes.\nChanges must be in the format {x, y, Cell.t() | map()}.\nReturns the updated buffer.","title":"Raxol.Terminal.Buffer.Updater.update/2","ref":"Raxol.Terminal.Buffer.Updater.html#update/2"},{"type":"module","doc":"Handles writing characters and strings to the Raxol.Terminal.ScreenBuffer.\nResponsible for character width, bidirectional text segmentation, and cell creation.","title":"Raxol.Terminal.Buffer.Writer","ref":"Raxol.Terminal.Buffer.Writer.html"},{"type":"function","doc":"Writes a character to the buffer at the specified position.\nHandles wide characters by taking up two cells when necessary.\nAccepts an optional style to apply to the cell.","title":"Raxol.Terminal.Buffer.Writer.write_char/5","ref":"Raxol.Terminal.Buffer.Writer.html#write_char/5"},{"type":"function","doc":"Writes a string to the buffer at the specified position.\nHandles wide characters and bidirectional text.","title":"Raxol.Terminal.Buffer.Writer.write_string/4","ref":"Raxol.Terminal.Buffer.Writer.html#write_string/4"},{"type":"module","doc":"Terminal character cell module.\n\nThis module handles the representation and manipulation of individual\ncharacter cells in the terminal screen buffer, including:\n- Character content\n- Text attributes (color, style)\n- Cell state","title":"Raxol.Terminal.Cell","ref":"Raxol.Terminal.Cell.html"},{"type":"function","doc":"Creates a deep copy of a cell.","title":"Raxol.Terminal.Cell.copy/1","ref":"Raxol.Terminal.Cell.html#copy/1"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> copy = Cell.copy(cell)\n    iex> Cell.get_char(copy)\n    \"A\"\n    iex> Cell.get_style(copy)\n    %{foreground: :red}","title":"Examples - Raxol.Terminal.Cell.copy/1","ref":"Raxol.Terminal.Cell.html#copy/1-examples"},{"type":"function","doc":"Checks if the cell is in double-height mode.","title":"Raxol.Terminal.Cell.double_height?/1","ref":"Raxol.Terminal.Cell.html#double_height?/1"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.double_height?(cell)\n    false","title":"Examples - Raxol.Terminal.Cell.double_height?/1","ref":"Raxol.Terminal.Cell.html#double_height?/1-examples"},{"type":"function","doc":"Checks if the cell is in double-width mode.","title":"Raxol.Terminal.Cell.double_width?/1","ref":"Raxol.Terminal.Cell.html#double_width?/1"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.double_width?(cell)\n    false","title":"Examples - Raxol.Terminal.Cell.double_width?/1","ref":"Raxol.Terminal.Cell.html#double_width?/1-examples"},{"type":"function","doc":"Compares two cells for equality.\n\nCells are considered equal if they have the same character and the same style map.\nHandles comparison with `nil`.","title":"Raxol.Terminal.Cell.equals?/2","ref":"Raxol.Terminal.Cell.html#equals?/2"},{"type":"function","doc":"iex> style1 = TextFormatting.new() |> TextFormatting.apply_attribute(:bold)\n    iex> style2 = TextFormatting.new() |> TextFormatting.apply_attribute(:bold)\n    iex> style3 = TextFormatting.new() |> TextFormatting.apply_attribute(:underline)\n    iex> cell1 = Cell.new(\"A\", style1)\n    iex> cell2 = Cell.new(\"A\", style2) # Same char and style attributes\n    iex> cell3 = Cell.new(\"B\", style1) # Different char\n    iex> cell4 = Cell.new(\"A\", style3) # Different style\n    iex> Cell.equals?(cell1, cell2)\n    true\n    iex> Cell.equals?(cell1, cell3)\n    false\n    iex> Cell.equals?(cell1, cell4)\n    false\n    iex> Cell.equals?(cell1, nil)\n    false\n    iex> Cell.equals?(nil, cell1)\n    false\n    iex> Cell.equals?(nil, nil)\n    true","title":"Examples - Raxol.Terminal.Cell.equals?/2","ref":"Raxol.Terminal.Cell.html#equals?/2-examples"},{"type":"function","doc":"Creates a Cell struct from a map representation, typically from rendering.\nExpects a map like %{char: integer_codepoint, style: map, is_wide_placeholder: boolean | nil}.\nReturns nil if the map is invalid.","title":"Raxol.Terminal.Cell.from_map/1","ref":"Raxol.Terminal.Cell.html#from_map/1"},{"type":"function","doc":"Returns the character of the cell.","title":"Raxol.Terminal.Cell.get_char/1","ref":"Raxol.Terminal.Cell.html#get_char/1"},{"type":"function","doc":"Gets the text style of the cell.","title":"Raxol.Terminal.Cell.get_style/1","ref":"Raxol.Terminal.Cell.html#get_style/1"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.get_style(cell)\n    %{foreground: :red}","title":"Examples - Raxol.Terminal.Cell.get_style/1","ref":"Raxol.Terminal.Cell.html#get_style/1-examples"},{"type":"function","doc":"Checks if the cell has a specific attribute.","title":"Raxol.Terminal.Cell.has_attribute?/2","ref":"Raxol.Terminal.Cell.html#has_attribute?/2"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.has_attribute?(cell, :foreground)\n    true","title":"Examples - Raxol.Terminal.Cell.has_attribute?/2","ref":"Raxol.Terminal.Cell.html#has_attribute?/2-examples"},{"type":"function","doc":"Checks if the cell has a specific decoration.","title":"Raxol.Terminal.Cell.has_decoration?/2","ref":"Raxol.Terminal.Cell.html#has_decoration?/2"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.has_decoration?(cell, :bold)\n    false","title":"Examples - Raxol.Terminal.Cell.has_decoration?/2","ref":"Raxol.Terminal.Cell.html#has_decoration?/2-examples"},{"type":"function","doc":"Checks if a cell is empty.\n\nA cell is considered empty if it contains a space character *and*\nhas the default text formatting style.","title":"Raxol.Terminal.Cell.is_empty?/1","ref":"Raxol.Terminal.Cell.html#is_empty?/1"},{"type":"function","doc":"iex> cell = Cell.new()\n    iex> Cell.is_empty?(cell)\n    true\n\n    iex> cell = Cell.new(\"A\")\n    iex> Cell.is_empty?(cell)\n    false\n\n    iex> bold_style = TextFormatting.new() |> TextFormatting.apply_attribute(:bold)\n    iex> cell = Cell.new(\" \", bold_style) # Space char but non-default style\n    iex> Cell.is_empty?(cell)\n    false","title":"Examples - Raxol.Terminal.Cell.is_empty?/1","ref":"Raxol.Terminal.Cell.html#is_empty?/1-examples"},{"type":"function","doc":"Merges a given style map into the cell's style.\n\nOnly non-default attributes from the `style` map will overwrite existing attributes\nin the cell's style. This prevents merging default values (like `bold: false`)\nand unintentionally removing existing attributes.","title":"Raxol.Terminal.Cell.merge_style/2","ref":"Raxol.Terminal.Cell.html#merge_style/2"},{"type":"function","doc":"iex> initial_style = TextFormatting.new() |> TextFormatting.apply_attribute(:bold) # %{bold: true, ...}\n    iex> merge_style = TextFormatting.new() |> TextFormatting.apply_attribute(:underline) # %{underline: true, bold: false, ...}\n    iex> cell = Cell.new(\"A\", initial_style)\n    iex> merged_cell = Cell.merge_style(cell, merge_style)\n    iex> Cell.get_style(merged_cell)\n    %{bold: true, underline: true} # Note: :bold remains, :underline added","title":"Examples - Raxol.Terminal.Cell.merge_style/2","ref":"Raxol.Terminal.Cell.html#merge_style/2-examples"},{"type":"function","doc":"Creates a new cell with optional character and style.","title":"Raxol.Terminal.Cell.new/3","ref":"Raxol.Terminal.Cell.html#new/3"},{"type":"function","doc":"iex> cell = Cell.new()\n    iex> Cell.is_empty?(cell)\n    true\n\n    iex> cell = Cell.new(\"A\")\n    iex> Cell.get_char(cell)\n    \"A\"\n\n    iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> Cell.get_char(cell)\n    \"A\"\n    iex> Cell.get_style(cell)\n    %{foreground: :red}","title":"Examples - Raxol.Terminal.Cell.new/3","ref":"Raxol.Terminal.Cell.html#new/3-examples"},{"type":"function","doc":"Creates a new cell representing the second half of a wide character.\nInherits the style from the primary cell.","title":"Raxol.Terminal.Cell.new_wide_placeholder/1","ref":"Raxol.Terminal.Cell.html#new_wide_placeholder/1"},{"type":"function","doc":"Sets the character content of a cell.","title":"Raxol.Terminal.Cell.set_char/2","ref":"Raxol.Terminal.Cell.html#set_char/2"},{"type":"function","doc":"iex> cell = Cell.new()\n    iex> cell = Cell.set_char(cell, \"A\")\n    iex> Cell.get_char(cell)\n    \"A\"","title":"Examples - Raxol.Terminal.Cell.set_char/2","ref":"Raxol.Terminal.Cell.html#set_char/2-examples"},{"type":"function","doc":"Sets the text style of the cell.","title":"Raxol.Terminal.Cell.set_style/2","ref":"Raxol.Terminal.Cell.html#set_style/2"},{"type":"function","doc":"iex> cell = Cell.new(\"A\")\n    iex> cell = Cell.set_style(cell, %{foreground: :red})\n    iex> Cell.get_style(cell)\n    %{foreground: :red}","title":"Examples - Raxol.Terminal.Cell.set_style/2","ref":"Raxol.Terminal.Cell.html#set_style/2-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Cell.t/0","ref":"Raxol.Terminal.Cell.html#t:t/0"},{"type":"function","doc":"Creates a copy of a cell with new attributes applied.\n\nAccepts a map of attributes or a list of attribute atoms.\nIf a list is provided, the attributes are applied sequentially, starting from the cell's *existing* style.","title":"Raxol.Terminal.Cell.with_attributes/2","ref":"Raxol.Terminal.Cell.html#with_attributes/2"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{bold: true})\n    iex> new_cell = Cell.with_attributes(cell, %{underline: true}) # Using a map\n    iex> Cell.get_style(new_cell)\n    %{bold: true, underline: true} # Merged\n\n    iex> cell = Cell.new(\"B\", %{bold: true})\n    iex> new_cell = Cell.with_attributes(cell, [:underline, :reverse]) # Using a list\n    iex> Cell.get_style(new_cell)\n    %{bold: true, underline: true, reverse: true} # Original bold + list applied","title":"Examples - Raxol.Terminal.Cell.with_attributes/2","ref":"Raxol.Terminal.Cell.html#with_attributes/2-examples"},{"type":"function","doc":"Creates a copy of a cell with a new character.","title":"Raxol.Terminal.Cell.with_char/2","ref":"Raxol.Terminal.Cell.html#with_char/2"},{"type":"function","doc":"iex> cell = Cell.new(\"A\", %{foreground: :red})\n    iex> new_cell = Cell.with_char(cell, \"B\")\n    iex> Cell.get_char(new_cell)\n    \"B\"\n    iex> Cell.get_style(new_cell)\n    %{foreground: :red}","title":"Examples - Raxol.Terminal.Cell.with_char/2","ref":"Raxol.Terminal.Cell.html#with_char/2-examples"},{"type":"module","doc":"Handles wide character and bidirectional text support for the terminal emulator.\n\nThis module provides functions for:\n- Determining character width (single, double, or variable width)\n- Handling bidirectional text rendering\n- Managing character combining\n- Supporting Unicode character properties","title":"Raxol.Terminal.CharacterHandling","ref":"Raxol.Terminal.CharacterHandling.html"},{"type":"function","doc":"Determines the bidirectional character type.\nReturns :LTR, :RTL, :NEUTRAL, or :COMBINING.","title":"Raxol.Terminal.CharacterHandling.get_bidi_type/1","ref":"Raxol.Terminal.CharacterHandling.html#get_bidi_type/1"},{"type":"function","doc":"Determine the display width of a given character code point or string.","title":"Raxol.Terminal.CharacterHandling.get_char_width/1","ref":"Raxol.Terminal.CharacterHandling.html#get_char_width/1"},{"type":"function","doc":"Gets the effective width of a string, taking into account wide characters\nand ignoring combining characters.","title":"Raxol.Terminal.CharacterHandling.get_string_width/1","ref":"Raxol.Terminal.CharacterHandling.html#get_string_width/1"},{"type":"function","doc":"Determines if a character is a combining character.","title":"Raxol.Terminal.CharacterHandling.is_combining_char?/1","ref":"Raxol.Terminal.CharacterHandling.html#is_combining_char?/1"},{"type":"function","doc":"Determines if a character is a wide character (takes up two cells).","title":"Raxol.Terminal.CharacterHandling.is_wide_char?/1","ref":"Raxol.Terminal.CharacterHandling.html#is_wide_char?/1"},{"type":"function","doc":"Processes a string for bidirectional text rendering.\nReturns a list of segments with their rendering order.","title":"Raxol.Terminal.CharacterHandling.process_bidi_text/1","ref":"Raxol.Terminal.CharacterHandling.html#process_bidi_text/1"},{"type":"function","doc":"Splits a string at a given width, respecting wide characters.","title":"Raxol.Terminal.CharacterHandling.split_at_width/2","ref":"Raxol.Terminal.CharacterHandling.html#split_at_width/2"},{"type":"module","doc":"Manages terminal command history and processing, including command buffer,\nhistory, and command execution.","title":"Raxol.Terminal.Command.Manager","ref":"Raxol.Terminal.Command.Manager.html"},{"type":"function","doc":"Adds a command to the history, maintaining the maximum history size.","title":"Raxol.Terminal.Command.Manager.add_to_history/2","ref":"Raxol.Terminal.Command.Manager.html#add_to_history/2"},{"type":"function","doc":"Clears the command history.","title":"Raxol.Terminal.Command.Manager.clear_history/1","ref":"Raxol.Terminal.Command.Manager.html#clear_history/1"},{"type":"function","doc":"Gets the current command buffer.","title":"Raxol.Terminal.Command.Manager.get_command_buffer/1","ref":"Raxol.Terminal.Command.Manager.html#get_command_buffer/1"},{"type":"function","doc":"Gets the command history.","title":"Raxol.Terminal.Command.Manager.get_command_history/1","ref":"Raxol.Terminal.Command.Manager.html#get_command_history/1"},{"type":"function","doc":"Gets a command from history by index (0-based).\nReturns nil if index is out of bounds.","title":"Raxol.Terminal.Command.Manager.get_history_command/2","ref":"Raxol.Terminal.Command.Manager.html#get_history_command/2"},{"type":"function","doc":"Gets the last key event.","title":"Raxol.Terminal.Command.Manager.get_last_key_event/1","ref":"Raxol.Terminal.Command.Manager.html#get_last_key_event/1"},{"type":"function","doc":"Creates a new command manager with default values.","title":"Raxol.Terminal.Command.Manager.new/1","ref":"Raxol.Terminal.Command.Manager.html#new/1"},{"type":"function","doc":"Processes a key event and updates the command buffer accordingly.\nReturns {new_manager, command_to_execute} where command_to_execute is nil\nif no command should be executed.","title":"Raxol.Terminal.Command.Manager.process_key_event/2","ref":"Raxol.Terminal.Command.Manager.html#process_key_event/2"},{"type":"function","doc":"Searches command history for commands matching the given prefix.\nReturns a list of matching commands.","title":"Raxol.Terminal.Command.Manager.search_history/2","ref":"Raxol.Terminal.Command.Manager.html#search_history/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Command.Manager.t/0","ref":"Raxol.Terminal.Command.Manager.html#t:t/0"},{"type":"function","doc":"Updates the current command buffer.","title":"Raxol.Terminal.Command.Manager.update_command_buffer/2","ref":"Raxol.Terminal.Command.Manager.html#update_command_buffer/2"},{"type":"function","doc":"Updates the last key event.","title":"Raxol.Terminal.Command.Manager.update_last_key_event/2","ref":"Raxol.Terminal.Command.Manager.html#update_last_key_event/2"},{"type":"function","doc":"Updates the maximum command history size.\nIf the new size is smaller than the current history, older commands are removed.","title":"Raxol.Terminal.Command.Manager.update_max_history/2","ref":"Raxol.Terminal.Command.Manager.html#update_max_history/2"},{"type":"module","doc":"DEPRECATED: Handles the execution of parsed terminal commands.\n\nThis module is being replaced by `Raxol.Terminal.Commands.Executor` and\nvarious submodules within `Raxol.Terminal.Commands.*`.\n\nExisting functions are kept temporarily for backward compatibility or as\nplaceholders during refactoring, but they primarily log warnings and delegate\nto the new modules where possible.","title":"Raxol.Terminal.CommandExecutor","ref":"Raxol.Terminal.CommandExecutor.html"},{"type":"function","doc":"Clears a line or part of a line based on the mode parameter.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.clear_line/2 instead.","title":"Raxol.Terminal.CommandExecutor.clear_line/2","ref":"Raxol.Terminal.CommandExecutor.html#clear_line/2"},{"type":"function","doc":"Clears the screen or a part of it based on the mode parameter.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.clear_screen/2 instead.","title":"Raxol.Terminal.CommandExecutor.clear_screen/2","ref":"Raxol.Terminal.CommandExecutor.html#clear_screen/2"},{"type":"function","doc":"Deletes lines at the current cursor position.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.delete_lines/2 instead.","title":"Raxol.Terminal.CommandExecutor.delete_line/2","ref":"Raxol.Terminal.CommandExecutor.html#delete_line/2"},{"type":"function","doc":"Executes a CSI (Control Sequence Introducer) command.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Executor.execute_csi_command/4 instead.","title":"Raxol.Terminal.CommandExecutor.execute_csi_command/4","ref":"Raxol.Terminal.CommandExecutor.html#execute_csi_command/4"},{"type":"function","doc":"Executes a DCS (Device Control String) command.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Executor.execute_dcs_command/5 instead.","title":"Raxol.Terminal.CommandExecutor.execute_dcs_command/5","ref":"Raxol.Terminal.CommandExecutor.html#execute_dcs_command/5"},{"type":"function","doc":"Executes an OSC (Operating System Command).\n\nDEPRECATED: Use Raxol.Terminal.Commands.Executor.execute_osc_command/2 instead.","title":"Raxol.Terminal.CommandExecutor.execute_osc_command/2","ref":"Raxol.Terminal.CommandExecutor.html#execute_osc_command/2"},{"type":"function","doc":"Gets a parameter at a specific index from the params list.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Parser.get_param/3 instead.","title":"Raxol.Terminal.CommandExecutor.get_param/3","ref":"Raxol.Terminal.CommandExecutor.html#get_param/3"},{"type":"function","doc":"Handles Standard Mode Set (CSI Pn h) and Reset (CSI Pn l).","title":"Raxol.Terminal.CommandExecutor.handle_ansi_mode/3","ref":"Raxol.Terminal.CommandExecutor.html#handle_ansi_mode/3"},{"type":"function","doc":"Handles DEC Private Mode Set (CSI ? Pn h) and Reset (CSI ? Pn l).","title":"Raxol.Terminal.CommandExecutor.handle_dec_private_mode/3","ref":"Raxol.Terminal.CommandExecutor.html#handle_dec_private_mode/3"},{"type":"function","doc":"Erase Display handler.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.erase_display/2 instead.","title":"Raxol.Terminal.CommandExecutor.handle_ed/2","ref":"Raxol.Terminal.CommandExecutor.html#handle_ed/2"},{"type":"function","doc":"Erase Line handler.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.erase_line/2 instead.","title":"Raxol.Terminal.CommandExecutor.handle_el/2","ref":"Raxol.Terminal.CommandExecutor.html#handle_el/2"},{"type":"function","doc":"Handles Sixel graphics.\n\nDEPRECATED: This should be moved to a dedicated Sixel handler module.","title":"Raxol.Terminal.CommandExecutor.handle_sixel_graphics/2","ref":"Raxol.Terminal.CommandExecutor.html#handle_sixel_graphics/2"},{"type":"function","doc":"Inserts blank lines at the current cursor position.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Screen.insert_lines/2 instead.","title":"Raxol.Terminal.CommandExecutor.insert_line/2","ref":"Raxol.Terminal.CommandExecutor.html#insert_line/2"},{"type":"function","doc":"Parses a raw parameter string buffer into a list of integers or nil values.\n\nDEPRECATED: Use Raxol.Terminal.Commands.Parser.parse_params/1 instead.","title":"Raxol.Terminal.CommandExecutor.parse_params/1","ref":"Raxol.Terminal.CommandExecutor.html#parse_params/1"},{"type":"module","doc":"Handles buffer manipulation related CSI commands.\n\nThis module contains handlers for buffer operations like insert/delete lines,\ninsert/delete characters, and erase operations. Each function takes the current\nemulator state and parsed parameters, returning the updated emulator state.","title":"Raxol.Terminal.Commands.BufferHandlers","ref":"Raxol.Terminal.Commands.BufferHandlers.html"},{"type":"function","doc":"Helper function to get active buffer, cursor position, and default style.\nReturns a tuple of {active_buffer, cursor_pos, default_style}.","title":"Raxol.Terminal.Commands.BufferHandlers.get_buffer_state/1","ref":"Raxol.Terminal.Commands.BufferHandlers.html#get_buffer_state/1"},{"type":"function","doc":"Handles Insert Character (ICH - '@')","title":"Raxol.Terminal.Commands.BufferHandlers.handle_at/2","ref":"Raxol.Terminal.Commands.BufferHandlers.html#handle_at/2"},{"type":"function","doc":"Handles Insert Line (IL - 'L')","title":"Raxol.Terminal.Commands.BufferHandlers.handle_L/2","ref":"Raxol.Terminal.Commands.BufferHandlers.html#handle_L/2"},{"type":"function","doc":"Handles Delete Line (DL - 'M')","title":"Raxol.Terminal.Commands.BufferHandlers.handle_M/2","ref":"Raxol.Terminal.Commands.BufferHandlers.html#handle_M/2"},{"type":"function","doc":"Handles Delete Character (DCH - 'P')","title":"Raxol.Terminal.Commands.BufferHandlers.handle_P/2","ref":"Raxol.Terminal.Commands.BufferHandlers.html#handle_P/2"},{"type":"function","doc":"Handles Erase Character (ECH - 'X')","title":"Raxol.Terminal.Commands.BufferHandlers.handle_X/2","ref":"Raxol.Terminal.Commands.BufferHandlers.html#handle_X/2"},{"type":"function","doc":"Helper function to perform a buffer operation and update the emulator.\nTakes the emulator, a function that performs the buffer operation,\nand any additional arguments needed by the operation function.","title":"Raxol.Terminal.Commands.BufferHandlers.with_buffer_operation/3","ref":"Raxol.Terminal.Commands.BufferHandlers.html#with_buffer_operation/3"},{"type":"module","doc":"Handles the execution logic for specific CSI commands.\n\nThis module serves as the main entry point for CSI command handling,\ndelegating to specialized handler modules for different types of commands.","title":"Raxol.Terminal.Commands.CSIHandlers","ref":"Raxol.Terminal.Commands.CSIHandlers.html"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_A/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_A/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_at/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_at/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_B/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_B/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_C/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_C/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_c/3","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_c/3"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_D/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_D/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_d/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_d/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_E/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_E/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_F/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_F/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_G/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_G/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_H/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_H/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_h_or_l/4","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_h_or_l/4"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_J/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_J/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_K/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_K/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_L/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_L/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_M/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_M/2"},{"type":"function","doc":"Handles Select Graphic Rendition (SGR - 'm')","title":"Raxol.Terminal.Commands.CSIHandlers.handle_m/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_m/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_n/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_n/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_P/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_P/2"},{"type":"function","doc":"Handles Set Cursor Style (DECSCUSR - 'q')","title":"Raxol.Terminal.Commands.CSIHandlers.handle_q_deccusr/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_q_deccusr/2"},{"type":"function","doc":"Handles DECSTBM (Set Scrolling Region - 'r')","title":"Raxol.Terminal.Commands.CSIHandlers.handle_r/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_r/2"},{"type":"function","doc":"Handles Save Cursor (SCP - 's')","title":"Raxol.Terminal.Commands.CSIHandlers.handle_s/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_s/2"},{"type":"function","doc":"Handles Designate Character Set (SCS - '(', ')', '*', '+')","title":"Raxol.Terminal.Commands.CSIHandlers.handle_scs/3","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_scs/3"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_t/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_t/2"},{"type":"function","doc":"Handles Restore Cursor (RCP - 'u')","title":"Raxol.Terminal.Commands.CSIHandlers.handle_u/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_u/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Commands.CSIHandlers.handle_X/2","ref":"Raxol.Terminal.Commands.CSIHandlers.html#handle_X/2"},{"type":"module","doc":"Handles cursor movement related CSI commands.\n\nThis module contains handlers for cursor movement commands like CUP, CUU, CUD, etc.\nEach function takes the current emulator state and parsed parameters,\nreturning the updated emulator state.","title":"Raxol.Terminal.Commands.CursorHandlers","ref":"Raxol.Terminal.Commands.CursorHandlers.html"},{"type":"function","doc":"Handles Cursor Up (CUU - 'A')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_A/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_A/2"},{"type":"function","doc":"Handles Cursor Down (CUD - 'B')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_B/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_B/2"},{"type":"function","doc":"Handles Cursor Forward (CUF - 'C')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_C/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_C/2"},{"type":"function","doc":"Helper function to handle cursor movement operations.\nTakes the emulator, movement function, and movement parameters.","title":"Raxol.Terminal.Commands.CursorHandlers.handle_cursor_movement/3","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_cursor_movement/3"},{"type":"function","doc":"Handles Cursor Backward (CUB - 'D')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_D/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_D/2"},{"type":"function","doc":"Handles Cursor Vertical Absolute (VPA - 'd')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_d/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_d/2"},{"type":"function","doc":"Handles Cursor Next Line (CNL - 'E')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_E/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_E/2"},{"type":"function","doc":"Handles Cursor Previous Line (CPL - 'F')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_F/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_F/2"},{"type":"function","doc":"Handles Cursor Horizontal Absolute (CHA - 'G')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_G/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_G/2"},{"type":"function","doc":"Handles Cursor Position (CUP - 'H')","title":"Raxol.Terminal.Commands.CursorHandlers.handle_H/2","ref":"Raxol.Terminal.Commands.CursorHandlers.html#handle_H/2"},{"type":"module","doc":"Handles the execution logic for specific DCS commands.\n\nFunctions are called by `Raxol.Terminal.Commands.Executor` after initial parsing.","title":"Raxol.Terminal.Commands.DCSHandlers","ref":"Raxol.Terminal.Commands.DCSHandlers.html"},{"type":"function","doc":"Dispatches DCS command execution based on intermediates and final byte.","title":"Raxol.Terminal.Commands.DCSHandlers.handle_dcs/5","ref":"Raxol.Terminal.Commands.DCSHandlers.html#handle_dcs/5"},{"type":"module","doc":"Handles device status and attribute related CSI commands.\n\nThis module contains handlers for device status reports (DSR) and device\nattributes (DA). Each function takes the current emulator state and parsed\nparameters, returning the updated emulator state.","title":"Raxol.Terminal.Commands.DeviceHandlers","ref":"Raxol.Terminal.Commands.DeviceHandlers.html"},{"type":"function","doc":"Handles Device Status Report (CPR - '6n') (stub).","title":"Raxol.Terminal.Commands.DeviceHandlers.handle_6n/2","ref":"Raxol.Terminal.Commands.DeviceHandlers.html#handle_6n/2"},{"type":"function","doc":"Handles Device Attributes (DA - 'c')","title":"Raxol.Terminal.Commands.DeviceHandlers.handle_c/3","ref":"Raxol.Terminal.Commands.DeviceHandlers.html#handle_c/3"},{"type":"function","doc":"Handles Device Status Report (DSR - 'n')","title":"Raxol.Terminal.Commands.DeviceHandlers.handle_n/2","ref":"Raxol.Terminal.Commands.DeviceHandlers.html#handle_n/2"},{"type":"module","doc":"Handles editor operations for the terminal buffer.\n\nThis module provides functions for inserting and deleting lines and characters,\nas well as erasing characters in the terminal buffer. It also handles screen\nand line operations like clearing the screen or parts of it.","title":"Raxol.Terminal.Commands.Editor","ref":"Raxol.Terminal.Commands.Editor.html"},{"type":"function","doc":"Clears a line or a part of it based on the mode parameter.","title":"Raxol.Terminal.Commands.Editor.clear_line/4","ref":"Raxol.Terminal.Commands.Editor.html#clear_line/4"},{"type":"function","doc":"* `buffer` - The current screen buffer\n* `cursor_pos` - The current cursor position {x, y}\n* `mode` - The clear mode:\n  * 0 - Clear from cursor to end of line\n  * 1 - Clear from beginning of line to cursor\n  * 2 - Clear entire line\n* `default_style` - The style to use for cleared areas","title":"Parameters - Raxol.Terminal.Commands.Editor.clear_line/4","ref":"Raxol.Terminal.Commands.Editor.html#clear_line/4-parameters"},{"type":"function","doc":"* Updated screen buffer","title":"Returns - Raxol.Terminal.Commands.Editor.clear_line/4","ref":"Raxol.Terminal.Commands.Editor.html#clear_line/4-returns"},{"type":"function","doc":"Clears a rectangular region of the screen.","title":"Raxol.Terminal.Commands.Editor.clear_region/6","ref":"Raxol.Terminal.Commands.Editor.html#clear_region/6"},{"type":"function","doc":"* `buffer` - The current screen buffer\n* `start_x` - Starting x coordinate\n* `start_y` - Starting y coordinate\n* `end_x` - Ending x coordinate\n* `end_y` - Ending y coordinate\n* `default_style` - The style to use for cleared areas","title":"Parameters - Raxol.Terminal.Commands.Editor.clear_region/6","ref":"Raxol.Terminal.Commands.Editor.html#clear_region/6-parameters"},{"type":"function","doc":"* Updated screen buffer","title":"Returns - Raxol.Terminal.Commands.Editor.clear_region/6","ref":"Raxol.Terminal.Commands.Editor.html#clear_region/6-returns"},{"type":"function","doc":"Clears the screen or a part of it based on the mode parameter.","title":"Raxol.Terminal.Commands.Editor.clear_screen/4","ref":"Raxol.Terminal.Commands.Editor.html#clear_screen/4"},{"type":"function","doc":"* `buffer` - The current screen buffer\n* `cursor_pos` - The current cursor position {x, y}\n* `mode` - The clear mode:\n  * 0 - Clear from cursor to end of screen\n  * 1 - Clear from beginning of screen to cursor\n  * 2 - Clear entire screen but don't move cursor\n  * 3 - Clear entire screen including scrollback\n* `default_style` - The style to use for cleared areas","title":"Parameters - Raxol.Terminal.Commands.Editor.clear_screen/4","ref":"Raxol.Terminal.Commands.Editor.html#clear_screen/4-parameters"},{"type":"function","doc":"* Updated screen buffer","title":"Returns - Raxol.Terminal.Commands.Editor.clear_screen/4","ref":"Raxol.Terminal.Commands.Editor.html#clear_screen/4-returns"},{"type":"function","doc":"Deletes a specified number of characters starting from the current cursor position.\nCharacters to the right of the deleted characters are shifted left, and blank characters are added at the end.","title":"Raxol.Terminal.Commands.Editor.delete_chars/5","ref":"Raxol.Terminal.Commands.Editor.html#delete_chars/5"},{"type":"function","doc":"Deletes a specified number of lines starting from the current cursor position.\nLines below the deleted lines are shifted up, and blank lines are added at the bottom.","title":"Raxol.Terminal.Commands.Editor.delete_lines/4","ref":"Raxol.Terminal.Commands.Editor.html#delete_lines/4"},{"type":"function","doc":"Erases a specified number of characters starting from the current cursor position.\nCharacters are replaced with blank spaces using the default style.","title":"Raxol.Terminal.Commands.Editor.erase_chars/5","ref":"Raxol.Terminal.Commands.Editor.html#erase_chars/5"},{"type":"function","doc":"Inserts a specified number of blank characters at the current cursor position.\nCharacters to the right of the cursor are shifted right, and characters shifted off the end are discarded.","title":"Raxol.Terminal.Commands.Editor.insert_chars/5","ref":"Raxol.Terminal.Commands.Editor.html#insert_chars/5"},{"type":"function","doc":"Inserts a specified number of blank lines at the current cursor position.\nLines below the cursor are shifted down, and lines shifted off the bottom are discarded.","title":"Raxol.Terminal.Commands.Editor.insert_lines/4","ref":"Raxol.Terminal.Commands.Editor.html#insert_lines/4"},{"type":"module","doc":"Handles erase related CSI commands.\n\nThis module contains handlers for erase operations like ED (Erase in Display)\nand EL (Erase in Line). Each function takes the current emulator state and\nparsed parameters, returning the updated emulator state.","title":"Raxol.Terminal.Commands.EraseHandlers","ref":"Raxol.Terminal.Commands.EraseHandlers.html"},{"type":"function","doc":"Helper function to get active buffer, cursor position, and default style.\nReturns a tuple of {active_buffer, cursor_pos, default_style}.","title":"Raxol.Terminal.Commands.EraseHandlers.get_buffer_state/1","ref":"Raxol.Terminal.Commands.EraseHandlers.html#get_buffer_state/1"},{"type":"function","doc":"Helper function to handle erase operations.\nTakes the emulator, erase type, and erase parameters.","title":"Raxol.Terminal.Commands.EraseHandlers.handle_erase/4","ref":"Raxol.Terminal.Commands.EraseHandlers.html#handle_erase/4"},{"type":"function","doc":"Handles Erase in Display (ED - 'J')","title":"Raxol.Terminal.Commands.EraseHandlers.handle_J/2","ref":"Raxol.Terminal.Commands.EraseHandlers.html#handle_J/2"},{"type":"function","doc":"Handles Erase in Line (EL - 'K')","title":"Raxol.Terminal.Commands.EraseHandlers.handle_K/2","ref":"Raxol.Terminal.Commands.EraseHandlers.html#handle_K/2"},{"type":"module","doc":"Executes parsed terminal commands (CSI, OSC, DCS).\n\nThis module takes parsed command details and the current emulator state,\nand returns the updated emulator state after applying the command's effects.","title":"Raxol.Terminal.Commands.Executor","ref":"Raxol.Terminal.Commands.Executor.html"},{"type":"function","doc":"Executes a CSI (Control Sequence Introducer) command.\n\nTODO: Implement the actual logic for handling various CSI commands.\nThis likely involves pattern matching on the final_byte and intermediates,\nparsing parameters, and calling specific handler functions (e.g., from\nModes, Screen, Cursor modules).","title":"Raxol.Terminal.Commands.Executor.execute_csi_command/4","ref":"Raxol.Terminal.Commands.Executor.html#execute_csi_command/4"},{"type":"function","doc":"Executes a DCS (Device Control String) command.\n\nParams: `params_buffer`, `intermediates_buffer`, `data_string` (content between DCS and ST).","title":"Raxol.Terminal.Commands.Executor.execute_dcs_command/5","ref":"Raxol.Terminal.Commands.Executor.html#execute_dcs_command/5"},{"type":"function","doc":"Executes an OSC (Operating System Command).\n\nParams: `command_string` (the content between OSC and ST).","title":"Raxol.Terminal.Commands.Executor.execute_osc_command/2","ref":"Raxol.Terminal.Commands.Executor.html#execute_osc_command/2"},{"type":"module","doc":"Manages command history for the terminal emulator.\n\nThis module provides functionality for:\n- Storing and retrieving command history\n- Navigating through command history\n- Persisting command history\n- Managing history size limits","title":"Raxol.Terminal.Commands.History","ref":"Raxol.Terminal.Commands.History.html"},{"type":"function","doc":"Adds a command to the history.","title":"Raxol.Terminal.Commands.History.add/2","ref":"Raxol.Terminal.Commands.History.html#add/2"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history.commands\n    [\"ls -la\"]","title":"Examples - Raxol.Terminal.Commands.History.add/2","ref":"Raxol.Terminal.Commands.History.html#add/2-examples"},{"type":"function","doc":"Clears the command history.","title":"Raxol.Terminal.Commands.History.clear/1","ref":"Raxol.Terminal.Commands.History.html#clear/1"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.clear(history)\n    iex> history.commands\n    []","title":"Examples - Raxol.Terminal.Commands.History.clear/1","ref":"Raxol.Terminal.Commands.History.html#clear/1-examples"},{"type":"function","doc":"Returns the current command history as a list.","title":"Raxol.Terminal.Commands.History.list/1","ref":"Raxol.Terminal.Commands.History.html#list/1"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.add(history, \"cd /tmp\")\n    iex> History.list(history)\n    [\"cd /tmp\", \"ls -la\"]","title":"Examples - Raxol.Terminal.Commands.History.list/1","ref":"Raxol.Terminal.Commands.History.html#list/1-examples"},{"type":"function","doc":"Creates a new command history manager.","title":"Raxol.Terminal.Commands.History.new/1","ref":"Raxol.Terminal.Commands.History.html#new/1"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history.max_size\n    1000","title":"Examples - Raxol.Terminal.Commands.History.new/1","ref":"Raxol.Terminal.Commands.History.html#new/1-examples"},{"type":"function","doc":"Retrieves the next command in history.","title":"Raxol.Terminal.Commands.History.next/1","ref":"Raxol.Terminal.Commands.History.html#next/1"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.add(history, \"cd /tmp\")\n    iex> {_, history} = History.previous(history)\n    iex> History.next(history)\n    {\"ls -la\", %History{...}}","title":"Examples - Raxol.Terminal.Commands.History.next/1","ref":"Raxol.Terminal.Commands.History.html#next/1-examples"},{"type":"function","doc":"Retrieves the previous command in history.","title":"Raxol.Terminal.Commands.History.previous/1","ref":"Raxol.Terminal.Commands.History.html#previous/1"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history = History.add(history, \"ls -la\")\n    iex> history = History.add(history, \"cd /tmp\")\n    iex> History.previous(history)\n    {\"cd /tmp\", %History{...}}","title":"Examples - Raxol.Terminal.Commands.History.previous/1","ref":"Raxol.Terminal.Commands.History.html#previous/1-examples"},{"type":"function","doc":"Saves the current input state.","title":"Raxol.Terminal.Commands.History.save_input/2","ref":"Raxol.Terminal.Commands.History.html#save_input/2"},{"type":"function","doc":"iex> history = History.new(1000)\n    iex> history = History.save_input(history, \"ls -l\")\n    iex> history.current_input\n    \"ls -l\"","title":"Examples - Raxol.Terminal.Commands.History.save_input/2","ref":"Raxol.Terminal.Commands.History.html#save_input/2-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Commands.History.t/0","ref":"Raxol.Terminal.Commands.History.html#t:t/0"},{"type":"module","doc":"Handles mode setting and resetting related CSI commands.\n\nThis module contains handlers for setting and resetting terminal modes,\nboth standard ANSI modes and DEC private modes. Each function takes the\ncurrent emulator state and parsed parameters, returning the updated\nemulator state.","title":"Raxol.Terminal.Commands.ModeHandlers","ref":"Raxol.Terminal.Commands.ModeHandlers.html"},{"type":"function","doc":"Handles Set Mode (SM - `h`) or Reset Mode (RM - `l`).\n\nDispatches to `ModeManager` to handle both standard ANSI modes and\nDEC private modes (prefixed with `?`).","title":"Raxol.Terminal.Commands.ModeHandlers.handle_h_or_l/4","ref":"Raxol.Terminal.Commands.ModeHandlers.html#handle_h_or_l/4"},{"type":"module","doc":"Handles the execution logic for specific OSC commands.\n\nFunctions are called by `Raxol.Terminal.Commands.Executor` after initial parsing.","title":"Raxol.Terminal.Commands.OSCHandlers","ref":"Raxol.Terminal.Commands.OSCHandlers.html"},{"type":"function","doc":"Handles OSC 0 (Set Icon Name and Window Title) or OSC 2 (Set Window Title)","title":"Raxol.Terminal.Commands.OSCHandlers.handle_0_or_2/2","ref":"Raxol.Terminal.Commands.OSCHandlers.html#handle_0_or_2/2"},{"type":"function","doc":"Handles OSC 4 (Set/Query Color Palette).\n\nFormat: OSC 4 ; c ; spec ST\n- c: Color index (0-255)\n- spec: Color specification or \"?\" for query\n\nColor specifications supported:\n- rgb:RRRR/GGGG/BBBB (hex, 1-4 digits per component)\n- #RRGGBB (hex, 2 digits per component)\n- #RGB (hex, 1 digit per component)\n- #RRGGBBAA (hex with alpha, 2 digits per component)\n- rgb(r,g,b) (decimal, 0-255)\n- rgb(r%,g%,b%) (percentage, 0-100%)\n\nReturns:\n- For set: Updated emulator with new color in palette\n- For query: Emulator with response in output_buffer","title":"Raxol.Terminal.Commands.OSCHandlers.handle_4/2","ref":"Raxol.Terminal.Commands.OSCHandlers.html#handle_4/2"},{"type":"function","doc":"Handles OSC 7 (Set/Query Current Working Directory URL)","title":"Raxol.Terminal.Commands.OSCHandlers.handle_7/2","ref":"Raxol.Terminal.Commands.OSCHandlers.html#handle_7/2"},{"type":"function","doc":"Handles OSC 8 (Hyperlink)","title":"Raxol.Terminal.Commands.OSCHandlers.handle_8/2","ref":"Raxol.Terminal.Commands.OSCHandlers.html#handle_8/2"},{"type":"function","doc":"Handles OSC 52 (Set/Query Clipboard Data)","title":"Raxol.Terminal.Commands.OSCHandlers.handle_52/2","ref":"Raxol.Terminal.Commands.OSCHandlers.html#handle_52/2"},{"type":"module","doc":"Provides parameter validation functions for CSI command handlers.\n\nThis module contains helper functions for validating and extracting\nparameters from CSI command sequences. Each function takes a list of\nparameters, an index, and a default value, returning either the\nvalidated parameter value or the default value if the parameter is\ninvalid.","title":"Raxol.Terminal.Commands.ParameterValidation","ref":"Raxol.Terminal.Commands.ParameterValidation.html"},{"type":"function","doc":"Gets a parameter value with validation for boolean values (0 or 1).\nReturns the parameter value if valid, or the default value if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.get_valid_bool_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_bool_param/3"},{"type":"function","doc":"* `params` - List of parameter values\n  * `index` - Index of the parameter to get\n  * `default` - Default value to use if parameter is invalid (must be 0 or 1)","title":"Parameters - Raxol.Terminal.Commands.ParameterValidation.get_valid_bool_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_bool_param/3-parameters"},{"type":"function","doc":"iex> ParameterValidation.get_valid_bool_param([1, 2, 3], 0, 0)\n    1\n\n    iex> ParameterValidation.get_valid_bool_param([nil, 2, 3], 0, 0)\n    0\n\n    iex> ParameterValidation.get_valid_bool_param([2, 2, 3], 0, 0)\n    0","title":"Examples - Raxol.Terminal.Commands.ParameterValidation.get_valid_bool_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_bool_param/3-examples"},{"type":"function","doc":"Gets a parameter value with validation for non-negative integers.\nReturns the parameter value if valid, or the default value if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.get_valid_non_neg_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_non_neg_param/3"},{"type":"function","doc":"* `params` - List of parameter values\n  * `index` - Index of the parameter to get\n  * `default` - Default value to use if parameter is invalid","title":"Parameters - Raxol.Terminal.Commands.ParameterValidation.get_valid_non_neg_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_non_neg_param/3-parameters"},{"type":"function","doc":"iex> ParameterValidation.get_valid_non_neg_param([1, 2, 3], 0, 0)\n    1\n\n    iex> ParameterValidation.get_valid_non_neg_param([nil, 2, 3], 0, 0)\n    0\n\n    iex> ParameterValidation.get_valid_non_neg_param([-1, 2, 3], 0, 0)\n    0","title":"Examples - Raxol.Terminal.Commands.ParameterValidation.get_valid_non_neg_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_non_neg_param/3-examples"},{"type":"function","doc":"Gets a parameter value with validation.\nReturns the parameter value if valid, or the default value if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.get_valid_param/5","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_param/5"},{"type":"function","doc":"* `params` - List of parameter values\n  * `index` - Index of the parameter to get\n  * `default` - Default value to use if parameter is invalid\n  * `min` - Minimum allowed value\n  * `max` - Maximum allowed value","title":"Parameters - Raxol.Terminal.Commands.ParameterValidation.get_valid_param/5","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_param/5-parameters"},{"type":"function","doc":"iex> ParameterValidation.get_valid_param([1, 2, 3], 0, 0, 0, 9999)\n    1\n\n    iex> ParameterValidation.get_valid_param([nil, 2, 3], 0, 0, 0, 9999)\n    0\n\n    iex> ParameterValidation.get_valid_param([-1, 2, 3], 0, 0, 0, 9999)\n    0","title":"Examples - Raxol.Terminal.Commands.ParameterValidation.get_valid_param/5","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_param/5-examples"},{"type":"function","doc":"Gets a parameter value with validation for positive integers.\nReturns the parameter value if valid, or the default value if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.get_valid_pos_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_pos_param/3"},{"type":"function","doc":"* `params` - List of parameter values\n  * `index` - Index of the parameter to get\n  * `default` - Default value to use if parameter is invalid","title":"Parameters - Raxol.Terminal.Commands.ParameterValidation.get_valid_pos_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_pos_param/3-parameters"},{"type":"function","doc":"iex> ParameterValidation.get_valid_pos_param([1, 2, 3], 0, 1)\n    1\n\n    iex> ParameterValidation.get_valid_pos_param([nil, 2, 3], 0, 1)\n    1\n\n    iex> ParameterValidation.get_valid_pos_param([0, 2, 3], 0, 1)\n    1","title":"Examples - Raxol.Terminal.Commands.ParameterValidation.get_valid_pos_param/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#get_valid_pos_param/3-examples"},{"type":"function","doc":"Normalizes parameters to expected length, padding with nil or truncating as needed.","title":"Raxol.Terminal.Commands.ParameterValidation.normalize_parameters/2","ref":"Raxol.Terminal.Commands.ParameterValidation.html#normalize_parameters/2"},{"type":"function","doc":"Validates boolean, returns true for 1, false for 0. Defaults to true if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.validate_boolean/1","ref":"Raxol.Terminal.Commands.ParameterValidation.html#validate_boolean/1"},{"type":"function","doc":"Validates color, clamping between 0 and 255. Defaults to 0 if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.validate_color/1","ref":"Raxol.Terminal.Commands.ParameterValidation.html#validate_color/1"},{"type":"function","doc":"Validates coordinates, clamping to emulator bounds. Defaults to {0, 0} if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.validate_coordinates/2","ref":"Raxol.Terminal.Commands.ParameterValidation.html#validate_coordinates/2"},{"type":"function","doc":"Validates count, clamping between 1 and 10. Defaults to 1 if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.validate_count/2","ref":"Raxol.Terminal.Commands.ParameterValidation.html#validate_count/2"},{"type":"function","doc":"Validates mode, must be 0, 1, or 2. Defaults to 0 if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.validate_mode/1","ref":"Raxol.Terminal.Commands.ParameterValidation.html#validate_mode/1"},{"type":"function","doc":"Validates a value in params[0], clamping between min and max. Defaults to min if invalid.","title":"Raxol.Terminal.Commands.ParameterValidation.validate_range/3","ref":"Raxol.Terminal.Commands.ParameterValidation.html#validate_range/3"},{"type":"module","doc":"Handles parsing of command parameters in terminal sequences.\n\nThis module is part of the terminal command execution system. It provides\nutilities for parsing and extracting parameters from CSI, OSC, and DCS\nsequence parameter strings.","title":"Raxol.Terminal.Commands.Parser","ref":"Raxol.Terminal.Commands.Parser.html"},{"type":"function","doc":"Gets a parameter at a specific index from the params list.\n\nIf the parameter is not available, returns the provided default value.","title":"Raxol.Terminal.Commands.Parser.get_param/3","ref":"Raxol.Terminal.Commands.Parser.html#get_param/3"},{"type":"function","doc":"iex> Parser.get_param([5, 10, 15], 2)\n    10\n\n    iex> Parser.get_param([5, 10], 3)\n    1\n\n    iex> Parser.get_param([5, 10], 3, 0)\n    0","title":"Examples - Raxol.Terminal.Commands.Parser.get_param/3","ref":"Raxol.Terminal.Commands.Parser.html#get_param/3-examples"},{"type":"function","doc":"Safely parses a string into an integer.\n\nReturns the parsed integer, or nil on failure.","title":"Raxol.Terminal.Commands.Parser.parse_int/1","ref":"Raxol.Terminal.Commands.Parser.html#parse_int/1"},{"type":"function","doc":"iex> Parser.parse_int(\"123\")\n    123\n\n    iex> Parser.parse_int(\"abc\")\n    nil","title":"Examples - Raxol.Terminal.Commands.Parser.parse_int/1","ref":"Raxol.Terminal.Commands.Parser.html#parse_int/1-examples"},{"type":"function","doc":"Parses a raw parameter string buffer into a list of integers or nil values.\n\nHandles empty or malformed parameters by converting them to nil.\nHandles parameters with sub-parameters (separated by ':')","title":"Raxol.Terminal.Commands.Parser.parse_params/1","ref":"Raxol.Terminal.Commands.Parser.html#parse_params/1"},{"type":"function","doc":"iex> Parser.parse_params(\"5;10;15\")\n    [5, 10, 15]\n\n    iex> Parser.parse_params(\"5;10;;15\")\n    [5, 10, nil, 15]\n\n    iex> Parser.parse_params(\"5:1;10:2;15:3\")\n    [[5, 1], [10, 2], [15, 3]]","title":"Examples - Raxol.Terminal.Commands.Parser.parse_params/1","ref":"Raxol.Terminal.Commands.Parser.html#parse_params/1-examples"},{"type":"module","doc":"Handles screen manipulation commands in the terminal.\n\nThis module provides functions for clearing the screen or parts of it,\ninserting and deleting lines, and other screen manipulation operations.","title":"Raxol.Terminal.Commands.Screen","ref":"Raxol.Terminal.Commands.Screen.html"},{"type":"function","doc":"Clears a line or part of a line based on the mode parameter.","title":"Raxol.Terminal.Commands.Screen.clear_line/2","ref":"Raxol.Terminal.Commands.Screen.html#clear_line/2"},{"type":"function","doc":"* `emulator` - The current emulator state\n* `mode` - The clear mode:\n  * 0 - Clear from cursor to end of line\n  * 1 - Clear from beginning of line to cursor\n  * 2 - Clear entire line","title":"Parameters - Raxol.Terminal.Commands.Screen.clear_line/2","ref":"Raxol.Terminal.Commands.Screen.html#clear_line/2-parameters"},{"type":"function","doc":"* Updated emulator state","title":"Returns - Raxol.Terminal.Commands.Screen.clear_line/2","ref":"Raxol.Terminal.Commands.Screen.html#clear_line/2-returns"},{"type":"function","doc":"Clears the screen or a part of it based on the mode parameter.","title":"Raxol.Terminal.Commands.Screen.clear_screen/2","ref":"Raxol.Terminal.Commands.Screen.html#clear_screen/2"},{"type":"function","doc":"* `emulator` - The current emulator state\n* `mode` - The clear mode:\n  * 0 - Clear from cursor to end of screen\n  * 1 - Clear from beginning of screen to cursor\n  * 2 - Clear entire screen but don't move cursor\n  * 3 - Clear entire screen including scrollback","title":"Parameters - Raxol.Terminal.Commands.Screen.clear_screen/2","ref":"Raxol.Terminal.Commands.Screen.html#clear_screen/2-parameters"},{"type":"function","doc":"* Updated emulator state","title":"Returns - Raxol.Terminal.Commands.Screen.clear_screen/2","ref":"Raxol.Terminal.Commands.Screen.html#clear_screen/2-returns"},{"type":"function","doc":"Deletes lines at the current cursor position.","title":"Raxol.Terminal.Commands.Screen.delete_lines/2","ref":"Raxol.Terminal.Commands.Screen.html#delete_lines/2"},{"type":"function","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to delete","title":"Parameters - Raxol.Terminal.Commands.Screen.delete_lines/2","ref":"Raxol.Terminal.Commands.Screen.html#delete_lines/2-parameters"},{"type":"function","doc":"* Updated emulator state","title":"Returns - Raxol.Terminal.Commands.Screen.delete_lines/2","ref":"Raxol.Terminal.Commands.Screen.html#delete_lines/2-returns"},{"type":"function","doc":"Inserts blank lines at the current cursor position.","title":"Raxol.Terminal.Commands.Screen.insert_lines/2","ref":"Raxol.Terminal.Commands.Screen.html#insert_lines/2"},{"type":"function","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to insert","title":"Parameters - Raxol.Terminal.Commands.Screen.insert_lines/2","ref":"Raxol.Terminal.Commands.Screen.html#insert_lines/2-parameters"},{"type":"function","doc":"* Updated emulator state","title":"Returns - Raxol.Terminal.Commands.Screen.insert_lines/2","ref":"Raxol.Terminal.Commands.Screen.html#insert_lines/2-returns"},{"type":"function","doc":"Scrolls the screen down.","title":"Raxol.Terminal.Commands.Screen.scroll_down/2","ref":"Raxol.Terminal.Commands.Screen.html#scroll_down/2"},{"type":"function","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to scroll","title":"Parameters - Raxol.Terminal.Commands.Screen.scroll_down/2","ref":"Raxol.Terminal.Commands.Screen.html#scroll_down/2-parameters"},{"type":"function","doc":"* Updated emulator state","title":"Returns - Raxol.Terminal.Commands.Screen.scroll_down/2","ref":"Raxol.Terminal.Commands.Screen.html#scroll_down/2-returns"},{"type":"function","doc":"Scrolls the screen up.","title":"Raxol.Terminal.Commands.Screen.scroll_up/2","ref":"Raxol.Terminal.Commands.Screen.html#scroll_up/2"},{"type":"function","doc":"* `emulator` - The current emulator state\n* `count` - The number of lines to scroll","title":"Parameters - Raxol.Terminal.Commands.Screen.scroll_up/2","ref":"Raxol.Terminal.Commands.Screen.html#scroll_up/2-parameters"},{"type":"function","doc":"* Updated emulator state","title":"Returns - Raxol.Terminal.Commands.Screen.scroll_up/2","ref":"Raxol.Terminal.Commands.Screen.html#scroll_up/2-returns"},{"type":"module","doc":"Handles window manipulation related CSI commands.\nThese commands are used to control the terminal window's position, size, and state.","title":"Raxol.Terminal.Commands.WindowHandlers","ref":"Raxol.Terminal.Commands.WindowHandlers.html"},{"type":"function","doc":"Handles window manipulation commands (CSI t).","title":"Raxol.Terminal.Commands.WindowHandlers.handle_t/2","ref":"Raxol.Terminal.Commands.WindowHandlers.html#handle_t/2"},{"type":"module","doc":"Terminal configuration system.\n\nThis module is the main entry point for terminal configuration, providing\na simplified interface to the underlying configuration modules.","title":"Raxol.Terminal.Config","ref":"Raxol.Terminal.Config.html"},{"type":"function","doc":"Applies a configuration to the terminal.","title":"Raxol.Terminal.Config.apply_config/2","ref":"Raxol.Terminal.Config.html#apply_config/2"},{"type":"function","doc":"* `config` - The configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","title":"Parameters - Raxol.Terminal.Config.apply_config/2","ref":"Raxol.Terminal.Config.html#apply_config/2-parameters"},{"type":"function","doc":"`{:ok, applied_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.apply_config/2","ref":"Raxol.Terminal.Config.html#apply_config/2-returns"},{"type":"function","doc":"Applies a partial configuration update to the terminal.","title":"Raxol.Terminal.Config.apply_partial_config/2","ref":"Raxol.Terminal.Config.html#apply_partial_config/2"},{"type":"function","doc":"* `partial_config` - The partial configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","title":"Parameters - Raxol.Terminal.Config.apply_partial_config/2","ref":"Raxol.Terminal.Config.html#apply_partial_config/2-parameters"},{"type":"function","doc":"`{:ok, updated_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.apply_partial_config/2","ref":"Raxol.Terminal.Config.html#apply_partial_config/2-returns"},{"type":"function","doc":"Returns the configuration schema.","title":"Raxol.Terminal.Config.config_schema/0","ref":"Raxol.Terminal.Config.html#config_schema/0"},{"type":"function","doc":"A map defining the structure and types for all configuration options.","title":"Returns - Raxol.Terminal.Config.config_schema/0","ref":"Raxol.Terminal.Config.html#config_schema/0-returns"},{"type":"function","doc":"Detects terminal capabilities based on the environment.","title":"Raxol.Terminal.Config.detect_capabilities/0","ref":"Raxol.Terminal.Config.html#detect_capabilities/0"},{"type":"function","doc":"A map of detected capabilities.","title":"Returns - Raxol.Terminal.Config.detect_capabilities/0","ref":"Raxol.Terminal.Config.html#detect_capabilities/0-returns"},{"type":"function","doc":"Generates a default configuration based on terminal capabilities.","title":"Raxol.Terminal.Config.generate_default_config/0","ref":"Raxol.Terminal.Config.html#generate_default_config/0"},{"type":"function","doc":"A map containing default configuration values for all settings.","title":"Returns - Raxol.Terminal.Config.generate_default_config/0","ref":"Raxol.Terminal.Config.html#generate_default_config/0-returns"},{"type":"function","doc":"Gets the current terminal configuration.","title":"Raxol.Terminal.Config.get_current_config/1","ref":"Raxol.Terminal.Config.html#get_current_config/1"},{"type":"function","doc":"* `terminal_pid` - The PID of the terminal process (optional)","title":"Parameters - Raxol.Terminal.Config.get_current_config/1","ref":"Raxol.Terminal.Config.html#get_current_config/1-parameters"},{"type":"function","doc":"The current terminal configuration.","title":"Returns - Raxol.Terminal.Config.get_current_config/1","ref":"Raxol.Terminal.Config.html#get_current_config/1-returns"},{"type":"function","doc":"Returns the type information for a specific configuration path.","title":"Raxol.Terminal.Config.get_type/1","ref":"Raxol.Terminal.Config.html#get_type/1"},{"type":"function","doc":"* `path` - A list of keys representing the path to the configuration value","title":"Parameters - Raxol.Terminal.Config.get_type/1","ref":"Raxol.Terminal.Config.html#get_type/1-parameters"},{"type":"function","doc":"A tuple with type information or nil if the path doesn't exist","title":"Returns - Raxol.Terminal.Config.get_type/1","ref":"Raxol.Terminal.Config.html#get_type/1-returns"},{"type":"function","doc":"Lists all available terminal configuration profiles.","title":"Raxol.Terminal.Config.list_profiles/0","ref":"Raxol.Terminal.Config.html#list_profiles/0"},{"type":"function","doc":"A list of profile names.","title":"Returns - Raxol.Terminal.Config.list_profiles/0","ref":"Raxol.Terminal.Config.html#list_profiles/0-returns"},{"type":"function","doc":"Loads terminal configuration from the default path.","title":"Raxol.Terminal.Config.load_config/0","ref":"Raxol.Terminal.Config.html#load_config/0"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.load_config/0","ref":"Raxol.Terminal.Config.html#load_config/0-returns"},{"type":"function","doc":"Loads terminal configuration from the specified path.","title":"Raxol.Terminal.Config.load_config/1","ref":"Raxol.Terminal.Config.html#load_config/1"},{"type":"function","doc":"* `path` - The file path to load from","title":"Parameters - Raxol.Terminal.Config.load_config/1","ref":"Raxol.Terminal.Config.html#load_config/1-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.load_config/1","ref":"Raxol.Terminal.Config.html#load_config/1-returns"},{"type":"function","doc":"Loads a specific terminal configuration profile.","title":"Raxol.Terminal.Config.load_profile/1","ref":"Raxol.Terminal.Config.html#load_profile/1"},{"type":"function","doc":"* `name` - The name of the profile to load","title":"Parameters - Raxol.Terminal.Config.load_profile/1","ref":"Raxol.Terminal.Config.html#load_profile/1-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.load_profile/1","ref":"Raxol.Terminal.Config.html#load_profile/1-returns"},{"type":"function","doc":"Merges configuration options into an existing configuration map.\n\nDelegates to `Raxol.Terminal.Config.Utils.merge_opts/2`.","title":"Raxol.Terminal.Config.merge_opts/2","ref":"Raxol.Terminal.Config.html#merge_opts/2"},{"type":"function","doc":"Creates an optimized configuration based on detected capabilities.","title":"Raxol.Terminal.Config.optimized_config/0","ref":"Raxol.Terminal.Config.html#optimized_config/0"},{"type":"function","doc":"An optimized configuration for the current terminal.","title":"Returns - Raxol.Terminal.Config.optimized_config/0","ref":"Raxol.Terminal.Config.html#optimized_config/0-returns"},{"type":"function","doc":"Resets terminal configuration to default values.","title":"Raxol.Terminal.Config.reset_config/2","ref":"Raxol.Terminal.Config.html#reset_config/2"},{"type":"function","doc":"* `terminal_pid` - The PID of the terminal process (optional)\n* `optimize` - Whether to optimize for detected capabilities (default: true)","title":"Parameters - Raxol.Terminal.Config.reset_config/2","ref":"Raxol.Terminal.Config.html#reset_config/2-parameters"},{"type":"function","doc":"`{:ok, default_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.reset_config/2","ref":"Raxol.Terminal.Config.html#reset_config/2-returns"},{"type":"function","doc":"Saves terminal configuration to the default path.","title":"Raxol.Terminal.Config.save_config/1","ref":"Raxol.Terminal.Config.html#save_config/1"},{"type":"function","doc":"* `config` - The configuration to save","title":"Parameters - Raxol.Terminal.Config.save_config/1","ref":"Raxol.Terminal.Config.html#save_config/1-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.save_config/1","ref":"Raxol.Terminal.Config.html#save_config/1-returns"},{"type":"function","doc":"Saves terminal configuration to the specified path.","title":"Raxol.Terminal.Config.save_config/2","ref":"Raxol.Terminal.Config.html#save_config/2"},{"type":"function","doc":"* `config` - The configuration to save\n* `path` - The file path to save to","title":"Parameters - Raxol.Terminal.Config.save_config/2","ref":"Raxol.Terminal.Config.html#save_config/2-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.save_config/2","ref":"Raxol.Terminal.Config.html#save_config/2-returns"},{"type":"function","doc":"Saves the current configuration as a profile.","title":"Raxol.Terminal.Config.save_profile/2","ref":"Raxol.Terminal.Config.html#save_profile/2"},{"type":"function","doc":"* `name` - The name of the profile to save\n* `config` - The configuration to save","title":"Parameters - Raxol.Terminal.Config.save_profile/2","ref":"Raxol.Terminal.Config.html#save_profile/2-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.save_profile/2","ref":"Raxol.Terminal.Config.html#save_profile/2-returns"},{"type":"function","doc":"Validates a complete terminal configuration.","title":"Raxol.Terminal.Config.validate_config/1","ref":"Raxol.Terminal.Config.html#validate_config/1"},{"type":"function","doc":"* `config` - The configuration to validate","title":"Parameters - Raxol.Terminal.Config.validate_config/1","ref":"Raxol.Terminal.Config.html#validate_config/1-parameters"},{"type":"function","doc":"`{:ok, validated_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.validate_config/1","ref":"Raxol.Terminal.Config.html#validate_config/1-returns"},{"type":"function","doc":"Validates a specific configuration value against its schema.","title":"Raxol.Terminal.Config.validate_value/2","ref":"Raxol.Terminal.Config.html#validate_value/2"},{"type":"function","doc":"* `path` - A list of keys representing the path to the configuration value\n* `value` - The value to validate","title":"Parameters - Raxol.Terminal.Config.validate_value/2","ref":"Raxol.Terminal.Config.html#validate_value/2-parameters"},{"type":"function","doc":"`{:ok, validated_value}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.validate_value/2","ref":"Raxol.Terminal.Config.html#validate_value/2-returns"},{"type":"module","doc":"Manages caching for terminal animations.","title":"Raxol.Terminal.Config.AnimationCache","ref":"Raxol.Terminal.Config.AnimationCache.html"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.cache_animation/2","ref":"Raxol.Terminal.Config.AnimationCache.html#cache_animation/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.clear_animation_cache/0","ref":"Raxol.Terminal.Config.AnimationCache.html#clear_animation_cache/0"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.decompress_animation/1","ref":"Raxol.Terminal.Config.AnimationCache.html#decompress_animation/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.get_animation_cache_stats/0","ref":"Raxol.Terminal.Config.AnimationCache.html#get_animation_cache_stats/0"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.get_cache_size/0","ref":"Raxol.Terminal.Config.AnimationCache.html#get_cache_size/0"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.get_cached_animation/1","ref":"Raxol.Terminal.Config.AnimationCache.html#get_cached_animation/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.init_animation_cache/0","ref":"Raxol.Terminal.Config.AnimationCache.html#init_animation_cache/0"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.preload_animation/1","ref":"Raxol.Terminal.Config.AnimationCache.html#preload_animation/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Config.AnimationCache.preload_animations/0","ref":"Raxol.Terminal.Config.AnimationCache.html#preload_animations/0"},{"type":"module","doc":"Terminal configuration application.\n\nThis module handles applying configuration settings to the terminal,\nensuring all changes are properly propagated throughout the system.","title":"Raxol.Terminal.Config.Application","ref":"Raxol.Terminal.Config.Application.html"},{"type":"function","doc":"Applies a configuration to the terminal.\n\nThis function takes a configuration and applies it to the current terminal\ninstance, updating the terminal state and behavior.","title":"Raxol.Terminal.Config.Application.apply_config/2","ref":"Raxol.Terminal.Config.Application.html#apply_config/2"},{"type":"function","doc":"* `config` - The configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","title":"Parameters - Raxol.Terminal.Config.Application.apply_config/2","ref":"Raxol.Terminal.Config.Application.html#apply_config/2-parameters"},{"type":"function","doc":"`{:ok, applied_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Application.apply_config/2","ref":"Raxol.Terminal.Config.Application.html#apply_config/2-returns"},{"type":"function","doc":"Applies a partial configuration update to the terminal.\n\nThis allows updating only specific parts of the configuration without\nchanging other settings.","title":"Raxol.Terminal.Config.Application.apply_partial_config/2","ref":"Raxol.Terminal.Config.Application.html#apply_partial_config/2"},{"type":"function","doc":"* `partial_config` - The partial configuration to apply\n* `terminal_pid` - The PID of the terminal process (optional)","title":"Parameters - Raxol.Terminal.Config.Application.apply_partial_config/2","ref":"Raxol.Terminal.Config.Application.html#apply_partial_config/2-parameters"},{"type":"function","doc":"`{:ok, updated_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Application.apply_partial_config/2","ref":"Raxol.Terminal.Config.Application.html#apply_partial_config/2-returns"},{"type":"function","doc":"Gets the current terminal configuration.","title":"Raxol.Terminal.Config.Application.get_current_config/1","ref":"Raxol.Terminal.Config.Application.html#get_current_config/1"},{"type":"function","doc":"* `terminal_pid` - The PID of the terminal process (optional)","title":"Parameters - Raxol.Terminal.Config.Application.get_current_config/1","ref":"Raxol.Terminal.Config.Application.html#get_current_config/1-parameters"},{"type":"function","doc":"The current terminal configuration.","title":"Returns - Raxol.Terminal.Config.Application.get_current_config/1","ref":"Raxol.Terminal.Config.Application.html#get_current_config/1-returns"},{"type":"function","doc":"Resets terminal configuration to default values.","title":"Raxol.Terminal.Config.Application.reset_config/2","ref":"Raxol.Terminal.Config.Application.html#reset_config/2"},{"type":"function","doc":"* `terminal_pid` - The PID of the terminal process (optional)\n* `optimize` - Whether to optimize for detected capabilities (default: true)","title":"Parameters - Raxol.Terminal.Config.Application.reset_config/2","ref":"Raxol.Terminal.Config.Application.html#reset_config/2-parameters"},{"type":"function","doc":"`{:ok, default_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Application.reset_config/2","ref":"Raxol.Terminal.Config.Application.html#reset_config/2-returns"},{"type":"module","doc":"Terminal capability detection and management.\n\nProvides functionality to detect and determine terminal capabilities\nsuch as color support, unicode support, etc.","title":"Raxol.Terminal.Config.Capabilities","ref":"Raxol.Terminal.Config.Capabilities.html"},{"type":"function","doc":"Merges detected capabilities with configuration using a specific adapter.\n\nTakes a terminal configuration and enhances it with detected capabilities\nwhere those capabilities aren't already explicitly configured.","title":"Raxol.Terminal.Config.Capabilities.apply_capabilities/2","ref":"Raxol.Terminal.Config.Capabilities.html#apply_capabilities/2"},{"type":"function","doc":"* `config` - The existing configuration\n* `adapter_module` - The module implementing `EnvironmentAdapterBehaviour`.","title":"Parameters - Raxol.Terminal.Config.Capabilities.apply_capabilities/2","ref":"Raxol.Terminal.Config.Capabilities.html#apply_capabilities/2-parameters"},{"type":"function","doc":"The configuration enhanced with detected capabilities.","title":"Returns - Raxol.Terminal.Config.Capabilities.apply_capabilities/2","ref":"Raxol.Terminal.Config.Capabilities.html#apply_capabilities/2-returns"},{"type":"function","doc":"Detects terminal capabilities based on the environment using a specific adapter.\n\nThis examines environment variables, terminal responses, and other indicators\nto determine capabilities of the current terminal.","title":"Raxol.Terminal.Config.Capabilities.detect_capabilities/1","ref":"Raxol.Terminal.Config.Capabilities.html#detect_capabilities/1"},{"type":"function","doc":"* `adapter_module` - The module implementing `EnvironmentAdapterBehaviour`.","title":"Parameters - Raxol.Terminal.Config.Capabilities.detect_capabilities/1","ref":"Raxol.Terminal.Config.Capabilities.html#detect_capabilities/1-parameters"},{"type":"function","doc":"A map of detected capabilities.","title":"Returns - Raxol.Terminal.Config.Capabilities.detect_capabilities/1","ref":"Raxol.Terminal.Config.Capabilities.html#detect_capabilities/1-returns"},{"type":"function","doc":"Creates an optimized configuration based on detected capabilities using the default adapter.\n\nThis generates a configuration that's optimized for the current terminal\nenvironment, balancing features and performance.","title":"Raxol.Terminal.Config.Capabilities.optimized_config/0","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/0"},{"type":"function","doc":"An optimized configuration for the current terminal.","title":"Returns - Raxol.Terminal.Config.Capabilities.optimized_config/0","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/0-returns"},{"type":"function","doc":"Creates an optimized configuration based on detected capabilities using a specific adapter.","title":"Raxol.Terminal.Config.Capabilities.optimized_config/1","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/1"},{"type":"function","doc":"* `adapter_module` - The module implementing `EnvironmentAdapterBehaviour`.","title":"Parameters - Raxol.Terminal.Config.Capabilities.optimized_config/1","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/1-parameters"},{"type":"function","doc":"An optimized configuration for the current terminal.","title":"Returns - Raxol.Terminal.Config.Capabilities.optimized_config/1","ref":"Raxol.Terminal.Config.Capabilities.html#optimized_config/1-returns"},{"type":"module","doc":"Default terminal configuration values.\n\nProvides functions for generating default terminal configurations.","title":"Raxol.Terminal.Config.Defaults","ref":"Raxol.Terminal.Config.Defaults.html"},{"type":"function","doc":"Generates a default animation configuration.","title":"Raxol.Terminal.Config.Defaults.default_animation_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_animation_config/0"},{"type":"function","doc":"A map containing default animation configuration values.","title":"Returns - Raxol.Terminal.Config.Defaults.default_animation_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_animation_config/0-returns"},{"type":"function","doc":"Generates a default background configuration.","title":"Raxol.Terminal.Config.Defaults.default_background_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_background_config/0"},{"type":"function","doc":"A map containing default background configuration values.","title":"Returns - Raxol.Terminal.Config.Defaults.default_background_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_background_config/0-returns"},{"type":"function","doc":"Generates a default behavior configuration.","title":"Raxol.Terminal.Config.Defaults.default_behavior_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_behavior_config/0"},{"type":"function","doc":"A map containing default behavior configuration values.","title":"Returns - Raxol.Terminal.Config.Defaults.default_behavior_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_behavior_config/0-returns"},{"type":"function","doc":"Generates a default display configuration.","title":"Raxol.Terminal.Config.Defaults.default_display_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_display_config/0"},{"type":"function","doc":"A map containing default display configuration values.","title":"Returns - Raxol.Terminal.Config.Defaults.default_display_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_display_config/0-returns"},{"type":"function","doc":"Generates a default rendering configuration.","title":"Raxol.Terminal.Config.Defaults.default_rendering_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_rendering_config/0"},{"type":"function","doc":"A map containing default rendering configuration values.","title":"Returns - Raxol.Terminal.Config.Defaults.default_rendering_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_rendering_config/0-returns"},{"type":"function","doc":"Generates a default system/performance configuration.","title":"Raxol.Terminal.Config.Defaults.default_system_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_system_config/0"},{"type":"function","doc":"A map containing default system/performance configuration values.","title":"Returns - Raxol.Terminal.Config.Defaults.default_system_config/0","ref":"Raxol.Terminal.Config.Defaults.html#default_system_config/0-returns"},{"type":"function","doc":"Generates a default configuration map merging all specific defaults.\n\nThis map represents the base configuration before any detection or user overrides.","title":"Raxol.Terminal.Config.Defaults.generate_default_config/0","ref":"Raxol.Terminal.Config.Defaults.html#generate_default_config/0"},{"type":"function","doc":"A map containing default configuration values for all settings.","title":"Returns - Raxol.Terminal.Config.Defaults.generate_default_config/0","ref":"Raxol.Terminal.Config.Defaults.html#generate_default_config/0-returns"},{"type":"behaviour","doc":"Defines the behaviour for terminal environment configuration.\n\nThis behaviour is responsible for:\n- Managing terminal environment variables\n- Handling terminal configuration\n- Providing environment-specific settings\n- Adapting to different terminal environments","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html"},{"type":"callback","doc":"Gets all environment variables.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.get_all_env/0","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:get_all_env/0"},{"type":"callback","doc":"Gets the value of an environment variable.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.get_env/1","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:get_env/1"},{"type":"callback","doc":"Gets terminal-specific configuration.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.get_terminal_config/0","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:get_terminal_config/0"},{"type":"callback","doc":"Gets the current terminal type.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.get_terminal_type/0","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:get_terminal_type/0"},{"type":"callback","doc":"Sets an environment variable.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.set_env/2","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:set_env/2"},{"type":"callback","doc":"Checks if a specific terminal feature is supported.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.supports_feature?/1","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:supports_feature?/1"},{"type":"callback","doc":"Updates terminal configuration.","title":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.update_terminal_config/1","ref":"Raxol.Terminal.Config.EnvironmentAdapterBehaviour.html#c:update_terminal_config/1"},{"type":"module","doc":"Handles loading and saving terminal configuration.\n\nProvides functions for persisting configuration to disk and loading it back.","title":"Raxol.Terminal.Config.Persistence","ref":"Raxol.Terminal.Config.Persistence.html"},{"type":"function","doc":"Loads terminal configuration from the default path.\n\nIf the configuration file doesn't exist, returns the default configuration.","title":"Raxol.Terminal.Config.Persistence.load_config/0","ref":"Raxol.Terminal.Config.Persistence.html#load_config/0"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Persistence.load_config/0","ref":"Raxol.Terminal.Config.Persistence.html#load_config/0-returns"},{"type":"function","doc":"Loads terminal configuration from the specified path.\n\nIf the configuration file doesn't exist, returns the default configuration.","title":"Raxol.Terminal.Config.Persistence.load_config/1","ref":"Raxol.Terminal.Config.Persistence.html#load_config/1"},{"type":"function","doc":"* `path` - The file path to load from","title":"Parameters - Raxol.Terminal.Config.Persistence.load_config/1","ref":"Raxol.Terminal.Config.Persistence.html#load_config/1-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Persistence.load_config/1","ref":"Raxol.Terminal.Config.Persistence.html#load_config/1-returns"},{"type":"function","doc":"Parses configuration from JSON string.","title":"Raxol.Terminal.Config.Persistence.parse_config/1","ref":"Raxol.Terminal.Config.Persistence.html#parse_config/1"},{"type":"function","doc":"* `json` - The JSON string to parse","title":"Parameters - Raxol.Terminal.Config.Persistence.parse_config/1","ref":"Raxol.Terminal.Config.Persistence.html#parse_config/1-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Persistence.parse_config/1","ref":"Raxol.Terminal.Config.Persistence.html#parse_config/1-returns"},{"type":"function","doc":"Saves terminal configuration to the default path.","title":"Raxol.Terminal.Config.Persistence.save_config/1","ref":"Raxol.Terminal.Config.Persistence.html#save_config/1"},{"type":"function","doc":"* `config` - The configuration to save","title":"Parameters - Raxol.Terminal.Config.Persistence.save_config/1","ref":"Raxol.Terminal.Config.Persistence.html#save_config/1-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Persistence.save_config/1","ref":"Raxol.Terminal.Config.Persistence.html#save_config/1-returns"},{"type":"function","doc":"Saves terminal configuration to the specified path.","title":"Raxol.Terminal.Config.Persistence.save_config/2","ref":"Raxol.Terminal.Config.Persistence.html#save_config/2"},{"type":"function","doc":"* `config` - The configuration to save\n* `path` - The file path to save to","title":"Parameters - Raxol.Terminal.Config.Persistence.save_config/2","ref":"Raxol.Terminal.Config.Persistence.html#save_config/2-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Persistence.save_config/2","ref":"Raxol.Terminal.Config.Persistence.html#save_config/2-returns"},{"type":"module","doc":"Terminal configuration profile management.\n\nAllows users to define, save, load, and switch between different\nterminal configuration profiles.","title":"Raxol.Terminal.Config.Profiles","ref":"Raxol.Terminal.Config.Profiles.html"},{"type":"type","doc":"","title":"Raxol.Terminal.Config.Profiles.animation_type/0","ref":"Raxol.Terminal.Config.Profiles.html#t:animation_type/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Config.Profiles.background_type/0","ref":"Raxol.Terminal.Config.Profiles.html#t:background_type/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Config.Profiles.color_mode/0","ref":"Raxol.Terminal.Config.Profiles.html#t:color_mode/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Config.Profiles.config/0","ref":"Raxol.Terminal.Config.Profiles.html#t:config/0"},{"type":"function","doc":"Creates a new profile with default settings.","title":"Raxol.Terminal.Config.Profiles.create_default_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#create_default_profile/1"},{"type":"function","doc":"* `name` - The name of the new profile","title":"Parameters - Raxol.Terminal.Config.Profiles.create_default_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#create_default_profile/1-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Profiles.create_default_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#create_default_profile/1-returns"},{"type":"function","doc":"Deletes a terminal configuration profile.","title":"Raxol.Terminal.Config.Profiles.delete_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#delete_profile/1"},{"type":"function","doc":"* `name` - The name of the profile to delete","title":"Parameters - Raxol.Terminal.Config.Profiles.delete_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#delete_profile/1-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Profiles.delete_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#delete_profile/1-returns"},{"type":"function","doc":"Duplicates an existing profile with a new name.","title":"Raxol.Terminal.Config.Profiles.duplicate_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#duplicate_profile/2"},{"type":"function","doc":"* `source_name` - The name of the profile to duplicate\n* `target_name` - The name for the new profile","title":"Parameters - Raxol.Terminal.Config.Profiles.duplicate_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#duplicate_profile/2-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Profiles.duplicate_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#duplicate_profile/2-returns"},{"type":"function","doc":"Lists all available terminal configuration profiles.","title":"Raxol.Terminal.Config.Profiles.list_profiles/0","ref":"Raxol.Terminal.Config.Profiles.html#list_profiles/0"},{"type":"function","doc":"A list of profile names.","title":"Returns - Raxol.Terminal.Config.Profiles.list_profiles/0","ref":"Raxol.Terminal.Config.Profiles.html#list_profiles/0-returns"},{"type":"function","doc":"Loads a specific terminal configuration profile.","title":"Raxol.Terminal.Config.Profiles.load_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#load_profile/1"},{"type":"function","doc":"* `name` - The name of the profile to load","title":"Parameters - Raxol.Terminal.Config.Profiles.load_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#load_profile/1-parameters"},{"type":"function","doc":"`{:ok, config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Profiles.load_profile/1","ref":"Raxol.Terminal.Config.Profiles.html#load_profile/1-returns"},{"type":"function","doc":"Saves the current configuration as a profile.","title":"Raxol.Terminal.Config.Profiles.save_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#save_profile/2"},{"type":"function","doc":"* `name` - The name of the profile to save\n* `config` - The configuration to save","title":"Parameters - Raxol.Terminal.Config.Profiles.save_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#save_profile/2-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Profiles.save_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#save_profile/2-returns"},{"type":"type","doc":"","title":"Raxol.Terminal.Config.Profiles.terminal_type/0","ref":"Raxol.Terminal.Config.Profiles.html#t:terminal_type/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Config.Profiles.theme_map/0","ref":"Raxol.Terminal.Config.Profiles.html#t:theme_map/0"},{"type":"function","doc":"Updates an existing profile with new settings.","title":"Raxol.Terminal.Config.Profiles.update_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#update_profile/2"},{"type":"function","doc":"* `name` - The name of the profile to update\n* `config` - The new configuration","title":"Parameters - Raxol.Terminal.Config.Profiles.update_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#update_profile/2-parameters"},{"type":"function","doc":"`:ok` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Profiles.update_profile/2","ref":"Raxol.Terminal.Config.Profiles.html#update_profile/2-returns"},{"type":"module","doc":"Schema definitions for terminal configuration.\n\nDefines the structure and types for all terminal configuration options.","title":"Raxol.Terminal.Config.Schema","ref":"Raxol.Terminal.Config.Schema.html"},{"type":"function","doc":"Defines the schema for terminal configuration.\n\nThis includes all possible configuration fields with their types,\ndefault values, and descriptions.","title":"Raxol.Terminal.Config.Schema.config_schema/0","ref":"Raxol.Terminal.Config.Schema.html#config_schema/0"},{"type":"function","doc":"Returns the default configuration values.\nThis delegates to the Defaults module for actual values.","title":"Raxol.Terminal.Config.Schema.default_config/0","ref":"Raxol.Terminal.Config.Schema.html#default_config/0"},{"type":"function","doc":"Returns the type information for a specific configuration path.","title":"Raxol.Terminal.Config.Schema.get_type/1","ref":"Raxol.Terminal.Config.Schema.html#get_type/1"},{"type":"function","doc":"* `path` - A list of keys representing the path to the configuration value","title":"Parameters - Raxol.Terminal.Config.Schema.get_type/1","ref":"Raxol.Terminal.Config.Schema.html#get_type/1-parameters"},{"type":"function","doc":"A tuple with type information or nil if the path doesn't exist","title":"Returns - Raxol.Terminal.Config.Schema.get_type/1","ref":"Raxol.Terminal.Config.Schema.html#get_type/1-returns"},{"type":"module","doc":"Utility functions for handling terminal configuration maps.","title":"Raxol.Terminal.Config.Utils","ref":"Raxol.Terminal.Config.Utils.html"},{"type":"function","doc":"Deeply merges two maps.\n\nKeys in the right map take precedence. If both values for a key are maps,\nthey are merged recursively.","title":"Raxol.Terminal.Config.Utils.deep_merge/2","ref":"Raxol.Terminal.Config.Utils.html#deep_merge/2"},{"type":"function","doc":"Merges configuration options into an existing configuration map.\n\nThe `opts` are first converted into a nested map structure and then\ndeeply merged into the `current_config`.","title":"Raxol.Terminal.Config.Utils.merge_opts/2","ref":"Raxol.Terminal.Config.Utils.html#merge_opts/2"},{"type":"function","doc":"Converts a keyword list or map of potentially nested options into a nested map.\n\nHandles flat keys like `theme: \"light\"` and nested paths represented\nby lists like `[behavior: [scrollback: 100]]` within the keyword list.","title":"Raxol.Terminal.Config.Utils.opts_to_nested_map/1","ref":"Raxol.Terminal.Config.Utils.html#opts_to_nested_map/1"},{"type":"module","doc":"Validation logic for terminal configuration.\n\nEnsures that configuration values are valid according to their schema.","title":"Raxol.Terminal.Config.Validation","ref":"Raxol.Terminal.Config.Validation.html"},{"type":"function","doc":"Validates a complete terminal configuration.","title":"Raxol.Terminal.Config.Validation.validate_config/1","ref":"Raxol.Terminal.Config.Validation.html#validate_config/1"},{"type":"function","doc":"* `config` - The configuration to validate","title":"Parameters - Raxol.Terminal.Config.Validation.validate_config/1","ref":"Raxol.Terminal.Config.Validation.html#validate_config/1-parameters"},{"type":"function","doc":"`{:ok, validated_config}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Validation.validate_config/1","ref":"Raxol.Terminal.Config.Validation.html#validate_config/1-returns"},{"type":"function","doc":"Validates a specific configuration value against its schema.","title":"Raxol.Terminal.Config.Validation.validate_value/2","ref":"Raxol.Terminal.Config.Validation.html#validate_value/2"},{"type":"function","doc":"* `path` - A list of keys representing the path to the configuration value\n* `value` - The value to validate","title":"Parameters - Raxol.Terminal.Config.Validation.validate_value/2","ref":"Raxol.Terminal.Config.Validation.html#validate_value/2-parameters"},{"type":"function","doc":"`{:ok, validated_value}` or `{:error, reason}`","title":"Returns - Raxol.Terminal.Config.Validation.validate_value/2","ref":"Raxol.Terminal.Config.Validation.html#validate_value/2-returns"},{"type":"module","doc":"Manages the core Raxol terminal configuration struct.\n\nThis module defines the main configuration structure and provides functions\nfor creating and updating configuration based on defaults and user-provided options.\n\nIt collaborates with other modules under `Raxol.Terminal.Config.*` for specific\nfunctionalities like defaults, profiles, capabilities detection, and applying\nsettings to the running terminal.","title":"Raxol.Terminal.Configuration","ref":"Raxol.Terminal.Configuration.html"},{"type":"type","doc":"","title":"Raxol.Terminal.Configuration.animation_type/0","ref":"Raxol.Terminal.Configuration.html#t:animation_type/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Configuration.background_type/0","ref":"Raxol.Terminal.Configuration.html#t:background_type/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Configuration.color_mode/0","ref":"Raxol.Terminal.Configuration.html#t:color_mode/0"},{"type":"function","doc":"Creates a new configuration struct, merging defaults with provided options.\n\nFetches the base default configuration map and then merges any overrides\nprovided in `opts`. The final result is converted into the `%__MODULE__{}` struct.","title":"Raxol.Terminal.Configuration.new/1","ref":"Raxol.Terminal.Configuration.html#new/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Configuration.t/0","ref":"Raxol.Terminal.Configuration.html#t:t/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Configuration.terminal_type/0","ref":"Raxol.Terminal.Configuration.html#t:terminal_type/0"},{"type":"function","doc":"Updates an existing configuration struct with new values from a keyword list.","title":"Raxol.Terminal.Configuration.update/2","ref":"Raxol.Terminal.Configuration.html#update/2"},{"type":"module","doc":"Re-exports constants from ExTermbox NIF v2.0.1 for use within Raxol.\n\nThis module provides a convenience wrapper around the constant values\ndefined in the ExTermbox module.","title":"Raxol.Terminal.Constants","ref":"Raxol.Terminal.Constants.html"},{"type":"function","doc":"Returns the numeric value for the given attribute name","title":"Raxol.Terminal.Constants.attribute/1","ref":"Raxol.Terminal.Constants.html#attribute/1"},{"type":"function","doc":"Returns the numeric value for the given color name","title":"Raxol.Terminal.Constants.color/1","ref":"Raxol.Terminal.Constants.html#color/1"},{"type":"function","doc":"Returns the numeric value for the given event type","title":"Raxol.Terminal.Constants.event_type/1","ref":"Raxol.Terminal.Constants.html#event_type/1"},{"type":"function","doc":"Returns the numeric value for the given key name","title":"Raxol.Terminal.Constants.key/1","ref":"Raxol.Terminal.Constants.html#key/1"},{"type":"module","doc":"Handles C0 control codes and simple ESC sequences.\n\nExtracted from Terminal.Emulator for better organization.\nRelies on Emulator state and ScreenBuffer for actions.","title":"Raxol.Terminal.ControlCodes","ref":"Raxol.Terminal.ControlCodes.html"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_bel/1","ref":"Raxol.Terminal.ControlCodes.html#handle_bel/1"},{"type":"function","doc":"Handle Backspace (BS)","title":"Raxol.Terminal.ControlCodes.handle_bs/1","ref":"Raxol.Terminal.ControlCodes.html#handle_bs/1"},{"type":"function","doc":"Handles a C0 control code (0-31) or DEL (127).\nDelegates to specific handlers based on the codepoint.","title":"Raxol.Terminal.ControlCodes.handle_c0/2","ref":"Raxol.Terminal.ControlCodes.html#handle_c0/2"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_can/1","ref":"Raxol.Terminal.ControlCodes.html#handle_can/1"},{"type":"function","doc":"Handle Carriage Return (CR)","title":"Raxol.Terminal.ControlCodes.handle_cr/1","ref":"Raxol.Terminal.ControlCodes.html#handle_cr/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_decrc/1","ref":"Raxol.Terminal.ControlCodes.html#handle_decrc/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_decsc/1","ref":"Raxol.Terminal.ControlCodes.html#handle_decsc/1"},{"type":"function","doc":"Handle Horizontal Tab (HT)","title":"Raxol.Terminal.ControlCodes.handle_ht/1","ref":"Raxol.Terminal.ControlCodes.html#handle_ht/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_hts/1","ref":"Raxol.Terminal.ControlCodes.html#handle_hts/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_ind/1","ref":"Raxol.Terminal.ControlCodes.html#handle_ind/1"},{"type":"function","doc":"Handle Line Feed (LF), New Line (NL), Vertical Tab (VT)","title":"Raxol.Terminal.ControlCodes.handle_lf/1","ref":"Raxol.Terminal.ControlCodes.html#handle_lf/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_nel/1","ref":"Raxol.Terminal.ControlCodes.html#handle_nel/1"},{"type":"function","doc":"Handle Reverse Index (RI) - ESC M","title":"Raxol.Terminal.ControlCodes.handle_ri/1","ref":"Raxol.Terminal.ControlCodes.html#handle_ri/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_ris/1","ref":"Raxol.Terminal.ControlCodes.html#handle_ris/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_si/1","ref":"Raxol.Terminal.ControlCodes.html#handle_si/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_so/1","ref":"Raxol.Terminal.ControlCodes.html#handle_so/1"},{"type":"function","doc":"","title":"Raxol.Terminal.ControlCodes.handle_sub/1","ref":"Raxol.Terminal.ControlCodes.html#handle_sub/1"},{"type":"module","doc":"Core state struct for the terminal emulator. This struct holds the main state fields used by the emulator state management functions.","title":"Raxol.Terminal.Core","ref":"Raxol.Terminal.Core.html"},{"type":"type","doc":"","title":"Raxol.Terminal.Core.t/0","ref":"Raxol.Terminal.Core.html#t:t/0"},{"type":"module","doc":"Manages cursor state and operations.","title":"Raxol.Terminal.Cursor.Manager","ref":"Raxol.Terminal.Cursor.Manager.html"},{"type":"function","doc":"Adds the current cursor state to history (stub; not yet implemented).","title":"Raxol.Terminal.Cursor.Manager.add_to_history/1","ref":"Raxol.Terminal.Cursor.Manager.html#add_to_history/1"},{"type":"function","doc":"Clamps a position to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.clamp_position/3","ref":"Raxol.Terminal.Cursor.Manager.html#clamp_position/3"},{"type":"type","doc":"","title":"Raxol.Terminal.Cursor.Manager.cursor/0","ref":"Raxol.Terminal.Cursor.Manager.html#t:cursor/0"},{"type":"function","doc":"Gets the cursor's current position.","title":"Raxol.Terminal.Cursor.Manager.get_position/1","ref":"Raxol.Terminal.Cursor.Manager.html#get_position/1"},{"type":"function","doc":"Gets the cursor's current state.","title":"Raxol.Terminal.Cursor.Manager.get_state/1","ref":"Raxol.Terminal.Cursor.Manager.html#get_state/1"},{"type":"function","doc":"Gets the cursor's current style.","title":"Raxol.Terminal.Cursor.Manager.get_style/1","ref":"Raxol.Terminal.Cursor.Manager.html#get_style/1"},{"type":"function","doc":"Gets whether the cursor is visible.","title":"Raxol.Terminal.Cursor.Manager.is_visible?/1","ref":"Raxol.Terminal.Cursor.Manager.html#is_visible?/1"},{"type":"function","doc":"Moves the cursor down by the specified number of lines, clamped to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.move_down/4","ref":"Raxol.Terminal.Cursor.Manager.html#move_down/4"},{"type":"function","doc":"Moves the cursor left by the specified number of columns, clamped to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.move_left/4","ref":"Raxol.Terminal.Cursor.Manager.html#move_left/4"},{"type":"function","doc":"Moves the cursor right by the specified number of columns, clamped to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.move_right/4","ref":"Raxol.Terminal.Cursor.Manager.html#move_right/4"},{"type":"function","doc":"Moves the cursor to a new position (no clamping, arity 2).","title":"Raxol.Terminal.Cursor.Manager.move_to/2","ref":"Raxol.Terminal.Cursor.Manager.html#move_to/2"},{"type":"function","doc":"Moves the cursor to a new position (no clamping, arity 3 for compatibility).","title":"Raxol.Terminal.Cursor.Manager.move_to/3","ref":"Raxol.Terminal.Cursor.Manager.html#move_to/3"},{"type":"function","doc":"Moves the cursor to a new position (clamped to the screen bounds).","title":"Raxol.Terminal.Cursor.Manager.move_to/4","ref":"Raxol.Terminal.Cursor.Manager.html#move_to/4"},{"type":"function","doc":"Moves the cursor to a new position, clamped to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.move_to/5","ref":"Raxol.Terminal.Cursor.Manager.html#move_to/5"},{"type":"function","doc":"Moves the cursor to the specified column, clamped to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.move_to_column/4","ref":"Raxol.Terminal.Cursor.Manager.html#move_to_column/4"},{"type":"function","doc":"Moves the cursor to the beginning of the line.","title":"Raxol.Terminal.Cursor.Manager.move_to_line_start/1","ref":"Raxol.Terminal.Cursor.Manager.html#move_to_line_start/1"},{"type":"function","doc":"Moves the cursor to the next tab stop.","title":"Raxol.Terminal.Cursor.Manager.move_to_next_tab/3","ref":"Raxol.Terminal.Cursor.Manager.html#move_to_next_tab/3"},{"type":"function","doc":"Moves the cursor to the previous tab stop.","title":"Raxol.Terminal.Cursor.Manager.move_to_previous_tab/2","ref":"Raxol.Terminal.Cursor.Manager.html#move_to_previous_tab/2"},{"type":"function","doc":"Moves the cursor up by the specified number of lines, clamped to the screen bounds.","title":"Raxol.Terminal.Cursor.Manager.move_up/4","ref":"Raxol.Terminal.Cursor.Manager.html#move_up/4"},{"type":"function","doc":"Creates a new cursor with default values.","title":"Raxol.Terminal.Cursor.Manager.new/1","ref":"Raxol.Terminal.Cursor.Manager.html#new/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Cursor.Manager.position/0","ref":"Raxol.Terminal.Cursor.Manager.html#t:position/0"},{"type":"function","doc":"Restores the cursor state from history (stub; not yet implemented).","title":"Raxol.Terminal.Cursor.Manager.restore_from_history/1","ref":"Raxol.Terminal.Cursor.Manager.html#restore_from_history/1"},{"type":"function","doc":"Restores the cursor's saved position (if any).","title":"Raxol.Terminal.Cursor.Manager.restore_position/1","ref":"Raxol.Terminal.Cursor.Manager.html#restore_position/1"},{"type":"function","doc":"Restores the cursor's saved state.","title":"Raxol.Terminal.Cursor.Manager.restore_state/1","ref":"Raxol.Terminal.Cursor.Manager.html#restore_state/1"},{"type":"function","doc":"Saves the cursor's current position (only position, not style or state).","title":"Raxol.Terminal.Cursor.Manager.save_position/1","ref":"Raxol.Terminal.Cursor.Manager.html#save_position/1"},{"type":"function","doc":"Saves the cursor's current state.","title":"Raxol.Terminal.Cursor.Manager.save_state/1","ref":"Raxol.Terminal.Cursor.Manager.html#save_state/1"},{"type":"function","doc":"Sets a custom cursor shape and dimensions.","title":"Raxol.Terminal.Cursor.Manager.set_custom_shape/3","ref":"Raxol.Terminal.Cursor.Manager.html#set_custom_shape/3"},{"type":"function","doc":"Sets the cursor's state.","title":"Raxol.Terminal.Cursor.Manager.set_state/2","ref":"Raxol.Terminal.Cursor.Manager.html#set_state/2"},{"type":"function","doc":"Sets the cursor's style.","title":"Raxol.Terminal.Cursor.Manager.set_style/2","ref":"Raxol.Terminal.Cursor.Manager.html#set_style/2"},{"type":"function","doc":"Sets the cursor visibility.","title":"Raxol.Terminal.Cursor.Manager.set_visibility/2","ref":"Raxol.Terminal.Cursor.Manager.html#set_visibility/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Cursor.Manager.state/0","ref":"Raxol.Terminal.Cursor.Manager.html#t:state/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Cursor.Manager.style/0","ref":"Raxol.Terminal.Cursor.Manager.html#t:style/0"},{"type":"function","doc":"Updates the cursor's blink state.","title":"Raxol.Terminal.Cursor.Manager.update_blink/1","ref":"Raxol.Terminal.Cursor.Manager.html#update_blink/1"},{"type":"module","doc":"Handles cursor movement and positioning for the terminal emulator.\n\nThis module provides functions for moving the cursor in various directions,\nhandling relative and absolute positioning, and managing cursor boundaries.","title":"Raxol.Terminal.Cursor.Movement","ref":"Raxol.Terminal.Cursor.Movement.html"},{"type":"function","doc":"Moves the cursor down by the specified number of lines.","title":"Raxol.Terminal.Cursor.Movement.move_down/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_down/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_down(cursor, 2)\n    iex> cursor.position\n    {0, 2}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_down/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_down/2-examples"},{"type":"function","doc":"Moves the cursor to the home position (0, 0).","title":"Raxol.Terminal.Cursor.Movement.move_home/1","ref":"Raxol.Terminal.Cursor.Movement.html#move_home/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 10, 5)\n    iex> cursor = Movement.move_home(cursor)\n    iex> cursor.position\n    {0, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_home/1","ref":"Raxol.Terminal.Cursor.Movement.html#move_home/1-examples"},{"type":"function","doc":"Moves the cursor left by the specified number of columns.","title":"Raxol.Terminal.Cursor.Movement.move_left/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_left/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 5, 0)\n    iex> cursor = Movement.move_left(cursor, 2)\n    iex> cursor.position\n    {3, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_left/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_left/2-examples"},{"type":"function","doc":"Moves the cursor right by the specified number of columns.","title":"Raxol.Terminal.Cursor.Movement.move_right/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_right/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_right(cursor, 2)\n    iex> cursor.position\n    {2, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_right/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_right/2-examples"},{"type":"function","doc":"Moves the cursor to the specified column.","title":"Raxol.Terminal.Cursor.Movement.move_to_column/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_column/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_column(cursor, 10)\n    iex> cursor.position\n    {10, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_column/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_column/2-examples"},{"type":"function","doc":"Moves the cursor to the specified line.","title":"Raxol.Terminal.Cursor.Movement.move_to_line/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_line(cursor, 5)\n    iex> cursor.position\n    {0, 5}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_line/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line/2-examples"},{"type":"function","doc":"Moves the cursor to the end of the line.","title":"Raxol.Terminal.Cursor.Movement.move_to_line_end/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_end/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_line_end(cursor, 80)\n    iex> cursor.position\n    {79, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_line_end/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_end/2-examples"},{"type":"function","doc":"Moves the cursor to the beginning of the line.","title":"Raxol.Terminal.Cursor.Movement.move_to_line_start/1","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_start/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 10, 0)\n    iex> cursor = Movement.move_to_line_start(cursor)\n    iex> cursor.position\n    {0, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_line_start/1","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_line_start/1-examples"},{"type":"function","doc":"Moves the cursor to the next tab stop.","title":"Raxol.Terminal.Cursor.Movement.move_to_next_tab/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_next_tab/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_next_tab(cursor, 8)\n    iex> cursor.position\n    {8, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_next_tab/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_next_tab/2-examples"},{"type":"function","doc":"Moves the cursor to the specified position.","title":"Raxol.Terminal.Cursor.Movement.move_to_position/3","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_position/3"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_to_position(cursor, 10, 5)\n    iex> cursor.position\n    {10, 5}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_position/3","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_position/3-examples"},{"type":"function","doc":"Moves the cursor to the previous tab stop.","title":"Raxol.Terminal.Cursor.Movement.move_to_prev_tab/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_prev_tab/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.move_to(cursor, 10, 0)\n    iex> cursor = Movement.move_to_prev_tab(cursor, 8)\n    iex> cursor.position\n    {8, 0}","title":"Examples - Raxol.Terminal.Cursor.Movement.move_to_prev_tab/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_to_prev_tab/2-examples"},{"type":"function","doc":"Moves the cursor up by the specified number of lines.","title":"Raxol.Terminal.Cursor.Movement.move_up/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_up/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Movement}\n    iex> cursor = Manager.new()\n    iex> cursor = Movement.move_up(cursor, 2)\n    iex> cursor.position\n    {0, 0}  # Already at top, no change","title":"Examples - Raxol.Terminal.Cursor.Movement.move_up/2","ref":"Raxol.Terminal.Cursor.Movement.html#move_up/2-examples"},{"type":"module","doc":"Handles cursor style and visibility control for the terminal emulator.\n\nThis module provides functions for changing cursor appearance, controlling\nvisibility, and managing cursor blinking.","title":"Raxol.Terminal.Cursor.Style","ref":"Raxol.Terminal.Cursor.Style.html"},{"type":"function","doc":"Makes the cursor blink.","title":"Raxol.Terminal.Cursor.Style.blink/1","ref":"Raxol.Terminal.Cursor.Style.html#blink/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.blink(cursor)\n    iex> cursor.state\n    :blinking","title":"Examples - Raxol.Terminal.Cursor.Style.blink/1","ref":"Raxol.Terminal.Cursor.Style.html#blink/1-examples"},{"type":"function","doc":"Hides the cursor.","title":"Raxol.Terminal.Cursor.Style.hide/1","ref":"Raxol.Terminal.Cursor.Style.html#hide/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.hide(cursor)\n    iex> cursor.state\n    :hidden","title":"Examples - Raxol.Terminal.Cursor.Style.hide/1","ref":"Raxol.Terminal.Cursor.Style.html#hide/1-examples"},{"type":"function","doc":"Sets the cursor style to bar.","title":"Raxol.Terminal.Cursor.Style.set_bar/1","ref":"Raxol.Terminal.Cursor.Style.html#set_bar/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_bar(cursor)\n    iex> cursor.style\n    :bar","title":"Examples - Raxol.Terminal.Cursor.Style.set_bar/1","ref":"Raxol.Terminal.Cursor.Style.html#set_bar/1-examples"},{"type":"function","doc":"Sets the cursor blink rate in milliseconds.","title":"Raxol.Terminal.Cursor.Style.set_blink_rate/2","ref":"Raxol.Terminal.Cursor.Style.html#set_blink_rate/2"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_blink_rate(cursor, 1000)\n    iex> cursor.blink_rate\n    1000","title":"Examples - Raxol.Terminal.Cursor.Style.set_blink_rate/2","ref":"Raxol.Terminal.Cursor.Style.html#set_blink_rate/2-examples"},{"type":"function","doc":"Sets the cursor style to block.","title":"Raxol.Terminal.Cursor.Style.set_block/1","ref":"Raxol.Terminal.Cursor.Style.html#set_block/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_block(cursor)\n    iex> cursor.style\n    :block","title":"Examples - Raxol.Terminal.Cursor.Style.set_block/1","ref":"Raxol.Terminal.Cursor.Style.html#set_block/1-examples"},{"type":"function","doc":"Sets a custom cursor shape.","title":"Raxol.Terminal.Cursor.Style.set_custom/3","ref":"Raxol.Terminal.Cursor.Style.html#set_custom/3"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_custom(cursor, \"█\", {2, 1})\n    iex> cursor.style\n    :custom\n    iex> cursor.custom_shape\n    \"█\"","title":"Examples - Raxol.Terminal.Cursor.Style.set_custom/3","ref":"Raxol.Terminal.Cursor.Style.html#set_custom/3-examples"},{"type":"function","doc":"Sets the cursor style to underline.","title":"Raxol.Terminal.Cursor.Style.set_underline/1","ref":"Raxol.Terminal.Cursor.Style.html#set_underline/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.set_underline(cursor)\n    iex> cursor.style\n    :underline","title":"Examples - Raxol.Terminal.Cursor.Style.set_underline/1","ref":"Raxol.Terminal.Cursor.Style.html#set_underline/1-examples"},{"type":"function","doc":"Makes the cursor visible.","title":"Raxol.Terminal.Cursor.Style.show/1","ref":"Raxol.Terminal.Cursor.Style.html#show/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Manager.set_state(cursor, :hidden)\n    iex> cursor = Style.show(cursor)\n    iex> cursor.state\n    :visible","title":"Examples - Raxol.Terminal.Cursor.Style.show/1","ref":"Raxol.Terminal.Cursor.Style.html#show/1-examples"},{"type":"function","doc":"Toggles the cursor blinking state.","title":"Raxol.Terminal.Cursor.Style.toggle_blink/1","ref":"Raxol.Terminal.Cursor.Style.html#toggle_blink/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.toggle_blink(cursor)\n    iex> cursor.state\n    :blinking\n    iex> cursor = Style.toggle_blink(cursor)\n    iex> cursor.state\n    :visible","title":"Examples - Raxol.Terminal.Cursor.Style.toggle_blink/1","ref":"Raxol.Terminal.Cursor.Style.html#toggle_blink/1-examples"},{"type":"function","doc":"Toggles the cursor visibility.","title":"Raxol.Terminal.Cursor.Style.toggle_visibility/1","ref":"Raxol.Terminal.Cursor.Style.html#toggle_visibility/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.toggle_visibility(cursor)\n    iex> cursor.state\n    :hidden\n    iex> cursor = Style.toggle_visibility(cursor)\n    iex> cursor.state\n    :visible","title":"Examples - Raxol.Terminal.Cursor.Style.toggle_visibility/1","ref":"Raxol.Terminal.Cursor.Style.html#toggle_visibility/1-examples"},{"type":"function","doc":"Updates the cursor blink state and returns the updated cursor and visibility.","title":"Raxol.Terminal.Cursor.Style.update_blink/1","ref":"Raxol.Terminal.Cursor.Style.html#update_blink/1"},{"type":"function","doc":"iex> alias Raxol.Terminal.Cursor.{Manager, Style}\n    iex> cursor = Manager.new()\n    iex> cursor = Style.blink(cursor)\n    iex> {cursor, visible} = Style.update_blink(cursor)\n    iex> is_boolean(visible)\n    true","title":"Examples - Raxol.Terminal.Cursor.Style.update_blink/1","ref":"Raxol.Terminal.Cursor.Style.html#update_blink/1-examples"},{"type":"module","doc":"ASCII art rendering system for the Raxol terminal emulator.\n\nThis module provides functionality for:\n- Rendering ASCII art templates\n- Creating custom ASCII art\n- Animating ASCII art\n- Integrating with the terminal display system","title":"Raxol.Terminal.Display.AsciiArt","ref":"Raxol.Terminal.Display.AsciiArt.html"},{"type":"function","doc":"Returns an ASCII art box with the given text.","title":"Raxol.Terminal.Display.AsciiArt.box/1","ref":"Raxol.Terminal.Display.AsciiArt.html#box/1"},{"type":"function","doc":"Returns an ASCII art error indicator.","title":"Raxol.Terminal.Display.AsciiArt.error/0","ref":"Raxol.Terminal.Display.AsciiArt.html#error/0"},{"type":"function","doc":"Returns a stylized header with the given text.","title":"Raxol.Terminal.Display.AsciiArt.header/1","ref":"Raxol.Terminal.Display.AsciiArt.html#header/1"},{"type":"function","doc":"Returns an ASCII art help screen.","title":"Raxol.Terminal.Display.AsciiArt.help/0","ref":"Raxol.Terminal.Display.AsciiArt.html#help/0"},{"type":"function","doc":"Returns an ASCII art loading animation for the given text.","title":"Raxol.Terminal.Display.AsciiArt.loading/2","ref":"Raxol.Terminal.Display.AsciiArt.html#loading/2"},{"type":"function","doc":"Returns the ASCII art logo for the Raxol project.","title":"Raxol.Terminal.Display.AsciiArt.logo/0","ref":"Raxol.Terminal.Display.AsciiArt.html#logo/0"},{"type":"function","doc":"Returns an ASCII art progress bar with the given percentage.","title":"Raxol.Terminal.Display.AsciiArt.progress_bar/1","ref":"Raxol.Terminal.Display.AsciiArt.html#progress_bar/1"},{"type":"function","doc":"Returns an ASCII art spinner animation frame for the given step.","title":"Raxol.Terminal.Display.AsciiArt.spinner/1","ref":"Raxol.Terminal.Display.AsciiArt.html#spinner/1"},{"type":"function","doc":"Returns an ASCII art success indicator.","title":"Raxol.Terminal.Display.AsciiArt.success/0","ref":"Raxol.Terminal.Display.AsciiArt.html#success/0"},{"type":"function","doc":"Returns an ASCII art table with the given headers and rows.","title":"Raxol.Terminal.Display.AsciiArt.table/2","ref":"Raxol.Terminal.Display.AsciiArt.html#table/2"},{"type":"function","doc":"Returns an ASCII art theme preview.","title":"Raxol.Terminal.Display.AsciiArt.theme_preview/0","ref":"Raxol.Terminal.Display.AsciiArt.html#theme_preview/0"},{"type":"function","doc":"Returns an ASCII art warning indicator.","title":"Raxol.Terminal.Display.AsciiArt.warning/0","ref":"Raxol.Terminal.Display.AsciiArt.html#warning/0"},{"type":"module","doc":"Handles raw terminal input/output and event generation.\n\nResponsibilities:\n- Setting terminal mode (raw, echo)\n- Reading input events via rrex_termbox NIF v2.0.1\n- Parsing input events into `Raxol.Core.Events.Event` structs\n- Detecting terminal resize events\n- Sending parsed events to the `Dispatcher`\n- Restoring terminal state on exit","title":"Raxol.Terminal.Driver","ref":"Raxol.Terminal.Driver.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.Driver.child_spec/1","ref":"Raxol.Terminal.Driver.html#child_spec/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Driver.dispatcher_pid/0","ref":"Raxol.Terminal.Driver.html#t:dispatcher_pid/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Driver.original_stty/0","ref":"Raxol.Terminal.Driver.html#t:original_stty/0"},{"type":"function","doc":"Starts the GenServer.","title":"Raxol.Terminal.Driver.start_link/1","ref":"Raxol.Terminal.Driver.html#start_link/1"},{"type":"behaviour","doc":"Behaviour for Terminal.Driver, used for mocking.","title":"Raxol.Terminal.Driver.Behaviour","ref":"Raxol.Terminal.Driver.Behaviour.html"},{"type":"callback","doc":"","title":"Raxol.Terminal.Driver.Behaviour.start_link/1","ref":"Raxol.Terminal.Driver.Behaviour.html#c:start_link/1"},{"type":"module","doc":"Manages the state of the terminal emulator, including screen buffer,\ncursor position, attributes, and modes.","title":"Raxol.Terminal.Emulator","ref":"Raxol.Terminal.Emulator.html"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.add_to_history/2","ref":"Raxol.Terminal.Emulator.html#add_to_history/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.clear_history/1","ref":"Raxol.Terminal.Emulator.html#clear_history/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Emulator.cursor_style_type/0","ref":"Raxol.Terminal.Emulator.html#t:cursor_style_type/0"},{"type":"function","doc":"Gets the currently active buffer (:main or :alt) from the emulator state.","title":"Raxol.Terminal.Emulator.get_active_buffer/1","ref":"Raxol.Terminal.Emulator.html#get_active_buffer/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_charset_state/1","ref":"Raxol.Terminal.Emulator.html#get_charset_state/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_command_buffer/1","ref":"Raxol.Terminal.Emulator.html#get_command_buffer/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_command_history/1","ref":"Raxol.Terminal.Emulator.html#get_command_history/1"},{"type":"function","doc":"Gets the current cursor position from the emulator.","title":"Raxol.Terminal.Emulator.get_cursor_position/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_position/1"},{"type":"function","doc":"* `emulator` - The emulator to get the cursor position from","title":"Parameters - Raxol.Terminal.Emulator.get_cursor_position/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_position/1-parameters"},{"type":"function","doc":"A tuple {x, y} representing the cursor position","title":"Returns - Raxol.Terminal.Emulator.get_cursor_position/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_position/1-returns"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_cursor_style/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_style/1"},{"type":"function","doc":"Gets whether the cursor is currently visible.","title":"Raxol.Terminal.Emulator.get_cursor_visible/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_visible/1"},{"type":"function","doc":"* `emulator` - The emulator to check","title":"Parameters - Raxol.Terminal.Emulator.get_cursor_visible/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_visible/1-parameters"},{"type":"function","doc":"Boolean indicating if cursor is visible","title":"Returns - Raxol.Terminal.Emulator.get_cursor_visible/1","ref":"Raxol.Terminal.Emulator.html#get_cursor_visible/1-returns"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_history_command/2","ref":"Raxol.Terminal.Emulator.html#get_history_command/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_hyperlink_url/1","ref":"Raxol.Terminal.Emulator.html#get_hyperlink_url/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_icon_name/1","ref":"Raxol.Terminal.Emulator.html#get_icon_name/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_last_col_exceeded/1","ref":"Raxol.Terminal.Emulator.html#get_last_col_exceeded/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_last_key_event/1","ref":"Raxol.Terminal.Emulator.html#get_last_key_event/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_mode_manager/1","ref":"Raxol.Terminal.Emulator.html#get_mode_manager/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_scroll_region/1","ref":"Raxol.Terminal.Emulator.html#get_scroll_region/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_state_stack/1","ref":"Raxol.Terminal.Emulator.html#get_state_stack/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.get_window_title/1","ref":"Raxol.Terminal.Emulator.html#get_window_title/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.is_cursor_visible?/1","ref":"Raxol.Terminal.Emulator.html#is_cursor_visible?/1"},{"type":"function","doc":"Checks if the cursor is below the scroll region and scrolls up if necessary.\nCalled after operations like LF, IND, NEL that might move the cursor off-screen.\nVersion called with no specific target Y - checks current cursor position.","title":"Raxol.Terminal.Emulator.maybe_scroll/1","ref":"Raxol.Terminal.Emulator.html#maybe_scroll/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_down/2","ref":"Raxol.Terminal.Emulator.html#move_cursor_down/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_left/2","ref":"Raxol.Terminal.Emulator.html#move_cursor_left/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_right/2","ref":"Raxol.Terminal.Emulator.html#move_cursor_right/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_to/2","ref":"Raxol.Terminal.Emulator.html#move_cursor_to/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_to_column/2","ref":"Raxol.Terminal.Emulator.html#move_cursor_to_column/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_to_line_start/1","ref":"Raxol.Terminal.Emulator.html#move_cursor_to_line_start/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.move_cursor_up/2","ref":"Raxol.Terminal.Emulator.html#move_cursor_up/2"},{"type":"function","doc":"Creates a new terminal emulator instance with the specified dimensions and options.","title":"Raxol.Terminal.Emulator.new/3","ref":"Raxol.Terminal.Emulator.html#new/3"},{"type":"function","doc":"iex> emulator = Raxol.Terminal.Emulator.new(80, 24, %{})\n    iex> emulator.width\n    80\n    iex> emulator.height\n    24\n    iex> emulator.cursor.position\n    {0, 0}","title":"Examples - Raxol.Terminal.Emulator.new/3","ref":"Raxol.Terminal.Emulator.html#new/3-examples"},{"type":"function","doc":"Creates a new terminal emulator instance with specified dimensions, session ID, and client options.\nThis function is required by the TerminalChannel.","title":"Raxol.Terminal.Emulator.new/4","ref":"Raxol.Terminal.Emulator.html#new/4"},{"type":"function","doc":"Processes input from the user, handling both regular characters and escape sequences.\nProcesses the entire input string recursively.","title":"Raxol.Terminal.Emulator.process_input/2","ref":"Raxol.Terminal.Emulator.html#process_input/2"},{"type":"function","doc":"iex> emulator = Raxol.Terminal.Emulator.new(80, 24, %{})\n    iex> {emulator, _} = Raxol.Terminal.Emulator.process_input(emulator, \"a\")\n    # Cursor position is now 1-based, so {1, 1} after 'a'\n    iex> emulator.cursor.position\n    {1, 1}\n    iex> emulator = Raxol.Terminal.Emulator.new()\n    iex> {emulator, _} = Raxol.Terminal.Emulator.process_input(emulator, \"\u001B[1;31mRed\u001B[0m Text\")\n    iex> {x, y} = emulator.cursor.position\n    iex> x # Length of \"Red Text\" (8 chars) + starting at 1 = 9\n    9\n    iex> emulator.style.foreground # Should be reset by \u001B[0m\n    nil","title":"Examples - Raxol.Terminal.Emulator.process_input/2","ref":"Raxol.Terminal.Emulator.html#process_input/2-examples"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.process_key_event/2","ref":"Raxol.Terminal.Emulator.html#process_key_event/2"},{"type":"function","doc":"Resizes the emulator's screen buffers.","title":"Raxol.Terminal.Emulator.resize/3","ref":"Raxol.Terminal.Emulator.html#resize/3"},{"type":"function","doc":"* `emulator` - The emulator to resize\n* `new_width` - New width in columns\n* `new_height` - New height in rows","title":"Parameters - Raxol.Terminal.Emulator.resize/3","ref":"Raxol.Terminal.Emulator.html#resize/3-parameters"},{"type":"function","doc":"Updated emulator with resized buffers","title":"Returns - Raxol.Terminal.Emulator.resize/3","ref":"Raxol.Terminal.Emulator.html#resize/3-returns"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.restore_cursor_state/1","ref":"Raxol.Terminal.Emulator.html#restore_cursor_state/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.restore_state/1","ref":"Raxol.Terminal.Emulator.html#restore_state/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.save_cursor_state/1","ref":"Raxol.Terminal.Emulator.html#save_cursor_state/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.save_state/1","ref":"Raxol.Terminal.Emulator.html#save_state/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.search_history/2","ref":"Raxol.Terminal.Emulator.html#search_history/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.set_cursor_position/2","ref":"Raxol.Terminal.Emulator.html#set_cursor_position/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.set_cursor_style/2","ref":"Raxol.Terminal.Emulator.html#set_cursor_style/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.set_cursor_visibility/2","ref":"Raxol.Terminal.Emulator.html#set_cursor_visibility/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Emulator.t/0","ref":"Raxol.Terminal.Emulator.html#t:t/0"},{"type":"function","doc":"Updates the currently active screen buffer.","title":"Raxol.Terminal.Emulator.update_active_buffer/2","ref":"Raxol.Terminal.Emulator.html#update_active_buffer/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_charset_state/2","ref":"Raxol.Terminal.Emulator.html#update_charset_state/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_command_buffer/2","ref":"Raxol.Terminal.Emulator.html#update_command_buffer/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_hyperlink_url/2","ref":"Raxol.Terminal.Emulator.html#update_hyperlink_url/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_icon_name/2","ref":"Raxol.Terminal.Emulator.html#update_icon_name/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_last_col_exceeded/2","ref":"Raxol.Terminal.Emulator.html#update_last_col_exceeded/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_last_key_event/2","ref":"Raxol.Terminal.Emulator.html#update_last_key_event/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_max_history/2","ref":"Raxol.Terminal.Emulator.html#update_max_history/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_mode_manager/2","ref":"Raxol.Terminal.Emulator.html#update_mode_manager/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_scroll_region/2","ref":"Raxol.Terminal.Emulator.html#update_scroll_region/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_state_stack/2","ref":"Raxol.Terminal.Emulator.html#update_state_stack/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Emulator.update_window_title/2","ref":"Raxol.Terminal.Emulator.html#update_window_title/2"},{"type":"module","doc":"Handles screen buffer management for the terminal emulator.\nProvides functions for buffer operations, scroll region handling, and buffer switching.","title":"Raxol.Terminal.Emulator.Buffer","ref":"Raxol.Terminal.Emulator.Buffer.html"},{"type":"function","doc":"Clears the active buffer.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.clear_buffer/1","ref":"Raxol.Terminal.Emulator.Buffer.html#clear_buffer/1"},{"type":"function","doc":"Clears the active buffer from cursor to end of screen.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.clear_from_cursor_to_end/1","ref":"Raxol.Terminal.Emulator.Buffer.html#clear_from_cursor_to_end/1"},{"type":"function","doc":"Clears the active buffer from cursor to start of screen.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.clear_from_cursor_to_start/1","ref":"Raxol.Terminal.Emulator.Buffer.html#clear_from_cursor_to_start/1"},{"type":"function","doc":"Clears the current line in the active buffer.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.clear_line/1","ref":"Raxol.Terminal.Emulator.Buffer.html#clear_line/1"},{"type":"function","doc":"Clears the scroll region, allowing scrolling of the entire screen.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Buffer.clear_scroll_region/1","ref":"Raxol.Terminal.Emulator.Buffer.html#clear_scroll_region/1"},{"type":"function","doc":"Scrolls the active buffer down by the specified number of lines.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.scroll_down/2","ref":"Raxol.Terminal.Emulator.Buffer.html#scroll_down/2"},{"type":"function","doc":"Scrolls the active buffer up by the specified number of lines.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.scroll_up/2","ref":"Raxol.Terminal.Emulator.Buffer.html#scroll_up/2"},{"type":"function","doc":"Sets the scroll region for the active buffer.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.set_scroll_region/3","ref":"Raxol.Terminal.Emulator.Buffer.html#set_scroll_region/3"},{"type":"function","doc":"Switches between main and alternate screen buffers.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Buffer.switch_buffer/2","ref":"Raxol.Terminal.Emulator.Buffer.html#switch_buffer/2"},{"type":"module","doc":"Core functionality for the terminal emulator.\nHandles basic initialization, state management, and fundamental operations.","title":"Raxol.Terminal.Emulator.Core","ref":"Raxol.Terminal.Emulator.Core.html"},{"type":"type","doc":"","title":"Raxol.Terminal.Emulator.Core.cursor_style_type/0","ref":"Raxol.Terminal.Emulator.Core.html#t:cursor_style_type/0"},{"type":"function","doc":"Returns the currently active screen buffer.","title":"Raxol.Terminal.Emulator.Core.get_active_buffer/1","ref":"Raxol.Terminal.Emulator.Core.html#get_active_buffer/1"},{"type":"function","doc":"Returns the current command buffer.","title":"Raxol.Terminal.Emulator.Core.get_command_buffer/1","ref":"Raxol.Terminal.Emulator.Core.html#get_command_buffer/1"},{"type":"function","doc":"Returns the current command history.","title":"Raxol.Terminal.Emulator.Core.get_command_history/1","ref":"Raxol.Terminal.Emulator.Core.html#get_command_history/1"},{"type":"function","doc":"Returns the current cursor position.","title":"Raxol.Terminal.Emulator.Core.get_cursor_position/1","ref":"Raxol.Terminal.Emulator.Core.html#get_cursor_position/1"},{"type":"function","doc":"Returns the current icon name.","title":"Raxol.Terminal.Emulator.Core.get_icon_name/1","ref":"Raxol.Terminal.Emulator.Core.html#get_icon_name/1"},{"type":"function","doc":"Returns the current output buffer.","title":"Raxol.Terminal.Emulator.Core.get_output_buffer/1","ref":"Raxol.Terminal.Emulator.Core.html#get_output_buffer/1"},{"type":"function","doc":"Returns the current window state.","title":"Raxol.Terminal.Emulator.Core.get_window_state/1","ref":"Raxol.Terminal.Emulator.Core.html#get_window_state/1"},{"type":"function","doc":"Returns the current window title.","title":"Raxol.Terminal.Emulator.Core.get_window_title/1","ref":"Raxol.Terminal.Emulator.Core.html#get_window_title/1"},{"type":"function","doc":"Creates a new terminal emulator instance with the specified dimensions and options.","title":"Raxol.Terminal.Emulator.Core.new/3","ref":"Raxol.Terminal.Emulator.Core.html#new/3"},{"type":"type","doc":"","title":"Raxol.Terminal.Emulator.Core.t/0","ref":"Raxol.Terminal.Emulator.Core.html#t:t/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Emulator.Core.window_state/0","ref":"Raxol.Terminal.Emulator.Core.html#t:window_state/0"},{"type":"module","doc":"Handles cursor management for the terminal emulator.\nProvides functions for cursor position, style, movement, and state management.","title":"Raxol.Terminal.Emulator.Cursor","ref":"Raxol.Terminal.Emulator.Cursor.html"},{"type":"function","doc":"Hides the cursor.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Cursor.hide/1","ref":"Raxol.Terminal.Emulator.Cursor.html#hide/1"},{"type":"function","doc":"Moves the cursor down by the specified number of lines.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.move_down/2","ref":"Raxol.Terminal.Emulator.Cursor.html#move_down/2"},{"type":"function","doc":"Moves the cursor left by the specified number of columns.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.move_left/2","ref":"Raxol.Terminal.Emulator.Cursor.html#move_left/2"},{"type":"function","doc":"Moves the cursor right by the specified number of columns.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.move_right/2","ref":"Raxol.Terminal.Emulator.Cursor.html#move_right/2"},{"type":"function","doc":"Moves the cursor to the specified position.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.move_to/3","ref":"Raxol.Terminal.Emulator.Cursor.html#move_to/3"},{"type":"function","doc":"Moves the cursor up by the specified number of lines.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.move_up/2","ref":"Raxol.Terminal.Emulator.Cursor.html#move_up/2"},{"type":"function","doc":"Restores the previously saved cursor state.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.restore_state/1","ref":"Raxol.Terminal.Emulator.Cursor.html#restore_state/1"},{"type":"function","doc":"Saves the current cursor state.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Cursor.save_state/1","ref":"Raxol.Terminal.Emulator.Cursor.html#save_state/1"},{"type":"function","doc":"Sets the cursor style.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Cursor.set_style/2","ref":"Raxol.Terminal.Emulator.Cursor.html#set_style/2"},{"type":"function","doc":"Shows the cursor.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Cursor.show/1","ref":"Raxol.Terminal.Emulator.Cursor.html#show/1"},{"type":"module","doc":"Handles input processing for the terminal emulator.\nProvides functions for key event handling, command history, and input parsing.","title":"Raxol.Terminal.Emulator.Input","ref":"Raxol.Terminal.Emulator.Input.html"},{"type":"function","doc":"Updates the command history with a new command.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Input.add_to_history/2","ref":"Raxol.Terminal.Emulator.Input.html#add_to_history/2"},{"type":"function","doc":"Clears the command buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Input.clear_command_buffer/1","ref":"Raxol.Terminal.Emulator.Input.html#clear_command_buffer/1"},{"type":"function","doc":"Clears the command history.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Input.clear_history/1","ref":"Raxol.Terminal.Emulator.Input.html#clear_history/1"},{"type":"function","doc":"Gets the current command buffer.\nReturns the current command buffer.","title":"Raxol.Terminal.Emulator.Input.get_command_buffer/1","ref":"Raxol.Terminal.Emulator.Input.html#get_command_buffer/1"},{"type":"function","doc":"Gets the command history.\nReturns the list of commands in history.","title":"Raxol.Terminal.Emulator.Input.get_history/1","ref":"Raxol.Terminal.Emulator.Input.html#get_history/1"},{"type":"function","doc":"Processes a key event.\nReturns {:ok, updated_emulator, commands} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Input.process_key_event/2","ref":"Raxol.Terminal.Emulator.Input.html#process_key_event/2"},{"type":"function","doc":"Processes a key press event.\nReturns {:ok, updated_emulator, commands} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Input.process_key_press/2","ref":"Raxol.Terminal.Emulator.Input.html#process_key_press/2"},{"type":"function","doc":"Processes a mouse event.\nReturns {:ok, updated_emulator, commands} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Input.process_mouse_event/2","ref":"Raxol.Terminal.Emulator.Input.html#process_mouse_event/2"},{"type":"function","doc":"Sets the command buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Input.set_command_buffer/2","ref":"Raxol.Terminal.Emulator.Input.html#set_command_buffer/2"},{"type":"module","doc":"Handles output processing for the terminal emulator.\nProvides functions for output buffering, processing, and formatting.","title":"Raxol.Terminal.Emulator.Output","ref":"Raxol.Terminal.Emulator.Output.html"},{"type":"function","doc":"Clears the output buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Output.clear_output_buffer/1","ref":"Raxol.Terminal.Emulator.Output.html#clear_output_buffer/1"},{"type":"function","doc":"Flushes the output buffer.\nReturns {:ok, updated_emulator, commands} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Output.flush_output_buffer/1","ref":"Raxol.Terminal.Emulator.Output.html#flush_output_buffer/1"},{"type":"function","doc":"Gets the current output buffer.\nReturns the current output buffer.","title":"Raxol.Terminal.Emulator.Output.get_output_buffer/1","ref":"Raxol.Terminal.Emulator.Output.html#get_output_buffer/1"},{"type":"function","doc":"Processes output data.\nReturns {:ok, updated_emulator, commands} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Output.process_output/2","ref":"Raxol.Terminal.Emulator.Output.html#process_output/2"},{"type":"function","doc":"Writes data to the output buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Output.write/2","ref":"Raxol.Terminal.Emulator.Output.html#write/2"},{"type":"function","doc":"Writes a control character to the output buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Output.write_control/2","ref":"Raxol.Terminal.Emulator.Output.html#write_control/2"},{"type":"function","doc":"Writes an escape sequence to the output buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Output.write_escape/2","ref":"Raxol.Terminal.Emulator.Output.html#write_escape/2"},{"type":"function","doc":"Writes a line to the output buffer.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Output.write_line/2","ref":"Raxol.Terminal.Emulator.Output.html#write_line/2"},{"type":"module","doc":"Handles state management for the terminal emulator.\nProvides functions for managing terminal state, modes, and character sets.","title":"Raxol.Terminal.Emulator.State","ref":"Raxol.Terminal.Emulator.State.html"},{"type":"function","doc":"Gets the current character set state.\nReturns the current charset state.","title":"Raxol.Terminal.Emulator.State.get_charset_state/1","ref":"Raxol.Terminal.Emulator.State.html#get_charset_state/1"},{"type":"function","doc":"Gets the current state from the state stack.\nReturns the current state or nil if stack is empty.","title":"Raxol.Terminal.Emulator.State.get_current_state/1","ref":"Raxol.Terminal.Emulator.State.html#get_current_state/1"},{"type":"function","doc":"Gets the current hyperlink URL.\nReturns the current hyperlink URL or nil.","title":"Raxol.Terminal.Emulator.State.get_hyperlink_url/1","ref":"Raxol.Terminal.Emulator.State.html#get_hyperlink_url/1"},{"type":"function","doc":"Gets the current memory limit.\nReturns the memory limit.","title":"Raxol.Terminal.Emulator.State.get_memory_limit/1","ref":"Raxol.Terminal.Emulator.State.html#get_memory_limit/1"},{"type":"function","doc":"Gets the value of a terminal mode.\nReturns the mode value or nil if not set.","title":"Raxol.Terminal.Emulator.State.get_mode/2","ref":"Raxol.Terminal.Emulator.State.html#get_mode/2"},{"type":"function","doc":"Gets the current tab stops.\nReturns the current tab stops.","title":"Raxol.Terminal.Emulator.State.get_tab_stops/1","ref":"Raxol.Terminal.Emulator.State.html#get_tab_stops/1"},{"type":"function","doc":"Pops a state from the state stack.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.State.pop_state/1","ref":"Raxol.Terminal.Emulator.State.html#pop_state/1"},{"type":"function","doc":"Pushes a new state onto the state stack.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.State.push_state/1","ref":"Raxol.Terminal.Emulator.State.html#push_state/1"},{"type":"function","doc":"Sets the character set state.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.State.set_charset_state/2","ref":"Raxol.Terminal.Emulator.State.html#set_charset_state/2"},{"type":"function","doc":"Sets the current hyperlink URL.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.State.set_hyperlink_url/2","ref":"Raxol.Terminal.Emulator.State.html#set_hyperlink_url/2"},{"type":"function","doc":"Sets the memory limit for the terminal.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.State.set_memory_limit/2","ref":"Raxol.Terminal.Emulator.State.html#set_memory_limit/2"},{"type":"function","doc":"Sets a terminal mode.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.State.set_mode/3","ref":"Raxol.Terminal.Emulator.State.html#set_mode/3"},{"type":"function","doc":"Sets the tab stops for the terminal.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.State.set_tab_stops/2","ref":"Raxol.Terminal.Emulator.State.html#set_tab_stops/2"},{"type":"module","doc":"Handles text styling and formatting for the terminal emulator.\nProvides functions for managing character attributes, colors, and text formatting.","title":"Raxol.Terminal.Emulator.Style","ref":"Raxol.Terminal.Emulator.Style.html"},{"type":"function","doc":"Gets the current text style.\nReturns the current style.","title":"Raxol.Terminal.Emulator.Style.get_style/1","ref":"Raxol.Terminal.Emulator.Style.html#get_style/1"},{"type":"function","doc":"Resets all text attributes to default.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Style.reset_attributes/1","ref":"Raxol.Terminal.Emulator.Style.html#reset_attributes/1"},{"type":"function","doc":"Sets the text style attributes.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_attributes/2","ref":"Raxol.Terminal.Emulator.Style.html#set_attributes/2"},{"type":"function","doc":"Sets the background color.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_background/2","ref":"Raxol.Terminal.Emulator.Style.html#set_background/2"},{"type":"function","doc":"Sets the text blink mode.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_blink/2","ref":"Raxol.Terminal.Emulator.Style.html#set_blink/2"},{"type":"function","doc":"Sets the text decoration (underline, strikethrough, etc.).\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_decoration/2","ref":"Raxol.Terminal.Emulator.Style.html#set_decoration/2"},{"type":"function","doc":"Sets the foreground color.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_foreground/2","ref":"Raxol.Terminal.Emulator.Style.html#set_foreground/2"},{"type":"function","doc":"Sets the text intensity (bold, faint).\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_intensity/2","ref":"Raxol.Terminal.Emulator.Style.html#set_intensity/2"},{"type":"function","doc":"Sets the text inverse mode.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_inverse/2","ref":"Raxol.Terminal.Emulator.Style.html#set_inverse/2"},{"type":"function","doc":"Sets the text visibility.\nReturns {:ok, updated_emulator} or {:error, reason}.","title":"Raxol.Terminal.Emulator.Style.set_visibility/2","ref":"Raxol.Terminal.Emulator.Style.html#set_visibility/2"},{"type":"module","doc":"Handles window management for the terminal emulator.\nProvides functions for window state, manipulation, and properties.","title":"Raxol.Terminal.Emulator.Window","ref":"Raxol.Terminal.Emulator.Window.html"},{"type":"function","doc":"Deiconifies the window.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.deiconify/1","ref":"Raxol.Terminal.Emulator.Window.html#deiconify/1"},{"type":"function","doc":"Gets the current window state.\nReturns the window state.","title":"Raxol.Terminal.Emulator.Window.get_state/1","ref":"Raxol.Terminal.Emulator.Window.html#get_state/1"},{"type":"function","doc":"Iconifies the window.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.iconify/1","ref":"Raxol.Terminal.Emulator.Window.html#iconify/1"},{"type":"function","doc":"Maximizes the window.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.maximize/1","ref":"Raxol.Terminal.Emulator.Window.html#maximize/1"},{"type":"function","doc":"Restores the window from maximized state.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.restore/1","ref":"Raxol.Terminal.Emulator.Window.html#restore/1"},{"type":"function","doc":"Sets the window icon name.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.set_icon_name/2","ref":"Raxol.Terminal.Emulator.Window.html#set_icon_name/2"},{"type":"function","doc":"Sets the window position.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.set_position/3","ref":"Raxol.Terminal.Emulator.Window.html#set_position/3"},{"type":"function","doc":"Sets the window size.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.set_size/3","ref":"Raxol.Terminal.Emulator.Window.html#set_size/3"},{"type":"function","doc":"Sets the window stacking order.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.set_stacking_order/2","ref":"Raxol.Terminal.Emulator.Window.html#set_stacking_order/2"},{"type":"function","doc":"Sets the window title.\nReturns {:ok, updated_emulator}.","title":"Raxol.Terminal.Emulator.Window.set_title/2","ref":"Raxol.Terminal.Emulator.Window.html#set_title/2"},{"type":"behaviour","doc":"Defines the behaviour for the core Terminal Emulator.\n\nThis contract outlines the essential functions for managing terminal state,\nprocessing input, and handling resizing.","title":"Raxol.Terminal.EmulatorBehaviour","ref":"Raxol.Terminal.EmulatorBehaviour.html"},{"type":"callback","doc":"Returns the currently active screen buffer.","title":"Raxol.Terminal.EmulatorBehaviour.get_active_buffer/1","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:get_active_buffer/1"},{"type":"callback","doc":"Gets the current cursor position (0-based).","title":"Raxol.Terminal.EmulatorBehaviour.get_cursor_position/1","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:get_cursor_position/1"},{"type":"callback","doc":"Gets the current cursor visibility state.","title":"Raxol.Terminal.EmulatorBehaviour.get_cursor_visible/1","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:get_cursor_visible/1"},{"type":"callback","doc":"Creates a new emulator with default dimensions and options.","title":"Raxol.Terminal.EmulatorBehaviour.new/0","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:new/0"},{"type":"callback","doc":"Creates a new emulator with specified dimensions and default options.","title":"Raxol.Terminal.EmulatorBehaviour.new/2","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:new/2"},{"type":"callback","doc":"Creates a new emulator with specified dimensions and options.","title":"Raxol.Terminal.EmulatorBehaviour.new/3","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:new/3"},{"type":"callback","doc":"Creates a new emulator with specified dimensions, session ID, and client options.","title":"Raxol.Terminal.EmulatorBehaviour.new/4","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:new/4"},{"type":"callback","doc":"Processes input data (e.g., user typing, escape sequences).","title":"Raxol.Terminal.EmulatorBehaviour.process_input/2","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:process_input/2"},{"type":"callback","doc":"Resizes the emulator's screen buffers.","title":"Raxol.Terminal.EmulatorBehaviour.resize/3","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:resize/3"},{"type":"type","doc":"","title":"Raxol.Terminal.EmulatorBehaviour.t/0","ref":"Raxol.Terminal.EmulatorBehaviour.html#t:t/0"},{"type":"callback","doc":"Updates the currently active screen buffer in the emulator state.","title":"Raxol.Terminal.EmulatorBehaviour.update_active_buffer/2","ref":"Raxol.Terminal.EmulatorBehaviour.html#c:update_active_buffer/2"},{"type":"module","doc":"Handles parsing of ANSI escape sequences and other control sequences.\n\nThis module provides functions for parsing ANSI escape sequences\ninto structured data representing terminal commands.","title":"Raxol.Terminal.EscapeSequence","ref":"Raxol.Terminal.EscapeSequence.html"},{"type":"function","doc":"Parses an input string, potentially containing an escape sequence.\n\nReturns:\n  * `{:ok, command_data, remaining_input}` if a complete sequence is parsed.\n  * `{:incomplete, remaining_input}` if the input is potentially part of a sequence but incomplete.\n  * `{:error, :invalid_sequence, remaining_input}` if the sequence is malformed.\n  * `{:error, :not_escape_sequence, input}` if the input doesn't start with ESC.\n\n`command_data` is a tuple representing the parsed command, e.g.:\n  * `{:cursor_position, {row, col}}`\n  * `{:cursor_move, :up, count}`\n  * `{:set_mode, :dec_private, mode_code, boolean_value}`\n  * `{:set_mode, :standard, mode_code, boolean_value}`\n  * `{:designate_charset, target_g_set, charset_atom}`\n  * `{:invoke_charset, target_g_set}`\n  * etc.","title":"Raxol.Terminal.EscapeSequence.parse/1","ref":"Raxol.Terminal.EscapeSequence.html#parse/1"},{"type":"module","doc":"Terminal input module.\n\nThis module handles keyboard and mouse input events for the terminal, including:\n- Input buffering\n- Mode management\n- Input history\n- Special key handling","title":"Raxol.Terminal.Input","ref":"Raxol.Terminal.Input.html"},{"type":"function","doc":"Adds a command to the history.","title":"Raxol.Terminal.Input.add_to_history/2","ref":"Raxol.Terminal.Input.html#add_to_history/2"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.add_to_history(input, \"test\")\n    iex> length(input.history)\n    1","title":"Examples - Raxol.Terminal.Input.add_to_history/2","ref":"Raxol.Terminal.Input.html#add_to_history/2-examples"},{"type":"function","doc":"Clears the input buffer.","title":"Raxol.Terminal.Input.clear_buffer/1","ref":"Raxol.Terminal.Input.html#clear_buffer/1"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.process_keyboard(input, \"test\")\n    iex> input = Input.clear_buffer(input)\n    iex> Input.get_buffer(input)\n    \"\"","title":"Examples - Raxol.Terminal.Input.clear_buffer/1","ref":"Raxol.Terminal.Input.html#clear_buffer/1-examples"},{"type":"function","doc":"Gets the current input buffer.","title":"Raxol.Terminal.Input.get_buffer/1","ref":"Raxol.Terminal.Input.html#get_buffer/1"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.process_keyboard(input, \"test\")\n    iex> Input.get_buffer(input)\n    \"test\"","title":"Examples - Raxol.Terminal.Input.get_buffer/1","ref":"Raxol.Terminal.Input.html#get_buffer/1-examples"},{"type":"function","doc":"Gets the input mode.","title":"Raxol.Terminal.Input.get_mode/1","ref":"Raxol.Terminal.Input.html#get_mode/1"},{"type":"function","doc":"iex> input = Input.new()\n    iex> Input.get_mode(input)\n    :normal","title":"Examples - Raxol.Terminal.Input.get_mode/1","ref":"Raxol.Terminal.Input.html#get_mode/1-examples"},{"type":"function","doc":"Creates a new input handler.","title":"Raxol.Terminal.Input.new/1","ref":"Raxol.Terminal.Input.html#new/1"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input.mode\n    :normal\n    iex> input.buffer\n    \"\"","title":"Examples - Raxol.Terminal.Input.new/1","ref":"Raxol.Terminal.Input.html#new/1-examples"},{"type":"function","doc":"Gets the next command from history.","title":"Raxol.Terminal.Input.next_command/1","ref":"Raxol.Terminal.Input.html#next_command/1"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.add_to_history(input, \"test\")\n    iex> input = Input.previous_command(input)\n    iex> input = Input.next_command(input)\n    iex> input.buffer\n    \"\"","title":"Examples - Raxol.Terminal.Input.next_command/1","ref":"Raxol.Terminal.Input.html#next_command/1-examples"},{"type":"function","doc":"Gets the previous command from history.","title":"Raxol.Terminal.Input.previous_command/1","ref":"Raxol.Terminal.Input.html#previous_command/1"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.add_to_history(input, \"test\")\n    iex> input = Input.previous_command(input)\n    iex> input.buffer\n    \"test\"","title":"Examples - Raxol.Terminal.Input.previous_command/1","ref":"Raxol.Terminal.Input.html#previous_command/1-examples"},{"type":"function","doc":"Processes a keyboard event.","title":"Raxol.Terminal.Input.process_keyboard/2","ref":"Raxol.Terminal.Input.html#process_keyboard/2"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.process_keyboard(input, \"a\")\n    iex> input.buffer\n    \"a\"","title":"Examples - Raxol.Terminal.Input.process_keyboard/2","ref":"Raxol.Terminal.Input.html#process_keyboard/2-examples"},{"type":"function","doc":"Processes a mouse event.","title":"Raxol.Terminal.Input.process_mouse/2","ref":"Raxol.Terminal.Input.html#process_mouse/2"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.process_mouse(input, {:click, 1, 2, 1})\n    iex> input.buffer\n    \"\"","title":"Examples - Raxol.Terminal.Input.process_mouse/2","ref":"Raxol.Terminal.Input.html#process_mouse/2-examples"},{"type":"function","doc":"Sets the input mode.","title":"Raxol.Terminal.Input.set_mode/2","ref":"Raxol.Terminal.Input.html#set_mode/2"},{"type":"function","doc":"iex> input = Input.new()\n    iex> input = Input.set_mode(input, :insert)\n    iex> input.mode\n    :insert","title":"Examples - Raxol.Terminal.Input.set_mode/2","ref":"Raxol.Terminal.Input.html#set_mode/2-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.t/0","ref":"Raxol.Terminal.Input.html#t:t/0"},{"type":"module","doc":"Handles input buffering for the terminal emulator.\nProvides functionality for storing, retrieving, and manipulating input data.","title":"Raxol.Terminal.Input.InputBuffer","ref":"Raxol.Terminal.Input.InputBuffer.html"},{"type":"function","doc":"Appends data to the buffer, handling escape sequences appropriately.","title":"Raxol.Terminal.Input.InputBuffer.append/2","ref":"Raxol.Terminal.Input.InputBuffer.html#append/2"},{"type":"function","doc":"Removes the last character from the buffer.\nUses graphemes to handle multi-byte characters correctly.","title":"Raxol.Terminal.Input.InputBuffer.backspace/1","ref":"Raxol.Terminal.Input.InputBuffer.html#backspace/1"},{"type":"function","doc":"Clears the buffer.","title":"Raxol.Terminal.Input.InputBuffer.clear/1","ref":"Raxol.Terminal.Input.InputBuffer.html#clear/1"},{"type":"function","doc":"Removes the first character from the buffer.","title":"Raxol.Terminal.Input.InputBuffer.delete_first/1","ref":"Raxol.Terminal.Input.InputBuffer.html#delete_first/1"},{"type":"function","doc":"Checks if the buffer is empty.","title":"Raxol.Terminal.Input.InputBuffer.empty?/1","ref":"Raxol.Terminal.Input.InputBuffer.html#empty?/1"},{"type":"function","doc":"Gets the buffer contents.","title":"Raxol.Terminal.Input.InputBuffer.get_contents/1","ref":"Raxol.Terminal.Input.InputBuffer.html#get_contents/1"},{"type":"function","doc":"Handles escape sequence processing.","title":"Raxol.Terminal.Input.InputBuffer.handle_escape_sequence/2","ref":"Raxol.Terminal.Input.InputBuffer.html#handle_escape_sequence/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Input.InputBuffer.handle_resize/2","ref":"Raxol.Terminal.Input.InputBuffer.html#handle_resize/2"},{"type":"function","doc":"Inserts a character at the specified position.\nRaises ArgumentError if position is out of bounds.","title":"Raxol.Terminal.Input.InputBuffer.insert_at/3","ref":"Raxol.Terminal.Input.InputBuffer.html#insert_at/3"},{"type":"function","doc":"Gets the maximum size of the buffer.","title":"Raxol.Terminal.Input.InputBuffer.max_size/1","ref":"Raxol.Terminal.Input.InputBuffer.html#max_size/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Input.InputBuffer.move_cursor_to_end_of_line/1","ref":"Raxol.Terminal.Input.InputBuffer.html#move_cursor_to_end_of_line/1"},{"type":"function","doc":"Creates a new input buffer with default values.","title":"Raxol.Terminal.Input.InputBuffer.new/2","ref":"Raxol.Terminal.Input.InputBuffer.html#new/2"},{"type":"function","doc":"Gets the overflow mode of the buffer.","title":"Raxol.Terminal.Input.InputBuffer.overflow_mode/1","ref":"Raxol.Terminal.Input.InputBuffer.html#overflow_mode/1"},{"type":"function","doc":"Prepends data to the buffer.","title":"Raxol.Terminal.Input.InputBuffer.prepend/2","ref":"Raxol.Terminal.Input.InputBuffer.html#prepend/2"},{"type":"function","doc":"Replaces a character at the specified position.\nRaises ArgumentError if position is out of bounds.","title":"Raxol.Terminal.Input.InputBuffer.replace_at/3","ref":"Raxol.Terminal.Input.InputBuffer.html#replace_at/3"},{"type":"function","doc":"Sets the buffer contents.","title":"Raxol.Terminal.Input.InputBuffer.set_contents/2","ref":"Raxol.Terminal.Input.InputBuffer.html#set_contents/2"},{"type":"function","doc":"Sets the maximum size of the buffer.\nIf the current content exceeds the new max size, it will be handled\naccording to the current overflow mode.","title":"Raxol.Terminal.Input.InputBuffer.set_max_size/2","ref":"Raxol.Terminal.Input.InputBuffer.html#set_max_size/2"},{"type":"function","doc":"Sets the overflow mode of the buffer.","title":"Raxol.Terminal.Input.InputBuffer.set_overflow_mode/2","ref":"Raxol.Terminal.Input.InputBuffer.html#set_overflow_mode/2"},{"type":"function","doc":"Gets the current size of the buffer.","title":"Raxol.Terminal.Input.InputBuffer.size/1","ref":"Raxol.Terminal.Input.InputBuffer.html#size/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputBuffer.t/0","ref":"Raxol.Terminal.Input.InputBuffer.html#t:t/0"},{"type":"module","doc":"Utility functions for Raxol.Terminal.Input.InputBuffer.","title":"Raxol.Terminal.Input.InputBufferUtils","ref":"Raxol.Terminal.Input.InputBufferUtils.html"},{"type":"function","doc":"","title":"Raxol.Terminal.Input.InputBufferUtils.calculate_new_cursor_pos_v2/5","ref":"Raxol.Terminal.Input.InputBufferUtils.html#calculate_new_cursor_pos_v2/5"},{"type":"function","doc":"","title":"Raxol.Terminal.Input.InputBufferUtils.find_logical_position/2","ref":"Raxol.Terminal.Input.InputBufferUtils.html#find_logical_position/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Input.InputBufferUtils.wrap_line/2","ref":"Raxol.Terminal.Input.InputBufferUtils.html#wrap_line/2"},{"type":"module","doc":"Handles input processing for the terminal emulator, including:\n- Mouse events (clicks, movement, scrolling)\n- Special key handling\n- Input mode switching\n- Input buffering\n- Extended key combinations\n- Tab completion","title":"Raxol.Terminal.Input.InputHandler","ref":"Raxol.Terminal.Input.InputHandler.html"},{"type":"function","doc":"Adds the current buffer contents to the input history.\nResets the history navigation index and clears the buffer.","title":"Raxol.Terminal.Input.InputHandler.add_to_history/1","ref":"Raxol.Terminal.Input.InputHandler.html#add_to_history/1"},{"type":"function","doc":"Checks if the buffer is empty.","title":"Raxol.Terminal.Input.InputHandler.buffer_empty?/1","ref":"Raxol.Terminal.Input.InputHandler.html#buffer_empty?/1"},{"type":"function","doc":"Clears the input buffer.","title":"Raxol.Terminal.Input.InputHandler.clear_buffer/1","ref":"Raxol.Terminal.Input.InputHandler.html#clear_buffer/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.completion_callback/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:completion_callback/0"},{"type":"function","doc":"Gets the contents of the internal input buffer.","title":"Raxol.Terminal.Input.InputHandler.get_buffer_contents/1","ref":"Raxol.Terminal.Input.InputHandler.html#get_buffer_contents/1"},{"type":"function","doc":"Retrieves a specific input from history by its index (0 is most recent).\nSets the history_index to track navigation.","title":"Raxol.Terminal.Input.InputHandler.get_history_entry/2","ref":"Raxol.Terminal.Input.InputHandler.html#get_history_entry/2"},{"type":"function","doc":"Gets the current input mode.","title":"Raxol.Terminal.Input.InputHandler.get_mode/1","ref":"Raxol.Terminal.Input.InputHandler.html#get_mode/1"},{"type":"function","doc":"Processes tab completion.","title":"Raxol.Terminal.Input.InputHandler.handle_tab/1","ref":"Raxol.Terminal.Input.InputHandler.html#handle_tab/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.input_mode/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:input_mode/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.mouse_button/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:mouse_button/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.mouse_event/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:mouse_event/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.mouse_event_type/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:mouse_event_type/0"},{"type":"function","doc":"Creates a new input handler with default values.","title":"Raxol.Terminal.Input.InputHandler.new/0","ref":"Raxol.Terminal.Input.InputHandler.html#new/0"},{"type":"function","doc":"Moves to the next history entry (newer / Down Arrow).","title":"Raxol.Terminal.Input.InputHandler.next_history_entry/1","ref":"Raxol.Terminal.Input.InputHandler.html#next_history_entry/1"},{"type":"function","doc":"Moves to the previous history entry (older / Up Arrow).\nIf not currently navigating history, it starts from the most recent entry (index 0).","title":"Raxol.Terminal.Input.InputHandler.previous_history_entry/1","ref":"Raxol.Terminal.Input.InputHandler.html#previous_history_entry/1"},{"type":"function","doc":"Processes a key with the current modifier state.","title":"Raxol.Terminal.Input.InputHandler.process_key_with_modifiers/2","ref":"Raxol.Terminal.Input.InputHandler.html#process_key_with_modifiers/2"},{"type":"function","doc":"Processes a keyboard input event.","title":"Raxol.Terminal.Input.InputHandler.process_keyboard/2","ref":"Raxol.Terminal.Input.InputHandler.html#process_keyboard/2"},{"type":"function","doc":"Processes a mouse event.","title":"Raxol.Terminal.Input.InputHandler.process_mouse/2","ref":"Raxol.Terminal.Input.InputHandler.html#process_mouse/2"},{"type":"function","doc":"Processes a special key event.","title":"Raxol.Terminal.Input.InputHandler.process_special_key/2","ref":"Raxol.Terminal.Input.InputHandler.html#process_special_key/2"},{"type":"function","doc":"Sets a completion callback function for tab completion.","title":"Raxol.Terminal.Input.InputHandler.set_completion_callback/2","ref":"Raxol.Terminal.Input.InputHandler.html#set_completion_callback/2"},{"type":"function","doc":"Sets the input mode.","title":"Raxol.Terminal.Input.InputHandler.set_mode/2","ref":"Raxol.Terminal.Input.InputHandler.html#set_mode/2"},{"type":"function","doc":"Enables or disables mouse event handling.","title":"Raxol.Terminal.Input.InputHandler.set_mouse_enabled/2","ref":"Raxol.Terminal.Input.InputHandler.html#set_mouse_enabled/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.special_key/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:special_key/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.InputHandler.t/0","ref":"Raxol.Terminal.Input.InputHandler.html#t:t/0"},{"type":"function","doc":"Updates the modifier state for a key.","title":"Raxol.Terminal.Input.InputHandler.update_modifier/3","ref":"Raxol.Terminal.Input.InputHandler.html#update_modifier/3"},{"type":"module","doc":"Manages input handling for the terminal emulator, including:\n- Keyboard input processing\n- Mouse event handling\n- Input buffering\n- Input history\n- Input modes\n- Special key handling\n- Modifier state management","title":"Raxol.Terminal.Input.Manager","ref":"Raxol.Terminal.Input.Manager.html"},{"type":"function","doc":"Adds the current buffer contents to the input history.\nResets the history navigation index and clears the buffer.","title":"Raxol.Terminal.Input.Manager.add_to_history/1","ref":"Raxol.Terminal.Input.Manager.html#add_to_history/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.completion_callback/0","ref":"Raxol.Terminal.Input.Manager.html#t:completion_callback/0"},{"type":"function","doc":"Gets the current buffer contents.","title":"Raxol.Terminal.Input.Manager.get_buffer_contents/1","ref":"Raxol.Terminal.Input.Manager.html#get_buffer_contents/1"},{"type":"function","doc":"Gets the current input mode.","title":"Raxol.Terminal.Input.Manager.get_mode/1","ref":"Raxol.Terminal.Input.Manager.html#get_mode/1"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.input_mode/0","ref":"Raxol.Terminal.Input.Manager.html#t:input_mode/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.mouse_button/0","ref":"Raxol.Terminal.Input.Manager.html#t:mouse_button/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.mouse_event/0","ref":"Raxol.Terminal.Input.Manager.html#t:mouse_event/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.mouse_event_type/0","ref":"Raxol.Terminal.Input.Manager.html#t:mouse_event_type/0"},{"type":"function","doc":"Creates a new input manager with default values.","title":"Raxol.Terminal.Input.Manager.new/0","ref":"Raxol.Terminal.Input.Manager.html#new/0"},{"type":"function","doc":"Processes a key with the current modifier state.","title":"Raxol.Terminal.Input.Manager.process_key_with_modifiers/2","ref":"Raxol.Terminal.Input.Manager.html#process_key_with_modifiers/2"},{"type":"function","doc":"Processes a keyboard input event.","title":"Raxol.Terminal.Input.Manager.process_keyboard/2","ref":"Raxol.Terminal.Input.Manager.html#process_keyboard/2"},{"type":"function","doc":"Processes a mouse event.","title":"Raxol.Terminal.Input.Manager.process_mouse/2","ref":"Raxol.Terminal.Input.Manager.html#process_mouse/2"},{"type":"function","doc":"Processes a special key event.","title":"Raxol.Terminal.Input.Manager.process_special_key/2","ref":"Raxol.Terminal.Input.Manager.html#process_special_key/2"},{"type":"function","doc":"Sets the input mode.","title":"Raxol.Terminal.Input.Manager.set_mode/2","ref":"Raxol.Terminal.Input.Manager.html#set_mode/2"},{"type":"function","doc":"Enables or disables mouse event handling.","title":"Raxol.Terminal.Input.Manager.set_mouse_enabled/2","ref":"Raxol.Terminal.Input.Manager.html#set_mouse_enabled/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.special_key/0","ref":"Raxol.Terminal.Input.Manager.html#t:special_key/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.Manager.t/0","ref":"Raxol.Terminal.Input.Manager.html#t:t/0"},{"type":"function","doc":"Updates the modifier state for a key.","title":"Raxol.Terminal.Input.Manager.update_modifier/3","ref":"Raxol.Terminal.Input.Manager.html#update_modifier/3"},{"type":"module","doc":"Handles special key combinations and their escape sequences.\n\nThis module provides functionality for:\n- Detecting special key combinations (Ctrl, Alt, Shift, Meta)\n- Converting special keys to their corresponding escape sequences\n- Handling modifier key state\n- Supporting extended key combinations","title":"Raxol.Terminal.Input.SpecialKeys","ref":"Raxol.Terminal.Input.SpecialKeys.html"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.SpecialKeys.modifier/0","ref":"Raxol.Terminal.Input.SpecialKeys.html#t:modifier/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Input.SpecialKeys.modifier_state/0","ref":"Raxol.Terminal.Input.SpecialKeys.html#t:modifier_state/0"},{"type":"function","doc":"Creates a new modifier state.","title":"Raxol.Terminal.Input.SpecialKeys.new_state/0","ref":"Raxol.Terminal.Input.SpecialKeys.html#new_state/0"},{"type":"function","doc":"iex> state = SpecialKeys.new_state()\n    iex> state.ctrl\n    false","title":"Examples - Raxol.Terminal.Input.SpecialKeys.new_state/0","ref":"Raxol.Terminal.Input.SpecialKeys.html#new_state/0-examples"},{"type":"function","doc":"Converts a key combination to its corresponding escape sequence.","title":"Raxol.Terminal.Input.SpecialKeys.to_escape_sequence/2","ref":"Raxol.Terminal.Input.SpecialKeys.html#to_escape_sequence/2"},{"type":"function","doc":"iex> state = SpecialKeys.new_state() |> SpecialKeys.update_state(\"Control\", true)\n    iex> SpecialKeys.to_escape_sequence(state, \"c\")\n    \"\u001B[99\"","title":"Examples - Raxol.Terminal.Input.SpecialKeys.to_escape_sequence/2","ref":"Raxol.Terminal.Input.SpecialKeys.html#to_escape_sequence/2-examples"},{"type":"function","doc":"Updates the modifier state based on a key event.","title":"Raxol.Terminal.Input.SpecialKeys.update_state/3","ref":"Raxol.Terminal.Input.SpecialKeys.html#update_state/3"},{"type":"function","doc":"iex> state = SpecialKeys.new_state()\n    iex> state = SpecialKeys.update_state(state, \"Control\", true)\n    iex> state.ctrl\n    true","title":"Examples - Raxol.Terminal.Input.SpecialKeys.update_state/3","ref":"Raxol.Terminal.Input.SpecialKeys.html#update_state/3-examples"},{"type":"module","doc":"Defines shared types for the Raxol terminal input subsystem.","title":"Raxol.Terminal.Input.Types","ref":"Raxol.Terminal.Input.Types.html"},{"type":"type","doc":"Represents the state of the terminal input buffer.","title":"Raxol.Terminal.Input.Types.input_buffer/0","ref":"Raxol.Terminal.Input.Types.html#t:input_buffer/0"},{"type":"module","doc":"Handles parsed terminal input events (printable characters, control codes, escape sequences)\nand updates the Emulator state accordingly.","title":"Raxol.Terminal.InputHandler","ref":"Raxol.Terminal.InputHandler.html"},{"type":"function","doc":"Handle a control sequence in the input.","title":"Raxol.Terminal.InputHandler.handle_control_sequence/2","ref":"Raxol.Terminal.InputHandler.html#handle_control_sequence/2"},{"type":"function","doc":"Handles clipboard copy operation.\n(Currently copies the entire buffer)","title":"Raxol.Terminal.InputHandler.handle_copy/1","ref":"Raxol.Terminal.InputHandler.html#handle_copy/1"},{"type":"function","doc":"Handles clipboard cut operation.\n(Currently cuts the entire buffer)","title":"Raxol.Terminal.InputHandler.handle_cut/1","ref":"Raxol.Terminal.InputHandler.html#handle_cut/1"},{"type":"function","doc":"Handles clipboard paste operation.","title":"Raxol.Terminal.InputHandler.handle_paste/1","ref":"Raxol.Terminal.InputHandler.html#handle_paste/1"},{"type":"function","doc":"Inserts text at the specified position in the buffer.","title":"Raxol.Terminal.InputHandler.insert_text/3","ref":"Raxol.Terminal.InputHandler.html#insert_text/3"},{"type":"function","doc":"Creates a new input handler with default values.","title":"Raxol.Terminal.InputHandler.new/0","ref":"Raxol.Terminal.InputHandler.html#new/0"},{"type":"function","doc":"Processes a single character codepoint.\nDelegates to C0 handlers or printable character handlers.","title":"Raxol.Terminal.InputHandler.process_character/2","ref":"Raxol.Terminal.InputHandler.html#process_character/2"},{"type":"function","doc":"Process a complete input string, handling both normal characters and control sequences.","title":"Raxol.Terminal.InputHandler.process_complete_input/2","ref":"Raxol.Terminal.InputHandler.html#process_complete_input/2"},{"type":"function","doc":"Process a character or string input, handling character sets and translations.","title":"Raxol.Terminal.InputHandler.process_input/2","ref":"Raxol.Terminal.InputHandler.html#process_input/2"},{"type":"function","doc":"Processes a single printable character codepoint.\nHandles writing the character to the buffer, cursor advancement, and line wrapping.","title":"Raxol.Terminal.InputHandler.process_printable_character/2","ref":"Raxol.Terminal.InputHandler.html#process_printable_character/2"},{"type":"type","doc":"","title":"Raxol.Terminal.InputHandler.t/0","ref":"Raxol.Terminal.InputHandler.html#t:t/0"},{"type":"module","doc":"Coordinates terminal integration components and provides a unified interface\nfor terminal operations.\n\nThis module manages the interaction between various terminal components:\n- State management\n- Input processing\n- Buffer management\n- Rendering\n- Configuration","title":"Raxol.Terminal.Integration","ref":"Raxol.Terminal.Integration.html"},{"type":"function","doc":"Clears the terminal.","title":"Raxol.Terminal.Integration.clear/1","ref":"Raxol.Terminal.Integration.html#clear/1"},{"type":"function","doc":"Gets the current terminal configuration.","title":"Raxol.Terminal.Integration.get_config/1","ref":"Raxol.Terminal.Integration.html#get_config/1"},{"type":"function","doc":"Gets the current cursor position.","title":"Raxol.Terminal.Integration.get_cursor_position/1","ref":"Raxol.Terminal.Integration.html#get_cursor_position/1"},{"type":"function","doc":"Gets the current terminal dimensions.","title":"Raxol.Terminal.Integration.get_dimensions/1","ref":"Raxol.Terminal.Integration.html#get_dimensions/1"},{"type":"function","doc":"Gets the current scroll position.","title":"Raxol.Terminal.Integration.get_scroll_position/1","ref":"Raxol.Terminal.Integration.html#get_scroll_position/1"},{"type":"function","doc":"Gets the current terminal title.","title":"Raxol.Terminal.Integration.get_title/1","ref":"Raxol.Terminal.Integration.html#get_title/1"},{"type":"function","doc":"Gets the total number of lines in the buffer.","title":"Raxol.Terminal.Integration.get_total_lines/1","ref":"Raxol.Terminal.Integration.html#get_total_lines/1"},{"type":"function","doc":"Gets the current visible content.","title":"Raxol.Terminal.Integration.get_visible_content/1","ref":"Raxol.Terminal.Integration.html#get_visible_content/1"},{"type":"function","doc":"Gets the number of visible lines.","title":"Raxol.Terminal.Integration.get_visible_lines/1","ref":"Raxol.Terminal.Integration.html#get_visible_lines/1"},{"type":"function","doc":"Processes user input and updates the terminal state.","title":"Raxol.Terminal.Integration.handle_input/2","ref":"Raxol.Terminal.Integration.html#handle_input/2"},{"type":"function","doc":"Initializes a new terminal integration state.","title":"Raxol.Terminal.Integration.init/1","ref":"Raxol.Terminal.Integration.html#init/1"},{"type":"function","doc":"Moves the cursor to a specific position.","title":"Raxol.Terminal.Integration.move_cursor/3","ref":"Raxol.Terminal.Integration.html#move_cursor/3"},{"type":"function","doc":"Resets the terminal configuration to default values.","title":"Raxol.Terminal.Integration.reset_config/1","ref":"Raxol.Terminal.Integration.html#reset_config/1"},{"type":"function","doc":"Resizes the terminal.","title":"Raxol.Terminal.Integration.resize/3","ref":"Raxol.Terminal.Integration.html#resize/3"},{"type":"function","doc":"Scrolls the terminal.","title":"Raxol.Terminal.Integration.scroll/3","ref":"Raxol.Terminal.Integration.html#scroll/3"},{"type":"function","doc":"Sets a specific configuration value.","title":"Raxol.Terminal.Integration.set_config_value/3","ref":"Raxol.Terminal.Integration.html#set_config_value/3"},{"type":"function","doc":"Shows or hides the cursor.","title":"Raxol.Terminal.Integration.set_cursor_visibility/2","ref":"Raxol.Terminal.Integration.html#set_cursor_visibility/2"},{"type":"function","doc":"Sets the terminal title.","title":"Raxol.Terminal.Integration.set_title/2","ref":"Raxol.Terminal.Integration.html#set_title/2"},{"type":"function","doc":"Updates the terminal configuration.","title":"Raxol.Terminal.Integration.update_config/2","ref":"Raxol.Terminal.Integration.html#update_config/2"},{"type":"function","doc":"Writes text to the terminal.","title":"Raxol.Terminal.Integration.write/2","ref":"Raxol.Terminal.Integration.html#write/2"},{"type":"module","doc":"Handles buffer and cursor management for the terminal.","title":"Raxol.Terminal.Integration.Buffer","ref":"Raxol.Terminal.Integration.Buffer.html"},{"type":"function","doc":"Clears the terminal buffer.","title":"Raxol.Terminal.Integration.Buffer.clear/1","ref":"Raxol.Terminal.Integration.Buffer.html#clear/1"},{"type":"function","doc":"Gets the current cursor position.","title":"Raxol.Terminal.Integration.Buffer.get_cursor_position/1","ref":"Raxol.Terminal.Integration.Buffer.html#get_cursor_position/1"},{"type":"function","doc":"Gets the current scroll position.","title":"Raxol.Terminal.Integration.Buffer.get_scroll_position/1","ref":"Raxol.Terminal.Integration.Buffer.html#get_scroll_position/1"},{"type":"function","doc":"Gets the total number of lines in the buffer.","title":"Raxol.Terminal.Integration.Buffer.get_total_lines/1","ref":"Raxol.Terminal.Integration.Buffer.html#get_total_lines/1"},{"type":"function","doc":"Gets the current visible content.","title":"Raxol.Terminal.Integration.Buffer.get_visible_content/1","ref":"Raxol.Terminal.Integration.Buffer.html#get_visible_content/1"},{"type":"function","doc":"Gets the number of visible lines.","title":"Raxol.Terminal.Integration.Buffer.get_visible_lines/1","ref":"Raxol.Terminal.Integration.Buffer.html#get_visible_lines/1"},{"type":"function","doc":"Moves the cursor to a specific position.","title":"Raxol.Terminal.Integration.Buffer.move_cursor/3","ref":"Raxol.Terminal.Integration.Buffer.html#move_cursor/3"},{"type":"function","doc":"Resizes the terminal buffer.","title":"Raxol.Terminal.Integration.Buffer.resize/3","ref":"Raxol.Terminal.Integration.Buffer.html#resize/3"},{"type":"function","doc":"Scrolls the terminal buffer.","title":"Raxol.Terminal.Integration.Buffer.scroll/3","ref":"Raxol.Terminal.Integration.Buffer.html#scroll/3"},{"type":"function","doc":"Writes text to the terminal buffer.","title":"Raxol.Terminal.Integration.Buffer.write/2","ref":"Raxol.Terminal.Integration.Buffer.html#write/2"},{"type":"module","doc":"Handles configuration management for the terminal integration.","title":"Raxol.Terminal.Integration.Config","ref":"Raxol.Terminal.Integration.Config.html"},{"type":"function","doc":"Gets a specific configuration value.","title":"Raxol.Terminal.Integration.Config.get_config_value/2","ref":"Raxol.Terminal.Integration.Config.html#get_config_value/2"},{"type":"function","doc":"Resets the configuration to default values.","title":"Raxol.Terminal.Integration.Config.reset_config/1","ref":"Raxol.Terminal.Integration.Config.html#reset_config/1"},{"type":"function","doc":"Sets a specific configuration value.","title":"Raxol.Terminal.Integration.Config.set_config_value/3","ref":"Raxol.Terminal.Integration.Config.html#set_config_value/3"},{"type":"function","doc":"Updates the terminal configuration.\n\nMerges the provided `opts` into the current configuration and validates\nthe result before applying.","title":"Raxol.Terminal.Integration.Config.update_config/2","ref":"Raxol.Terminal.Integration.Config.html#update_config/2"},{"type":"module","doc":"Handles input processing and command history management for the terminal.","title":"Raxol.Terminal.Integration.Input","ref":"Raxol.Terminal.Integration.Input.html"},{"type":"function","doc":"Handles down arrow key press for command history navigation.","title":"Raxol.Terminal.Integration.Input.handle_down_arrow/1","ref":"Raxol.Terminal.Integration.Input.html#handle_down_arrow/1"},{"type":"function","doc":"Processes user input and updates the terminal state.","title":"Raxol.Terminal.Integration.Input.handle_input/2","ref":"Raxol.Terminal.Integration.Input.html#handle_input/2"},{"type":"function","doc":"Handles special key combinations.","title":"Raxol.Terminal.Integration.Input.handle_special_key/2","ref":"Raxol.Terminal.Integration.Input.html#handle_special_key/2"},{"type":"function","doc":"Handles tab completion for commands.","title":"Raxol.Terminal.Integration.Input.handle_tab_completion/1","ref":"Raxol.Terminal.Integration.Input.html#handle_tab_completion/1"},{"type":"function","doc":"Handles up arrow key press for command history navigation.","title":"Raxol.Terminal.Integration.Input.handle_up_arrow/1","ref":"Raxol.Terminal.Integration.Input.html#handle_up_arrow/1"},{"type":"module","doc":"Handles terminal output rendering and display management.","title":"Raxol.Terminal.Integration.Renderer","ref":"Raxol.Terminal.Integration.Renderer.html"},{"type":"function","doc":"Clears the terminal screen.","title":"Raxol.Terminal.Integration.Renderer.clear_screen/1","ref":"Raxol.Terminal.Integration.Renderer.html#clear_screen/1"},{"type":"function","doc":"Gets the current renderer configuration.","title":"Raxol.Terminal.Integration.Renderer.get_config/1","ref":"Raxol.Terminal.Integration.Renderer.html#get_config/1"},{"type":"function","doc":"Gets the current terminal dimensions.","title":"Raxol.Terminal.Integration.Renderer.get_dimensions/1","ref":"Raxol.Terminal.Integration.Renderer.html#get_dimensions/1"},{"type":"function","doc":"Gets the current terminal title.","title":"Raxol.Terminal.Integration.Renderer.get_title/1","ref":"Raxol.Terminal.Integration.Renderer.html#get_title/1"},{"type":"function","doc":"Moves the cursor to a specific position on the screen.","title":"Raxol.Terminal.Integration.Renderer.move_cursor/3","ref":"Raxol.Terminal.Integration.Renderer.html#move_cursor/3"},{"type":"function","doc":"Renders the current terminal state to the screen.","title":"Raxol.Terminal.Integration.Renderer.render/1","ref":"Raxol.Terminal.Integration.Renderer.html#render/1"},{"type":"function","doc":"Resets the renderer configuration to default values.","title":"Raxol.Terminal.Integration.Renderer.reset_config/1","ref":"Raxol.Terminal.Integration.Renderer.html#reset_config/1"},{"type":"function","doc":"Resizes the terminal display.","title":"Raxol.Terminal.Integration.Renderer.resize/3","ref":"Raxol.Terminal.Integration.Renderer.html#resize/3"},{"type":"function","doc":"Sets a specific renderer configuration value.","title":"Raxol.Terminal.Integration.Renderer.set_config_value/3","ref":"Raxol.Terminal.Integration.Renderer.html#set_config_value/3"},{"type":"function","doc":"Shows or hides the cursor.","title":"Raxol.Terminal.Integration.Renderer.set_cursor_visibility/2","ref":"Raxol.Terminal.Integration.Renderer.html#set_cursor_visibility/2"},{"type":"function","doc":"Sets the terminal title.","title":"Raxol.Terminal.Integration.Renderer.set_title/2","ref":"Raxol.Terminal.Integration.Renderer.html#set_title/2"},{"type":"function","doc":"Updates the renderer configuration.","title":"Raxol.Terminal.Integration.Renderer.update_config/2","ref":"Raxol.Terminal.Integration.Renderer.html#update_config/2"},{"type":"module","doc":"Manages the state of the integrated terminal system.","title":"Raxol.Terminal.Integration.State","ref":"Raxol.Terminal.Integration.State.html"},{"type":"function","doc":"Gets the current command history from the terminal state.","title":"Raxol.Terminal.Integration.State.get_command_history/1","ref":"Raxol.Terminal.Integration.State.html#get_command_history/1"},{"type":"function","doc":"Gets the current configuration from the terminal state.","title":"Raxol.Terminal.Integration.State.get_config/1","ref":"Raxol.Terminal.Integration.State.html#get_config/1"},{"type":"function","doc":"Gets the current cursor position from the terminal state.","title":"Raxol.Terminal.Integration.State.get_cursor_position/1","ref":"Raxol.Terminal.Integration.State.html#get_cursor_position/1"},{"type":"function","doc":"Gets the current memory usage from the terminal state.","title":"Raxol.Terminal.Integration.State.get_memory_usage/1","ref":"Raxol.Terminal.Integration.State.html#get_memory_usage/1"},{"type":"function","doc":"Gets the current scroll position from the terminal state.","title":"Raxol.Terminal.Integration.State.get_scroll_position/1","ref":"Raxol.Terminal.Integration.State.html#get_scroll_position/1"},{"type":"function","doc":"Gets the current visible content from the terminal state.","title":"Raxol.Terminal.Integration.State.get_visible_content/1","ref":"Raxol.Terminal.Integration.State.html#get_visible_content/1"},{"type":"function","doc":"Creates a new terminal state with the specified dimensions.","title":"Raxol.Terminal.Integration.State.new/3","ref":"Raxol.Terminal.Integration.State.html#new/3"},{"type":"type","doc":"","title":"Raxol.Terminal.Integration.State.t/0","ref":"Raxol.Terminal.Integration.State.html#t:t/0"},{"type":"function","doc":"Updates the terminal state with new components.","title":"Raxol.Terminal.Integration.State.update/2","ref":"Raxol.Terminal.Integration.State.html#update/2"},{"type":"module","doc":"Terminal manager module.\n\nThis module manages terminal sessions, including:\n- Session creation\n- Session destruction\n- Session listing\n- Session monitoring","title":"Raxol.Terminal.Manager","ref":"Raxol.Terminal.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.Manager.child_spec/1","ref":"Raxol.Terminal.Manager.html#child_spec/1"},{"type":"function","doc":"Gets the count of terminal sessions.","title":"Raxol.Terminal.Manager.count_sessions/1","ref":"Raxol.Terminal.Manager.html#count_sessions/1"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, _} = Manager.create_session(pid)\n    iex> {:ok, _} = Manager.create_session(pid)\n    iex> Manager.count_sessions(pid)\n    2","title":"Examples - Raxol.Terminal.Manager.count_sessions/1","ref":"Raxol.Terminal.Manager.html#count_sessions/1-examples"},{"type":"function","doc":"Creates a new terminal session.","title":"Raxol.Terminal.Manager.create_session/2","ref":"Raxol.Terminal.Manager.html#create_session/2"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid, %{width: 80, height: 24})\n    iex> is_binary(session_id)\n    true","title":"Examples - Raxol.Terminal.Manager.create_session/2","ref":"Raxol.Terminal.Manager.html#create_session/2-examples"},{"type":"function","doc":"Destroys a terminal session.","title":"Raxol.Terminal.Manager.destroy_session/2","ref":"Raxol.Terminal.Manager.html#destroy_session/2"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> :ok = Manager.destroy_session(pid, session_id)\n    iex> Manager.get_session(pid, session_id)\n    {:error, :not_found}","title":"Examples - Raxol.Terminal.Manager.destroy_session/2","ref":"Raxol.Terminal.Manager.html#destroy_session/2-examples"},{"type":"function","doc":"Gets a terminal session by ID.","title":"Raxol.Terminal.Manager.get_session/2","ref":"Raxol.Terminal.Manager.html#get_session/2"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> {:ok, session} = Manager.get_session(pid, session_id)\n    iex> session.id\n    session_id","title":"Examples - Raxol.Terminal.Manager.get_session/2","ref":"Raxol.Terminal.Manager.html#get_session/2-examples"},{"type":"function","doc":"","title":"Raxol.Terminal.Manager.get_state/0","ref":"Raxol.Terminal.Manager.html#get_state/0"},{"type":"function","doc":"Lists all terminal sessions.","title":"Raxol.Terminal.Manager.list_sessions/1","ref":"Raxol.Terminal.Manager.html#list_sessions/1"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id1} = Manager.create_session(pid)\n    iex> {:ok, session_id2} = Manager.create_session(pid)\n    iex> sessions = Manager.list_sessions(pid)\n    iex> length(sessions)\n    2","title":"Examples - Raxol.Terminal.Manager.list_sessions/1","ref":"Raxol.Terminal.Manager.html#list_sessions/1-examples"},{"type":"function","doc":"Monitors a terminal session.","title":"Raxol.Terminal.Manager.monitor_session/2","ref":"Raxol.Terminal.Manager.html#monitor_session/2"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> :ok = Manager.monitor_session(pid, session_id)\n    iex> Process.whereis({:via, Registry, {Registry, session_id}})\n    #PID<0.123.0>","title":"Examples - Raxol.Terminal.Manager.monitor_session/2","ref":"Raxol.Terminal.Manager.html#monitor_session/2-examples"},{"type":"function","doc":"Starts the terminal manager.","title":"Raxol.Terminal.Manager.start_link/1","ref":"Raxol.Terminal.Manager.html#start_link/1"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> Process.alive?(pid)\n    true","title":"Examples - Raxol.Terminal.Manager.start_link/1","ref":"Raxol.Terminal.Manager.html#start_link/1-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Manager.t/0","ref":"Raxol.Terminal.Manager.html#t:t/0"},{"type":"function","doc":"Unmonitors a terminal session.","title":"Raxol.Terminal.Manager.unmonitor_session/2","ref":"Raxol.Terminal.Manager.html#unmonitor_session/2"},{"type":"function","doc":"iex> {:ok, pid} = Manager.start_link()\n    iex> {:ok, session_id} = Manager.create_session(pid)\n    iex> :ok = Manager.monitor_session(pid, session_id)\n    iex> :ok = Manager.unmonitor_session(pid, session_id)\n    iex> Process.whereis({:via, Registry, {Registry, session_id}})\n    nil","title":"Examples - Raxol.Terminal.Manager.unmonitor_session/2","ref":"Raxol.Terminal.Manager.html#unmonitor_session/2-examples"},{"type":"function","doc":"","title":"Raxol.Terminal.Manager.update_state/1","ref":"Raxol.Terminal.Manager.html#update_state/1"},{"type":"module","doc":"Monitors and manages memory usage for terminal processes.\n\nCan trigger actions like trimming scrollback when limits are exceeded.","title":"Raxol.Terminal.MemoryManager","ref":"Raxol.Terminal.MemoryManager.html"},{"type":"function","doc":"Checks if memory usage exceeds the limit and performs cleanup if necessary.\n\nThis function should be called periodically.","title":"Raxol.Terminal.MemoryManager.check_and_cleanup/1","ref":"Raxol.Terminal.MemoryManager.html#check_and_cleanup/1"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.MemoryManager.child_spec/1","ref":"Raxol.Terminal.MemoryManager.html#child_spec/1"},{"type":"function","doc":"Estimates the total memory usage of the terminal state.\n\nSums the memory usage of the buffer manager, scroll buffer, and other relevant components.\nReturns the total in bytes.","title":"Raxol.Terminal.MemoryManager.estimate_memory_usage/1","ref":"Raxol.Terminal.MemoryManager.html#estimate_memory_usage/1"},{"type":"function","doc":"Performs memory cleanup operations on relevant terminal components.\n\nCurrently focuses on trimming the buffer manager.","title":"Raxol.Terminal.MemoryManager.perform_cleanup/1","ref":"Raxol.Terminal.MemoryManager.html#perform_cleanup/1"},{"type":"module","doc":"Manages terminal modes (DEC Private Modes, Standard Modes) and their effects.\n\nThis module centralizes the state and logic for various terminal modes,\nhandling both simple flag toggles and modes with side effects on the\nemulator state (like screen buffer switching or resizing).","title":"Raxol.Terminal.ModeManager","ref":"Raxol.Terminal.ModeManager.html"},{"type":"function","doc":"Looks up a DEC private mode code and returns the corresponding mode atom.","title":"Raxol.Terminal.ModeManager.lookup_private/1","ref":"Raxol.Terminal.ModeManager.html#lookup_private/1"},{"type":"function","doc":"Looks up a standard mode code and returns the corresponding mode atom.","title":"Raxol.Terminal.ModeManager.lookup_standard/1","ref":"Raxol.Terminal.ModeManager.html#lookup_standard/1"},{"type":"type","doc":"","title":"Raxol.Terminal.ModeManager.mode/0","ref":"Raxol.Terminal.ModeManager.html#t:mode/0"},{"type":"function","doc":"Checks if a specific mode flag is currently enabled.","title":"Raxol.Terminal.ModeManager.mode_enabled?/2","ref":"Raxol.Terminal.ModeManager.html#mode_enabled?/2"},{"type":"function","doc":"Creates a new mode manager state with default values.","title":"Raxol.Terminal.ModeManager.new/0","ref":"Raxol.Terminal.ModeManager.html#new/0"},{"type":"function","doc":"Resets one or more modes. Dispatches to specific handlers.\nReturns potentially updated Emulator state if side effects occurred.","title":"Raxol.Terminal.ModeManager.reset_mode/2","ref":"Raxol.Terminal.ModeManager.html#reset_mode/2"},{"type":"function","doc":"Sets one or more modes. Dispatches to specific handlers.\nReturns potentially updated Emulator state if side effects occurred.","title":"Raxol.Terminal.ModeManager.set_mode/2","ref":"Raxol.Terminal.ModeManager.html#set_mode/2"},{"type":"type","doc":"","title":"Raxol.Terminal.ModeManager.t/0","ref":"Raxol.Terminal.ModeManager.html#t:t/0"},{"type":"module","doc":"Handles terminal modes and state transitions for the terminal emulator.\n\nThis module provides functions for managing terminal modes, processing\nescape sequences, and handling terminal state transitions.","title":"Raxol.Terminal.Modes","ref":"Raxol.Terminal.Modes.html"},{"type":"function","doc":"Checks if a terminal mode is active.","title":"Raxol.Terminal.Modes.active?/2","ref":"Raxol.Terminal.Modes.html#active?/2"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> Modes.active?(modes, :normal)\n    true\n    iex> Modes.active?(modes, :insert)\n    false","title":"Examples - Raxol.Terminal.Modes.active?/2","ref":"Raxol.Terminal.Modes.html#active?/2-examples"},{"type":"function","doc":"Returns a list of all active terminal modes.","title":"Raxol.Terminal.Modes.active_modes/1","ref":"Raxol.Terminal.Modes.html#active_modes/1"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> Modes.active_modes(modes)\n    [:normal, :replace]","title":"Examples - Raxol.Terminal.Modes.active_modes/1","ref":"Raxol.Terminal.Modes.html#active_modes/1-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Modes.mode/0","ref":"Raxol.Terminal.Modes.html#t:mode/0"},{"type":"type","doc":"","title":"Raxol.Terminal.Modes.mode_state/0","ref":"Raxol.Terminal.Modes.html#t:mode_state/0"},{"type":"function","doc":"Creates a new terminal mode state.","title":"Raxol.Terminal.Modes.new/0","ref":"Raxol.Terminal.Modes.html#new/0"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> modes.insert\n    false","title":"Examples - Raxol.Terminal.Modes.new/0","ref":"Raxol.Terminal.Modes.html#new/0-examples"},{"type":"function","doc":"Processes an escape sequence for terminal mode changes.","title":"Raxol.Terminal.Modes.process_escape/2","ref":"Raxol.Terminal.Modes.html#process_escape/2"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> {modes, _} = Modes.process_escape(modes, \"?1049h\")\n    iex> Modes.active?(modes, :alternate_screen)\n    true","title":"Examples - Raxol.Terminal.Modes.process_escape/2","ref":"Raxol.Terminal.Modes.html#process_escape/2-examples"},{"type":"function","doc":"Resets a specific terminal mode to its default value.","title":"Raxol.Terminal.Modes.reset_mode/2","ref":"Raxol.Terminal.Modes.html#reset_mode/2"},{"type":"function","doc":"iex> modes = Modes.new() |> Modes.set_mode(:insert)\n    iex> modes.insert\n    true\n    iex> modes = Modes.reset_mode(modes, :insert)\n    iex> modes.insert\n    false\n    iex> modes = Modes.reset_mode(modes, :replace) # replace defaults to true\n    iex> modes.replace\n    true","title":"Examples - Raxol.Terminal.Modes.reset_mode/2","ref":"Raxol.Terminal.Modes.html#reset_mode/2-examples"},{"type":"function","doc":"Restores a previously saved terminal mode state.","title":"Raxol.Terminal.Modes.restore_state/2","ref":"Raxol.Terminal.Modes.html#restore_state/2"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> {modes, saved_modes} = Modes.save_state(modes)\n    iex> modes = Modes.set_mode(modes, :insert)\n    iex> modes = Modes.restore_state(modes, saved_modes)\n    iex> Modes.active?(modes, :normal)\n    true","title":"Examples - Raxol.Terminal.Modes.restore_state/2","ref":"Raxol.Terminal.Modes.html#restore_state/2-examples"},{"type":"function","doc":"Saves the current terminal mode state.","title":"Raxol.Terminal.Modes.save_state/1","ref":"Raxol.Terminal.Modes.html#save_state/1"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> {modes, saved_modes} = Modes.save_state(modes)\n    iex> modes = Modes.set_mode(modes, :insert)\n    iex> modes = Modes.restore_state(modes, saved_modes)\n    iex> Modes.active?(modes, :normal)\n    true","title":"Examples - Raxol.Terminal.Modes.save_state/1","ref":"Raxol.Terminal.Modes.html#save_state/1-examples"},{"type":"function","doc":"Sets a terminal mode.","title":"Raxol.Terminal.Modes.set_mode/2","ref":"Raxol.Terminal.Modes.html#set_mode/2"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> modes = Modes.set_mode(modes, :insert)\n    iex> modes.insert\n    true\n    iex> modes.replace\n    false","title":"Examples - Raxol.Terminal.Modes.set_mode/2","ref":"Raxol.Terminal.Modes.html#set_mode/2-examples"},{"type":"function","doc":"Returns a string representation of the terminal mode state.","title":"Raxol.Terminal.Modes.to_string/1","ref":"Raxol.Terminal.Modes.html#to_string/1"},{"type":"function","doc":"iex> modes = Modes.new()\n    iex> Modes.to_string(modes)\n    \"Terminal Modes: normal, replace\"","title":"Examples - Raxol.Terminal.Modes.to_string/1","ref":"Raxol.Terminal.Modes.html#to_string/1-examples"},{"type":"module","doc":"Parses raw byte streams into terminal events and commands.\nHandles escape sequences (CSI, OSC, DCS, etc.) and plain text.","title":"Raxol.Terminal.Parser","ref":"Raxol.Terminal.Parser.html"},{"type":"function","doc":"","title":"Raxol.Terminal.Parser.parse/2","ref":"Raxol.Terminal.Parser.html#parse/2"},{"type":"function","doc":"Parses a chunk of input data, updating the parser state and emulator.\n\nTakes the current emulator state and input binary, returns the updated emulator state\nafter processing the input chunk.\n\nTakes the emulator state, the *current* parser state, and the input binary.\nReturns `{final_emulator_state, final_parser_state}`.","title":"Raxol.Terminal.Parser.parse_chunk/3","ref":"Raxol.Terminal.Parser.html#parse_chunk/3"},{"type":"module","doc":"Manages parser state transitions and state-specific functionality for the terminal emulator.\nThis module provides a clean interface for managing the parser's state machine and delegating\nto appropriate state handlers.","title":"Raxol.Terminal.Parser.State.Manager","ref":"Raxol.Terminal.Parser.State.Manager.html"},{"type":"function","doc":"Appends a byte to the intermediates buffer.","title":"Raxol.Terminal.Parser.State.Manager.append_intermediate/2","ref":"Raxol.Terminal.Parser.State.Manager.html#append_intermediate/2"},{"type":"function","doc":"Appends a byte to the params buffer.","title":"Raxol.Terminal.Parser.State.Manager.append_param/2","ref":"Raxol.Terminal.Parser.State.Manager.html#append_param/2"},{"type":"function","doc":"Appends a byte to the payload buffer.","title":"Raxol.Terminal.Parser.State.Manager.append_payload/2","ref":"Raxol.Terminal.Parser.State.Manager.html#append_payload/2"},{"type":"function","doc":"Gets the current parser state.","title":"Raxol.Terminal.Parser.State.Manager.get_current_state/1","ref":"Raxol.Terminal.Parser.State.Manager.html#get_current_state/1"},{"type":"function","doc":"Creates a new parser state with default values.","title":"Raxol.Terminal.Parser.State.Manager.new/0","ref":"Raxol.Terminal.Parser.State.Manager.html#new/0"},{"type":"function","doc":"Processes input in the current parser state.\nReturns the updated emulator and parser state.","title":"Raxol.Terminal.Parser.State.Manager.process_input/3","ref":"Raxol.Terminal.Parser.State.Manager.html#process_input/3"},{"type":"function","doc":"Clears all buffers and resets the state to ground.","title":"Raxol.Terminal.Parser.State.Manager.reset/1","ref":"Raxol.Terminal.Parser.State.Manager.html#reset/1"},{"type":"function","doc":"Sets the G-set being designated.","title":"Raxol.Terminal.Parser.State.Manager.set_designating_gset/2","ref":"Raxol.Terminal.Parser.State.Manager.html#set_designating_gset/2"},{"type":"function","doc":"Sets the final byte for the current sequence.","title":"Raxol.Terminal.Parser.State.Manager.set_final_byte/2","ref":"Raxol.Terminal.Parser.State.Manager.html#set_final_byte/2"},{"type":"function","doc":"Sets the parser state to a new value.","title":"Raxol.Terminal.Parser.State.Manager.set_state/2","ref":"Raxol.Terminal.Parser.State.Manager.html#set_state/2"},{"type":"function","doc":"Transitions to a new parser state, clearing relevant buffers.","title":"Raxol.Terminal.Parser.State.Manager.transition_to/2","ref":"Raxol.Terminal.Parser.State.Manager.html#transition_to/2"},{"type":"module","doc":"Handles the :csi_entry state of the terminal parser.","title":"Raxol.Terminal.Parser.States.CSIEntryState","ref":"Raxol.Terminal.Parser.States.CSIEntryState.html"},{"type":"function","doc":"Processes input when the parser is in the :csi_entry state.","title":"Raxol.Terminal.Parser.States.CSIEntryState.handle/3","ref":"Raxol.Terminal.Parser.States.CSIEntryState.html#handle/3"},{"type":"module","doc":"Handles the :csi_intermediate state of the terminal parser.","title":"Raxol.Terminal.Parser.States.CSIIntermediateState","ref":"Raxol.Terminal.Parser.States.CSIIntermediateState.html"},{"type":"function","doc":"Processes input when the parser is in the :csi_intermediate state.\nCollects intermediate bytes (0x20-0x2F).","title":"Raxol.Terminal.Parser.States.CSIIntermediateState.handle/3","ref":"Raxol.Terminal.Parser.States.CSIIntermediateState.html#handle/3"},{"type":"module","doc":"Handles the :csi_param state of the terminal parser.","title":"Raxol.Terminal.Parser.States.CSIParamState","ref":"Raxol.Terminal.Parser.States.CSIParamState.html"},{"type":"function","doc":"Processes input when the parser is in the :csi_param state.\nCollects parameter digits (0-9) and semicolons (;).","title":"Raxol.Terminal.Parser.States.CSIParamState.handle/3","ref":"Raxol.Terminal.Parser.States.CSIParamState.html#handle/3"},{"type":"module","doc":"Handles the :dcs_entry state of the terminal parser.","title":"Raxol.Terminal.Parser.States.DCSEntryState","ref":"Raxol.Terminal.Parser.States.DCSEntryState.html"},{"type":"function","doc":"Processes input when the parser is in the :dcs_entry state.\nSimilar to CSI Entry - collects params/intermediates/final byte.","title":"Raxol.Terminal.Parser.States.DCSEntryState.handle/3","ref":"Raxol.Terminal.Parser.States.DCSEntryState.html#handle/3"},{"type":"module","doc":"Handles the :dcs_passthrough_maybe_st state of the terminal parser.","title":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState","ref":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState.html"},{"type":"function","doc":"Processes input when the parser is in the :dcs_passthrough_maybe_st state.","title":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState.handle/3","ref":"Raxol.Terminal.Parser.States.DCSPassthroughMaybeSTState.html#handle/3"},{"type":"module","doc":"Handles the :dcs_passthrough state of the terminal parser.","title":"Raxol.Terminal.Parser.States.DCSPassthroughState","ref":"Raxol.Terminal.Parser.States.DCSPassthroughState.html"},{"type":"function","doc":"Processes input when the parser is in the :dcs_passthrough state.\nCollects the DCS data string until ST (ESC ).","title":"Raxol.Terminal.Parser.States.DCSPassthroughState.handle/3","ref":"Raxol.Terminal.Parser.States.DCSPassthroughState.html#handle/3"},{"type":"module","doc":"Handles the :designate_charset state of the terminal parser.","title":"Raxol.Terminal.Parser.States.DesignateCharsetState","ref":"Raxol.Terminal.Parser.States.DesignateCharsetState.html"},{"type":"function","doc":"Processes input when the parser is in the :designate_charset state.\nExpects a single character designating the character set.","title":"Raxol.Terminal.Parser.States.DesignateCharsetState.handle/3","ref":"Raxol.Terminal.Parser.States.DesignateCharsetState.html#handle/3"},{"type":"module","doc":"Handles the :escape state of the terminal parser.","title":"Raxol.Terminal.Parser.States.EscapeState","ref":"Raxol.Terminal.Parser.States.EscapeState.html"},{"type":"function","doc":"Processes input when the parser is in the :escape state.","title":"Raxol.Terminal.Parser.States.EscapeState.handle/3","ref":"Raxol.Terminal.Parser.States.EscapeState.html#handle/3"},{"type":"module","doc":"Handles the :ground state of the terminal parser.\nProcesses plain text and transitions to other states on control codes/escape sequences.","title":"Raxol.Terminal.Parser.States.GroundState","ref":"Raxol.Terminal.Parser.States.GroundState.html"},{"type":"function","doc":"Processes input when the parser is in the :ground state.\n\nReturns:\n  - `{:continue, new_emulator, next_parser_state, remaining_input}` to continue parsing.\n  - `{:handled, final_emulator}` if the input is fully processed or an error occurs.","title":"Raxol.Terminal.Parser.States.GroundState.handle/3","ref":"Raxol.Terminal.Parser.States.GroundState.html#handle/3"},{"type":"module","doc":"Handles the :osc_string_maybe_st state of the terminal parser.","title":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState","ref":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState.html"},{"type":"function","doc":"Processes input when the parser is in the :osc_string_maybe_st state.","title":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState.handle/3","ref":"Raxol.Terminal.Parser.States.OSCStringMaybeSTState.html#handle/3"},{"type":"module","doc":"Handles the :osc_string state of the terminal parser.","title":"Raxol.Terminal.Parser.States.OSCStringState","ref":"Raxol.Terminal.Parser.States.OSCStringState.html"},{"type":"function","doc":"Processes input when the parser is in the :osc_string state.\nCollects the OSC string until ST (ESC ) or BEL.","title":"Raxol.Terminal.Parser.States.OSCStringState.handle/3","ref":"Raxol.Terminal.Parser.States.OSCStringState.html#handle/3"},{"type":"module","doc":"Terminal registry module.\n\nThis module manages the registry of terminal sessions, including:\n- Session registration\n- Session lookup\n- Session cleanup","title":"Raxol.Terminal.Registry","ref":"Raxol.Terminal.Registry.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.Registry.child_spec/1","ref":"Raxol.Terminal.Registry.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.count/0","ref":"Raxol.Terminal.Registry.html#count/0"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.exclude_by_id/1","ref":"Raxol.Terminal.Registry.html#exclude_by_id/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.filter_by_id/1","ref":"Raxol.Terminal.Registry.html#filter_by_id/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.init/1","ref":"Raxol.Terminal.Registry.html#init/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.list/0","ref":"Raxol.Terminal.Registry.html#list/0"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.lookup/1","ref":"Raxol.Terminal.Registry.html#lookup/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.match/1","ref":"Raxol.Terminal.Registry.html#match/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.match_except/1","ref":"Raxol.Terminal.Registry.html#match_except/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.register/2","ref":"Raxol.Terminal.Registry.html#register/2"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.start_link/1","ref":"Raxol.Terminal.Registry.html#start_link/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Registry.unregister/1","ref":"Raxol.Terminal.Registry.html#unregister/1"},{"type":"module","doc":"Terminal renderer module.\n\nThis module handles rendering of terminal output, including:\n- Character cell rendering\n- Text styling\n- Cursor rendering\n- Performance optimizations","title":"Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html"},{"type":"module","doc":"The Renderer module works closely with several specialized modules:","title":"Integration with Other Modules - Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html#module-integration-with-other-modules"},{"type":"module","doc":"- Receives text and style updates from the Manipulation module\n- Renders text with proper styling and positioning\n- Handles text insertion, deletion, and modification","title":"Manipulation Module - Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html#module-manipulation-module"},{"type":"module","doc":"- Renders text selections with visual highlighting\n- Supports multiple selections\n- Handles selection state changes","title":"Selection Module - Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html#module-selection-module"},{"type":"module","doc":"- Renders validation errors and warnings\n- Applies visual indicators for invalid input\n- Shows validation state through styling","title":"Validation Module - Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html#module-validation-module"},{"type":"module","doc":"The renderer includes several optimizations:\n- Only renders changed cells\n- Batches style updates for consecutive cells\n- Minimizes DOM updates\n- Caches rendered output when possible","title":"Performance Optimizations - Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html#module-performance-optimizations"},{"type":"module","doc":"```elixir\n# Create a new renderer\nbuffer = ScreenBuffer.new(80, 24)\nrenderer = Renderer.new(buffer)\n\n# Render with selection\nselection = Selection.new({0, 0}, {0, 5})\noutput = Renderer.render(renderer, selection: selection)\n\n# Render with validation\nvalidation = Validation.validate_input(buffer, 0, 0, \"text\")\noutput = Renderer.render(renderer, validation: validation)\n```","title":"Usage - Raxol.Terminal.Renderer","ref":"Raxol.Terminal.Renderer.html#module-usage"},{"type":"function","doc":"Clears the cursor position.","title":"Raxol.Terminal.Renderer.clear_cursor/1","ref":"Raxol.Terminal.Renderer.html#clear_cursor/1"},{"type":"function","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> renderer = Renderer.set_cursor(renderer, {10, 5})\n    iex> renderer = Renderer.clear_cursor(renderer)\n    iex> renderer.cursor\n    nil","title":"Examples - Raxol.Terminal.Renderer.clear_cursor/1","ref":"Raxol.Terminal.Renderer.html#clear_cursor/1-examples"},{"type":"function","doc":"Creates a new renderer with the given screen buffer.","title":"Raxol.Terminal.Renderer.new/3","ref":"Raxol.Terminal.Renderer.html#new/3"},{"type":"function","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> renderer.screen_buffer\n    %ScreenBuffer{}","title":"Examples - Raxol.Terminal.Renderer.new/3","ref":"Raxol.Terminal.Renderer.html#new/3-examples"},{"type":"function","doc":"Renders the screen buffer to a string.","title":"Raxol.Terminal.Renderer.render/2","ref":"Raxol.Terminal.Renderer.html#render/2"},{"type":"function","doc":"* `:selection` - A single selection to highlight\n  * `:selections` - Multiple selections to highlight\n  * `:validation` - Validation state to apply\n  * `:theme` - Override the default theme\n  * `:font_settings` - Override the default font settings","title":"Options - Raxol.Terminal.Renderer.render/2","ref":"Raxol.Terminal.Renderer.html#render/2-options"},{"type":"function","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> output = Renderer.render(renderer)\n    iex> is_binary(output)\n    true\n\n    iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> selection = Selection.new({0, 0}, {0, 5})\n    iex> output = Renderer.render(renderer, selection: selection)\n    iex> output =~ \"background-color: #0000FF\"\n    true","title":"Examples - Raxol.Terminal.Renderer.render/2","ref":"Raxol.Terminal.Renderer.html#render/2-examples"},{"type":"function","doc":"Sets the cursor position.","title":"Raxol.Terminal.Renderer.set_cursor/2","ref":"Raxol.Terminal.Renderer.html#set_cursor/2"},{"type":"function","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> renderer = Renderer.set_cursor(renderer, {10, 5})\n    iex> renderer.cursor\n    {10, 5}","title":"Examples - Raxol.Terminal.Renderer.set_cursor/2","ref":"Raxol.Terminal.Renderer.html#set_cursor/2-examples"},{"type":"function","doc":"Updates the font settings.","title":"Raxol.Terminal.Renderer.set_font_settings/2","ref":"Raxol.Terminal.Renderer.html#set_font_settings/2"},{"type":"function","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> settings = %{family: \"Fira Code\"}\n    iex> renderer = Renderer.set_font_settings(renderer, settings)\n    iex> renderer.font_settings\n    %{family: \"Fira Code\"}","title":"Examples - Raxol.Terminal.Renderer.set_font_settings/2","ref":"Raxol.Terminal.Renderer.html#set_font_settings/2-examples"},{"type":"function","doc":"Updates the theme settings.","title":"Raxol.Terminal.Renderer.set_theme/2","ref":"Raxol.Terminal.Renderer.html#set_theme/2"},{"type":"function","doc":"iex> screen_buffer = ScreenBuffer.new(80, 24)\n    iex> renderer = Renderer.new(screen_buffer)\n    iex> theme = %{foreground: %{default: \"#FFF\"}}\n    iex> renderer = Renderer.set_theme(renderer, theme)\n    iex> renderer.theme\n    %{foreground: %{default: \"#FFF\"}}","title":"Examples - Raxol.Terminal.Renderer.set_theme/2","ref":"Raxol.Terminal.Renderer.html#set_theme/2-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Renderer.t/0","ref":"Raxol.Terminal.Renderer.html#t:t/0"},{"type":"module","doc":"Manages the terminal's screen buffer state (grid, scrollback, selection).\nDelegates operations to specialized modules in Raxol.Terminal.Buffer.*","title":"Raxol.Terminal.ScreenBuffer","ref":"Raxol.Terminal.ScreenBuffer.html"},{"type":"function","doc":"Clears buffer. See `Raxol.Terminal.Buffer.Eraser.clear_screen/2`.","title":"Raxol.Terminal.ScreenBuffer.clear/2","ref":"Raxol.Terminal.ScreenBuffer.html#clear/2"},{"type":"function","doc":"Clears region. See `Raxol.Terminal.Buffer.Eraser.clear_region/6`.","title":"Raxol.Terminal.ScreenBuffer.clear_region/6","ref":"Raxol.Terminal.ScreenBuffer.html#clear_region/6"},{"type":"function","doc":"Clears scroll region. See `Raxol.Terminal.Buffer.Operations.clear_scroll_region/1`.","title":"Raxol.Terminal.ScreenBuffer.clear_scroll_region/1","ref":"Raxol.Terminal.ScreenBuffer.html#clear_scroll_region/1"},{"type":"function","doc":"Deletes `count` characters starting at `{row, col}`.\n\nCharacters to the right are shifted left.\nBlank cells are inserted at the end of the line.\n\nDelegates to `CharEditor.delete_characters/5`. Requires default_style.","title":"Raxol.Terminal.ScreenBuffer.delete_characters/5","ref":"Raxol.Terminal.ScreenBuffer.html#delete_characters/5"},{"type":"function","doc":"Deletes `n` lines starting at `start_y`.\nOptionally operates only within the given `scroll_region` {top, bottom}.","title":"Raxol.Terminal.ScreenBuffer.delete_lines/5","ref":"Raxol.Terminal.ScreenBuffer.html#delete_lines/5"},{"type":"function","doc":"Calculates diff. See `Raxol.Terminal.Buffer.Operations.diff/2`.","title":"Raxol.Terminal.ScreenBuffer.diff/2","ref":"Raxol.Terminal.ScreenBuffer.html#diff/2"},{"type":"function","doc":"Erases in display. See `Raxol.Terminal.Buffer.Eraser.erase_in_display/4`.","title":"Raxol.Terminal.ScreenBuffer.erase_in_display/4","ref":"Raxol.Terminal.ScreenBuffer.html#erase_in_display/4"},{"type":"function","doc":"Erases in line. See `Raxol.Terminal.Buffer.Eraser.erase_in_line/4`.","title":"Raxol.Terminal.ScreenBuffer.erase_in_line/4","ref":"Raxol.Terminal.ScreenBuffer.html#erase_in_line/4"},{"type":"function","doc":"Gets cell. See `Raxol.Terminal.Buffer.Operations.get_cell/3`.","title":"Raxol.Terminal.ScreenBuffer.get_cell/3","ref":"Raxol.Terminal.ScreenBuffer.html#get_cell/3"},{"type":"function","doc":"Gets cell at. See `Raxol.Terminal.Buffer.Operations.get_cell_at/3`.","title":"Raxol.Terminal.ScreenBuffer.get_cell_at/3","ref":"Raxol.Terminal.ScreenBuffer.html#get_cell_at/3"},{"type":"function","doc":"Gets the character at the specified position.\nReturns nil if coordinates are out of bounds.","title":"Raxol.Terminal.ScreenBuffer.get_char/3","ref":"Raxol.Terminal.ScreenBuffer.html#get_char/3"},{"type":"function","doc":"Gets content as string. See `Raxol.Terminal.Buffer.Operations.get_content/1`.","title":"Raxol.Terminal.ScreenBuffer.get_content/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_content/1"},{"type":"function","doc":"Gets dimensions. See `Raxol.Terminal.Buffer.Operations.get_dimensions/1`.","title":"Raxol.Terminal.ScreenBuffer.get_dimensions/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_dimensions/1"},{"type":"function","doc":"Gets height. See `Raxol.Terminal.Buffer.Operations.get_height/1`.","title":"Raxol.Terminal.ScreenBuffer.get_height/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_height/1"},{"type":"function","doc":"Gets line. See `Raxol.Terminal.Buffer.Operations.get_line/2`.","title":"Raxol.Terminal.ScreenBuffer.get_line/2","ref":"Raxol.Terminal.ScreenBuffer.html#get_line/2"},{"type":"function","doc":"Gets scrollback size. See `Raxol.Terminal.Buffer.Scrollback.size/1`.","title":"Raxol.Terminal.ScreenBuffer.get_scroll_position/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_scroll_position/1"},{"type":"function","doc":"Gets scroll region boundaries. See `Raxol.Terminal.Buffer.Operations.get_scroll_region_boundaries/1`.","title":"Raxol.Terminal.ScreenBuffer.get_scroll_region_boundaries/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_scroll_region_boundaries/1"},{"type":"function","doc":"Gets selected text. See `Raxol.Terminal.Buffer.Selection.get_text/1`.","title":"Raxol.Terminal.ScreenBuffer.get_selection/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_selection/1"},{"type":"function","doc":"Gets selection boundaries. See `Raxol.Terminal.Buffer.Selection.get_boundaries/1`.","title":"Raxol.Terminal.ScreenBuffer.get_selection_boundaries/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_selection_boundaries/1"},{"type":"function","doc":"Gets text in region. See `Raxol.Terminal.Buffer.Selection.get_text_in_region/5`.","title":"Raxol.Terminal.ScreenBuffer.get_text_in_region/5","ref":"Raxol.Terminal.ScreenBuffer.html#get_text_in_region/5"},{"type":"function","doc":"Gets width. See `Raxol.Terminal.Buffer.Operations.get_width/1`.","title":"Raxol.Terminal.ScreenBuffer.get_width/1","ref":"Raxol.Terminal.ScreenBuffer.html#get_width/1"},{"type":"function","doc":"Checks if in selection. See `Raxol.Terminal.Buffer.Selection.contains?/3`.","title":"Raxol.Terminal.ScreenBuffer.in_selection?/3","ref":"Raxol.Terminal.ScreenBuffer.html#in_selection?/3"},{"type":"function","doc":"Inserts `count` blank characters at `{row, col}`.\n\nCharacters from `col` right are shifted right.\nCharacters shifted off the end of the line are discarded.\n\nDelegates to `CharEditor.insert_characters/5`. Requires default_style.","title":"Raxol.Terminal.ScreenBuffer.insert_characters/5","ref":"Raxol.Terminal.ScreenBuffer.html#insert_characters/5"},{"type":"function","doc":"Inserts `count` blank lines at `row`.\n\nLines from `row` down are shifted down.\nLines shifted off the bottom are discarded.\n\nDelegates to `LineEditor.insert_lines/4`. Requires default_style.","title":"Raxol.Terminal.ScreenBuffer.insert_lines/4","ref":"Raxol.Terminal.ScreenBuffer.html#insert_lines/4"},{"type":"function","doc":"Checks if the buffer contains only default cells.","title":"Raxol.Terminal.ScreenBuffer.is_empty?/1","ref":"Raxol.Terminal.ScreenBuffer.html#is_empty?/1"},{"type":"function","doc":"Creates a new screen buffer with the specified dimensions.","title":"Raxol.Terminal.ScreenBuffer.new/3","ref":"Raxol.Terminal.ScreenBuffer.html#new/3"},{"type":"function","doc":"Resizes buffer. See `Raxol.Terminal.Buffer.Operations.resize/3`.","title":"Raxol.Terminal.ScreenBuffer.resize/3","ref":"Raxol.Terminal.ScreenBuffer.html#resize/3"},{"type":"function","doc":"Scrolls down. See `Raxol.Terminal.Buffer.Operations.scroll_down/3`.","title":"Raxol.Terminal.ScreenBuffer.scroll_down/3","ref":"Raxol.Terminal.ScreenBuffer.html#scroll_down/3"},{"type":"function","doc":"Scrolls up. See `Raxol.Terminal.Buffer.Operations.scroll_up/3`.","title":"Raxol.Terminal.ScreenBuffer.scroll_up/3","ref":"Raxol.Terminal.ScreenBuffer.html#scroll_up/3"},{"type":"function","doc":"Sets scroll region. See `Raxol.Terminal.Buffer.Operations.set_scroll_region/3`.","title":"Raxol.Terminal.ScreenBuffer.set_scroll_region/3","ref":"Raxol.Terminal.ScreenBuffer.html#set_scroll_region/3"},{"type":"function","doc":"Starts selection. See `Raxol.Terminal.Buffer.Selection.start/3`.","title":"Raxol.Terminal.ScreenBuffer.start_selection/3","ref":"Raxol.Terminal.ScreenBuffer.html#start_selection/3"},{"type":"type","doc":"","title":"Raxol.Terminal.ScreenBuffer.t/0","ref":"Raxol.Terminal.ScreenBuffer.html#t:t/0"},{"type":"function","doc":"Updates buffer from changes. See `Raxol.Terminal.Buffer.Operations.update/2`.","title":"Raxol.Terminal.ScreenBuffer.update/2","ref":"Raxol.Terminal.ScreenBuffer.html#update/2"},{"type":"function","doc":"Updates selection. See `Raxol.Terminal.Buffer.Selection.update/3`.","title":"Raxol.Terminal.ScreenBuffer.update_selection/3","ref":"Raxol.Terminal.ScreenBuffer.html#update_selection/3"},{"type":"function","doc":"Writes a character. See `Raxol.Terminal.Buffer.Operations.write_char/5`.","title":"Raxol.Terminal.ScreenBuffer.write_char/5","ref":"Raxol.Terminal.ScreenBuffer.html#write_char/5"},{"type":"function","doc":"Writes a string. See `Raxol.Terminal.Buffer.Operations.write_string/4`.","title":"Raxol.Terminal.ScreenBuffer.write_string/4","ref":"Raxol.Terminal.ScreenBuffer.html#write_string/4"},{"type":"behaviour","doc":"Behaviour for terminal screen buffer operations.","title":"Raxol.Terminal.ScreenBufferBehaviour","ref":"Raxol.Terminal.ScreenBufferBehaviour.html"},{"type":"callback","doc":"","title":"Raxol.Terminal.ScreenBufferBehaviour.clear/2","ref":"Raxol.Terminal.ScreenBufferBehaviour.html#c:clear/2"},{"type":"callback","doc":"","title":"Raxol.Terminal.ScreenBufferBehaviour.get_dimensions/1","ref":"Raxol.Terminal.ScreenBufferBehaviour.html#c:get_dimensions/1"},{"type":"callback","doc":"","title":"Raxol.Terminal.ScreenBufferBehaviour.new/3","ref":"Raxol.Terminal.ScreenBufferBehaviour.html#c:new/3"},{"type":"callback","doc":"","title":"Raxol.Terminal.ScreenBufferBehaviour.resize/3","ref":"Raxol.Terminal.ScreenBufferBehaviour.html#c:resize/3"},{"type":"module","doc":"Terminal session module.\n\nThis module manages terminal sessions, including:\n- Session lifecycle\n- Input/output handling\n- State management\n- Configuration","title":"Raxol.Terminal.Session","ref":"Raxol.Terminal.Session.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.Session.child_spec/1","ref":"Raxol.Terminal.Session.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Session.count_active_sessions/0","ref":"Raxol.Terminal.Session.html#count_active_sessions/0"},{"type":"function","doc":"Gets the current state of a terminal session.","title":"Raxol.Terminal.Session.get_state/1","ref":"Raxol.Terminal.Session.html#get_state/1"},{"type":"function","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> state = Session.get_state(pid)\n    iex> state.width\n    80","title":"Examples - Raxol.Terminal.Session.get_state/1","ref":"Raxol.Terminal.Session.html#get_state/1-examples"},{"type":"function","doc":"Sends input to a terminal session.","title":"Raxol.Terminal.Session.send_input/2","ref":"Raxol.Terminal.Session.html#send_input/2"},{"type":"function","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> :ok = Session.send_input(pid, \"test\")\n    iex> state = Session.get_state(pid)\n    iex> state.input.buffer\n    \"test\"","title":"Examples - Raxol.Terminal.Session.send_input/2","ref":"Raxol.Terminal.Session.html#send_input/2-examples"},{"type":"function","doc":"Starts a new terminal session.","title":"Raxol.Terminal.Session.start_link/1","ref":"Raxol.Terminal.Session.html#start_link/1"},{"type":"function","doc":"iex> {:ok, pid} = Session.start_link(%{width: 80, height: 24})\n    iex> Process.alive?(pid)\n    true","title":"Examples - Raxol.Terminal.Session.start_link/1","ref":"Raxol.Terminal.Session.html#start_link/1-examples"},{"type":"function","doc":"Stops a terminal session.","title":"Raxol.Terminal.Session.stop/1","ref":"Raxol.Terminal.Session.html#stop/1"},{"type":"function","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> :ok = Session.stop(pid)\n    iex> Process.alive?(pid)\n    false","title":"Examples - Raxol.Terminal.Session.stop/1","ref":"Raxol.Terminal.Session.html#stop/1-examples"},{"type":"type","doc":"","title":"Raxol.Terminal.Session.t/0","ref":"Raxol.Terminal.Session.html#t:t/0"},{"type":"function","doc":"Updates the configuration of a terminal session.","title":"Raxol.Terminal.Session.update_config/2","ref":"Raxol.Terminal.Session.html#update_config/2"},{"type":"function","doc":"iex> {:ok, pid} = Session.start_link()\n    iex> :ok = Session.update_config(pid, %{width: 100, height: 30})\n    iex> state = Session.get_state(pid)\n    iex> state.width\n    100","title":"Examples - Raxol.Terminal.Session.update_config/2","ref":"Raxol.Terminal.Session.html#update_config/2-examples"},{"type":"module","doc":"Manages terminal state including modes, character sets, and state stack.","title":"Raxol.Terminal.State.Manager","ref":"Raxol.Terminal.State.Manager.html"},{"type":"function","doc":"Gets the current character set state.","title":"Raxol.Terminal.State.Manager.get_charset_state/1","ref":"Raxol.Terminal.State.Manager.html#get_charset_state/1"},{"type":"function","doc":"Gets the current hyperlink URL.","title":"Raxol.Terminal.State.Manager.get_hyperlink_url/1","ref":"Raxol.Terminal.State.Manager.html#get_hyperlink_url/1"},{"type":"function","doc":"Gets the current icon name.","title":"Raxol.Terminal.State.Manager.get_icon_name/1","ref":"Raxol.Terminal.State.Manager.html#get_icon_name/1"},{"type":"function","doc":"Gets whether the last column was exceeded.","title":"Raxol.Terminal.State.Manager.get_last_col_exceeded/1","ref":"Raxol.Terminal.State.Manager.html#get_last_col_exceeded/1"},{"type":"function","doc":"Gets the current mode manager state.","title":"Raxol.Terminal.State.Manager.get_mode_manager/1","ref":"Raxol.Terminal.State.Manager.html#get_mode_manager/1"},{"type":"function","doc":"Gets the current scroll region.","title":"Raxol.Terminal.State.Manager.get_scroll_region/1","ref":"Raxol.Terminal.State.Manager.html#get_scroll_region/1"},{"type":"function","doc":"Gets the current state stack.","title":"Raxol.Terminal.State.Manager.get_state_stack/1","ref":"Raxol.Terminal.State.Manager.html#get_state_stack/1"},{"type":"function","doc":"Gets the current window title.","title":"Raxol.Terminal.State.Manager.get_window_title/1","ref":"Raxol.Terminal.State.Manager.html#get_window_title/1"},{"type":"function","doc":"Creates a new state manager with default values.","title":"Raxol.Terminal.State.Manager.new/0","ref":"Raxol.Terminal.State.Manager.html#new/0"},{"type":"function","doc":"Restores the previous state from the state stack.","title":"Raxol.Terminal.State.Manager.restore_state/1","ref":"Raxol.Terminal.State.Manager.html#restore_state/1"},{"type":"function","doc":"Saves the current state to the state stack.","title":"Raxol.Terminal.State.Manager.save_state/1","ref":"Raxol.Terminal.State.Manager.html#save_state/1"},{"type":"type","doc":"","title":"Raxol.Terminal.State.Manager.t/0","ref":"Raxol.Terminal.State.Manager.html#t:t/0"},{"type":"function","doc":"Updates the character set state.","title":"Raxol.Terminal.State.Manager.update_charset_state/2","ref":"Raxol.Terminal.State.Manager.html#update_charset_state/2"},{"type":"function","doc":"Updates the current hyperlink URL.","title":"Raxol.Terminal.State.Manager.update_hyperlink_url/2","ref":"Raxol.Terminal.State.Manager.html#update_hyperlink_url/2"},{"type":"function","doc":"Updates the icon name.","title":"Raxol.Terminal.State.Manager.update_icon_name/2","ref":"Raxol.Terminal.State.Manager.html#update_icon_name/2"},{"type":"function","doc":"Updates the last column exceeded flag.","title":"Raxol.Terminal.State.Manager.update_last_col_exceeded/2","ref":"Raxol.Terminal.State.Manager.html#update_last_col_exceeded/2"},{"type":"function","doc":"Updates the mode manager state.","title":"Raxol.Terminal.State.Manager.update_mode_manager/2","ref":"Raxol.Terminal.State.Manager.html#update_mode_manager/2"},{"type":"function","doc":"Updates the scroll region.","title":"Raxol.Terminal.State.Manager.update_scroll_region/2","ref":"Raxol.Terminal.State.Manager.html#update_scroll_region/2"},{"type":"function","doc":"Updates the state stack.","title":"Raxol.Terminal.State.Manager.update_state_stack/2","ref":"Raxol.Terminal.State.Manager.html#update_state_stack/2"},{"type":"function","doc":"Updates the window title.","title":"Raxol.Terminal.State.Manager.update_window_title/2","ref":"Raxol.Terminal.State.Manager.html#update_window_title/2"},{"type":"module","doc":"Manages text styling and formatting for the terminal emulator.\nThis module provides a clean interface for managing text styles, colors, and attributes.","title":"Raxol.Terminal.Style.Manager","ref":"Raxol.Terminal.Style.Manager.html"},{"type":"function","doc":"Converts an ANSI color code to a color name.","title":"Raxol.Terminal.Style.Manager.ansi_code_to_color_name/1","ref":"Raxol.Terminal.Style.Manager.html#ansi_code_to_color_name/1"},{"type":"function","doc":"Applies a text attribute to the style.","title":"Raxol.Terminal.Style.Manager.apply_style/2","ref":"Raxol.Terminal.Style.Manager.html#apply_style/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Style.Manager.color/0","ref":"Raxol.Terminal.Style.Manager.html#t:color/0"},{"type":"function","doc":"Calculates the effective width of a character based on the current style.","title":"Raxol.Terminal.Style.Manager.effective_width/2","ref":"Raxol.Terminal.Style.Manager.html#effective_width/2"},{"type":"function","doc":"Formats SGR parameters for DECRQSS responses.","title":"Raxol.Terminal.Style.Manager.format_sgr_params/1","ref":"Raxol.Terminal.Style.Manager.html#format_sgr_params/1"},{"type":"function","doc":"Gets the background color.","title":"Raxol.Terminal.Style.Manager.get_background/1","ref":"Raxol.Terminal.Style.Manager.html#get_background/1"},{"type":"function","doc":"Gets the current style.","title":"Raxol.Terminal.Style.Manager.get_current_style/1","ref":"Raxol.Terminal.Style.Manager.html#get_current_style/1"},{"type":"function","doc":"Gets the foreground color.","title":"Raxol.Terminal.Style.Manager.get_foreground/1","ref":"Raxol.Terminal.Style.Manager.html#get_foreground/1"},{"type":"function","doc":"Gets the hyperlink URI.","title":"Raxol.Terminal.Style.Manager.get_hyperlink/1","ref":"Raxol.Terminal.Style.Manager.html#get_hyperlink/1"},{"type":"function","doc":"Creates a new text style with default values.","title":"Raxol.Terminal.Style.Manager.new/0","ref":"Raxol.Terminal.Style.Manager.html#new/0"},{"type":"function","doc":"Resets to single-width, single-height mode.","title":"Raxol.Terminal.Style.Manager.reset_size/1","ref":"Raxol.Terminal.Style.Manager.html#reset_size/1"},{"type":"function","doc":"Resets all text formatting attributes to their default values.","title":"Raxol.Terminal.Style.Manager.reset_style/1","ref":"Raxol.Terminal.Style.Manager.html#reset_style/1"},{"type":"function","doc":"Sets the background color.","title":"Raxol.Terminal.Style.Manager.set_background/2","ref":"Raxol.Terminal.Style.Manager.html#set_background/2"},{"type":"function","doc":"Sets double-height bottom half mode for the current line.","title":"Raxol.Terminal.Style.Manager.set_double_height_bottom/1","ref":"Raxol.Terminal.Style.Manager.html#set_double_height_bottom/1"},{"type":"function","doc":"Sets double-height top half mode for the current line.","title":"Raxol.Terminal.Style.Manager.set_double_height_top/1","ref":"Raxol.Terminal.Style.Manager.html#set_double_height_top/1"},{"type":"function","doc":"Sets double-width mode for the current line.","title":"Raxol.Terminal.Style.Manager.set_double_width/1","ref":"Raxol.Terminal.Style.Manager.html#set_double_width/1"},{"type":"function","doc":"Sets the foreground color.","title":"Raxol.Terminal.Style.Manager.set_foreground/2","ref":"Raxol.Terminal.Style.Manager.html#set_foreground/2"},{"type":"function","doc":"Sets a hyperlink URI.","title":"Raxol.Terminal.Style.Manager.set_hyperlink/2","ref":"Raxol.Terminal.Style.Manager.html#set_hyperlink/2"},{"type":"function","doc":"Sets the style to a new value.","title":"Raxol.Terminal.Style.Manager.set_style/2","ref":"Raxol.Terminal.Style.Manager.html#set_style/2"},{"type":"type","doc":"","title":"Raxol.Terminal.Style.Manager.text_style/0","ref":"Raxol.Terminal.Style.Manager.html#t:text_style/0"},{"type":"module","doc":"Supervisor for terminal-related processes.","title":"Raxol.Terminal.Supervisor","ref":"Raxol.Terminal.Supervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Terminal.Supervisor.child_spec/1","ref":"Raxol.Terminal.Supervisor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Terminal.Supervisor.start_link/1","ref":"Raxol.Terminal.Supervisor.html#start_link/1"},{"type":"module","doc":"Utility functions for terminal operations, providing cross-platform and\nconsistent handling of terminal capabilities and dimensions.","title":"Raxol.Terminal.TerminalUtils","ref":"Raxol.Terminal.TerminalUtils.html"},{"type":"function","doc":"Returns the current cursor position, if available.","title":"Raxol.Terminal.TerminalUtils.cursor_position/0","ref":"Raxol.Terminal.TerminalUtils.html#cursor_position/0"},{"type":"function","doc":"Detects terminal dimensions using a multi-layered approach:\n1. Uses `:io.columns` and `:io.rows` (preferred)\n2. Falls back to rrex_termbox v2.0.1 NIF if `:io` methods fail\n3. Falls back to `stty size` system command if needed\n4. Finally uses hardcoded default dimensions if all else fails\n\nReturns a tuple of {width, height}.","title":"Raxol.Terminal.TerminalUtils.detect_dimensions/0","ref":"Raxol.Terminal.TerminalUtils.html#detect_dimensions/0"},{"type":"function","doc":"Creates a bounds map with dimensions, starting at origin (0,0)","title":"Raxol.Terminal.TerminalUtils.get_bounds_map/0","ref":"Raxol.Terminal.TerminalUtils.html#get_bounds_map/0"},{"type":"function","doc":"Gets terminal dimensions and returns them in a map format.","title":"Raxol.Terminal.TerminalUtils.get_dimensions_map/0","ref":"Raxol.Terminal.TerminalUtils.html#get_dimensions_map/0"},{"type":"module","doc":"Alias module for Raxol.Terminal.ANSI.TextFormatting.\nThis module re-exports the functionality from ANSI.TextFormatting to maintain compatibility.","title":"Raxol.Terminal.TextFormatting","ref":"Raxol.Terminal.TextFormatting.html"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.ansi_code_to_color_name/1","ref":"Raxol.Terminal.TextFormatting.html#ansi_code_to_color_name/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.apply_attribute/2","ref":"Raxol.Terminal.TextFormatting.html#apply_attribute/2"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.apply_color/3","ref":"Raxol.Terminal.TextFormatting.html#apply_color/3"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.effective_width/2","ref":"Raxol.Terminal.TextFormatting.html#effective_width/2"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.get_background/1","ref":"Raxol.Terminal.TextFormatting.html#get_background/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.get_default_style/0","ref":"Raxol.Terminal.TextFormatting.html#get_default_style/0"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.get_foreground/1","ref":"Raxol.Terminal.TextFormatting.html#get_foreground/1"},{"type":"function","doc":"Gets the paired line type for double-height mode.","title":"Raxol.Terminal.TextFormatting.get_paired_line_type/1","ref":"Raxol.Terminal.TextFormatting.html#get_paired_line_type/1"},{"type":"function","doc":"Checks if the current style needs a paired line for double-height mode.","title":"Raxol.Terminal.TextFormatting.needs_paired_line?/1","ref":"Raxol.Terminal.TextFormatting.html#needs_paired_line?/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.new/0","ref":"Raxol.Terminal.TextFormatting.html#new/0"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.reset_size/1","ref":"Raxol.Terminal.TextFormatting.html#reset_size/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.set_background/2","ref":"Raxol.Terminal.TextFormatting.html#set_background/2"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.set_double_height_bottom/1","ref":"Raxol.Terminal.TextFormatting.html#set_double_height_bottom/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.set_double_height_top/1","ref":"Raxol.Terminal.TextFormatting.html#set_double_height_top/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.set_double_width/1","ref":"Raxol.Terminal.TextFormatting.html#set_double_width/1"},{"type":"function","doc":"","title":"Raxol.Terminal.TextFormatting.set_foreground/2","ref":"Raxol.Terminal.TextFormatting.html#set_foreground/2"},{"type":"module","doc":"Common assertion helpers for Raxol tests.\nProvides standardized assertions for components, events, and state.","title":"Raxol.Test.AssertionHelpers","ref":"Raxol.Test.AssertionHelpers.html"},{"type":"function","doc":"Asserts that a component properly handles errors.","title":"Raxol.Test.AssertionHelpers.assert_error_handled/2","ref":"Raxol.Test.AssertionHelpers.html#assert_error_handled/2"},{"type":"function","doc":"Asserts that a component received an event.","title":"Raxol.Test.AssertionHelpers.assert_event_received/2","ref":"Raxol.Test.AssertionHelpers.html#assert_event_received/2"},{"type":"function","doc":"Asserts that a component's render output matches a snapshot.","title":"Raxol.Test.AssertionHelpers.assert_matches_snapshot/3","ref":"Raxol.Test.AssertionHelpers.html#assert_matches_snapshot/3"},{"type":"function","doc":"Asserts that a component's render output matches expected text.","title":"Raxol.Test.AssertionHelpers.assert_renders_with/2","ref":"Raxol.Test.AssertionHelpers.html#assert_renders_with/2"},{"type":"function","doc":"Asserts that a component is responsive across different sizes.","title":"Raxol.Test.AssertionHelpers.assert_responsive/2","ref":"Raxol.Test.AssertionHelpers.html#assert_responsive/2"},{"type":"function","doc":"Asserts that a component's state matches expected values.","title":"Raxol.Test.AssertionHelpers.assert_state_match/2","ref":"Raxol.Test.AssertionHelpers.html#assert_state_match/2"},{"type":"function","doc":"Asserts that a component maintains consistent styling across themes.","title":"Raxol.Test.AssertionHelpers.assert_theme_consistent/2","ref":"Raxol.Test.AssertionHelpers.html#assert_theme_consistent/2"},{"type":"function","doc":"Asserts that a component did not receive an event.","title":"Raxol.Test.AssertionHelpers.refute_event_received/2","ref":"Raxol.Test.AssertionHelpers.html#refute_event_received/2"},{"type":"module","doc":"Canonical test helpers for clipboard-related tests in Raxol.\nProvides utilities for state creation, clipboard command assertions, and Mox setup.","title":"Raxol.Test.ClipboardHelpers","ref":"Raxol.Test.ClipboardHelpers.html"},{"type":"function","doc":"Asserts that the clipboard read command is present in the command list.","title":"Raxol.Test.ClipboardHelpers.assert_clipboard_read/1","ref":"Raxol.Test.ClipboardHelpers.html#assert_clipboard_read/1"},{"type":"function","doc":"Asserts that the clipboard write command is present in the command list with the expected content.","title":"Raxol.Test.ClipboardHelpers.assert_clipboard_write/2","ref":"Raxol.Test.ClipboardHelpers.html#assert_clipboard_write/2"},{"type":"function","doc":"Creates a MultiLineInput state for clipboard tests.","title":"Raxol.Test.ClipboardHelpers.create_state/3","ref":"Raxol.Test.ClipboardHelpers.html#create_state/3"},{"type":"function","doc":"Sets up Mox expectations for clipboard copy and paste.","title":"Raxol.Test.ClipboardHelpers.expect_clipboard_copy/3","ref":"Raxol.Test.ClipboardHelpers.html#expect_clipboard_copy/3"},{"type":"function","doc":"","title":"Raxol.Test.ClipboardHelpers.expect_clipboard_paste/2","ref":"Raxol.Test.ClipboardHelpers.html#expect_clipboard_paste/2"},{"type":"module","doc":"Helpers for testing event handling in Raxol components.\nProvides utilities for simulating and verifying events.","title":"Raxol.Test.EventHelpers","ref":"Raxol.Test.EventHelpers.html"},{"type":"function","doc":"Asserts that a child component received an event from parent.","title":"Raxol.Test.EventHelpers.assert_child_received/2","ref":"Raxol.Test.EventHelpers.html#assert_child_received/2"},{"type":"function","doc":"Verifies that error handling works properly between components.","title":"Raxol.Test.EventHelpers.assert_error_contained/3","ref":"Raxol.Test.EventHelpers.html#assert_error_contained/3"},{"type":"function","doc":"Asserts that a parent component was updated after a child event.","title":"Raxol.Test.EventHelpers.assert_parent_updated/2","ref":"Raxol.Test.EventHelpers.html#assert_parent_updated/2"},{"type":"function","doc":"Verifies that state is synchronized between components.","title":"Raxol.Test.EventHelpers.assert_state_synchronized/2","ref":"Raxol.Test.EventHelpers.html#assert_state_synchronized/2"},{"type":"function","doc":"Verifies that a component properly handles system events.","title":"Raxol.Test.EventHelpers.assert_system_events_handled/2","ref":"Raxol.Test.EventHelpers.html#assert_system_events_handled/2"},{"type":"function","doc":"Simulates an event on a component.","title":"Raxol.Test.EventHelpers.simulate_event/2","ref":"Raxol.Test.EventHelpers.html#simulate_event/2"},{"type":"function","doc":"Simulates a user action on a component.","title":"Raxol.Test.EventHelpers.simulate_user_action/2","ref":"Raxol.Test.EventHelpers.html#simulate_user_action/2"},{"type":"module","doc":"Provides utilities for testing component interactions and system integration.\n\nThis module focuses on testing:\n- Multi-component interactions\n- Event propagation between components\n- State synchronization\n- Terminal I/O simulation\n- Component hierarchy behavior","title":"Raxol.Test.Integration","ref":"Raxol.Test.Integration.html"},{"type":"module","doc":"defmodule MyApp.IntegrationTest do\n      use ExUnit.Case\n      use Raxol.Test.Integration\n\n      test_scenario \"parent-child communication\", %{parent: Parent, child: Child} do\n        # Set up component hierarchy\n        {:ok, parent, child} = setup_component_hierarchy(Parent, Child)\n\n        # Simulate user interaction\n        simulate_user_action(parent, {:click, {10, 10}})\n\n        # Verify component interaction\n        assert_child_received(child, :parent_clicked)\n        assert_parent_updated(parent, :child_responded)\n      end\n    end","title":"Example - Raxol.Test.Integration","ref":"Raxol.Test.Integration.html#module-example"},{"type":"function","doc":"Verifies that a component properly handles a system event.","title":"Raxol.Test.Integration.assert_handles_system_event/2","ref":"Raxol.Test.Integration.html#assert_handles_system_event/2"},{"type":"function","doc":"Simulates component mounting in the application.","title":"Raxol.Test.Integration.mount_component/2","ref":"Raxol.Test.Integration.html#mount_component/2"},{"type":"function","doc":"Sets up a parent-child component hierarchy for testing.\n\nReturns the initialized parent and child components with proper event routing.","title":"Raxol.Test.Integration.setup_component_hierarchy/3","ref":"Raxol.Test.Integration.html#setup_component_hierarchy/3"},{"type":"function","doc":"Sets up a test scenario with multiple components.\n\nThis function:\n1. Initializes all components\n2. Sets up event routing\n3. Configures component relationships\n4. Establishes test monitoring","title":"Raxol.Test.Integration.setup_test_scenario/1","ref":"Raxol.Test.Integration.html#setup_test_scenario/1"},{"type":"function","doc":"Simulates a user action on a component.\n\nHandles various types of user interactions and ensures proper event propagation.","title":"Raxol.Test.Integration.simulate_user_action/2","ref":"Raxol.Test.Integration.html#simulate_user_action/2"},{"type":"macro","doc":"","title":"Raxol.Test.Integration.test_scenario/3","ref":"Raxol.Test.Integration.html#test_scenario/3"},{"type":"function","doc":"Simulates component unmounting from the application.","title":"Raxol.Test.Integration.unmount_component/1","ref":"Raxol.Test.Integration.html#unmount_component/1"},{"type":"module","doc":"Provides custom assertions for integration testing of Raxol components.\n\nThis module includes assertions for:\n- Component interaction verification\n- Event propagation validation\n- State synchronization checking\n- Command routing verification\n- Component lifecycle testing","title":"Raxol.Test.Integration.Assertions","ref":"Raxol.Test.Integration.Assertions.html"},{"type":"function","doc":"Asserts that a child component received an event from its parent.","title":"Raxol.Test.Integration.Assertions.assert_child_received/2","ref":"Raxol.Test.Integration.Assertions.html#assert_child_received/2"},{"type":"function","doc":"assert_child_received child, :parent_clicked","title":"Example - Raxol.Test.Integration.Assertions.assert_child_received/2","ref":"Raxol.Test.Integration.Assertions.html#assert_child_received/2-example"},{"type":"function","doc":"Asserts that commands are properly routed between components.","title":"Raxol.Test.Integration.Assertions.assert_command_routing/3","ref":"Raxol.Test.Integration.Assertions.html#assert_command_routing/3"},{"type":"function","doc":"assert_command_routing source, target, command","title":"Example - Raxol.Test.Integration.Assertions.assert_command_routing/3","ref":"Raxol.Test.Integration.Assertions.html#assert_command_routing/3-example"},{"type":"function","doc":"Asserts that error boundaries contain component failures.","title":"Raxol.Test.Integration.Assertions.assert_error_contained/3","ref":"Raxol.Test.Integration.Assertions.html#assert_error_contained/3"},{"type":"function","doc":"assert_error_contained parent, child, fn ->\n      simulate_user_action(child, :trigger_error)\n    end","title":"Example - Raxol.Test.Integration.Assertions.assert_error_contained/3","ref":"Raxol.Test.Integration.Assertions.html#assert_error_contained/3-example"},{"type":"function","doc":"Asserts that events are properly propagated through the component hierarchy.","title":"Raxol.Test.Integration.Assertions.assert_event_propagation/3","ref":"Raxol.Test.Integration.Assertions.html#assert_event_propagation/3"},{"type":"function","doc":"assert_event_propagation [parent, child1, child2], event, fn components ->\n      # Verify each component's response\n    end","title":"Example - Raxol.Test.Integration.Assertions.assert_event_propagation/3","ref":"Raxol.Test.Integration.Assertions.html#assert_event_propagation/3-example"},{"type":"function","doc":"Asserts that components are properly connected in a hierarchy.","title":"Raxol.Test.Integration.Assertions.assert_hierarchy_valid/2","ref":"Raxol.Test.Integration.Assertions.html#assert_hierarchy_valid/2"},{"type":"function","doc":"assert_hierarchy_valid parent, [child1, child2]","title":"Example - Raxol.Test.Integration.Assertions.assert_hierarchy_valid/2","ref":"Raxol.Test.Integration.Assertions.html#assert_hierarchy_valid/2-example"},{"type":"function","doc":"Asserts that a component properly handles mounting and unmounting.","title":"Raxol.Test.Integration.Assertions.assert_lifecycle_handled/2","ref":"Raxol.Test.Integration.Assertions.html#assert_lifecycle_handled/2"},{"type":"function","doc":"assert_lifecycle_handled component, fn comp ->\n      mount_component(comp)\n      # Test mounted state\n      unmount_component(comp)\n      # Test unmounted state\n    end","title":"Example - Raxol.Test.Integration.Assertions.assert_lifecycle_handled/2","ref":"Raxol.Test.Integration.Assertions.html#assert_lifecycle_handled/2-example"},{"type":"function","doc":"Asserts that a parent component was updated in response to a child event.","title":"Raxol.Test.Integration.Assertions.assert_parent_updated/2","ref":"Raxol.Test.Integration.Assertions.html#assert_parent_updated/2"},{"type":"function","doc":"assert_parent_updated parent, :child_responded","title":"Example - Raxol.Test.Integration.Assertions.assert_parent_updated/2","ref":"Raxol.Test.Integration.Assertions.html#assert_parent_updated/2-example"},{"type":"function","doc":"Asserts that component state is synchronized after interactions.","title":"Raxol.Test.Integration.Assertions.assert_state_synchronized/2","ref":"Raxol.Test.Integration.Assertions.html#assert_state_synchronized/2"},{"type":"function","doc":"assert_state_synchronized [comp1, comp2], fn states ->\n      Enum.all?(states, & &1.counter == 0)\n    end","title":"Example - Raxol.Test.Integration.Assertions.assert_state_synchronized/2","ref":"Raxol.Test.Integration.Assertions.html#assert_state_synchronized/2-example"},{"type":"function","doc":"Asserts that a component handles system events without corruption.","title":"Raxol.Test.Integration.Assertions.assert_system_events_handled/2","ref":"Raxol.Test.Integration.Assertions.html#assert_system_events_handled/2"},{"type":"function","doc":"assert_system_events_handled component, [:resize, :focus, :blur]","title":"Example - Raxol.Test.Integration.Assertions.assert_system_events_handled/2","ref":"Raxol.Test.Integration.Assertions.html#assert_system_events_handled/2-example"},{"type":"module","doc":"","title":"Raxol.Test.MockApplicationSupervisor","ref":"Raxol.Test.MockApplicationSupervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Test.MockApplicationSupervisor.child_spec/1","ref":"Raxol.Test.MockApplicationSupervisor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Test.MockApplicationSupervisor.start_link/1","ref":"Raxol.Test.MockApplicationSupervisor.html#start_link/1"},{"type":"module","doc":"Mock implementation of rrex_termbox v2.0.1 for testing environments.\n\nThis module provides stub implementations of all rrex_termbox NIF-based functions\nto allow tests to run in CI environments where a real TTY may not be available.","title":"Raxol.Test.MockTermbox","ref":"Raxol.Test.MockTermbox.html"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.change_cell/6","ref":"Raxol.Test.MockTermbox.html#change_cell/6"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.clear/1","ref":"Raxol.Test.MockTermbox.html#clear/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.height/1","ref":"Raxol.Test.MockTermbox.html#height/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.init/1","ref":"Raxol.Test.MockTermbox.html#init/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.present/1","ref":"Raxol.Test.MockTermbox.html#present/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.select_input_mode/2","ref":"Raxol.Test.MockTermbox.html#select_input_mode/2"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.set_cell/5","ref":"Raxol.Test.MockTermbox.html#set_cell/5"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.set_cursor/3","ref":"Raxol.Test.MockTermbox.html#set_cursor/3"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.set_output_mode/2","ref":"Raxol.Test.MockTermbox.html#set_output_mode/2"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.shutdown/1","ref":"Raxol.Test.MockTermbox.html#shutdown/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.size/0","ref":"Raxol.Test.MockTermbox.html#size/0"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.start_link/0","ref":"Raxol.Test.MockTermbox.html#start_link/0"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.subscribe/0","ref":"Raxol.Test.MockTermbox.html#subscribe/0"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.unsubscribe/0","ref":"Raxol.Test.MockTermbox.html#unsubscribe/0"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.width/1","ref":"Raxol.Test.MockTermbox.html#width/1"},{"type":"module","doc":"","title":"Raxol.Test.MockTermbox.Constants","ref":"Raxol.Test.MockTermbox.Constants.html"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.Constants.attribute/1","ref":"Raxol.Test.MockTermbox.Constants.html#attribute/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.Constants.color/1","ref":"Raxol.Test.MockTermbox.Constants.html#color/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.Constants.event_type/1","ref":"Raxol.Test.MockTermbox.Constants.html#event_type/1"},{"type":"function","doc":"","title":"Raxol.Test.MockTermbox.Constants.key/1","ref":"Raxol.Test.MockTermbox.Constants.html#key/1"},{"type":"module","doc":"Provides utilities for performance testing of Raxol components.\n\nThis module includes:\n- Render time benchmarking\n- Memory usage profiling\n- Event handling latency testing\n- Resource utilization tracking","title":"Raxol.Test.Performance","ref":"Raxol.Test.Performance.html"},{"type":"function","doc":"Measures event handling latency.","title":"Raxol.Test.Performance.measure_event_latency/2","ref":"Raxol.Test.Performance.html#measure_event_latency/2"},{"type":"function","doc":"Measures memory usage during component operations.","title":"Raxol.Test.Performance.measure_memory_usage/2","ref":"Raxol.Test.Performance.html#measure_memory_usage/2"},{"type":"function","doc":"Measures the time taken to render a component multiple times.","title":"Raxol.Test.Performance.measure_render_time/2","ref":"Raxol.Test.Performance.html#measure_render_time/2"},{"type":"function","doc":"Runs a benchmark suite for a component.","title":"Raxol.Test.Performance.run_benchmark_suite/1","ref":"Raxol.Test.Performance.html#run_benchmark_suite/1"},{"type":"function","doc":"Sets up a component for performance testing with benchmark configuration.","title":"Raxol.Test.Performance.setup_benchmark_component/2","ref":"Raxol.Test.Performance.html#setup_benchmark_component/2"},{"type":"function","doc":"Tracks resource utilization over time.","title":"Raxol.Test.Performance.track_resource_utilization/2","ref":"Raxol.Test.Performance.html#track_resource_utilization/2"},{"type":"module","doc":"Provides assertions for performance testing of Raxol components.\n\nThis module includes assertions for:\n- Render time thresholds\n- Memory usage limits\n- Event latency requirements\n- Resource utilization bounds","title":"Raxol.Test.Performance.Assertions","ref":"Raxol.Test.Performance.Assertions.html"},{"type":"function","doc":"Asserts that event handling latency stays within acceptable bounds.","title":"Raxol.Test.Performance.Assertions.assert_event_latency/3","ref":"Raxol.Test.Performance.Assertions.html#assert_event_latency/3"},{"type":"function","doc":"assert_event_latency component, :click, under: 10 # milliseconds","title":"Example - Raxol.Test.Performance.Assertions.assert_event_latency/3","ref":"Raxol.Test.Performance.Assertions.html#assert_event_latency/3-example"},{"type":"function","doc":"Asserts that a component's memory usage stays within specified limits.","title":"Raxol.Test.Performance.Assertions.assert_memory_usage/3","ref":"Raxol.Test.Performance.Assertions.html#assert_memory_usage/3"},{"type":"function","doc":"assert_memory_usage component, fn ->\n      render_with_large_dataset(component)\n    end, under: 1024 * 1024 # 1MB","title":"Example - Raxol.Test.Performance.Assertions.assert_memory_usage/3","ref":"Raxol.Test.Performance.Assertions.html#assert_memory_usage/3-example"},{"type":"function","doc":"Asserts that a component's performance hasn't regressed from baseline.","title":"Raxol.Test.Performance.Assertions.assert_no_performance_regression/2","ref":"Raxol.Test.Performance.Assertions.html#assert_no_performance_regression/2"},{"type":"function","doc":"assert_no_performance_regression component, \"button_baseline\"","title":"Example - Raxol.Test.Performance.Assertions.assert_no_performance_regression/2","ref":"Raxol.Test.Performance.Assertions.html#assert_no_performance_regression/2-example"},{"type":"function","doc":"Asserts that a component's performance metrics meet all requirements.","title":"Raxol.Test.Performance.Assertions.assert_performance_requirements/2","ref":"Raxol.Test.Performance.Assertions.html#assert_performance_requirements/2"},{"type":"function","doc":"assert_performance_requirements component, %{\n      render_time: 100,\n      memory_usage: 1024 * 1024,\n      event_latency: 10\n    }","title":"Example - Raxol.Test.Performance.Assertions.assert_performance_requirements/2","ref":"Raxol.Test.Performance.Assertions.html#assert_performance_requirements/2-example"},{"type":"function","doc":"Asserts that a component renders within a specified time limit.","title":"Raxol.Test.Performance.Assertions.assert_render_time/3","ref":"Raxol.Test.Performance.Assertions.html#assert_render_time/3"},{"type":"function","doc":"assert_render_time component, fn ->\n      render_iterations(component, 1000)\n    end, under: 100 # milliseconds","title":"Example - Raxol.Test.Performance.Assertions.assert_render_time/3","ref":"Raxol.Test.Performance.Assertions.html#assert_render_time/3-example"},{"type":"function","doc":"Asserts that a component's resource utilization remains stable.","title":"Raxol.Test.Performance.Assertions.assert_stable_resource_usage/2","ref":"Raxol.Test.Performance.Assertions.html#assert_stable_resource_usage/2"},{"type":"function","doc":"assert_stable_resource_usage component, duration: 1000","title":"Example - Raxol.Test.Performance.Assertions.assert_stable_resource_usage/2","ref":"Raxol.Test.Performance.Assertions.html#assert_stable_resource_usage/2-example"},{"type":"module","doc":"Provides utilities for performance testing and benchmarking in Raxol.\n\nThis module includes:\n- Benchmarking utilities\n- Performance test setup and teardown\n- Common performance test scenarios\n- Metrics collection and reporting","title":"Raxol.Test.PerformanceHelper","ref":"Raxol.Test.PerformanceHelper.html"},{"type":"function","doc":"Asserts that a set of concurrent operations' average execution time is below a threshold.","title":"Raxol.Test.PerformanceHelper.assert_concurrent_performance/4","ref":"Raxol.Test.PerformanceHelper.html#assert_concurrent_performance/4"},{"type":"function","doc":"Asserts that an operation's memory usage is below a threshold.","title":"Raxol.Test.PerformanceHelper.assert_memory_usage/3","ref":"Raxol.Test.PerformanceHelper.html#assert_memory_usage/3"},{"type":"function","doc":"Asserts that an operation's average execution time is below a threshold.\nUse this for direct operation timing, not for benchmark result structs.","title":"Raxol.Test.PerformanceHelper.assert_operation_performance/4","ref":"Raxol.Test.PerformanceHelper.html#assert_operation_performance/4"},{"type":"function","doc":"Asserts that a benchmark meets performance requirements.","title":"Raxol.Test.PerformanceHelper.assert_performance/2","ref":"Raxol.Test.PerformanceHelper.html#assert_performance/2"},{"type":"function","doc":"* `:max_average_time` - Maximum allowed average time in microseconds\n  * `:max_p95_time` - Maximum allowed 95th percentile time in microseconds\n  * `:min_iterations` - Minimum number of iterations required","title":"Options - Raxol.Test.PerformanceHelper.assert_performance/2","ref":"Raxol.Test.PerformanceHelper.html#assert_performance/2-options"},{"type":"function","doc":"Measures and asserts both time and memory performance.","title":"Raxol.Test.PerformanceHelper.assert_performance_metrics/4","ref":"Raxol.Test.PerformanceHelper.html#assert_performance_metrics/4"},{"type":"function","doc":"Runs a benchmark with the given function and options.","title":"Raxol.Test.PerformanceHelper.benchmark/2","ref":"Raxol.Test.PerformanceHelper.html#benchmark/2"},{"type":"function","doc":"* `:iterations` - Number of iterations to run (default: 1000)\n  * `:warmup` - Number of warmup iterations (default: 100)\n  * `:timeout` - Maximum time to run in milliseconds (default: 5000)","title":"Options - Raxol.Test.PerformanceHelper.benchmark/2","ref":"Raxol.Test.PerformanceHelper.html#benchmark/2-options"},{"type":"function","doc":"Calculates the nth percentile from a list of times.","title":"Raxol.Test.PerformanceHelper.calculate_percentile/2","ref":"Raxol.Test.PerformanceHelper.html#calculate_percentile/2"},{"type":"function","doc":"Formats benchmark results for human-readable output.","title":"Raxol.Test.PerformanceHelper.format_benchmark_results/1","ref":"Raxol.Test.PerformanceHelper.html#format_benchmark_results/1"},{"type":"function","doc":"Measures the average execution time of an operation over multiple iterations.\nReturns the average time in milliseconds.","title":"Raxol.Test.PerformanceHelper.measure_average_time/2","ref":"Raxol.Test.PerformanceHelper.html#measure_average_time/2"},{"type":"function","doc":"Measures memory usage of an operation.\nReturns {memory_in_bytes, result}.","title":"Raxol.Test.PerformanceHelper.measure_memory/1","ref":"Raxol.Test.PerformanceHelper.html#measure_memory/1"},{"type":"function","doc":"Measures the execution time of an operation.\nReturns {time_in_ms, result}.","title":"Raxol.Test.PerformanceHelper.measure_time/1","ref":"Raxol.Test.PerformanceHelper.html#measure_time/1"},{"type":"function","doc":"Sets up a test environment optimized for performance testing.\n\nReturns a context map with initialized services and performance monitoring.","title":"Raxol.Test.PerformanceHelper.setup_performance_test_env/0","ref":"Raxol.Test.PerformanceHelper.html#setup_performance_test_env/0"},{"type":"module","doc":"DEPRECATED: Use Raxol.Test.PerformanceHelper instead.\nThis module is deprecated and will be removed in a future release.\nPlease update your tests to use Raxol.Test.PerformanceHelper.","title":"Raxol.Test.PerformanceHelpers","ref":"Raxol.Test.PerformanceHelpers.html"},{"type":"function","doc":"Asserts that a set of concurrent operations' average execution time is below a threshold.","title":"Raxol.Test.PerformanceHelpers.assert_concurrent_performance/4","ref":"Raxol.Test.PerformanceHelpers.html#assert_concurrent_performance/4"},{"type":"function","doc":"Asserts that an operation's memory usage is below a threshold.","title":"Raxol.Test.PerformanceHelpers.assert_memory_usage/3","ref":"Raxol.Test.PerformanceHelpers.html#assert_memory_usage/3"},{"type":"function","doc":"Asserts that an operation's average execution time is below a threshold.","title":"Raxol.Test.PerformanceHelpers.assert_performance/4","ref":"Raxol.Test.PerformanceHelpers.html#assert_performance/4"},{"type":"function","doc":"Measures and asserts both time and memory performance.","title":"Raxol.Test.PerformanceHelpers.assert_performance_metrics/4","ref":"Raxol.Test.PerformanceHelpers.html#assert_performance_metrics/4"},{"type":"function","doc":"Measures the average execution time of an operation over multiple iterations.\nReturns the average time in milliseconds.","title":"Raxol.Test.PerformanceHelpers.measure_average_time/2","ref":"Raxol.Test.PerformanceHelpers.html#measure_average_time/2"},{"type":"function","doc":"Measures memory usage of an operation.\nReturns {memory_in_bytes, result}.","title":"Raxol.Test.PerformanceHelpers.measure_memory/1","ref":"Raxol.Test.PerformanceHelpers.html#measure_memory/1"},{"type":"function","doc":"Measures the execution time of an operation.\nReturns {time_in_ms, result}.","title":"Raxol.Test.PerformanceHelpers.measure_time/1","ref":"Raxol.Test.PerformanceHelpers.html#measure_time/1"},{"type":"module","doc":"Provides common test utilities and setup functions for Raxol tests.\n\nThis module includes:\n- Test environment setup\n- Mock data generation\n- Common test scenarios\n- Cleanup utilities","title":"Raxol.Test.TestHelper","ref":"Raxol.Test.TestHelper.html"},{"type":"function","doc":"Captures all terminal output during a test.","title":"Raxol.Test.TestHelper.capture_terminal_output/1","ref":"Raxol.Test.TestHelper.html#capture_terminal_output/1"},{"type":"function","doc":"Cleans up test resources and resets the environment.","title":"Raxol.Test.TestHelper.cleanup_test_env/1","ref":"Raxol.Test.TestHelper.html#cleanup_test_env/1"},{"type":"function","doc":"Creates a test component with the given module and initial state.","title":"Raxol.Test.TestHelper.create_test_component/2","ref":"Raxol.Test.TestHelper.html#create_test_component/2"},{"type":"function","doc":"Sets up a test environment with all necessary dependencies.\n\nReturns a context map with initialized services.","title":"Raxol.Test.TestHelper.setup_test_env/0","ref":"Raxol.Test.TestHelper.html#setup_test_env/0"},{"type":"function","doc":"Creates a mock terminal for testing.","title":"Raxol.Test.TestHelper.setup_test_terminal/0","ref":"Raxol.Test.TestHelper.html#setup_test_terminal/0"},{"type":"function","doc":"Simulates a sequence of events on a component.","title":"Raxol.Test.TestHelper.simulate_event_sequence/2","ref":"Raxol.Test.TestHelper.html#simulate_event_sequence/2"},{"type":"function","doc":"Generates test events for common scenarios.","title":"Raxol.Test.TestHelper.test_events/0","ref":"Raxol.Test.TestHelper.html#test_events/0"},{"type":"function","doc":"Generates test layouts for component positioning.","title":"Raxol.Test.TestHelper.test_layouts/0","ref":"Raxol.Test.TestHelper.html#test_layouts/0"},{"type":"function","doc":"Generates test styles for component rendering.","title":"Raxol.Test.TestHelper.test_styles/0","ref":"Raxol.Test.TestHelper.html#test_styles/0"},{"type":"module","doc":"Provides utilities for unit testing Raxol components and modules.\n\nThis module offers a comprehensive set of tools for:\n- Component isolation and testing\n- Event simulation and verification\n- State management testing\n- Render output validation","title":"Raxol.Test.Unit","ref":"Raxol.Test.Unit.html"},{"type":"module","doc":"defmodule MyComponent.Test do\n      use ExUnit.Case\n      use Raxol.Test.Unit\n\n      test_component \"handles keyboard input\", MyComponent do\n        event = keyboard_event(:enter)\n        result = simulate_event(component, event)\n\n        assert_state(component, %{text: \"\"})\n        assert_command_emitted(result, :submit)\n      end\n    end","title":"Example - Raxol.Test.Unit","ref":"Raxol.Test.Unit.html#module-example"},{"type":"function","doc":"Asserts that a command was emitted by the component.","title":"Raxol.Test.Unit.assert_command_emitted/2","ref":"Raxol.Test.Unit.html#assert_command_emitted/2"},{"type":"function","doc":"Asserts that a specific event was handled by the component.","title":"Raxol.Test.Unit.assert_event_handled/3","ref":"Raxol.Test.Unit.html#assert_event_handled/3"},{"type":"function","doc":"Asserts that a component's state matches the expected state.","title":"Raxol.Test.Unit.assert_state/2","ref":"Raxol.Test.Unit.html#assert_state/2"},{"type":"function","doc":"Creates a custom event for testing.","title":"Raxol.Test.Unit.custom_event/1","ref":"Raxol.Test.Unit.html#custom_event/1"},{"type":"function","doc":"Creates a keyboard event for testing.","title":"Raxol.Test.Unit.keyboard_event/1","ref":"Raxol.Test.Unit.html#keyboard_event/1"},{"type":"function","doc":"","title":"Raxol.Test.Unit.setup_isolated_component/1","ref":"Raxol.Test.Unit.html#setup_isolated_component/1"},{"type":"function","doc":"Sets up a component for isolated testing with initial properties.","title":"Raxol.Test.Unit.setup_isolated_component/2","ref":"Raxol.Test.Unit.html#setup_isolated_component/2"},{"type":"function","doc":"Simulates an event being sent to a component.\n\nReturns the updated state and any emitted commands.","title":"Raxol.Test.Unit.simulate_event/2","ref":"Raxol.Test.Unit.html#simulate_event/2"},{"type":"macro","doc":"","title":"Raxol.Test.Unit.test_component/3","ref":"Raxol.Test.Unit.html#test_component/3"},{"type":"function","doc":"Creates a window event for testing.","title":"Raxol.Test.Unit.window_event/3","ref":"Raxol.Test.Unit.html#window_event/3"},{"type":"module","doc":"Provides custom assertions for testing Raxol components.\n\nThis module includes assertions for:\n- Component state validation\n- Event handling verification\n- Command emission checking\n- Render output validation\n- Layout verification\n- Style application testing","title":"Raxol.Test.Unit.Assertions","ref":"Raxol.Test.Unit.Assertions.html"},{"type":"function","doc":"Asserts that a component emitted specific commands in sequence.","title":"Raxol.Test.Unit.Assertions.assert_command_sequence/2","ref":"Raxol.Test.Unit.Assertions.html#assert_command_sequence/2"},{"type":"function","doc":"assert_command_sequence component, [\n      {:update, :text},\n      {:notify, :changed},\n      {:submit}\n    ]","title":"Example - Raxol.Test.Unit.Assertions.assert_command_sequence/2","ref":"Raxol.Test.Unit.Assertions.html#assert_command_sequence/2-example"},{"type":"function","doc":"Asserts that a component properly handles an error condition.","title":"Raxol.Test.Unit.Assertions.assert_handles_error/2","ref":"Raxol.Test.Unit.Assertions.html#assert_handles_error/2"},{"type":"function","doc":"assert_handles_error component, fn ->\n      simulate_event(component, invalid_event())\n    end","title":"Example - Raxol.Test.Unit.Assertions.assert_handles_error/2","ref":"Raxol.Test.Unit.Assertions.html#assert_handles_error/2-example"},{"type":"function","doc":"Asserts that a component's layout matches the expected constraints.","title":"Raxol.Test.Unit.Assertions.assert_layout/2","ref":"Raxol.Test.Unit.Assertions.html#assert_layout/2"},{"type":"function","doc":"assert_layout component, %{\n      width: 10,\n      height: 5,\n      x: 0,\n      y: 0\n    }","title":"Example - Raxol.Test.Unit.Assertions.assert_layout/2","ref":"Raxol.Test.Unit.Assertions.html#assert_layout/2-example"},{"type":"macro","doc":"Asserts that a component's rendered output matches the expected output.","title":"Raxol.Test.Unit.Assertions.assert_rendered/2","ref":"Raxol.Test.Unit.Assertions.html#assert_rendered/2"},{"type":"macro","doc":"assert_rendered component, fn output ->\n      assert output.type == :text\n      assert output.content == \"Hello, World!\"\n    end","title":"Example - Raxol.Test.Unit.Assertions.assert_rendered/2","ref":"Raxol.Test.Unit.Assertions.html#assert_rendered/2-example"},{"type":"function","doc":"Asserts that a component's state history includes specific changes.","title":"Raxol.Test.Unit.Assertions.assert_state_history/2","ref":"Raxol.Test.Unit.Assertions.html#assert_state_history/2"},{"type":"function","doc":"assert_state_history component, [\n      %{text: \"\"},\n      %{text: \"Hello\"},\n      %{text: \"Hello, World!\"}\n    ]","title":"Example - Raxol.Test.Unit.Assertions.assert_state_history/2","ref":"Raxol.Test.Unit.Assertions.html#assert_state_history/2-example"},{"type":"function","doc":"","title":"Raxol.Test.Unit.Assertions.assert_state_match/2","ref":"Raxol.Test.Unit.Assertions.html#assert_state_match/2"},{"type":"function","doc":"Asserts that a style is properly applied to a component.","title":"Raxol.Test.Unit.Assertions.assert_style/2","ref":"Raxol.Test.Unit.Assertions.html#assert_style/2"},{"type":"function","doc":"assert_style component, %{\n      color: :blue,\n      background: :white,\n      bold: true\n    }","title":"Example - Raxol.Test.Unit.Assertions.assert_style/2","ref":"Raxol.Test.Unit.Assertions.html#assert_style/2-example"},{"type":"function","doc":"Asserts that a component has specific subscriptions active.","title":"Raxol.Test.Unit.Assertions.assert_subscribed/2","ref":"Raxol.Test.Unit.Assertions.html#assert_subscribed/2"},{"type":"function","doc":"assert_subscribed component, [:keyboard, :mouse]","title":"Example - Raxol.Test.Unit.Assertions.assert_subscribed/2","ref":"Raxol.Test.Unit.Assertions.html#assert_subscribed/2-example"},{"type":"module","doc":"Provides utilities for visual testing of Raxol components.\n\nThis module handles:\n- Component rendering verification\n- Layout testing\n- Style validation\n- Terminal output comparison\n- Cross-terminal compatibility testing","title":"Raxol.Test.Visual","ref":"Raxol.Test.Visual.html"},{"type":"module","doc":"defmodule MyComponent.VisualTest do\n      use ExUnit.Case\n      use Raxol.Test.Visual\n\n      test \"renders correctly\" do\n        component = setup_visual_component(MyComponent)\n\n        assert_renders_as component, fn output ->\n          assert output =~ \"Expected Content\"\n          assert_layout_matches output, width: 10, height: 5\n        end\n      end\n    end","title":"Example - Raxol.Test.Visual","ref":"Raxol.Test.Visual.html#module-example"},{"type":"function","doc":"Verifies that a component renders as expected.\n\nTakes a function that can make assertions about the rendered output.","title":"Raxol.Test.Visual.assert_renders_as/2","ref":"Raxol.Test.Visual.html#assert_renders_as/2"},{"type":"function","doc":"Captures the rendered output of a component.\n\nReturns the terminal output as a string for comparison.","title":"Raxol.Test.Visual.capture_render/1","ref":"Raxol.Test.Visual.html#capture_render/1"},{"type":"function","doc":"Compares a component's current render with its snapshot.\n\nReturns a detailed diff if there are differences.","title":"Raxol.Test.Visual.compare_with_snapshot/3","ref":"Raxol.Test.Visual.html#compare_with_snapshot/3"},{"type":"function","doc":"Renders a component state within a controlled test environment.\nAccepts an optional context map.","title":"Raxol.Test.Visual.render_component/2","ref":"Raxol.Test.Visual.html#render_component/2"},{"type":"function","doc":"Sets up a component for visual testing.\n\nThis function:\n1. Initializes the component\n2. Sets up the render context\n3. Configures the test terminal\n4. Prepares snapshot directories","title":"Raxol.Test.Visual.setup_visual_component/2","ref":"Raxol.Test.Visual.html#setup_visual_component/2"},{"type":"function","doc":"Creates or updates a snapshot of the component's rendered output.\n\nUsed for visual regression testing.","title":"Raxol.Test.Visual.snapshot_component/3","ref":"Raxol.Test.Visual.html#snapshot_component/3"},{"type":"function","doc":"Tests a component's rendering across different terminal sizes.\n\nVerifies responsive behavior and layout adaptability.","title":"Raxol.Test.Visual.test_responsive_rendering/2","ref":"Raxol.Test.Visual.html#test_responsive_rendering/2"},{"type":"function","doc":"Tests a component's rendering with different style themes.\n\nVerifies proper style application and theme switching.","title":"Raxol.Test.Visual.test_themed_rendering/2","ref":"Raxol.Test.Visual.html#test_themed_rendering/2"},{"type":"module","doc":"Provides custom assertions for visual testing of Raxol components.\n\nThis module includes assertions for:\n- Component rendering verification\n- Layout validation\n- Style checking\n- Visual regression testing\n- Terminal output comparison","title":"Raxol.Test.Visual.Assertions","ref":"Raxol.Test.Visual.Assertions.html"},{"type":"function","doc":"Asserts that a component's borders and edges align properly.","title":"Raxol.Test.Visual.Assertions.assert_aligned/2","ref":"Raxol.Test.Visual.Assertions.html#assert_aligned/2"},{"type":"function","doc":"assert_aligned component, :all\n    assert_aligned component, [:top, :left]","title":"Example - Raxol.Test.Visual.Assertions.assert_aligned/2","ref":"Raxol.Test.Visual.Assertions.html#assert_aligned/2-example"},{"type":"function","doc":"Asserts that a component's rendered output matches the expected snapshot.","title":"Raxol.Test.Visual.Assertions.assert_matches_snapshot/3","ref":"Raxol.Test.Visual.Assertions.html#assert_matches_snapshot/3"},{"type":"function","doc":"assert_matches_snapshot(component, \"button_primary\")","title":"Example - Raxol.Test.Visual.Assertions.assert_matches_snapshot/3","ref":"Raxol.Test.Visual.Assertions.html#assert_matches_snapshot/3-example"},{"type":"function","doc":"Asserts that a component renders with the expected content.","title":"Raxol.Test.Visual.Assertions.assert_renders_with/2","ref":"Raxol.Test.Visual.Assertions.html#assert_renders_with/2"},{"type":"function","doc":"assert_renders_with component, \"Expected Content\"","title":"Example - Raxol.Test.Visual.Assertions.assert_renders_with/2","ref":"Raxol.Test.Visual.Assertions.html#assert_renders_with/2-example"},{"type":"function","doc":"Asserts that a component renders correctly at different terminal sizes.","title":"Raxol.Test.Visual.Assertions.assert_responsive/2","ref":"Raxol.Test.Visual.Assertions.html#assert_responsive/2"},{"type":"function","doc":"assert_responsive component, [\n      {80, 24},\n      {40, 12},\n      {20, 6}\n    ]","title":"Example - Raxol.Test.Visual.Assertions.assert_responsive/2","ref":"Raxol.Test.Visual.Assertions.html#assert_responsive/2-example"},{"type":"function","doc":"Asserts that a component's style matches the expected theme.","title":"Raxol.Test.Visual.Assertions.assert_styled_with/2","ref":"Raxol.Test.Visual.Assertions.html#assert_styled_with/2"},{"type":"function","doc":"assert_styled_with component, %{color: :blue, bold: true}","title":"Example - Raxol.Test.Visual.Assertions.assert_styled_with/2","ref":"Raxol.Test.Visual.Assertions.html#assert_styled_with/2-example"},{"type":"function","doc":"Asserts that a component renders consistently across different themes.","title":"Raxol.Test.Visual.Assertions.assert_theme_consistent/2","ref":"Raxol.Test.Visual.Assertions.html#assert_theme_consistent/2"},{"type":"function","doc":"assert_theme_consistent component, %{\n      light: light_theme,\n      dark: dark_theme\n    }","title":"Example - Raxol.Test.Visual.Assertions.assert_theme_consistent/2","ref":"Raxol.Test.Visual.Assertions.html#assert_theme_consistent/2-example"},{"type":"module","doc":"Provides pattern matching helpers for visual testing of Raxol components.\n\nThis module includes matchers for:\n- ANSI color and style patterns\n- Terminal layout patterns\n- Border and edge patterns\n- Component structure patterns","title":"Raxol.Test.Visual.Matchers","ref":"Raxol.Test.Visual.Matchers.html"},{"type":"function","doc":"Matches specific text alignment patterns in the output.","title":"Raxol.Test.Visual.Matchers.matches_alignment/3","ref":"Raxol.Test.Visual.Matchers.html#matches_alignment/3"},{"type":"function","doc":"output\n    |> matches_alignment(:left)\n    |> matches_alignment(:right, width: 80)","title":"Example - Raxol.Test.Visual.Matchers.matches_alignment/3","ref":"Raxol.Test.Visual.Matchers.html#matches_alignment/3-example"},{"type":"function","doc":"Matches box drawing characters in the output.","title":"Raxol.Test.Visual.Matchers.matches_box_edges/1","ref":"Raxol.Test.Visual.Matchers.html#matches_box_edges/1"},{"type":"function","doc":"output\n    |> matches_box_edges()\n    |> matches_box_corners()","title":"Example - Raxol.Test.Visual.Matchers.matches_box_edges/1","ref":"Raxol.Test.Visual.Matchers.html#matches_box_edges/1-example"},{"type":"function","doc":"Matches ANSI color codes in the output.","title":"Raxol.Test.Visual.Matchers.matches_color/3","ref":"Raxol.Test.Visual.Matchers.html#matches_color/3"},{"type":"function","doc":"output\n    |> matches_color(:red, \"Error message\")\n    |> matches_color(:green, \"Success\")","title":"Example - Raxol.Test.Visual.Matchers.matches_color/3","ref":"Raxol.Test.Visual.Matchers.html#matches_color/3-example"},{"type":"function","doc":"Matches specific component patterns in the output.","title":"Raxol.Test.Visual.Matchers.matches_component/3","ref":"Raxol.Test.Visual.Matchers.html#matches_component/3"},{"type":"function","doc":"output\n    |> matches_component(:button, \"Click me\")\n    |> matches_component(:input, placeholder: \"Enter text\")","title":"Example - Raxol.Test.Visual.Matchers.matches_component/3","ref":"Raxol.Test.Visual.Matchers.html#matches_component/3-example"},{"type":"function","doc":"Matches specific layout patterns in the output.","title":"Raxol.Test.Visual.Matchers.matches_layout/3","ref":"Raxol.Test.Visual.Matchers.html#matches_layout/3"},{"type":"function","doc":"output\n    |> matches_layout(:centered)\n    |> matches_layout(:padded, padding: 2)","title":"Example - Raxol.Test.Visual.Matchers.matches_layout/3","ref":"Raxol.Test.Visual.Matchers.html#matches_layout/3-example"},{"type":"function","doc":"Matches ANSI style codes in the output.","title":"Raxol.Test.Visual.Matchers.matches_style/3","ref":"Raxol.Test.Visual.Matchers.html#matches_style/3"},{"type":"function","doc":"output\n    |> matches_style(:bold, \"Important\")\n    |> matches_style(:underline, \"Link\")","title":"Example - Raxol.Test.Visual.Matchers.matches_style/3","ref":"Raxol.Test.Visual.Matchers.html#matches_style/3-example"},{"type":"behaviour","doc":"Defines the behavior for UI components in the Raxol system.\n\nThis module provides the core structure for building reusable UI components\nwith lifecycle hooks, state management, and event handling. Components follow\na similar pattern to the main application architecture but at a smaller scale.","title":"Raxol.UI.Components.Base.Component","ref":"Raxol.UI.Components.Base.Component.html"},{"type":"behaviour","doc":"1. `init/1` - Initialize component state with props\n2. `mount/1` - Called when the component is first mounted\n3. `update/2` - Handle messages and update component state\n4. `render/1` - Generate the visual representation of the component\n5. `handle_event/2` - Handle UI events\n6. `unmount/1` - Clean up resources when component is removed","title":"Component Lifecycle - Raxol.UI.Components.Base.Component","ref":"Raxol.UI.Components.Base.Component.html#module-component-lifecycle"},{"type":"behaviour","doc":"defmodule MyComponent do\n      use Raxol.UI.Components.Base.Component\n\n      def init(props) do\n        Map.merge(%{count: 0}, props)\n      end\n\n      def mount(state) do\n        {state, []}\n      end\n\n      def update(:increment, state) do\n        %{state | count: state.count + 1}\n      end\n\n      def render(state) do\n        row do\n          button(label: \"-\", on_click: :decrement)\n          text(\"Count: #{state.count}\")\n          button(label: \"+\", on_click: :increment)\n        end\n      end\n\n      def handle_event({:click, :increment}, state) do\n        {update(:increment, state), []}\n      end\n\n      def handle_event({:click, :decrement}, state) do\n        {%{state | count: state.count - 1}, []}\n      end\n    end","title":"Example - Raxol.UI.Components.Base.Component","ref":"Raxol.UI.Components.Base.Component.html#module-example"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.command/0","ref":"Raxol.UI.Components.Base.Component.html#t:command/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.context/0","ref":"Raxol.UI.Components.Base.Component.html#t:context/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.element/0","ref":"Raxol.UI.Components.Base.Component.html#t:element/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.event/0","ref":"Raxol.UI.Components.Base.Component.html#t:event/0"},{"type":"callback","doc":"Handles UI events that occur on the component.\n\nThe context map provides additional event details or UI state.\nReturns the potentially modified state and any commands to execute.","title":"Raxol.UI.Components.Base.Component.handle_event/3","ref":"Raxol.UI.Components.Base.Component.html#c:handle_event/3"},{"type":"callback","doc":"Initializes the component with the given props.\n\nCalled when the component is created. Should merge default values with\nthe provided props to create the initial state.","title":"Raxol.UI.Components.Base.Component.init/1","ref":"Raxol.UI.Components.Base.Component.html#c:init/1"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.message/0","ref":"Raxol.UI.Components.Base.Component.html#t:message/0"},{"type":"callback","doc":"Called when the component is mounted in the UI.\n\nThis is where you can set up subscriptions, execute initial commands,\nor perform other setup tasks. Returns the potentially modified state\nand any commands to execute.","title":"Raxol.UI.Components.Base.Component.mount/1","ref":"Raxol.UI.Components.Base.Component.html#c:mount/1"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.props/0","ref":"Raxol.UI.Components.Base.Component.html#t:props/0"},{"type":"callback","doc":"Renders the component based on its current state.\n\nReturns an element tree that will be rendered to the screen. The context\nmap contains theme, layout constraints, etc.","title":"Raxol.UI.Components.Base.Component.render/2","ref":"Raxol.UI.Components.Base.Component.html#c:render/2"},{"type":"type","doc":"","title":"Raxol.UI.Components.Base.Component.state/0","ref":"Raxol.UI.Components.Base.Component.html#t:state/0"},{"type":"callback","doc":"Called when the component is being removed from the UI.\n\nUse this to clean up any resources or perform final actions.","title":"Raxol.UI.Components.Base.Component.unmount/1","ref":"Raxol.UI.Components.Base.Component.html#c:unmount/1"},{"type":"callback","doc":"Updates the component state in response to messages.\n\nSimilar to the application update function, this handles messages sent to\nthe component and returns the new state.","title":"Raxol.UI.Components.Base.Component.update/2","ref":"Raxol.UI.Components.Base.Component.html#c:update/2"},{"type":"module","doc":"Provides component lifecycle hooks and management for UI components.\n\nThis module handles:\n- Component mounting and initialization\n- Update propagation to components\n- Component unmounting and cleanup\n- Lifecycle event tracking","title":"Raxol.UI.Components.Base.Lifecycle","ref":"Raxol.UI.Components.Base.Lifecycle.html"},{"type":"function","doc":"Adds a lifecycle event to the component for debugging purposes.","title":"Raxol.UI.Components.Base.Lifecycle.add_lifecycle_event/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#add_lifecycle_event/2"},{"type":"function","doc":"* `component` - The component to add the event to\n* `event` - The lifecycle event to record","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.add_lifecycle_event/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#add_lifecycle_event/2-parameters"},{"type":"function","doc":"The component with the added lifecycle event","title":"Returns - Raxol.UI.Components.Base.Lifecycle.add_lifecycle_event/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#add_lifecycle_event/2-returns"},{"type":"function","doc":"Gets the lifecycle events recorded for a component.","title":"Raxol.UI.Components.Base.Lifecycle.get_lifecycle_events/1","ref":"Raxol.UI.Components.Base.Lifecycle.html#get_lifecycle_events/1"},{"type":"function","doc":"* `component` - The component to get events for","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.get_lifecycle_events/1","ref":"Raxol.UI.Components.Base.Lifecycle.html#get_lifecycle_events/1-parameters"},{"type":"function","doc":"List of lifecycle events with timestamps","title":"Returns - Raxol.UI.Components.Base.Lifecycle.get_lifecycle_events/1","ref":"Raxol.UI.Components.Base.Lifecycle.html#get_lifecycle_events/1-returns"},{"type":"function","doc":"Mounts a component, initializing its state and triggering mount-time effects.","title":"Raxol.UI.Components.Base.Lifecycle.mount/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#mount/3"},{"type":"function","doc":"* `component` - The component to mount\n* `props` - Initial properties for the component\n* `context` - The rendering context","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.mount/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#mount/3-parameters"},{"type":"function","doc":"The mounted component","title":"Returns - Raxol.UI.Components.Base.Lifecycle.mount/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#mount/3-returns"},{"type":"function","doc":"Processes an event on a component.","title":"Raxol.UI.Components.Base.Lifecycle.process_event/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#process_event/3"},{"type":"function","doc":"* `component` - The component to process the event on\n* `event` - The event to process\n* `context` - The event context","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.process_event/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#process_event/3-parameters"},{"type":"function","doc":"`{:update, updated_component}` if the component state changed,\n`{:handled, component}` if the event was handled but state didn't change,\n`:passthrough` if the event wasn't handled by the component.","title":"Returns - Raxol.UI.Components.Base.Lifecycle.process_event/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#process_event/3-returns"},{"type":"function","doc":"Renders a component, creating its view representation.\n\nThis is a wrapper around the component's render function that ensures\nconsistent handling of the rendering process.","title":"Raxol.UI.Components.Base.Lifecycle.render/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#render/2"},{"type":"function","doc":"* `component` - The component to render\n* `context` - The rendering context","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.render/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#render/2-parameters"},{"type":"function","doc":"The rendered view representation and updated component state","title":"Returns - Raxol.UI.Components.Base.Lifecycle.render/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#render/2-returns"},{"type":"function","doc":"Unmounts a component, allowing it to clean up resources.","title":"Raxol.UI.Components.Base.Lifecycle.unmount/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#unmount/2"},{"type":"function","doc":"* `component` - The component to unmount\n* `context` - The rendering context","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.unmount/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#unmount/2-parameters"},{"type":"function","doc":"The unmounted component, typically for tracking/debugging only","title":"Returns - Raxol.UI.Components.Base.Lifecycle.unmount/2","ref":"Raxol.UI.Components.Base.Lifecycle.html#unmount/2-returns"},{"type":"function","doc":"Updates a component with new props.","title":"Raxol.UI.Components.Base.Lifecycle.update/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#update/3"},{"type":"function","doc":"* `component` - The component to update\n* `props` - New properties to apply\n* `context` - The rendering context","title":"Parameters - Raxol.UI.Components.Base.Lifecycle.update/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#update/3-parameters"},{"type":"function","doc":"The updated component","title":"Returns - Raxol.UI.Components.Base.Lifecycle.update/3","ref":"Raxol.UI.Components.Base.Lifecycle.html#update/3-returns"},{"type":"module","doc":"A progress bar component for displaying completion status.\n\nFeatures:\n* Customizable colors (harmonized style/theme prop merging)\n* Percentage display option\n* Custom width\n* Animated progress\n* Optional label\n* Accessibility/extra props (aria_label, tooltip, etc)\n* Robust lifecycle hooks (mount/unmount)","title":"Raxol.UI.Components.Display.Progress","ref":"Raxol.UI.Components.Display.Progress.html"},{"type":"function","doc":"Initializes the progress bar state from props.","title":"Raxol.UI.Components.Display.Progress.init/1","ref":"Raxol.UI.Components.Display.Progress.html#init/1"},{"type":"function","doc":"Mounts the progress bar (for future extensibility: timers, subscriptions, etc).","title":"Raxol.UI.Components.Display.Progress.mount/1","ref":"Raxol.UI.Components.Display.Progress.html#mount/1"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Progress.props/0","ref":"Raxol.UI.Components.Display.Progress.html#t:props/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Progress.state/0","ref":"Raxol.UI.Components.Display.Progress.html#t:state/0"},{"type":"function","doc":"Unmounts the progress bar (cleanup for future extensibility).","title":"Raxol.UI.Components.Display.Progress.unmount/1","ref":"Raxol.UI.Components.Display.Progress.html#unmount/1"},{"type":"module","doc":"A component for displaying tabular data with sorting, filtering, and pagination.","title":"Raxol.UI.Components.Display.Table","ref":"Raxol.UI.Components.Display.Table.html"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.cell/0","ref":"Raxol.UI.Components.Display.Table.html#t:cell/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.header/0","ref":"Raxol.UI.Components.Display.Table.html#t:header/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.headers/0","ref":"Raxol.UI.Components.Display.Table.html#t:headers/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.props/0","ref":"Raxol.UI.Components.Display.Table.html#t:props/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.row/0","ref":"Raxol.UI.Components.Display.Table.html#t:row/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.rows/0","ref":"Raxol.UI.Components.Display.Table.html#t:rows/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Display.Table.state/0","ref":"Raxol.UI.Components.Display.Table.html#t:state/0"},{"type":"module","doc":"Button component for interactive UI elements.\n\nThis component provides a clickable button with customizable appearance and behavior.","title":"Raxol.UI.Components.Input.Button","ref":"Raxol.UI.Components.Input.Button.html"},{"type":"function","doc":"Handles input events for the button component.","title":"Raxol.UI.Components.Input.Button.handle_event/3","ref":"Raxol.UI.Components.Input.Button.html#handle_event/3"},{"type":"function","doc":"* `button` - The button component\n* `event` - The input event to handle\n* `context` - The event context","title":"Parameters - Raxol.UI.Components.Input.Button.handle_event/3","ref":"Raxol.UI.Components.Input.Button.html#handle_event/3-parameters"},{"type":"function","doc":"`{:update, updated_button}` if the button state changed,\n`{:handled, button}` if the event was handled but state didn't change,\n`:passthrough` if the event wasn't handled by the button.","title":"Returns - Raxol.UI.Components.Input.Button.handle_event/3","ref":"Raxol.UI.Components.Input.Button.html#handle_event/3-returns"},{"type":"function","doc":"Initializes the button component state.","title":"Raxol.UI.Components.Input.Button.init/1","ref":"Raxol.UI.Components.Input.Button.html#init/1"},{"type":"function","doc":"Creates a new Button state map, applying defaults.\nExpects opts to be a Map.","title":"Raxol.UI.Components.Input.Button.new/1","ref":"Raxol.UI.Components.Input.Button.html#new/1"},{"type":"function","doc":"Renders the button component based on its current state.","title":"Raxol.UI.Components.Input.Button.render/2","ref":"Raxol.UI.Components.Input.Button.html#render/2"},{"type":"function","doc":"* `button` - The button component to render\n* `context` - The rendering context","title":"Parameters - Raxol.UI.Components.Input.Button.render/2","ref":"Raxol.UI.Components.Input.Button.html#render/2-parameters"},{"type":"function","doc":"A rendered view representation of the button.","title":"Returns - Raxol.UI.Components.Input.Button.render/2","ref":"Raxol.UI.Components.Input.Button.html#render/2-returns"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.Button.t/0","ref":"Raxol.UI.Components.Input.Button.html#t:t/0"},{"type":"function","doc":"Updates the button component state based on external messages.","title":"Raxol.UI.Components.Input.Button.update/2","ref":"Raxol.UI.Components.Input.Button.html#update/2"},{"type":"module","doc":"Checkbox component for toggling boolean values.\n\nThis component provides a selectable checkbox with customizable appearance and behavior.\nFully supports style and theme props (with correct merging/precedence),\nimplements robust lifecycle hooks, and supports accessibility/extra props.","title":"Raxol.UI.Components.Input.Checkbox","ref":"Raxol.UI.Components.Input.Checkbox.html"},{"type":"function","doc":"Creates a new checkbox component with the given options.\nSee `init/1` for details.","title":"Raxol.UI.Components.Input.Checkbox.new/1","ref":"Raxol.UI.Components.Input.Checkbox.html#new/1"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.Checkbox.t/0","ref":"Raxol.UI.Components.Input.Checkbox.html#t:t/0"},{"type":"module","doc":"A multi-line input component for text editing, supporting line wrapping, scrolling, selection, and accessibility.\n\n**BREAKING:** All styling is now theme-driven. The `style` field and `@default_style` are removed. Use the theme system for all appearance customization.\n\nHarmonized with modern Raxol component standards (style/theme merging, lifecycle hooks, accessibility props).","title":"Raxol.UI.Components.Input.MultiLineInput","ref":"Raxol.UI.Components.Input.MultiLineInput.html"},{"type":"function","doc":"Initializes the MultiLineInput state, harmonizing style/theme/extra props and splitting lines for editing.","title":"Raxol.UI.Components.Input.MultiLineInput.init/1","ref":"Raxol.UI.Components.Input.MultiLineInput.html#init/1"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.t/0","ref":"Raxol.UI.Components.Input.MultiLineInput.html#t:t/0"},{"type":"module","doc":"UI adapter for MultiLineInput's ClipboardHelper. Delegates to the implementation in\nRaxol.Components.Input.MultiLineInput.ClipboardHelper.","title":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper","ref":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.html"},{"type":"function","doc":"Copies the currently selected text to the clipboard.","title":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.copy_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.html#copy_selection/1"},{"type":"function","doc":"Cuts the selected text (copies then deletes).","title":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.cut_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.html#cut_selection/1"},{"type":"function","doc":"Initiates a paste operation from clipboard.","title":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.paste/1","ref":"Raxol.UI.Components.Input.MultiLineInput.ClipboardHelper.html#paste/1"},{"type":"module","doc":"Handles key and mouse events for MultiLineInput, translating them into update messages.","title":"Raxol.UI.Components.Input.MultiLineInput.EventHandler","ref":"Raxol.UI.Components.Input.MultiLineInput.EventHandler.html"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.EventHandler.handle_event/2","ref":"Raxol.UI.Components.Input.MultiLineInput.EventHandler.html#handle_event/2"},{"type":"module","doc":"Helper functions for cursor navigation and text selection in MultiLineInput.","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.clear_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#clear_selection/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.is_line_in_selection?/3","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#is_line_in_selection?/3"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor/2","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor/2"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_doc_end/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_doc_end/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_doc_start/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_doc_start/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_line_end/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_line_end/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_line_start/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_line_start/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_page/2","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_page/2"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_word_left/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_word_left/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.move_cursor_word_right/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#move_cursor_word_right/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.normalize_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#normalize_selection/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.select/2","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#select/2"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.select_all/1","ref":"Raxol.UI.Components.Input.MultiLineInput.NavigationHelper.html#select_all/1"},{"type":"module","doc":"UI adapter for MultiLineInput's RenderHelper. Delegates to the implementation in\nRaxol.Components.Input.MultiLineInput.RenderHelper.","title":"Raxol.UI.Components.Input.MultiLineInput.RenderHelper","ref":"Raxol.UI.Components.Input.MultiLineInput.RenderHelper.html"},{"type":"function","doc":"Renders the multi-line input component with proper styling based on the state.\nReturns a grid of cell data for the visible portion of text.\n\nDelegates to the implementation in Raxol.Components.Input.MultiLineInput.RenderHelper.","title":"Raxol.UI.Components.Input.MultiLineInput.RenderHelper.render/3","ref":"Raxol.UI.Components.Input.MultiLineInput.RenderHelper.html#render/3"},{"type":"function","doc":"- state: The MultiLineInput state\n- context: The render context\n- theme: The theme containing style information","title":"Parameters - Raxol.UI.Components.Input.MultiLineInput.RenderHelper.render/3","ref":"Raxol.UI.Components.Input.MultiLineInput.RenderHelper.html#render/3-parameters"},{"type":"module","doc":"Helper functions for text and line manipulation in MultiLineInput.","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.calculate_new_position/3","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#calculate_new_position/3"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.clamp/3","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#clamp/3"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.delete_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#delete_selection/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.handle_backspace_no_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#handle_backspace_no_selection/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.handle_delete_no_selection/1","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#handle_delete_no_selection/1"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.insert_char/2","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#insert_char/2"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.pos_to_index/2","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#pos_to_index/2"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.replace_text_range/4","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#replace_text_range/4"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.split_and_wrap/3","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#split_and_wrap/3"},{"type":"function","doc":"","title":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.split_into_lines/3","ref":"Raxol.UI.Components.Input.MultiLineInput.TextHelper.html#split_into_lines/3"},{"type":"module","doc":"A component that allows users to select an option from a list.\n\nFeatures:\n* Single or multiple selections\n* Robust keyboard navigation with stateful scrolling\n* Search/filtering capabilities\n* Accessibility support\n* Custom styling and theming\n* Pagination for very large lists","title":"Raxol.UI.Components.Input.SelectList","ref":"Raxol.UI.Components.Input.SelectList.html"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.option/0","ref":"Raxol.UI.Components.Input.SelectList.html#t:option/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.options/0","ref":"Raxol.UI.Components.Input.SelectList.html#t:options/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.props/0","ref":"Raxol.UI.Components.Input.SelectList.html#t:props/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.state/0","ref":"Raxol.UI.Components.Input.SelectList.html#t:state/0"},{"type":"module","doc":"Handles keyboard navigation functionality for the SelectList component.","title":"Raxol.UI.Components.Input.SelectList.Navigation","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html"},{"type":"function","doc":"Handles arrow down key press, moving focus down one item.","title":"Raxol.UI.Components.Input.SelectList.Navigation.handle_arrow_down/1","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#handle_arrow_down/1"},{"type":"function","doc":"Handles arrow up key press, moving focus up one item.","title":"Raxol.UI.Components.Input.SelectList.Navigation.handle_arrow_up/1","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#handle_arrow_up/1"},{"type":"function","doc":"Handles end key press, moving focus to the last item.","title":"Raxol.UI.Components.Input.SelectList.Navigation.handle_end/1","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#handle_end/1"},{"type":"function","doc":"Handles home key press, moving focus to the first item.","title":"Raxol.UI.Components.Input.SelectList.Navigation.handle_home/1","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#handle_home/1"},{"type":"function","doc":"Handles page down key press, moving focus down one page.","title":"Raxol.UI.Components.Input.SelectList.Navigation.handle_page_down/1","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#handle_page_down/1"},{"type":"function","doc":"Handles page up key press, moving focus up one page.","title":"Raxol.UI.Components.Input.SelectList.Navigation.handle_page_up/1","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#handle_page_up/1"},{"type":"function","doc":"Updates focus index and scroll position to ensure the focused item is visible.","title":"Raxol.UI.Components.Input.SelectList.Navigation.update_focus_and_scroll/2","ref":"Raxol.UI.Components.Input.SelectList.Navigation.html#update_focus_and_scroll/2"},{"type":"module","doc":"Handles pagination functionality for the SelectList component.","title":"Raxol.UI.Components.Input.SelectList.Pagination","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html"},{"type":"function","doc":"Calculates the total number of pages based on the number of options and page size.","title":"Raxol.UI.Components.Input.SelectList.Pagination.calculate_total_pages/2","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html#calculate_total_pages/2"},{"type":"function","doc":"Gets the effective options list (filtered or original) based on current state.","title":"Raxol.UI.Components.Input.SelectList.Pagination.get_effective_options/1","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html#get_effective_options/1"},{"type":"function","doc":"Gets the options for a specific page.","title":"Raxol.UI.Components.Input.SelectList.Pagination.get_page_options/3","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html#get_page_options/3"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.Pagination.option/0","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html#t:option/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.Pagination.options/0","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html#t:options/0"},{"type":"function","doc":"Updates pagination state based on a new page number.","title":"Raxol.UI.Components.Input.SelectList.Pagination.update_page_state/2","ref":"Raxol.UI.Components.Input.SelectList.Pagination.html#update_page_state/2"},{"type":"module","doc":"Handles rendering functionality for the SelectList component.","title":"Raxol.UI.Components.Input.SelectList.Renderer","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html"},{"type":"function","doc":"Renders the SelectList component.","title":"Raxol.UI.Components.Input.SelectList.Renderer.render/1","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html#render/1"},{"type":"function","doc":"Renders the main list container with options.","title":"Raxol.UI.Components.Input.SelectList.Renderer.render_list_container/2","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html#render_list_container/2"},{"type":"function","doc":"Renders a single option.","title":"Raxol.UI.Components.Input.SelectList.Renderer.render_option/5","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html#render_option/5"},{"type":"function","doc":"Renders the list of options.","title":"Raxol.UI.Components.Input.SelectList.Renderer.render_options/2","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html#render_options/2"},{"type":"function","doc":"Renders pagination controls.","title":"Raxol.UI.Components.Input.SelectList.Renderer.render_pagination_controls/1","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html#render_pagination_controls/1"},{"type":"function","doc":"Renders the search input element.","title":"Raxol.UI.Components.Input.SelectList.Renderer.render_search_input/1","ref":"Raxol.UI.Components.Input.SelectList.Renderer.html#render_search_input/1"},{"type":"module","doc":"Handles search and filtering functionality for the SelectList component.","title":"Raxol.UI.Components.Input.SelectList.Search","ref":"Raxol.UI.Components.Input.SelectList.Search.html"},{"type":"function","doc":"Filters options based on search text and optional searchable fields.\nReturns nil if no search text is provided, otherwise returns filtered options.","title":"Raxol.UI.Components.Input.SelectList.Search.filter_options/3","ref":"Raxol.UI.Components.Input.SelectList.Search.html#filter_options/3"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.Search.option/0","ref":"Raxol.UI.Components.Input.SelectList.Search.html#t:option/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.SelectList.Search.options/0","ref":"Raxol.UI.Components.Input.SelectList.Search.html#t:options/0"},{"type":"function","doc":"Checks if an option matches the search text.\nIf searchable_fields is provided, only those fields are searched.\nOtherwise, the option label is searched.","title":"Raxol.UI.Components.Input.SelectList.Search.search_matches?/3","ref":"Raxol.UI.Components.Input.SelectList.Search.html#search_matches?/3"},{"type":"function","doc":"Updates search-related state based on new search text.","title":"Raxol.UI.Components.Input.SelectList.Search.update_search_state/2","ref":"Raxol.UI.Components.Input.SelectList.Search.html#update_search_state/2"},{"type":"module","doc":"Handles selection functionality for the SelectList component.","title":"Raxol.UI.Components.Input.SelectList.Selection","ref":"Raxol.UI.Components.Input.SelectList.Selection.html"},{"type":"function","doc":"Generates commands based on selection callbacks.","title":"Raxol.UI.Components.Input.SelectList.Selection.generate_selection_commands/2","ref":"Raxol.UI.Components.Input.SelectList.Selection.html#generate_selection_commands/2"},{"type":"function","doc":"Updates selection state based on a selected index.\nReturns updated state and any commands to execute.","title":"Raxol.UI.Components.Input.SelectList.Selection.handle_select/1","ref":"Raxol.UI.Components.Input.SelectList.Selection.html#handle_select/1"},{"type":"function","doc":"Updates selection state for a specific index.","title":"Raxol.UI.Components.Input.SelectList.Selection.update_selection_state/2","ref":"Raxol.UI.Components.Input.SelectList.Selection.html#update_selection_state/2"},{"type":"module","doc":"A text field component for single-line text input.\n\nIt supports validation, placeholders, masks, and styling.","title":"Raxol.UI.Components.Input.TextField","ref":"Raxol.UI.Components.Input.TextField.html"},{"type":"module","doc":"A text input component for capturing user text input.\n\nFeatures:\n* Customizable placeholder text\n* Value binding\n* Focus handling\n* Character validation\n* Input masking (for password fields)\n* Event callbacks","title":"Raxol.UI.Components.Input.TextInput","ref":"Raxol.UI.Components.Input.TextInput.html"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.TextInput.props/0","ref":"Raxol.UI.Components.Input.TextInput.html#t:props/0"},{"type":"type","doc":"","title":"Raxol.UI.Components.Input.TextInput.state/0","ref":"Raxol.UI.Components.Input.TextInput.html#t:state/0"},{"type":"module","doc":"Handles layout calculations for container elements like rows and columns.\n\nThis module is responsible for:\n* Row layout calculations\n* Column layout calculations\n* Flexbox-like distribution of space\n* Gap and alignment handling","title":"Raxol.UI.Layout.Containers","ref":"Raxol.UI.Layout.Containers.html"},{"type":"function","doc":"Measures the space needed by a column element.","title":"Raxol.UI.Layout.Containers.measure_column/2","ref":"Raxol.UI.Layout.Containers.html#measure_column/2"},{"type":"function","doc":"* `column` - The column element to measure\n* `available_space` - The available space for the column","title":"Parameters - Raxol.UI.Layout.Containers.measure_column/2","ref":"Raxol.UI.Layout.Containers.html#measure_column/2-parameters"},{"type":"function","doc":"The dimensions of the column: %{width: w, height: h}","title":"Returns - Raxol.UI.Layout.Containers.measure_column/2","ref":"Raxol.UI.Layout.Containers.html#measure_column/2-returns"},{"type":"function","doc":"Measures the space needed by a row element.","title":"Raxol.UI.Layout.Containers.measure_row/2","ref":"Raxol.UI.Layout.Containers.html#measure_row/2"},{"type":"function","doc":"* `row` - The row element to measure\n* `available_space` - The available space for the row","title":"Parameters - Raxol.UI.Layout.Containers.measure_row/2","ref":"Raxol.UI.Layout.Containers.html#measure_row/2-parameters"},{"type":"function","doc":"The dimensions of the row: %{width: w, height: h}","title":"Returns - Raxol.UI.Layout.Containers.measure_row/2","ref":"Raxol.UI.Layout.Containers.html#measure_row/2-returns"},{"type":"function","doc":"Processes a column element, calculating layout for it and its children.","title":"Raxol.UI.Layout.Containers.process_column/3","ref":"Raxol.UI.Layout.Containers.html#process_column/3"},{"type":"function","doc":"* `column` - The column element to process\n* `space` - The available space for the column\n* `acc` - The accumulator for rendered elements","title":"Parameters - Raxol.UI.Layout.Containers.process_column/3","ref":"Raxol.UI.Layout.Containers.html#process_column/3-parameters"},{"type":"function","doc":"A list of positioned elements with absolute coordinates.","title":"Returns - Raxol.UI.Layout.Containers.process_column/3","ref":"Raxol.UI.Layout.Containers.html#process_column/3-returns"},{"type":"function","doc":"Processes a row element, calculating layout for it and its children.","title":"Raxol.UI.Layout.Containers.process_row/3","ref":"Raxol.UI.Layout.Containers.html#process_row/3"},{"type":"function","doc":"* `row` - The row element to process\n* `space` - The available space for the row\n* `acc` - The accumulator for rendered elements","title":"Parameters - Raxol.UI.Layout.Containers.process_row/3","ref":"Raxol.UI.Layout.Containers.html#process_row/3-parameters"},{"type":"function","doc":"A list of positioned elements with absolute coordinates.","title":"Returns - Raxol.UI.Layout.Containers.process_row/3","ref":"Raxol.UI.Layout.Containers.html#process_row/3-returns"},{"type":"module","doc":"Core layout engine that translates the logical view structure into absolute positions.\n\nThis module is responsible for:\n* Calculating element positions based on available space\n* Resolving layout constraints\n* Managing the layout pipeline","title":"Raxol.UI.Layout.Engine","ref":"Raxol.UI.Layout.Engine.html"},{"type":"function","doc":"Applies layout to a view, calculating absolute positions for all elements.","title":"Raxol.UI.Layout.Engine.apply_layout/2","ref":"Raxol.UI.Layout.Engine.html#apply_layout/2"},{"type":"function","doc":"* `view` - The view to calculate layout for\n* `dimensions` - Terminal dimensions `%{width: w, height: h}`","title":"Parameters - Raxol.UI.Layout.Engine.apply_layout/2","ref":"Raxol.UI.Layout.Engine.html#apply_layout/2-parameters"},{"type":"function","doc":"A list of positioned elements with absolute coordinates.","title":"Returns - Raxol.UI.Layout.Engine.apply_layout/2","ref":"Raxol.UI.Layout.Engine.html#apply_layout/2-returns"},{"type":"function","doc":"Calculates the intrinsic dimensions (width, height) of an element.\n\nThis function determines the natural size of an element before layout constraints\nare applied. For containers, it might recursively measure children.","title":"Raxol.UI.Layout.Engine.measure_element/2","ref":"Raxol.UI.Layout.Engine.html#measure_element/2"},{"type":"function","doc":"* `element` - The element map to measure.\n* `available_space` - Map providing context (e.g., max width).\n- Defaults to an empty map.","title":"Parameters - Raxol.UI.Layout.Engine.measure_element/2","ref":"Raxol.UI.Layout.Engine.html#measure_element/2-parameters"},{"type":"function","doc":"A map representing the dimensions: `%{width: integer(), height: integer()}`.","title":"Returns - Raxol.UI.Layout.Engine.measure_element/2","ref":"Raxol.UI.Layout.Engine.html#measure_element/2-returns"},{"type":"function","doc":"","title":"Raxol.UI.Layout.Engine.process_element/3","ref":"Raxol.UI.Layout.Engine.html#process_element/3"},{"type":"module","doc":"Handles layout calculations for grid UI elements.\n\nThis module is responsible for:\n* Grid-based layout calculations\n* Cell sizing and positioning\n* Column and row spanning elements\n* Grid-specific spacing and constraints","title":"Raxol.UI.Layout.Grid","ref":"Raxol.UI.Layout.Grid.html"},{"type":"function","doc":"Creates grid cell information for a grid layout.","title":"Raxol.UI.Layout.Grid.calculate_grid_cells/2","ref":"Raxol.UI.Layout.Grid.html#calculate_grid_cells/2"},{"type":"function","doc":"* `grid_attrs` - The grid attributes\n* `space` - The available space","title":"Parameters - Raxol.UI.Layout.Grid.calculate_grid_cells/2","ref":"Raxol.UI.Layout.Grid.html#calculate_grid_cells/2-parameters"},{"type":"function","doc":"A map containing cell dimensions and grid information.","title":"Returns - Raxol.UI.Layout.Grid.calculate_grid_cells/2","ref":"Raxol.UI.Layout.Grid.html#calculate_grid_cells/2-returns"},{"type":"function","doc":"Calculates the position for a cell in the grid.","title":"Raxol.UI.Layout.Grid.cell_position/4","ref":"Raxol.UI.Layout.Grid.html#cell_position/4"},{"type":"function","doc":"* `col` - The column index (0-based)\n* `row` - The row index (0-based)\n* `grid_cells` - The grid cell information from `calculate_grid_cells/2`\n* `space` - The base space for the grid","title":"Parameters - Raxol.UI.Layout.Grid.cell_position/4","ref":"Raxol.UI.Layout.Grid.html#cell_position/4-parameters"},{"type":"function","doc":"A space map with x, y, width, and height for the cell.","title":"Returns - Raxol.UI.Layout.Grid.cell_position/4","ref":"Raxol.UI.Layout.Grid.html#cell_position/4-returns"},{"type":"function","doc":"Measures the space needed by a grid element.","title":"Raxol.UI.Layout.Grid.measure_grid/2","ref":"Raxol.UI.Layout.Grid.html#measure_grid/2"},{"type":"function","doc":"* `grid` - The grid element to measure\n* `available_space` - The available space for the grid","title":"Parameters - Raxol.UI.Layout.Grid.measure_grid/2","ref":"Raxol.UI.Layout.Grid.html#measure_grid/2-parameters"},{"type":"function","doc":"The dimensions of the grid: %{width: w, height: h}","title":"Returns - Raxol.UI.Layout.Grid.measure_grid/2","ref":"Raxol.UI.Layout.Grid.html#measure_grid/2-returns"},{"type":"function","doc":"Processes a grid element, calculating layout for it and its children.","title":"Raxol.UI.Layout.Grid.process/3","ref":"Raxol.UI.Layout.Grid.html#process/3"},{"type":"function","doc":"* `grid` - The grid element to process\n* `space` - The available space for the grid\n* `acc` - The accumulator for rendered elements","title":"Parameters - Raxol.UI.Layout.Grid.process/3","ref":"Raxol.UI.Layout.Grid.html#process/3-parameters"},{"type":"function","doc":"A list of positioned elements with absolute coordinates.","title":"Returns - Raxol.UI.Layout.Grid.process/3","ref":"Raxol.UI.Layout.Grid.html#process/3-returns"},{"type":"module","doc":"Handles layout calculations for panel UI elements.\n\nThis module is responsible for:\n* Panel border rendering\n* Panel content layout\n* Panel title positioning\n* Panel-specific spacing and constraints","title":"Raxol.UI.Layout.Panels","ref":"Raxol.UI.Layout.Panels.html"},{"type":"function","doc":"Measures the space required by a panel element.","title":"Raxol.UI.Layout.Panels.measure_panel/2","ref":"Raxol.UI.Layout.Panels.html#measure_panel/2"},{"type":"function","doc":"* `panel` - The panel element to measure\n* `available_space` - The available space for the panel","title":"Parameters - Raxol.UI.Layout.Panels.measure_panel/2","ref":"Raxol.UI.Layout.Panels.html#measure_panel/2-parameters"},{"type":"function","doc":"The dimensions of the panel: %{width: w, height: h}","title":"Returns - Raxol.UI.Layout.Panels.measure_panel/2","ref":"Raxol.UI.Layout.Panels.html#measure_panel/2-returns"},{"type":"function","doc":"Processes a panel element, calculating layout for it and its children.","title":"Raxol.UI.Layout.Panels.process/3","ref":"Raxol.UI.Layout.Panels.html#process/3"},{"type":"function","doc":"* `panel` - The panel element to process\n* `space` - The available space for the panel\n* `acc` - The accumulator for rendered elements","title":"Parameters - Raxol.UI.Layout.Panels.process/3","ref":"Raxol.UI.Layout.Panels.html#process/3-parameters"},{"type":"function","doc":"A list of positioned elements with absolute coordinates.","title":"Returns - Raxol.UI.Layout.Panels.process/3","ref":"Raxol.UI.Layout.Panels.html#process/3-returns"},{"type":"module","doc":"Handles measurement and positioning logic for Table elements within the LayoutEngine.","title":"Raxol.UI.Layout.Table","ref":"Raxol.UI.Layout.Table.html"},{"type":"function","doc":"Measures the required space for a table and returns a single positioned table element.","title":"Raxol.UI.Layout.Table.measure_and_position/3","ref":"Raxol.UI.Layout.Table.html#measure_and_position/3"},{"type":"module","doc":"Translates a positioned element tree into a flat list of renderable cells.\n\nTakes the output of the Layout Engine and converts UI primitives (text, boxes, etc.)\ninto styled characters at specific coordinates.","title":"Raxol.UI.Renderer","ref":"Raxol.UI.Renderer.html"},{"type":"type","doc":"","title":"Raxol.UI.Renderer.cell/0","ref":"Raxol.UI.Renderer.html#t:cell/0"},{"type":"type","doc":"","title":"Raxol.UI.Renderer.positioned_element/0","ref":"Raxol.UI.Renderer.html#t:positioned_element/0"},{"type":"function","doc":"Renders a tree of positioned elements into a list of cells.\n\nArgs:\n  - `elements`: A list or single map representing positioned elements from the Layout Engine.\n  - `theme`: The current theme map (expected %Theme{}).\n\nReturns:\n  - `list(cell())`","title":"Raxol.UI.Renderer.render_to_cells/2","ref":"Raxol.UI.Renderer.html#render_to_cells/2"},{"type":"type","doc":"","title":"Raxol.UI.Renderer.theme/0","ref":"Raxol.UI.Renderer.html#t:theme/0"},{"type":"module","doc":"Manages the rendering pipeline for the UI.","title":"Raxol.UI.Rendering.Pipeline","ref":"Raxol.UI.Rendering.Pipeline.html"},{"type":"function","doc":"","title":"Raxol.UI.Rendering.Pipeline.apply_animation_settings/8","ref":"Raxol.UI.Rendering.Pipeline.html#apply_animation_settings/8"},{"type":"module","doc":"A terminal UI rendering module for Raxol.\n\nThis module provides basic terminal rendering capabilities for Raxol applications,\nwith support for accessibility features, internationalization, and color system\nintegration.","title":"Raxol.UI.Terminal","ref":"Raxol.UI.Terminal.html"},{"type":"module","doc":"- Terminal screen management (clearing, cursor positioning)\n- Text rendering with colors and styles\n- Input handling with support for keyboard shortcuts\n- Basic UI elements (boxes, lines, progress bars)\n- RTL rendering support\n- Accessibility-friendly output formatting","title":"Features - Raxol.UI.Terminal","ref":"Raxol.UI.Terminal.html#module-features"},{"type":"function","doc":"Clear the terminal screen.","title":"Raxol.UI.Terminal.clear/0","ref":"Raxol.UI.Terminal.html#clear/0"},{"type":"function","doc":"iex> Terminal.clear()\n    :ok","title":"Examples - Raxol.UI.Terminal.clear/0","ref":"Raxol.UI.Terminal.html#clear/0-examples"},{"type":"function","doc":"Move the cursor to a specific position.","title":"Raxol.UI.Terminal.move_cursor/2","ref":"Raxol.UI.Terminal.html#move_cursor/2"},{"type":"function","doc":"* `row` - The row (1-indexed)\n* `col` - The column (1-indexed)","title":"Parameters - Raxol.UI.Terminal.move_cursor/2","ref":"Raxol.UI.Terminal.html#move_cursor/2-parameters"},{"type":"function","doc":"iex> Terminal.move_cursor(1, 1)\n    :ok","title":"Examples - Raxol.UI.Terminal.move_cursor/2","ref":"Raxol.UI.Terminal.html#move_cursor/2-examples"},{"type":"function","doc":"Print text with optional styling.","title":"Raxol.UI.Terminal.print/2","ref":"Raxol.UI.Terminal.html#print/2"},{"type":"function","doc":"* `:color` - The text color (hex string or color name)\n* `:background` - The background color (hex string or color name)\n* `:bold` - Whether to display the text in bold (default: false)\n* `:italic` - Whether to display the text in italic (default: false)\n* `:underline` - Whether to underline the text (default: false)\n* `:dim` - Whether to display the text dimmed (default: false)\n* `:blink` - Whether to make the text blink (default: false)\n* `:rtl` - Whether to render the text right-to-left (default: from I18n)","title":"Options - Raxol.UI.Terminal.print/2","ref":"Raxol.UI.Terminal.html#print/2-options"},{"type":"function","doc":"iex> Terminal.print(\"Hello\", color: \"#FF0000\", bold: true)\n    :ok","title":"Examples - Raxol.UI.Terminal.print/2","ref":"Raxol.UI.Terminal.html#print/2-examples"},{"type":"function","doc":"Print a box with content.","title":"Raxol.UI.Terminal.print_box/2","ref":"Raxol.UI.Terminal.html#print_box/2"},{"type":"function","doc":"* `content` - The text content to display inside the box\n* `opts` - Styling options","title":"Parameters - Raxol.UI.Terminal.print_box/2","ref":"Raxol.UI.Terminal.html#print_box/2-parameters"},{"type":"function","doc":"* `:width` - Box width (default: content width + 4)\n* `:height` - Box height (default: content lines + 2)\n* `:border_color` - Color for the border\n* `:title` - Optional title for the box\n* `:title_color` - Color for the title\n* `:centered` - Whether to center the box horizontally (default: false)","title":"Options - Raxol.UI.Terminal.print_box/2","ref":"Raxol.UI.Terminal.html#print_box/2-options"},{"type":"function","doc":"iex> Terminal.print_box(\"Hello\nWorld\", title: \"Greeting\", border_color: \"#0000FF\")\n    :ok","title":"Examples - Raxol.UI.Terminal.print_box/2","ref":"Raxol.UI.Terminal.html#print_box/2-examples"},{"type":"function","doc":"Print centered text.","title":"Raxol.UI.Terminal.print_centered/2","ref":"Raxol.UI.Terminal.html#print_centered/2"},{"type":"function","doc":"Takes the same options as `print/2`.","title":"Options - Raxol.UI.Terminal.print_centered/2","ref":"Raxol.UI.Terminal.html#print_centered/2-options"},{"type":"function","doc":"iex> Terminal.print_centered(\"Title\", color: \"#FF0000\", bold: true)\n    :ok","title":"Examples - Raxol.UI.Terminal.print_centered/2","ref":"Raxol.UI.Terminal.html#print_centered/2-examples"},{"type":"function","doc":"Print a horizontal line spanning the terminal width.","title":"Raxol.UI.Terminal.print_horizontal_line/1","ref":"Raxol.UI.Terminal.html#print_horizontal_line/1"},{"type":"function","doc":"* `:char` - The character to use for the line (default: \"─\")\n* Other options are passed to `print/2`","title":"Options - Raxol.UI.Terminal.print_horizontal_line/1","ref":"Raxol.UI.Terminal.html#print_horizontal_line/1-options"},{"type":"function","doc":"iex> Terminal.print_horizontal_line(char: \"-\", color: \"#CCCCCC\")\n    :ok","title":"Examples - Raxol.UI.Terminal.print_horizontal_line/1","ref":"Raxol.UI.Terminal.html#print_horizontal_line/1-examples"},{"type":"function","doc":"Print text followed by a newline.\n\nTakes the same options as `print/2`.","title":"Raxol.UI.Terminal.println/2","ref":"Raxol.UI.Terminal.html#println/2"},{"type":"function","doc":"iex> Terminal.println(\"Hello\", color: \"#FF0000\", bold: true)\n    :ok","title":"Examples - Raxol.UI.Terminal.println/2","ref":"Raxol.UI.Terminal.html#println/2-examples"},{"type":"function","doc":"Read a keypress from the user.","title":"Raxol.UI.Terminal.read_key/1","ref":"Raxol.UI.Terminal.html#read_key/1"},{"type":"function","doc":"* `:timeout` - Timeout in milliseconds (default: :infinity)","title":"Options - Raxol.UI.Terminal.read_key/1","ref":"Raxol.UI.Terminal.html#read_key/1-options"},{"type":"function","doc":"* `{:ok, key}` - Where key is the key pressed\n* `:timeout` - If no key was pressed within the timeout\n* `{:error, reason}` - If an error occurred","title":"Returns - Raxol.UI.Terminal.read_key/1","ref":"Raxol.UI.Terminal.html#read_key/1-returns"},{"type":"function","doc":"iex> Terminal.read_key()\n    {:ok, :enter}\n\n    iex> Terminal.read_key(timeout: 1000)\n    :timeout","title":"Examples - Raxol.UI.Terminal.read_key/1","ref":"Raxol.UI.Terminal.html#read_key/1-examples"},{"type":"module","doc":"Color management utilities for theme handling.\n\nThis module provides functions for working with colors in the context of UI theming,\nincluding color format conversion, manipulation, and theme-specific operations.","title":"Raxol.UI.Theming.Colors","ref":"Raxol.UI.Theming.Colors.html"},{"type":"module","doc":"- Color format conversion (hex, RGB, ANSI)\n- Color manipulation (lighten, darken, blend)\n- Theme color management\n- Accessibility checks","title":"Features - Raxol.UI.Theming.Colors","ref":"Raxol.UI.Theming.Colors.html#module-features"},{"type":"function","doc":"Converts an ANSI color code to RGB values.","title":"Raxol.UI.Theming.Colors.ansi_to_rgb/1","ref":"Raxol.UI.Theming.Colors.html#ansi_to_rgb/1"},{"type":"function","doc":"iex> ansi_to_rgb(1)\n    {205, 0, 0}","title":"Examples - Raxol.UI.Theming.Colors.ansi_to_rgb/1","ref":"Raxol.UI.Theming.Colors.html#ansi_to_rgb/1-examples"},{"type":"function","doc":"Blends two colors with the specified alpha value.","title":"Raxol.UI.Theming.Colors.blend/3","ref":"Raxol.UI.Theming.Colors.html#blend/3"},{"type":"function","doc":"iex> blend(\"#FF0000\", \"#0000FF\", 0.5)\n    \"#800080\"\n    iex> blend(:red, :blue, 0.5)\n    \"#800080\"","title":"Examples - Raxol.UI.Theming.Colors.blend/3","ref":"Raxol.UI.Theming.Colors.html#blend/3-examples"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Colors.color_hex/0","ref":"Raxol.UI.Theming.Colors.html#t:color_hex/0"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Colors.color_hsl/0","ref":"Raxol.UI.Theming.Colors.html#t:color_hsl/0"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Colors.color_name/0","ref":"Raxol.UI.Theming.Colors.html#t:color_name/0"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Colors.color_rgb/0","ref":"Raxol.UI.Theming.Colors.html#t:color_rgb/0"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Colors.color_rgba/0","ref":"Raxol.UI.Theming.Colors.html#t:color_rgba/0"},{"type":"function","doc":"Calculates the contrast ratio between two colors.","title":"Raxol.UI.Theming.Colors.contrast_ratio/2","ref":"Raxol.UI.Theming.Colors.html#contrast_ratio/2"},{"type":"function","doc":"iex> contrast_ratio(\"#FFFFFF\", \"#000000\")\n    21.0\n    iex> contrast_ratio(:white, :black)\n    21.0","title":"Examples - Raxol.UI.Theming.Colors.contrast_ratio/2","ref":"Raxol.UI.Theming.Colors.html#contrast_ratio/2-examples"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Colors.convert_to_basic/1","ref":"Raxol.UI.Theming.Colors.html#convert_to_basic/1"},{"type":"function","doc":"Converts a color or theme map to use a specific palette (e.g., 256 colors).\nFinds the closest color in the palette for each color in the theme.\n*Currently only supports named palettes like :xterm256*","title":"Raxol.UI.Theming.Colors.convert_to_palette/2","ref":"Raxol.UI.Theming.Colors.html#convert_to_palette/2"},{"type":"function","doc":"Darkens a color by the specified amount.","title":"Raxol.UI.Theming.Colors.darken/2","ref":"Raxol.UI.Theming.Colors.html#darken/2"},{"type":"function","doc":"iex> darken(\"#FFFFFF\", 0.5)\n    \"#808080\"\n    iex> darken(:red, 0.5)\n    \"#800000\"","title":"Examples - Raxol.UI.Theming.Colors.darken/2","ref":"Raxol.UI.Theming.Colors.html#darken/2-examples"},{"type":"function","doc":"Finds the closest ANSI 256-color index (0-255) to the given RGB color.","title":"Raxol.UI.Theming.Colors.find_closest_256_color/1","ref":"Raxol.UI.Theming.Colors.html#find_closest_256_color/1"},{"type":"function","doc":"Finds the closest ANSI basic color index (0-15) to the given RGB color.","title":"Raxol.UI.Theming.Colors.find_closest_basic_color/1","ref":"Raxol.UI.Theming.Colors.html#find_closest_basic_color/1"},{"type":"function","doc":"Converts a hex color string to RGB values.","title":"Raxol.UI.Theming.Colors.hex_to_rgb/1","ref":"Raxol.UI.Theming.Colors.html#hex_to_rgb/1"},{"type":"function","doc":"iex> hex_to_rgb(\"#FF0000\")\n    {255, 0, 0}","title":"Examples - Raxol.UI.Theming.Colors.hex_to_rgb/1","ref":"Raxol.UI.Theming.Colors.html#hex_to_rgb/1-examples"},{"type":"function","doc":"Converts HSL values to RGB values.","title":"Raxol.UI.Theming.Colors.hsl_to_rgb/3","ref":"Raxol.UI.Theming.Colors.html#hsl_to_rgb/3"},{"type":"function","doc":"iex> hsl_to_rgb(0, 1.0, 0.5)\n    {255, 0, 0}","title":"Examples - Raxol.UI.Theming.Colors.hsl_to_rgb/3","ref":"Raxol.UI.Theming.Colors.html#hsl_to_rgb/3-examples"},{"type":"function","doc":"Lightens a color by the specified amount.","title":"Raxol.UI.Theming.Colors.lighten/2","ref":"Raxol.UI.Theming.Colors.html#lighten/2"},{"type":"function","doc":"iex> lighten(\"#000000\", 0.5)\n    \"#808080\"\n    iex> lighten(:red, 0.5)\n    \"#FF8080\"","title":"Examples - Raxol.UI.Theming.Colors.lighten/2","ref":"Raxol.UI.Theming.Colors.html#lighten/2-examples"},{"type":"function","doc":"Checks if two colors meet WCAG contrast requirements.","title":"Raxol.UI.Theming.Colors.meets_contrast_requirements?/4","ref":"Raxol.UI.Theming.Colors.html#meets_contrast_requirements?/4"},{"type":"function","doc":"iex> meets_contrast_requirements?(\"#FFFFFF\", \"#000000\", :AA, :normal)\n    true","title":"Examples - Raxol.UI.Theming.Colors.meets_contrast_requirements?/4","ref":"Raxol.UI.Theming.Colors.html#meets_contrast_requirements?/4-examples"},{"type":"function","doc":"Converts RGB values to the closest ANSI color code.","title":"Raxol.UI.Theming.Colors.rgb_to_ansi/3","ref":"Raxol.UI.Theming.Colors.html#rgb_to_ansi/3"},{"type":"function","doc":"iex> rgb_to_ansi(255, 0, 0)\n    196","title":"Examples - Raxol.UI.Theming.Colors.rgb_to_ansi/3","ref":"Raxol.UI.Theming.Colors.html#rgb_to_ansi/3-examples"},{"type":"function","doc":"Converts RGB values to a hex color string.","title":"Raxol.UI.Theming.Colors.rgb_to_hex/3","ref":"Raxol.UI.Theming.Colors.html#rgb_to_hex/3"},{"type":"function","doc":"iex> rgb_to_hex(255, 0, 0)\n    \"#FF0000\"","title":"Examples - Raxol.UI.Theming.Colors.rgb_to_hex/3","ref":"Raxol.UI.Theming.Colors.html#rgb_to_hex/3-examples"},{"type":"function","doc":"Converts RGB values to HSL values.","title":"Raxol.UI.Theming.Colors.rgb_to_hsl/3","ref":"Raxol.UI.Theming.Colors.html#rgb_to_hsl/3"},{"type":"function","doc":"iex> rgb_to_hsl(255, 0, 0)\n    {0, 1.0, 0.5}","title":"Examples - Raxol.UI.Theming.Colors.rgb_to_hsl/3","ref":"Raxol.UI.Theming.Colors.html#rgb_to_hsl/3-examples"},{"type":"function","doc":"Converts a color to its ANSI representation.","title":"Raxol.UI.Theming.Colors.to_ansi/1","ref":"Raxol.UI.Theming.Colors.html#to_ansi/1"},{"type":"function","doc":"iex> Colors.to_ansi(:red)\n    196\n\n    iex> Colors.to_ansi(\"#FF0000\")\n    196","title":"Examples - Raxol.UI.Theming.Colors.to_ansi/1","ref":"Raxol.UI.Theming.Colors.html#to_ansi/1-examples"},{"type":"function","doc":"Converts a color to its ANSI 16-color representation.","title":"Raxol.UI.Theming.Colors.to_ansi_16/1","ref":"Raxol.UI.Theming.Colors.html#to_ansi_16/1"},{"type":"function","doc":"iex> Colors.to_ansi_16(:red)\n    1\n\n    iex> Colors.to_ansi_16(\"#FF0000\")\n    1","title":"Examples - Raxol.UI.Theming.Colors.to_ansi_16/1","ref":"Raxol.UI.Theming.Colors.html#to_ansi_16/1-examples"},{"type":"function","doc":"Converts a color to its hex representation.","title":"Raxol.UI.Theming.Colors.to_hex/1","ref":"Raxol.UI.Theming.Colors.html#to_hex/1"},{"type":"function","doc":"iex> Colors.to_hex(:red)\n    \"#FF0000\"\n\n    iex> Colors.to_hex(\"#00FF00\")\n    \"#00FF00\"","title":"Examples - Raxol.UI.Theming.Colors.to_hex/1","ref":"Raxol.UI.Theming.Colors.html#to_hex/1-examples"},{"type":"function","doc":"Converts a color from one format to RGB values.","title":"Raxol.UI.Theming.Colors.to_rgb/1","ref":"Raxol.UI.Theming.Colors.html#to_rgb/1"},{"type":"function","doc":"iex> Colors.to_rgb(\"#FF0000\")\n    {255, 0, 0}\n\n    iex> Colors.to_rgb(:blue)\n    {0, 0, 255}","title":"Examples - Raxol.UI.Theming.Colors.to_rgb/1","ref":"Raxol.UI.Theming.Colors.html#to_rgb/1-examples"},{"type":"module","doc":"A component for selecting and applying themes.\n\nThis module provides:\n* A list-based theme selector UI\n* Theme preview capabilities\n* Theme application functionality\n* Theme management integration","title":"Raxol.UI.Theming.Selector","ref":"Raxol.UI.Theming.Selector.html"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Selector.broadcast/1","ref":"Raxol.UI.Theming.Selector.html#broadcast/1"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Selector.command/1","ref":"Raxol.UI.Theming.Selector.html#command/1"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Selector.mount/1","ref":"Raxol.UI.Theming.Selector.html#mount/1"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Selector.props/0","ref":"Raxol.UI.Theming.Selector.html#t:props/0"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Selector.schedule/2","ref":"Raxol.UI.Theming.Selector.html#schedule/2"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Selector.state/0","ref":"Raxol.UI.Theming.Selector.html#t:state/0"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Selector.t/0","ref":"Raxol.UI.Theming.Selector.html#t:t/0"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Selector.unmount/1","ref":"Raxol.UI.Theming.Selector.html#unmount/1"},{"type":"module","doc":"Theme management for Raxol UI components.\n\nThis module provides functionality for:\n- Theme definition and management\n- Color palette integration\n- Component styling\n- Theme variants and accessibility","title":"Raxol.UI.Theming.Theme","ref":"Raxol.UI.Theming.Theme.html"},{"type":"function","doc":"Returns a high-contrast version of the given theme, for accessibility support.\nIf the theme is already high-contrast, returns it unchanged.","title":"Raxol.UI.Theming.Theme.adjust_for_high_contrast/1","ref":"Raxol.UI.Theming.Theme.html#adjust_for_high_contrast/1"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Theme.color_value/0","ref":"Raxol.UI.Theming.Theme.html#t:color_value/0"},{"type":"function","doc":"","title":"Raxol.UI.Theming.Theme.component_style/2","ref":"Raxol.UI.Theming.Theme.html#component_style/2"},{"type":"function","doc":"Creates a high contrast variant of the theme.","title":"Raxol.UI.Theming.Theme.create_high_contrast_variant/1","ref":"Raxol.UI.Theming.Theme.html#create_high_contrast_variant/1"},{"type":"function","doc":"Returns the currently active theme. Defaults to :default if not set.","title":"Raxol.UI.Theming.Theme.current/0","ref":"Raxol.UI.Theming.Theme.html#current/0"},{"type":"function","doc":"Returns the dark theme.","title":"Raxol.UI.Theming.Theme.dark_theme/0","ref":"Raxol.UI.Theming.Theme.html#dark_theme/0"},{"type":"function","doc":"Returns the default theme.","title":"Raxol.UI.Theming.Theme.default_theme/0","ref":"Raxol.UI.Theming.Theme.html#default_theme/0"},{"type":"function","doc":"Gets a theme by ID.","title":"Raxol.UI.Theming.Theme.get/1","ref":"Raxol.UI.Theming.Theme.html#get/1"},{"type":"function","doc":"Gets a color from the theme, respecting variants and accessibility settings.","title":"Raxol.UI.Theming.Theme.get_color/3","ref":"Raxol.UI.Theming.Theme.html#get_color/3"},{"type":"function","doc":"Gets the component style for a specific component type.","title":"Raxol.UI.Theming.Theme.get_component_style/2","ref":"Raxol.UI.Theming.Theme.html#get_component_style/2"},{"type":"function","doc":"Initializes the theme system and registers the default theme.\nThis should be called during application startup.","title":"Raxol.UI.Theming.Theme.init/0","ref":"Raxol.UI.Theming.Theme.html#init/0"},{"type":"function","doc":"Lists all registered themes as a list of theme structs.","title":"Raxol.UI.Theming.Theme.list_themes/0","ref":"Raxol.UI.Theming.Theme.html#list_themes/0"},{"type":"function","doc":"Creates a new theme with the given attributes.","title":"Raxol.UI.Theming.Theme.new/1","ref":"Raxol.UI.Theming.Theme.html#new/1"},{"type":"function","doc":"Registers a theme in the application environment.","title":"Raxol.UI.Theming.Theme.register/1","ref":"Raxol.UI.Theming.Theme.html#register/1"},{"type":"type","doc":"","title":"Raxol.UI.Theming.Theme.style_map/0","ref":"Raxol.UI.Theming.Theme.html#t:style_map/0"},{"type":"behaviour","doc":"Defines the behaviour for Theme services.","title":"Raxol.UI.Theming.ThemeBehaviour","ref":"Raxol.UI.Theming.ThemeBehaviour.html"},{"type":"callback","doc":"Applies a theme to an element tree.","title":"Raxol.UI.Theming.ThemeBehaviour.apply_theme/2","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:apply_theme/2"},{"type":"callback","doc":"Gets a color from a theme.","title":"Raxol.UI.Theming.ThemeBehaviour.color/2","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:color/2"},{"type":"callback","doc":"Gets a component style from a theme.","title":"Raxol.UI.Theming.ThemeBehaviour.component_style/2","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:component_style/2"},{"type":"callback","doc":"Gets the dark theme.","title":"Raxol.UI.Theming.ThemeBehaviour.dark_theme/0","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:dark_theme/0"},{"type":"callback","doc":"Gets the default theme.","title":"Raxol.UI.Theming.ThemeBehaviour.default_theme/0","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:default_theme/0"},{"type":"callback","doc":"Gets a theme by ID.","title":"Raxol.UI.Theming.ThemeBehaviour.get/1","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:get/1"},{"type":"callback","doc":"Gets a color value considering the theme and an optional variant.","title":"Raxol.UI.Theming.ThemeBehaviour.get_color/3","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:get_color/3"},{"type":"callback","doc":"Initializes the theme system.","title":"Raxol.UI.Theming.ThemeBehaviour.init/0","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:init/0"},{"type":"callback","doc":"Lists all registered themes.","title":"Raxol.UI.Theming.ThemeBehaviour.list/0","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:list/0"},{"type":"callback","doc":"Registers a theme.","title":"Raxol.UI.Theming.ThemeBehaviour.register/1","ref":"Raxol.UI.Theming.ThemeBehaviour.html#c:register/1"},{"type":"type","doc":"","title":"Raxol.UI.Theming.ThemeBehaviour.theme_t/0","ref":"Raxol.UI.Theming.ThemeBehaviour.html#t:theme_t/0"},{"type":"module","doc":"Provides component functions for Raxol views.\n\nThis module contains functions for creating various UI components\nthat can be used in Raxol views.","title":"Raxol.View.Components","ref":"Raxol.View.Components.html"},{"type":"function","doc":"Creates a button component with options for label, click action, style, and disabled state.","title":"Raxol.View.Components.button/2","ref":"Raxol.View.Components.html#button/2"},{"type":"function","doc":"- `:label` - The button text\n- `:on_click` - Function to call when clicked\n- `:style` - Style options for the button\n- `:disabled` - Whether the button is disabled","title":"Options - Raxol.View.Components.button/2","ref":"Raxol.View.Components.html#button/2-options"},{"type":"function","doc":"button(\"Submit\", on_click: &handle_submit/0, style: [bg: :blue])","title":"Example - Raxol.View.Components.button/2","ref":"Raxol.View.Components.html#button/2-example"},{"type":"function","doc":"Creates a label component with options for text, width, and style.","title":"Raxol.View.Components.label/2","ref":"Raxol.View.Components.html#label/2"},{"type":"function","doc":"- `:width` - Width of the label in characters\n- `:style` - Style options for the label\n- `:align` - Text alignment (:left, :center, :right)","title":"Options - Raxol.View.Components.label/2","ref":"Raxol.View.Components.html#label/2-options"},{"type":"function","doc":"label(\"Username:\", width: 10)\n    label(\"Password:\", width: 10, align: :right)","title":"Example - Raxol.View.Components.label/2","ref":"Raxol.View.Components.html#label/2-example"},{"type":"function","doc":"Creates a space component with options for width and height.","title":"Raxol.View.Components.space/1","ref":"Raxol.View.Components.html#space/1"},{"type":"function","doc":"- `:width` - Width of the space in characters\n- `:height` - Height of the space in lines\n- `:style` - Style options for the space","title":"Options - Raxol.View.Components.space/1","ref":"Raxol.View.Components.html#space/1-options"},{"type":"function","doc":"space(width: 2)\n    space(width: 1, height: 2)","title":"Example - Raxol.View.Components.space/1","ref":"Raxol.View.Components.html#space/1-example"},{"type":"function","doc":"Creates a text component with options for content, style, foreground, and background colors.","title":"Raxol.View.Components.text/2","ref":"Raxol.View.Components.html#text/2"},{"type":"function","doc":"- `:content` - The text content to display\n- `:style` - Style options for the text (font, size, etc.)\n- `:fg` - Foreground color\n- `:bg` - Background color","title":"Options - Raxol.View.Components.text/2","ref":"Raxol.View.Components.html#text/2-options"},{"type":"function","doc":"text(\"Hello World\", style: [bold: true], fg: :blue)","title":"Example - Raxol.View.Components.text/2","ref":"Raxol.View.Components.html#text/2-example"},{"type":"function","doc":"Creates a text input component with options for value, placeholder, change action, and style.","title":"Raxol.View.Components.text_input/1","ref":"Raxol.View.Components.html#text_input/1"},{"type":"function","doc":"- `:value` - Current input value\n- `:placeholder` - Placeholder text\n- `:on_change` - Function to call when value changes\n- `:style` - Style options for the input","title":"Options - Raxol.View.Components.text_input/1","ref":"Raxol.View.Components.html#text_input/1-options"},{"type":"function","doc":"text_input(value: name, placeholder: \"Enter your name\", on_change: &handle_name_change/1)","title":"Example - Raxol.View.Components.text_input/1","ref":"Raxol.View.Components.html#text_input/1-example"},{"type":"module","doc":"Basic UI elements for Raxol views.\n\nThis module defines the core UI elements that can be used\nin Raxol views.","title":"Raxol.View.Elements","ref":"Raxol.View.Elements.html"},{"type":"macro","doc":"Creates a box container, often used for bordering or grouping.","title":"Raxol.View.Elements.box/2","ref":"Raxol.View.Elements.html#box/2"},{"type":"macro","doc":"* `:style` - Map containing styling attributes (e.g., border, padding)","title":"Options - Raxol.View.Elements.box/2","ref":"Raxol.View.Elements.html#box/2-options"},{"type":"macro","doc":"```elixir\nbox style: %{border: :single, padding: 1} do\n  text content: \"Content inside the box\"\nend\n```","title":"Example - Raxol.View.Elements.box/2","ref":"Raxol.View.Elements.html#box/2-example"},{"type":"macro","doc":"Creates a button that can be clicked.","title":"Raxol.View.Elements.button/1","ref":"Raxol.View.Elements.html#button/1"},{"type":"macro","doc":"* `:label` - The button text\n* `:on_click` - The message to send when clicked","title":"Options - Raxol.View.Elements.button/1","ref":"Raxol.View.Elements.html#button/1-options"},{"type":"macro","doc":"```elixir\nbutton label: \"Click me\", on_click: :button_clicked\n```","title":"Example - Raxol.View.Elements.button/1","ref":"Raxol.View.Elements.html#button/1-example"},{"type":"macro","doc":"Creates a checkbox.","title":"Raxol.View.Elements.checkbox/1","ref":"Raxol.View.Elements.html#checkbox/1"},{"type":"macro","doc":"* `:checked` - Whether the checkbox is checked\n* `:label` - The checkbox label\n* `:on_toggle` - Function to call when toggled","title":"Options - Raxol.View.Elements.checkbox/1","ref":"Raxol.View.Elements.html#checkbox/1-options"},{"type":"macro","doc":"```elixir\ncheckbox checked: model.agreed, label: \"I agree to terms\", on_toggle: fn value -> {:update_agreed, value} end\n```","title":"Example - Raxol.View.Elements.checkbox/1","ref":"Raxol.View.Elements.html#checkbox/1-example"},{"type":"macro","doc":"Creates a column layout for vertical arrangement.","title":"Raxol.View.Elements.column/2","ref":"Raxol.View.Elements.html#column/2"},{"type":"macro","doc":"* `:size` - The column size (1-12)","title":"Options - Raxol.View.Elements.column/2","ref":"Raxol.View.Elements.html#column/2-options"},{"type":"macro","doc":"```elixir\ncolumn size: 6 do\n  label content: \"Half width\"\nend\n```","title":"Example - Raxol.View.Elements.column/2","ref":"Raxol.View.Elements.html#column/2-example"},{"type":"macro","doc":"Creates a text input field.","title":"Raxol.View.Elements.input/1","ref":"Raxol.View.Elements.html#input/1"},{"type":"macro","doc":"* `:value` - The current input value\n* `:cursor` - The cursor position\n* `:focused` - Whether the input is focused\n* `:placeholder` - Placeholder text\n* `:password` - Whether to mask the input (boolean)","title":"Options - Raxol.View.Elements.input/1","ref":"Raxol.View.Elements.html#input/1-options"},{"type":"macro","doc":"Creates a text label.","title":"Raxol.View.Elements.label/1","ref":"Raxol.View.Elements.html#label/1"},{"type":"macro","doc":"* `:content` - The label text\n* Other options are passed as attributes","title":"Options - Raxol.View.Elements.label/1","ref":"Raxol.View.Elements.html#label/1-options"},{"type":"macro","doc":"Creates a panel with a title and content.","title":"Raxol.View.Elements.panel/2","ref":"Raxol.View.Elements.html#panel/2"},{"type":"macro","doc":"* `:title` - The panel title\n* `:height` - The panel height (optional)\n* `:width` - The panel width (optional)","title":"Options - Raxol.View.Elements.panel/2","ref":"Raxol.View.Elements.html#panel/2-options"},{"type":"macro","doc":"```elixir\npanel title: \"Information\" do\n  label content: \"Some information\"\nend\n```","title":"Example - Raxol.View.Elements.panel/2","ref":"Raxol.View.Elements.html#panel/2-example"},{"type":"macro","doc":"Creates a row layout for horizontal arrangement.","title":"Raxol.View.Elements.row/2","ref":"Raxol.View.Elements.html#row/2"},{"type":"macro","doc":"```elixir\nrow do\n  label content: \"Left\"\n  label content: \"Right\"\nend\n```","title":"Example - Raxol.View.Elements.row/2","ref":"Raxol.View.Elements.html#row/2-example"},{"type":"macro","doc":"Creates a table for displaying tabular data.","title":"Raxol.View.Elements.table/1","ref":"Raxol.View.Elements.html#table/1"},{"type":"macro","doc":"* `:headers` - List of column headers\n* `:data` - List of rows, where each row is a list of cells","title":"Options - Raxol.View.Elements.table/1","ref":"Raxol.View.Elements.html#table/1-options"},{"type":"macro","doc":"```elixir\ntable headers: [\"Name\", \"Age\", \"City\"], data: [[\"John\", \"25\", \"New York\"], [\"Jane\", \"30\", \"San Francisco\"]]\n```","title":"Example - Raxol.View.Elements.table/1","ref":"Raxol.View.Elements.html#table/1-example"},{"type":"macro","doc":"Creates a text input field.","title":"Raxol.View.Elements.text_input/1","ref":"Raxol.View.Elements.html#text_input/1"},{"type":"macro","doc":"* `:value` - The current input value\n* `:placeholder` - Placeholder text\n* `:on_change` - Function to call when value changes","title":"Options - Raxol.View.Elements.text_input/1","ref":"Raxol.View.Elements.html#text_input/1-options"},{"type":"macro","doc":"```elixir\ntext_input value: model.name, placeholder: \"Enter your name\", on_change: fn value -> {:update_name, value} end\n```","title":"Example - Raxol.View.Elements.text_input/1","ref":"Raxol.View.Elements.html#text_input/1-example"},{"type":"module","doc":"Provides layout functions for Raxol views.\n\nThis module previously contained functions for creating layout components\nthat can be used in Raxol views.\nThese have been superseded by macros in `Raxol.View.Elements`.","title":"Raxol.View.Layout","ref":"Raxol.View.Layout.html"},{"type":"module","doc":"Manages authentication state and operations for the Raxol application.","title":"Raxol.Web.Auth.Manager","ref":"Raxol.Web.Auth.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Web.Auth.Manager.child_spec/1","ref":"Raxol.Web.Auth.Manager.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Web.Auth.Manager.init/1","ref":"Raxol.Web.Auth.Manager.html#init/1"},{"type":"function","doc":"","title":"Raxol.Web.Auth.Manager.start_link/1","ref":"Raxol.Web.Auth.Manager.html#start_link/1"},{"type":"module","doc":"Manages web sessions and terminal connections for the Raxol application.","title":"Raxol.Web.Manager","ref":"Raxol.Web.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Web.Manager.child_spec/1","ref":"Raxol.Web.Manager.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Web.Manager.init/1","ref":"Raxol.Web.Manager.html#init/1"},{"type":"function","doc":"","title":"Raxol.Web.Manager.start_link/1","ref":"Raxol.Web.Manager.html#start_link/1"},{"type":"module","doc":"Handles session cleanup for Raxol applications.\n\nThis module provides functionality to clean up expired and inactive sessions,\nensuring efficient resource usage and data hygiene.","title":"Raxol.Web.Session.Cleanup","ref":"Raxol.Web.Session.Cleanup.html"},{"type":"function","doc":"Clean up expired sessions.","title":"Raxol.Web.Session.Cleanup.cleanup_expired_sessions/0","ref":"Raxol.Web.Session.Cleanup.html#cleanup_expired_sessions/0"},{"type":"function","doc":"Clean up old sessions.","title":"Raxol.Web.Session.Cleanup.cleanup_old_sessions/1","ref":"Raxol.Web.Session.Cleanup.html#cleanup_old_sessions/1"},{"type":"function","doc":"Clean up orphaned sessions.","title":"Raxol.Web.Session.Cleanup.cleanup_orphaned_sessions/0","ref":"Raxol.Web.Session.Cleanup.html#cleanup_orphaned_sessions/0"},{"type":"function","doc":"Initialize the session cleanup system.","title":"Raxol.Web.Session.Cleanup.init/0","ref":"Raxol.Web.Session.Cleanup.html#init/0"},{"type":"module","doc":"Manages web sessions for Raxol applications.\n\nThis module provides comprehensive session management capabilities:\n* Session storage and retrieval\n* Session recovery and cleanup\n* Session limits and monitoring\n* Session metadata management","title":"Raxol.Web.Session.Manager","ref":"Raxol.Web.Session.Manager.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Web.Session.Manager.child_spec/1","ref":"Raxol.Web.Session.Manager.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.cleanup_sessions/0","ref":"Raxol.Web.Session.Manager.html#cleanup_sessions/0"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.create_session/2","ref":"Raxol.Web.Session.Manager.html#create_session/2"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.end_session/1","ref":"Raxol.Web.Session.Manager.html#end_session/1"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.get_active_sessions/0","ref":"Raxol.Web.Session.Manager.html#get_active_sessions/0"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.get_session/1","ref":"Raxol.Web.Session.Manager.html#get_session/1"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.start_link/1","ref":"Raxol.Web.Session.Manager.html#start_link/1"},{"type":"function","doc":"","title":"Raxol.Web.Session.Manager.update_session/2","ref":"Raxol.Web.Session.Manager.html#update_session/2"},{"type":"module","doc":"Handles session monitoring for Raxol applications.\n\nThis module provides functionality to monitor active sessions, track usage\npatterns, and detect potential issues.","title":"Raxol.Web.Session.Monitor","ref":"Raxol.Web.Session.Monitor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Web.Session.Monitor.child_spec/1","ref":"Raxol.Web.Session.Monitor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Web.Session.Monitor.get_active_users/0","ref":"Raxol.Web.Session.Monitor.html#get_active_users/0"},{"type":"function","doc":"","title":"Raxol.Web.Session.Monitor.get_session_stats/0","ref":"Raxol.Web.Session.Monitor.html#get_session_stats/0"},{"type":"function","doc":"","title":"Raxol.Web.Session.Monitor.start_link/1","ref":"Raxol.Web.Session.Monitor.html#start_link/1"},{"type":"module","doc":"Handles session recovery for Raxol applications.\n\nThis module provides functionality to recover sessions after crashes or\nunexpected terminations, ensuring session continuity and data integrity.","title":"Raxol.Web.Session.Recovery","ref":"Raxol.Web.Session.Recovery.html"},{"type":"function","doc":"Initialize the session recovery system.","title":"Raxol.Web.Session.Recovery.init/0","ref":"Raxol.Web.Session.Recovery.html#init/0"},{"type":"function","doc":"Recover a specific session.","title":"Raxol.Web.Session.Recovery.recover_session/1","ref":"Raxol.Web.Session.Recovery.html#recover_session/1"},{"type":"module","doc":"Database schema for session storage.","title":"Raxol.Web.Session.Session","ref":"Raxol.Web.Session.Session.html"},{"type":"function","doc":"Creates a changeset for a session.","title":"Raxol.Web.Session.Session.changeset/2","ref":"Raxol.Web.Session.Session.html#changeset/2"},{"type":"module","doc":"Handles session storage and retrieval for Raxol applications.\n\nThis module provides persistent storage for session data using ETS tables\nand optional database storage for long-term persistence.","title":"Raxol.Web.Session.Storage","ref":"Raxol.Web.Session.Storage.html"},{"type":"function","doc":"Delete a session from storage.","title":"Raxol.Web.Session.Storage.delete/1","ref":"Raxol.Web.Session.Storage.html#delete/1"},{"type":"function","doc":"Retrieve a session from storage.","title":"Raxol.Web.Session.Storage.get/1","ref":"Raxol.Web.Session.Storage.html#get/1"},{"type":"function","doc":"Get all active sessions.","title":"Raxol.Web.Session.Storage.get_active_sessions/0","ref":"Raxol.Web.Session.Storage.html#get_active_sessions/0"},{"type":"function","doc":"Get all expired sessions.","title":"Raxol.Web.Session.Storage.get_expired_sessions/1","ref":"Raxol.Web.Session.Storage.html#get_expired_sessions/1"},{"type":"function","doc":"Initialize the session storage system.","title":"Raxol.Web.Session.Storage.init/0","ref":"Raxol.Web.Session.Storage.html#init/0"},{"type":"function","doc":"Store a session in the storage system.","title":"Raxol.Web.Session.Storage.store/1","ref":"Raxol.Web.Session.Storage.html#store/1"},{"type":"module","doc":"Supervisor for web-related processes.","title":"Raxol.Web.Supervisor","ref":"Raxol.Web.Supervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Raxol.Web.Supervisor.child_spec/1","ref":"Raxol.Web.Supervisor.html#child_spec/1"},{"type":"function","doc":"","title":"Raxol.Web.Supervisor.start_link/1","ref":"Raxol.Web.Supervisor.html#start_link/1"},{"type":"module","doc":"The entrypoint for defining your web interface, such\nas controllers, components, channels, and so on.\n\nThis can be used in your application as:\n\n    use RaxolWeb, :controller\n    use RaxolWeb, :live_view\n    use RaxolWeb, :live_component\n    use RaxolWeb, :channel\n\nThe definitions below will be executed for every component,\ncontroller, etc, so keep them short and clean, focused\non imports, uses and aliases.","title":"RaxolWeb","ref":"RaxolWeb.html"},{"type":"macro","doc":"When used, dispatch to the appropriate controller/view/etc.","title":"RaxolWeb.__using__/1","ref":"RaxolWeb.html#__using__/1"},{"type":"function","doc":"","title":"RaxolWeb.channel/0","ref":"RaxolWeb.html#channel/0"},{"type":"function","doc":"","title":"RaxolWeb.controller/0","ref":"RaxolWeb.html#controller/0"},{"type":"function","doc":"","title":"RaxolWeb.live_component/0","ref":"RaxolWeb.html#live_component/0"},{"type":"function","doc":"","title":"RaxolWeb.live_view/0","ref":"RaxolWeb.html#live_view/0"},{"type":"function","doc":"","title":"RaxolWeb.router/0","ref":"RaxolWeb.html#router/0"},{"type":"function","doc":"","title":"RaxolWeb.static_paths/0","ref":"RaxolWeb.html#static_paths/0"},{"type":"function","doc":"","title":"RaxolWeb.verified_routes/0","ref":"RaxolWeb.html#verified_routes/0"},{"type":"function","doc":"","title":"RaxolWeb.view/0","ref":"RaxolWeb.html#view/0"},{"type":"module","doc":"","title":"RaxolWeb.AccessibilityComponent","ref":"RaxolWeb.AccessibilityComponent.html"},{"type":"function","doc":"","title":"RaxolWeb.AccessibilityComponent.handle_event/3","ref":"RaxolWeb.AccessibilityComponent.html#handle_event/3"},{"type":"function","doc":"","title":"RaxolWeb.AccessibilityComponent.render/1","ref":"RaxolWeb.AccessibilityComponent.html#render/1"},{"type":"module","doc":"","title":"RaxolWeb.AuthPlug","ref":"RaxolWeb.AuthPlug.html"},{"type":"function","doc":"","title":"RaxolWeb.AuthPlug.call/2","ref":"RaxolWeb.AuthPlug.html#call/2"},{"type":"function","doc":"","title":"RaxolWeb.AuthPlug.init/1","ref":"RaxolWeb.AuthPlug.html#init/1"},{"type":"module","doc":"Provides core UI components for the Raxol web interface.","title":"RaxolWeb.CoreComponents","ref":"RaxolWeb.CoreComponents.html"},{"type":"function","doc":"Renders a button with the given text and options.","title":"RaxolWeb.CoreComponents.button/1","ref":"RaxolWeb.CoreComponents.html#button/1"},{"type":"function","doc":"* `type` (`:string`) - Defaults to `\"button\"`.\n* `class` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"form\", \"name\", \"value\"]`.","title":"Attributes - RaxolWeb.CoreComponents.button/1","ref":"RaxolWeb.CoreComponents.html#button/1-attributes"},{"type":"function","doc":"* `inner_block` (required)","title":"Slots - RaxolWeb.CoreComponents.button/1","ref":"RaxolWeb.CoreComponents.html#button/1-slots"},{"type":"function","doc":"Renders a flash message.","title":"RaxolWeb.CoreComponents.flash/1","ref":"RaxolWeb.CoreComponents.html#flash/1"},{"type":"function","doc":"* `kind` (`:string`) (required)\n* `title` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"phx-click\", \"phx-value\"]`.","title":"Attributes - RaxolWeb.CoreComponents.flash/1","ref":"RaxolWeb.CoreComponents.html#flash/1-attributes"},{"type":"function","doc":"* `inner_block` (required)","title":"Slots - RaxolWeb.CoreComponents.flash/1","ref":"RaxolWeb.CoreComponents.html#flash/1-slots"},{"type":"function","doc":"Renders a form group with a label and input.","title":"RaxolWeb.CoreComponents.form_group/1","ref":"RaxolWeb.CoreComponents.html#form_group/1"},{"type":"function","doc":"* `name` (`:string`) (required)\n* `label` (`:string`) (required)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `value` (`:any`)\n* `placeholder` (`:string`) - Defaults to `nil`.\n* `class` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"form\", \"required\"]`.","title":"Attributes - RaxolWeb.CoreComponents.form_group/1","ref":"RaxolWeb.CoreComponents.html#form_group/1-attributes"},{"type":"function","doc":"Renders a form input with the given type and options.","title":"RaxolWeb.CoreComponents.input/1","ref":"RaxolWeb.CoreComponents.html#input/1"},{"type":"function","doc":"* `type` (`:string`) - Defaults to `\"text\"`.\n* `name` (`:string`) (required)\n* `value` (`:any`)\n* `placeholder` (`:string`) - Defaults to `nil`.\n* `class` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"form\", \"required\"]`.","title":"Attributes - RaxolWeb.CoreComponents.input/1","ref":"RaxolWeb.CoreComponents.html#input/1-attributes"},{"type":"function","doc":"Renders a label for a form input.","title":"RaxolWeb.CoreComponents.label/1","ref":"RaxolWeb.CoreComponents.html#label/1"},{"type":"function","doc":"* `for` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.","title":"Attributes - RaxolWeb.CoreComponents.label/1","ref":"RaxolWeb.CoreComponents.html#label/1-attributes"},{"type":"function","doc":"* `inner_block` (required)","title":"Slots - RaxolWeb.CoreComponents.label/1","ref":"RaxolWeb.CoreComponents.html#label/1-slots"},{"type":"module","doc":"","title":"RaxolWeb.Endpoint","ref":"RaxolWeb.Endpoint.html"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.broadcast/3","ref":"RaxolWeb.Endpoint.html#broadcast/3"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.broadcast!/3","ref":"RaxolWeb.Endpoint.html#broadcast!/3"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.broadcast_from/4","ref":"RaxolWeb.Endpoint.html#broadcast_from/4"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.broadcast_from!/4","ref":"RaxolWeb.Endpoint.html#broadcast_from!/4"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.call/2","ref":"RaxolWeb.Endpoint.html#call/2"},{"type":"function","doc":"Returns the child specification to start the endpoint\nunder a supervision tree.","title":"RaxolWeb.Endpoint.child_spec/1","ref":"RaxolWeb.Endpoint.html#child_spec/1"},{"type":"function","doc":"Returns the endpoint configuration for `key`\n\nReturns `default` if the key does not exist.","title":"RaxolWeb.Endpoint.config/2","ref":"RaxolWeb.Endpoint.html#config/2"},{"type":"function","doc":"Reloads the configuration given the application environment changes.","title":"RaxolWeb.Endpoint.config_change/2","ref":"RaxolWeb.Endpoint.html#config_change/2"},{"type":"function","doc":"Returns the host for the given endpoint.","title":"RaxolWeb.Endpoint.host/0","ref":"RaxolWeb.Endpoint.html#host/0"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.init/1","ref":"RaxolWeb.Endpoint.html#init/1"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.local_broadcast/3","ref":"RaxolWeb.Endpoint.html#local_broadcast/3"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.local_broadcast_from/4","ref":"RaxolWeb.Endpoint.html#local_broadcast_from/4"},{"type":"function","doc":"Generates the path information when routing to this endpoint.","title":"RaxolWeb.Endpoint.path/1","ref":"RaxolWeb.Endpoint.html#path/1"},{"type":"function","doc":"Generates the script name.","title":"RaxolWeb.Endpoint.script_name/0","ref":"RaxolWeb.Endpoint.html#script_name/0"},{"type":"function","doc":"Returns the address and port that the server is running on","title":"RaxolWeb.Endpoint.server_info/1","ref":"RaxolWeb.Endpoint.html#server_info/1"},{"type":"function","doc":"Starts the endpoint supervision tree.\n\nAll other options are merged into the endpoint configuration.","title":"RaxolWeb.Endpoint.start_link/1","ref":"RaxolWeb.Endpoint.html#start_link/1"},{"type":"function","doc":"Generates a base64-encoded cryptographic hash (sha512) to a static file\nin `priv/static`. Meant to be used for Subresource Integrity with CDNs.","title":"RaxolWeb.Endpoint.static_integrity/1","ref":"RaxolWeb.Endpoint.html#static_integrity/1"},{"type":"function","doc":"Returns a two item tuple with the first item being the `static_path`\nand the second item being the `static_integrity`.","title":"RaxolWeb.Endpoint.static_lookup/1","ref":"RaxolWeb.Endpoint.html#static_lookup/1"},{"type":"function","doc":"Generates a route to a static file in `priv/static`.","title":"RaxolWeb.Endpoint.static_path/1","ref":"RaxolWeb.Endpoint.html#static_path/1"},{"type":"function","doc":"Generates the static URL without any path information.\n\nIt uses the configuration under `:static_url` to generate\nsuch. It falls back to `:url` if `:static_url` is not set.","title":"RaxolWeb.Endpoint.static_url/0","ref":"RaxolWeb.Endpoint.html#static_url/0"},{"type":"function","doc":"Generates the endpoint base URL but as a `URI` struct.\n\nIt uses the configuration under `:url` to generate such.\nUseful for manipulating the URL data and passing it to\nURL helpers.","title":"RaxolWeb.Endpoint.struct_url/0","ref":"RaxolWeb.Endpoint.html#struct_url/0"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.subscribe/2","ref":"RaxolWeb.Endpoint.html#subscribe/2"},{"type":"function","doc":"","title":"RaxolWeb.Endpoint.unsubscribe/1","ref":"RaxolWeb.Endpoint.html#unsubscribe/1"},{"type":"function","doc":"Generates the endpoint base URL without any path information.\n\nIt uses the configuration under `:url` to generate such.","title":"RaxolWeb.Endpoint.url/0","ref":"RaxolWeb.Endpoint.html#url/0"},{"type":"module","doc":"A module providing Internationalization with a gettext-based API.","title":"RaxolWeb.Gettext","ref":"RaxolWeb.Gettext.html"},{"type":"function","doc":"","title":"RaxolWeb.Gettext.handle_missing_bindings/2","ref":"RaxolWeb.Gettext.html#handle_missing_bindings/2"},{"type":"function","doc":"","title":"RaxolWeb.Gettext.handle_missing_plural_translation/7","ref":"RaxolWeb.Gettext.html#handle_missing_plural_translation/7"},{"type":"function","doc":"","title":"RaxolWeb.Gettext.handle_missing_translation/5","ref":"RaxolWeb.Gettext.html#handle_missing_translation/5"},{"type":"module","doc":"","title":"RaxolWeb.LoginLive","ref":"RaxolWeb.LoginLive.html"},{"type":"function","doc":"","title":"RaxolWeb.LoginLive.render/1","ref":"RaxolWeb.LoginLive.html#render/1"},{"type":"module","doc":"","title":"RaxolWeb.MonitoringLive","ref":"RaxolWeb.MonitoringLive.html"},{"type":"function","doc":"","title":"RaxolWeb.MonitoringLive.render/1","ref":"RaxolWeb.MonitoringLive.html#render/1"},{"type":"module","doc":"","title":"RaxolWeb.PageController","ref":"RaxolWeb.PageController.html"},{"type":"function","doc":"","title":"RaxolWeb.PageController.home/2","ref":"RaxolWeb.PageController.html#home/2"},{"type":"module","doc":"","title":"RaxolWeb.PageLive","ref":"RaxolWeb.PageLive.html"},{"type":"function","doc":"","title":"RaxolWeb.PageLive.handle_event/3","ref":"RaxolWeb.PageLive.html#handle_event/3"},{"type":"function","doc":"","title":"RaxolWeb.PageLive.handle_params/3","ref":"RaxolWeb.PageLive.html#handle_params/3"},{"type":"function","doc":"","title":"RaxolWeb.PageLive.mount/3","ref":"RaxolWeb.PageLive.html#mount/3"},{"type":"module","doc":"View module for pages served by PageController.","title":"RaxolWeb.PageView","ref":"RaxolWeb.PageView.html"},{"type":"module","doc":"","title":"RaxolWeb.Router","ref":"RaxolWeb.Router.html"},{"type":"function","doc":"","title":"RaxolWeb.Router.api/2","ref":"RaxolWeb.Router.html#api/2"},{"type":"function","doc":"","title":"RaxolWeb.Router.auth/2","ref":"RaxolWeb.Router.html#auth/2"},{"type":"function","doc":"","title":"RaxolWeb.Router.browser/2","ref":"RaxolWeb.Router.html#browser/2"},{"type":"function","doc":"Callback invoked by Plug on every request.","title":"RaxolWeb.Router.call/2","ref":"RaxolWeb.Router.html#call/2"},{"type":"function","doc":"Callback required by Plug that initializes the router\nfor serving web requests.","title":"RaxolWeb.Router.init/1","ref":"RaxolWeb.Router.html#init/1"},{"type":"module","doc":"","title":"RaxolWeb.SettingsLive","ref":"RaxolWeb.SettingsLive.html"},{"type":"function","doc":"","title":"RaxolWeb.SettingsLive.render/1","ref":"RaxolWeb.SettingsLive.html#render/1"},{"type":"module","doc":"","title":"RaxolWeb.Telemetry","ref":"RaxolWeb.Telemetry.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"RaxolWeb.Telemetry.child_spec/1","ref":"RaxolWeb.Telemetry.html#child_spec/1"},{"type":"function","doc":"","title":"RaxolWeb.Telemetry.metrics/0","ref":"RaxolWeb.Telemetry.html#metrics/0"},{"type":"function","doc":"","title":"RaxolWeb.Telemetry.start_link/1","ref":"RaxolWeb.Telemetry.html#start_link/1"},{"type":"module","doc":"WebSocket channel for real-time terminal communication.\n\nThis channel handles:\n- Terminal session initialization\n- Real-time input/output\n- Terminal resizing\n- Session management\n- Error handling","title":"RaxolWeb.TerminalChannel","ref":"RaxolWeb.TerminalChannel.html"},{"type":"function","doc":"","title":"RaxolWeb.TerminalChannel.child_spec/1","ref":"RaxolWeb.TerminalChannel.html#child_spec/1"},{"type":"function","doc":"","title":"RaxolWeb.TerminalChannel.start_link/1","ref":"RaxolWeb.TerminalChannel.html#start_link/1"},{"type":"type","doc":"","title":"RaxolWeb.TerminalChannel.t/0","ref":"RaxolWeb.TerminalChannel.html#t:t/0"},{"type":"module","doc":"LiveView component for the terminal interface.\n\nThis component provides:\n- Terminal rendering\n- Input handling\n- Resize management\n- Theme customization\n- Scroll management\n- Session management","title":"RaxolWeb.TerminalLive","ref":"RaxolWeb.TerminalLive.html"},{"type":"module","doc":"","title":"RaxolWeb.ThemeToggleComponent","ref":"RaxolWeb.ThemeToggleComponent.html"},{"type":"function","doc":"","title":"RaxolWeb.ThemeToggleComponent.handle_event/3","ref":"RaxolWeb.ThemeToggleComponent.html#handle_event/3"},{"type":"function","doc":"","title":"RaxolWeb.ThemeToggleComponent.render/1","ref":"RaxolWeb.ThemeToggleComponent.html#render/1"},{"type":"module","doc":"Provides authentication plugs and helpers.","title":"RaxolWeb.UserAuth","ref":"RaxolWeb.UserAuth.html"},{"type":"function","doc":"Authenticates the user by looking into the session\nand remember me token.","title":"RaxolWeb.UserAuth.fetch_current_user/2","ref":"RaxolWeb.UserAuth.html#fetch_current_user/2"},{"type":"function","doc":"Logs the user in.\n\nIt renews the session ID and clears the whole session\nto avoid fixation attacks. See the renew_session\nfunction to customize this behaviour.\n\nIt also sets a `:live_socket_id` key in the session,\nso LiveView sessions are identified and automatically\ndisconnected on log out. The line can be safely removed\nif you are not using LiveView.","title":"RaxolWeb.UserAuth.log_in_user/3","ref":"RaxolWeb.UserAuth.html#log_in_user/3"},{"type":"function","doc":"Logs the user out.\n\nIt clears all session data for safety. See renew_session.","title":"RaxolWeb.UserAuth.log_out_user/1","ref":"RaxolWeb.UserAuth.html#log_out_user/1"},{"type":"function","doc":"Used for routes that require the user to not be authenticated.","title":"RaxolWeb.UserAuth.redirect_if_user_is_authenticated/2","ref":"RaxolWeb.UserAuth.html#redirect_if_user_is_authenticated/2"},{"type":"function","doc":"Used for routes that require the user to be authenticated.\n\nIf you want to enforce the user email is confirmed before\nthey use the application at all, here would be a good place.","title":"RaxolWeb.UserAuth.require_authenticated_user/2","ref":"RaxolWeb.UserAuth.html#require_authenticated_user/2"},{"type":"module","doc":"Handles user registration.","title":"RaxolWeb.UserRegistrationController","ref":"RaxolWeb.UserRegistrationController.html"},{"type":"function","doc":"","title":"RaxolWeb.UserRegistrationController.create/2","ref":"RaxolWeb.UserRegistrationController.html#create/2"},{"type":"function","doc":"","title":"RaxolWeb.UserRegistrationController.new/2","ref":"RaxolWeb.UserRegistrationController.html#new/2"},{"type":"module","doc":"Handles user session management (login/logout).","title":"RaxolWeb.UserSessionController","ref":"RaxolWeb.UserSessionController.html"},{"type":"function","doc":"","title":"RaxolWeb.UserSessionController.create/2","ref":"RaxolWeb.UserSessionController.html#create/2"},{"type":"function","doc":"","title":"RaxolWeb.UserSessionController.delete/2","ref":"RaxolWeb.UserSessionController.html#delete/2"},{"type":"function","doc":"","title":"RaxolWeb.UserSessionController.new/2","ref":"RaxolWeb.UserSessionController.html#new/2"},{"type":"module","doc":"","title":"RaxolWeb.UserSocket","ref":"RaxolWeb.UserSocket.html"},{"type":"function","doc":"Identifies the socket connections.\n\nSocket params are passed from the client and can\nbe used to verify and authenticate a user.\n\nTo connect, url: \"ws://localhost:4000/socket/websocket?user_id=123\"","title":"RaxolWeb.UserSocket.connect/3","ref":"RaxolWeb.UserSocket.html#connect/3"},{"type":"function","doc":"Identifies the socket connections.","title":"RaxolWeb.UserSocket.id/1","ref":"RaxolWeb.UserSocket.html#id/1"},{"type":"extras","doc":"# Raxol\n\n[![Hex pm](https://img.shields.io/hexpm/v/raxol.svg)](https://hex.pm/packages/raxol)\n[![GitHub Actions CI](https://github.com/Hydepwns/raxol/actions/workflows/ci.yml/badge.svg)](https://github.com/Hydepwns/raxol/actions/workflows/ci.yml)\n\n**Raxol** is a modern toolkit for building interactive terminal (TUI) applications in Elixir.\nIt offers a powerful component system, a flexible runtime, and a robust plugin architecture—making it easy to create beautiful, responsive terminal UIs.\n\n> **Note:** Raxol is in active development (pre-release).\n> APIs will change as we improve the toolkit.\n>\n> <!-- TODO: Add a screenshot or GIF demo here -->","title":"Raxol","ref":"readme.html"},{"type":"extras","doc":"- **Component Model:** Build UIs from reusable, stateful components.\n- **Declarative View DSL:** Compose layouts with expressive macros (`panel`, `row`, `column`, `text`, etc.).\n- **Lifecycle Management:** Each component supports a full lifecycle (`init`, `mount`, `update`, `render`, `handle_event`, `unmount`).\n- **Theming & Preferences:** Customizable themes and persistent user settings.\n- **Plugin System:** Extend Raxol with hot-reloadable plugins and robust error handling.\n- **Terminal Handling:** Advanced ANSI/Sixel support, input handling, and double buffering.\n- **Performance & Testing:** Built-in benchmarking, event-based test helpers, and system interaction adapters for reliable, fast tests.","title":"✨ Features - Raxol","ref":"readme.html#features"},{"type":"extras","doc":"Add Raxol to your `mix.exs`:\n\n```elixir\n# mix.exs, check hex.pm/packages/raxol\ndef deps do\n  [\n    {:raxol, \"~> 0.3.0\"}\n  ]\nend\n```","title":"🚀 Get Started - Raxol","ref":"readme.html#get-started"},{"type":"extras","doc":"```bash\n# Fetch dependencies\nmix deps.get\n\n# Run tests\nmix test\nmix test.watch\nmix credo\nmix dialyzer\nmix format\nmix compile --warnings-as-errors\n```","title":"Common Commands - Raxol","ref":"readme.html#common-commands"},{"type":"extras","doc":"```elixir\ndefmodule ExampleApp do\n  use Raxol.Core.Runtime.Application\n  import Raxol.View.Elements\n\n  @impl true\n  def init(_), do: {:ok, %{count: 0}}\n\n  # Raxol event handling\n  @impl true\n  def update(:increment, state), do: {:ok, %{state | count: state.count + 1}, []}\n  def update(:decrement, state), do: {:ok, %{state | count: state.count - 1}, []}\n  def update(_, state), do: {:ok, state, []}\n\n  # Raxol view DSL\n  @impl true\n  def view(state) do\n    view do\n      panel title: \"Counter\" do\n        row do\n          button(label: \"-\", on_click: :decrement)\n          text(content: \"Count: #{state.count}\")\n          button(label: \"+\", on_click: :increment)\n        end\n      end\n    end\n  end\nend\n\n# Starts ExampleApp\nRaxol.start_link(ExampleApp)\n```\n\n> **Above example uses Raxol view DSL**, which lets you build TUI layouts and UI elements declaratively using Elixir macros.\n> Compose layouts and UI elements with a syntax _similar_ to HTML— but in pure, undiddled, and unopinionated Elixir.\n\n**How the View DSL works:**\n\n- `panel/1` – Draws a bordered panel with an optional title.\n- `row/1` and `column/1` – Arrange child elements horizontally or vertically.\n- `button/1` – Interactive button with label and event handler.\n- `text/1` – Displays static or dynamic text.\n\nYou can nest these macros to create complex layouts.\nAll properties (like `title`, `label`, `on_click`, etc.) are passed as keyword lists.\nFor more, see the [UI Components & Layout Guide](docs/guides/03_components_and_layout/components/README.md).","title":"🛠️ Example: A Simple Counter App - Raxol","ref":"readme.html#example-a-simple-counter-app"},{"type":"extras","doc":"- [Accessibility Guide](docs/guides/05_development_and_testing/development/planning/accessibility/accessibility_guide.md)\n- [Architecture Overview](docs/ARCHITECTURE.md)\n- [Changelog](CHANGELOG.md)\n- [Docs Index](docs/README.md)\n- [Plugin Development](docs/guides/04_extending_raxol/plugin_development.md)\n- [Testing Guide](docs/guides/05_development_and_testing/testing.md)\n- [Terminal Details](docs/guides/02_core_concepts/terminal/README.md)\n- [VS Code Extension](docs/guides/04_extending_raxol/vscode_extension.md)","title":"📚 Resources - Raxol","ref":"readme.html#resources"},{"type":"extras","doc":"MIT © 2024 Raxol Team","title":"License - Raxol","ref":"readme.html#license"},{"type":"extras","doc":"---\ntitle: Quick Start Guide\ndescription: Create your first Raxol application\ndate: 2025-04-27\nauthor: Raxol Team\nsection: guides\ntags: [quick start, guide, tutorial, application, components]\n---\n\n# Quick Start Guide: Your First Raxol App\n\nThis guide walks you through creating a simple stateful counter application using Raxol.","title":"quick_start","ref":"quick_start.html"},{"type":"extras","doc":"Before you start, ensure you have:\n\n1. **Elixir installed:** Raxol requires Elixir. You can find installation instructions on the [official Elixir website](https://elixir-lang.org/install.html).\n2. **A new Mix project (optional):** If you don't have a project, create one:\n\n   ```bash\n   mix new my_raxol_app\n   cd my_raxol_app\n   ```","title":"Prerequisites - quick_start","ref":"quick_start.html#prerequisites"},{"type":"extras","doc":"First, add `raxol` to your project's dependencies. Open your `mix.exs` file and update the `deps` function:\n\n```elixir\ndef deps do\n  [\n    {:raxol, \"~> 0.1.0\"}\n    # Or {:raxol, github: \"Hydepwns/raxol\"} for the latest code\n  ]\nend\n```\n\nThen, fetch the dependency:\n\n```bash\nmix deps.get\n```\n\nFor more details, see the [Development Setup](/docs/guides/05_development_and_testing/DevelopmentSetup.md).","title":"1. Add Raxol Dependency - quick_start","ref":"quick_start.html#1-add-raxol-dependency"},{"type":"extras","doc":"Create a new Elixir file, for example, `lib/my_raxol_app/application.ex`, and define your application module. This module will use `Raxol.Core.Runtime.Application` and implement the `render/1` callback to define the user interface.\n\nRaxol offers two primary ways to define your UI within the `render/1` function:\n\n**Method 1: Using the HEEx Sigil (`~H`)**\n\nThis approach uses a syntax similar to HTML and is often convenient for static structures or when integrating with HEEx templates.\n\n```elixir\n# lib/my_raxol_app/application.ex\ndefmodule MyRaxolApp.Application do\n  use Raxol.Core.Runtime.Application\n\n  # The render/1 callback defines the UI.\n  # It receives assigns (data) and must return rendered content.\n  @impl true\n  def render(assigns) do\n    ~H\"\"\"\n     \n       Hello from HEEx! \n     \n    \"\"\"\n  end\nend\n```\n\n- `use Raxol.Core.Runtime.Application`: Imports necessary functions and defines the behaviour for a Raxol application.\n- `@impl true def render(assigns)`: Implements the required callback to define the UI structure.\n- `~H\"\"\" ... \"\"\"`: The HEEx sigil defines the component-based UI using HTML-like tags.\n\n**Method 2: Using `Raxol.View` and Component Functions**\n\nThis approach uses standard Elixir function calls for components, often providing more flexibility for programmatically building complex UIs. Many examples in the `/examples` directory use this method.\n\n```elixir\n# lib/my_raxol_app/application_view.ex\ndefmodule MyRaxolApp.ApplicationView do\n  use Raxol.Core.Runtime.Application\n  use Raxol.View # Use Raxol.View for this approach\n  import Raxol.View.Elements # Optional: Import elements for cleaner calls\n\n  @impl true\n  def render(assigns) do\n    # Use the view macro and nested component functions\n    view do\n      box border: :single, padding: 1 do\n        text content: \"Hello from Raxol.View!\", color: :cyan, attributes: [:bold]\n      end\n    end\n  end\nend\n\n```\n\n- `use Raxol.View`: Required to enable the `view` macro and component function syntax.\n- `import Raxol.View.Elements`: Allows calling components like `box` and `text` directly, otherwise you might need `Raxol.View.Elements.box(...)`.\n- `view do ... end`: A macro block containing nested component function calls (e.g., `box(...)`, `text(...)`). Note that attributes are passed as keyword lists or maps.\n\nChoose the method that best suits your needs or project style. Both achieve the same goal of defining the UI.","title":"2. Create Your Application Module - quick_start","ref":"quick_start.html#2-create-your-application-module"},{"type":"extras","doc":"Static UIs are useful, but most terminal applications need to manage state and respond to user input. Raxol handles this using the `init/1` and `update/2` callbacks, inspired by the Elm Architecture.\n\n**1. Initialize State with `init/1`**\n\nThe `init/1` callback is called once when the application starts. It should return the initial state of your application.\n\n**2. Handle Messages with `update/2`**\n\nThe `update/2` callback is triggered when a message is sent to your application (e.g., from a button click or a subscription). It receives the message and the current state, and returns the _new_ state. Optionally, it can also return a `Command` for executing background tasks (see `examples/advanced/commands.exs`).\n\n**3. Render State in `render/1`**\n\nThe `render/1` callback receives the current state (as `assigns`) and uses it to draw the UI.\n\n**Example: A Simple Counter**\n\nLet's modify our application to be a counter. We'll use the `Raxol.View` method here for illustration.\n\n```elixir\n# lib/my_raxol_app/counter.ex\ndefmodule MyRaxolApp.Counter do\n  use Raxol.Core.Runtime.Application\n  use Raxol.View\n  import Raxol.View.Elements\n\n  # 1. Define the initial state\n  @impl true\n  def init(_context), do: %{count: 0}\n\n  # 2. Handle messages to update the state\n  @impl true\n  def update(model, message) do\n    case message do\n      :increment ->\n        %{model | count: model.count + 1}\n      _ ->\n        model # Return the unchanged model for other messages\n    end\n  end\n\n  # 3. Render the UI based on the current state\n  @impl true\n  def render(assigns) do\n    view do\n      box border: :single, padding: 1 do\n        # Display the current count from assigns (state)\n        text content: \"Count: \\#{assigns.count}\"\n        # Add a button that sends the :increment message when clicked\n        button label: \"Increment\", on_click: :increment\n      end\n    end\n  end\nend\n```\n\n- `init/1` returns the initial state `%{count: 0}`.\n- `update/2` handles the `:increment` message by returning a new state map with the count increased.\n- `render/1` now uses `assigns.count` to display the value and includes a ` ` component.\n- The `button` has an `on_click: :increment` attribute. When clicked, Raxol sends the `:increment` message to the `update/2` function.\n\n**Subscriptions (`subscribe/1`)**\n\nFor handling external events like timers or keyboard events not tied to specific components, you can implement the `subscribe/1` callback. It returns subscriptions that send messages to `update/2`. See `examples/basic/subscriptions.exs` for details and the [Async Operations Guide](/docs/guides/02_core_concepts/async_operations.md) for a full explanation.","title":"2.5 Adding State and Interactivity (init, update) - quick_start","ref":"quick_start.html#2-5-adding-state-and-interactivity-init-update"},{"type":"extras","doc":"To run your application, you can start it directly in `iex` using the new `Lifecycle` module:\n\n```elixir\n  Raxol.Core.Runtime.Lifecycle.start_application(MyRaxolApp.Counter)\n# {:ok, #PID<0.xxx.0>}\n```\n\nFor long-running applications, you'll typically add the `Raxol.Core.Runtime.Application` to your application's supervision tree (e.g., in `lib/my_raxol_app/application.ex` if you used `mix new --sup`):\n\n```elixir\ndefmodule MyRaxolApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Other children...\n      {Raxol.Core.Runtime.Application, app: MyRaxolApp.Counter} # Use the module defined previously\n    ]\n\n    opts = [strategy: :one_for_one, name: MyRaxolApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nMake sure `MyRaxolApp.Application` is listed in your `mix.exs` `application/0` function.","title":"3. Start the Application - quick_start","ref":"quick_start.html#3-start-the-application"},{"type":"extras","doc":"Congratulations! You've built and run your first Raxol application.\n\n- Explore the different built-in [UI Components](/docs/guides/03_components_and_layout/components/README.md).\n- Dive deeper into [Asynchronous Operations (Subscriptions & Commands)](/docs/guides/02_core_concepts/async_operations.md).\n- Configure the application startup using [Runtime Options](/docs/guides/02_core_concepts/runtime_options.md).\n- Check out the `/examples` directory in the Raxol repository for more advanced use cases.","title":"Next Steps - quick_start","ref":"quick_start.html#next-steps"},{"type":"extras","doc":"---\ntitle: VS Code Extension Guide\ndescription: Integrating Raxol with the VS Code Extension.\ndate: 2025-04-27\nauthor: Raxol Team\nsection: guides\ntags: [vscode, extension, integration, guides]\n---\n\n# Raxol VS Code Extension Guide\n\nThis guide explains how to use and develop with the Raxol VS Code Extension, which aims to enable Raxol applications to run within a VS Code WebView panel.\n\n> **Feature Status: Not Implemented**\n> While the VS Code extension frontend exists (`extensions/vscode/`), the corresponding backend logic in the Raxol Elixir application to handle communication via stdio JSON is **currently missing or incomplete**. This guide describes the existing frontend structure and the _intended_ communication protocol, but the integration **does not function** at this time.","title":"vscode_extension","ref":"vscode_extension.html"},{"type":"extras","doc":"- **Purpose:** Allow running and interacting with Raxol terminal applications directly within a VS Code panel.\n- **Intended Mechanism:** Uses a VS Code WebView to display the UI and communicates with a Raxol backend process via stdio using a JSON-based protocol.\n- **Potential Benefits:** Integrated development workflow, easier debugging.","title":"1. Introduction - vscode_extension","ref":"vscode_extension.html#1-introduction"},{"type":"extras","doc":"- **Installation:** Assumed to be via VS Code Marketplace (if published) or manual installation.\n- **Running:** A command like `Raxol: Show Terminal` (registered in `extension.ts`) would launch the panel.\n- **Interaction:** User input in the panel would be sent to the backend; backend render updates would be displayed in the panel.","title":"2. User Guide (Intended) - vscode_extension","ref":"vscode_extension.html#2-user-guide-intended"},{"type":"extras","doc":"- **Location:** `extensions/vscode/`\n- **Architecture:**\n  - **Extension Entry:** `src/extension.ts` handles activation and command registration.\n  - **Panel Management:** `src/RaxolPanelManager.ts` creates/manages the WebView panel, loads HTML (`media/index.html`), JS (`media/main.js`), and CSS (`media/styles.css`), and orchestrates communication between the WebView and the backend manager.\n  - **Backend Process Management:** `src/BackendManager.ts` is responsible for spawning and managing the Raxol Elixir backend process (`mix run --no-halt`) and handling stdio communication with it.\n- **Building Locally:** Requires Node.js/npm. Use `npm install` and standard VS Code extension development workflows (`Run Extension` task).","title":"3. Development Guide (Frontend Structure) - vscode_extension","ref":"vscode_extension.html#3-development-guide-frontend-structure"},{"type":"extras","doc":"- **Transport:** Standard I/O (stdin/stdout) between `BackendManager.ts` and the Raxol Elixir process.\n- **Backend Identification:** `BackendManager.ts` sets the environment variable `RAXOL_MODE=vscode_ext` when spawning the backend.\n- **Extension -> Backend Messages (Sent to Backend stdin):**\n  - JSON objects, newline-delimited (`JSON.stringify(message) + '\\n'`).\n  - Key types: `initialize` (with workspace info, dimensions), `userInput`, `resize_panel`, `shutdown`.\n- **Backend -> Extension Messages (Expected from Backend stdout):**\n  - JSON objects wrapped in markers: `RAXOL-JSON-BEGIN{...json...}RAXOL-JSON-END`.\n  - Intended types: Render updates (specific type TBD), `log` messages.\n  - Output not wrapped in markers is treated as plain log text by `BackendManager.ts`.\n- **Current Status:** The Elixir backend **does not** currently implement logic to detect `RAXOL_MODE=vscode_ext` or handle the stdio JSON protocol described above. Existing stdio handling (`Terminal.Driver`) is for native terminal interaction.","title":"4. Communication Protocol (Intended) - vscode_extension","ref":"vscode_extension.html#4-communication-protocol-intended"},{"type":"extras","doc":"- **Environment Detection:** Backend would need to check `System.get_env(\"RAXOL_MODE\")`.\n- **I/O Handling:** Backend would need a dedicated I/O loop/process to read JSON from stdin and write marker-wrapped JSON to stdout, bypassing the `Terminal.Driver` used for native mode.\n- **Rendering:** The `Rendering.Engine` has a non-functional `render_to_vscode/2` placeholder.","title":"5. Raxol Application Considerations (Hypothetical) - vscode_extension","ref":"vscode_extension.html#5-raxol-application-considerations-hypothetical"},{"type":"extras","doc":"- **Backend Logs:** `BackendManager.ts` logs backend stdout/stderr and status messages to the \"Raxol Backend\" Output Channel in VS Code.\n- **Extension Logs:** Standard VS Code developer tools can be used to debug the TypeScript extension code.","title":"6. Troubleshooting - vscode_extension","ref":"vscode_extension.html#6-troubleshooting"},{"type":"extras","doc":"- Implementing the backend stdio JSON communication handler.\n- Defining the specific render update message format.\n- Connecting the rendering engine to the VS Code communication channel.","title":"7. Future Development - vscode_extension","ref":"vscode_extension.html#7-future-development"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}